%                    HOPS Topography Conditioning Package
%                    ====================================
%
%  This directory contains routine to condition the topographic slope
%  of a GRIDS netCDF file according to user specified constraints.
%
%  --------
%  Drivers:
%  --------
%
%     COND_INIT........Initialization script.  Sets-up all necessary
%                      variables for conditioning.
%     COND_TOPO........Conditioning routine.  Drives conditioning loop.
%     COND_WRITE.......Output script.  Writes result of COND_TOPO back
%                      to GRIDS netCDF file, if acceptible.
%
%  ---------
%  Plotting:
%  ---------
%
%     PLOT_CURR_FAC....Script to allow user to easily view a colormap
%                      of the current slope factor.
%     PLOT_TOPO........Script to allow user to easily view a colormap
%                      of the initial topography.
%     PLOT_TOPO_NEW....Script to allow user to easily view a colormap
%                      of the current, conditioned topography.
%     PLOT_TOPO_DIFF...Script to allow user to easily view a colormap
%                      of the difference between the original and conditioned
%                      topographies, overlain with contours of conditioned
%                      topography.
%
%  -------------
%  Conditioners:
%  -------------
%
%     NEW_TOPO.........Routine to condition the topographic slope.
%                      (1 iteration)
%     COND_LOOP........Routine to manage the loop around NEW_TOPO.
%     GRADT2U..........Routine to compute the slope.
%     SLOPEBOUND.......Routine to compute the desired bounds for the slope.
%     SLOPEFAC.........Routine to compute the slope factor.
%     SLOPETEST........Routine to test for invalid slopes factors.
%     MED_FILT2D.......Function to apply local, integral-weighted 2D median
%                      filter.
%     MED_FILT2DD......Function to apply local, integral-weighted 2D median
%                      filter with Dirichlet boundary conditions.  Used for
%                      filtering nested sub-domain.
%
%  -------------
%  Input/Output:
%  -------------
%
%     COND_READ........Routine to read the specified input file.
%     GRIDSREAD........Routine to extract the necessary data from the
%                      specified GRIDS netCDF file
%     NESTREAD.........Routine to extract the necessary data from the
%                      super domain within which the current domain is nested.
%     REDEFCDF.........Routine to define the conditioning parameters to
%                      specified GRIDS netCDF file
%     GET_DIM..........Routine to get the named dimension from a netCDF file.
%     GET_VAR..........Routine to get the named variable field from a netCDF
%                      file.
%     GET_VAR1.........Routine to get the named variable value from a netCDF
%                      file.
%     PUT_VAR..........Routine to put the named variable field into a netCDF
%                      file.
%     PUT_VAR1.........Routine to put the named variable value into a netCDF
%                      file.
%     NUM_READ.........Routine to read a single number from a line of ASCII
%                      text.
%
%  ------
%  Misc.:
%  ------
%
%     DATE_STAMP.......Routine to produce current time/date string.
%     DAY_CODE.........Routine to determine day of the week from date.
%     EXTREM...........Routine to determine the extrema of a field.
%     NICE.............Routine to select nice contour levels which
%                      encompass a field.
