function [crt_flg,bound,hshllw,hdeep,itmax,medfrq,iplot, ...
               iprint,addcnst,netfile,nestfile,status] = cond_read (infile);
%
% function [crt_flg,bound,hshllw,hdeep,itmax,medfrq,iplot, ...
%                iprint,addcnst,netfile,nestfile,status] = cond_read (infile);
%
% This function reads in the parameters necessary to begin conditioning
% the topography.
%
% ------
% Input:
% ------
%
%    INFILE     ASCII input data file.
%
% -------
% Output:
% -------
%
%    CRT_FLG    Criterion flag.  Indicates which quantity is bound.
%                  [0]  bound grad(h)/h  where h is the topography.
%                  [1]  bound grad(h)    where h is the topography.
%                  [2]  both 0 & 1.
%    BOUND      Bounding value for given criterion.
%    HSHLLW     Minimum depth above which the search is inactive.  (m)
%    HDEEP      Maximum depth below which the search is inactive.  (m)
%    ITMAX      Maximum number of iterations.
%    MEDFRQ     Frequency of applying median filter.
%    IPLOT      Flag for plotting sparse matrix [0] do NOT plot [1] plot
%    IPRINT     Flag for printing current cond. fac. [0] do NOT print [1] print
%    ADDCNST    Character string of additional constraints on active mask.
%    NETFILE    GRIDS netCDF file.
%    NESTFILE   GRIDS netCDF file for nesting super domain.  Used for
%               topography boundary conditions.
%    STATUS     Exit status.  [0] no error  [-1] error occurred.
%

%-------------------------------------------------------------------------------
% Open input file.
%-------------------------------------------------------------------------------

[fid,message] = fopen (infile,'r');

if (fid > 0),

%-------------------------------------------------------------------------------
%   Read input data.
%-------------------------------------------------------------------------------

   status = 0;

   crt_flg  = num_read (fid);
   bound    = num_read (fid);
   hshllw   = num_read (fid);
   hdeep    = num_read (fid);
   itmax    = num_read (fid);
   medfrq   = num_read (fid);
   iplot    = num_read (fid);
   iprint   = num_read (fid);
   wkstr    = fgetl (fid);
   netfile  = fgetl (fid);
   nestfile = fgetl (fid);

   fclose (fid);

   ind = find ((abs(wkstr)~=0)&(abs(wkstr)~=32)&(abs(wkstr)~=9));
   if (~isempty(ind) & ~strcmp(lower(wkstr),'none')),
      addcnst = wkstr;
    else
      addcnst = [];
   end;

   if ((iplot<0) | (iplot>1)),
      iplot = 0;
   end;

   if ((iprint<0) | (iprint>1)),
      iprint = 0;
   end;

 else

%-------------------------------------------------------------------------------
%   Unable to open input file.
%-------------------------------------------------------------------------------

   status = -1;
   disp(['*** Error:  COND_READ failed to open input file: ',infile]);
   disp(['            ',message]);

end;
