% plot_curr_fac
%
% This script creates a color map of
% the current slope factor.

% Thanks to Reiner Onken. 

%-------------------------------------------------------------------------------
% Determine MATLAB version number.
%-------------------------------------------------------------------------------

vstr = version;
vnum = str2num(vstr(1));

%-------------------------------------------------------------------------------
% Determine if the EXTCONTOUR package of Rich Pawlowicz is in the MATLAB path.
%-------------------------------------------------------------------------------

if (vnum<5),
   use_ext = exist('extcontour') == 2;
 else
   use_ext = 0;
end;

%-------------------------------------------------------------------------------
% Create new figure.
%-------------------------------------------------------------------------------

figure;

%-------------------------------------------------------------------------------
% Select contour levels to contain entire range of the field.
% Prevents holes in the color-filled contour map.  Only for EXTCONTOUR.
%-------------------------------------------------------------------------------

if (use_ext | (vnum>4)),
   levels=nice(extrem(curr_fac),4);
end;

%-------------------------------------------------------------------------------
% Draw the color map.
%-------------------------------------------------------------------------------

xmin = min([min(min(vlon)) min(min(tlon))]);
xmax = max([max(max(vlon)) max(max(tlon))]);
ymin = min([min(min(vlat)) min(min(tlat))]);
ymax = max([max(max(vlat)) max(max(tlat))]);

if (vnum>4),

   [C,H,CF] = contourf (vlon,vlat,curr_fac,levels); ...
   set (gca,'XLim',[xmin xmax], ...
            'YLim',[ymin ymax], ...
            'DataAspectRatio',[1 cos(mean([ymin ymax])*pi/180) 1], ...
           'FontName','Times','FontSize',14,'Box','On'); ...
   set (H,'EdgeColor','None');
   h=cbarf(curr_fac,levels);
   colim = get(h,'YLim');
   ctck = levels;
   ind = find ((ctck<colim(1)) | (ctck>colim(2)));
   ctck(ind) = [];
   set(h,'FontName','Times','FontSize',14,'YTick',ctck);
   clear C H CF h colim ctck ind;

 elseif (use_ext),

   extcontour (vlon,vlat,curr_fac,levels,'fill'); ...
   set (gca,'XLim',[xmin xmax], ...
            'YLim',[ymin ymax], ...
           'FontName','Times'); ...
   caxis ([levels(1) levels(length(levels))]); ...
   colormap (jet(length(levels)-1)); ...
   colorbar;

 else

   pcolor (lon,lat,curr_fac); ...
   shading interp; ...
   colormap (jet); ...
   colorbar;

end;

clear xmin xmax ymin ymax;


title ('Current Slope Factor');

%--------------------------------------------
%--- Add contours of the exclusion areas. ---
%--------------------------------------------

if (exist('topo_new') == 1),
   hold on; ...
   if ( (min(min(topo_new))<=hdeep) | (max(max(topo_new))>=hshllw) ),
      if (vnum>4),
         [CS,H] = contour (tlon,tlat,topo_new,[hdeep hshllw],'w');
         hlbl=clabel (CS,H);
         set (hlbl,'FontName','Times','FontSize',12,'Color','w');
         clear CS H hlbl;
       elseif (use_ext),
         extcontour (tlon,tlat,topo_new,[hdeep hshllw], ...
                     'w','Label','FontName','Times');
       else
         contour (tlon,tlat,topo_new,[hdeep hshllw],'w');
      end;
   end;
 else
   hold on; ...
   if ( (min(min(topo))<=hdeep) | (max(max(topo))>=hshllw) ),
      if (vnum>4),
         [CS,H] = contour (tlon,tlat,topo,[hdeep hshllw],'w');
         hlbl=clabel (CS,H);
         set (hlbl,'FontName','Times','FontSize',12,'Color','w');
         clear CS H hlbl;
       elseif (use_ext),
         extcontour (tlon,tlat,topo,[hdeep hshllw], ...
                     'w','Label','FontName','Times');
       else
         contour (tlon,tlat,topo,[hdeep hshllw],'w');
      end;
   end;
end;
