% plot_topo
%
% This script creates a color map of
% the initial topography.

% Thanks to Reiner Onken. 

%-------------------------------------------------------------------------------
% Determine MATLAB version number.
%-------------------------------------------------------------------------------

vstr = version;
vnum = str2num(vstr(1));

%-------------------------------------------------------------------------------
% Determine if the EXTCONTOUR package of Rich Pawlowicz is in the MATLAB path.
%-------------------------------------------------------------------------------

if (vnum<5),
   use_ext = exist('extcontour') == 2;
 else
   use_ext = 0;
end;

%-------------------------------------------------------------------------------
% Create new figure.
%-------------------------------------------------------------------------------

figure;

%-------------------------------------------------------------------------------
% Select contour levels to contain entire range of the field.
% Prevents holes in the color-filled contour map.  Only for EXTCONTOUR.
%-------------------------------------------------------------------------------

if (use_ext | (vnum>4)),
   levels=nice(extrem(-topo),4);
end;

%-------------------------------------------------------------------------------
% Draw the color-filled contour map.
%-------------------------------------------------------------------------------

if (vnum>4),

   [C,H,CF] = contourf (tlon,tlat,-topo,levels); ...
   set(gca,'XLim',[min(min(tlon)) max(max(tlon))], ...
           'YLim',[min(min(tlat)) max(max(tlat))], ...
            'DataAspectRatio',[1 ...
                     cos(mean([min(min(tlat)) max(max(tlat))])*pi/180) 1], ...
           'FontName','Times','FontSize',14,'Box','On'); ...
   set (H,'EdgeColor','None');
   h=cbarf(-topo,levels);
   colim = get(h,'YLim');
   ctck = levels;
   ind = find ((ctck<colim(1)) | (ctck>colim(2)));
   ctck(ind) = [];
   set(h,'FontName','Times','FontSize',14,'YTick',ctck);
   clear C H CF h colim ctck ind;

 elseif (use_ext),

   extcontour(tlon,tlat,-topo,levels,'fill'); ...
   set(gca,'XLim',[min(min(tlon)) max(max(tlon))], ...
           'YLim',[min(min(tlat)) max(max(tlat))], ...
           'FontName','Times'); ...
   caxis([levels(1) levels(length(levels))]); ...
   colormap(jet(length(levels)-1)); ...
   colorbar;

 else

   pcolor (tlon,tlat,-topo); ...
   shading interp; ...
   colormap (jet); ...
   colorbar;

end;

title('Original Topography');
