% plot_topo_diff
%
% This script creates a color map of
% the difference between initial and conditioned topographies.

% Thanks to Reiner Onken. 

%-------------------------------------------------------------------------------
% Determine MATLAB version number.
%-------------------------------------------------------------------------------

vstr = version;
vnum = str2num(vstr(1));

%-------------------------------------------------------------------------------
% Determine if the EXTCONTOUR package of Rich Pawlowicz is in the MATLAB path.
%-------------------------------------------------------------------------------

if (vnum<5),
   use_ext = exist('extcontour') == 2;
 else
   use_ext = 0;
end;

%-------------------------------------------------------------------------------
% Create new figure.
%-------------------------------------------------------------------------------

figure;

%-------------------------------------------------------------------------------
% Select contour levels to contain entire range of the field.
% Prevents holes in the color-filled contour map.  Only for EXTCONTOUR.
%-------------------------------------------------------------------------------

if (use_ext | (vnum>4)),
   lev_top=nice(extrem(-topo_new),2);
   lev_diff=nice(extrem(abs(topo_new-topo)),4);
end;

%-------------------------------------------------------------------------------
% Draw the color-filled contour map.
%-------------------------------------------------------------------------------

if (vnum>4),

   [C,H,CF] = contourf (tlon,tlat,abs(topo_new-topo),lev_diff); ...
   set(gca,'XLim',[min(min(tlon)) max(max(tlon))], ...
           'YLim',[min(min(tlat)) max(max(tlat))], ...
            'DataAspectRatio',[1 ...
                     cos(mean([min(min(tlat)) max(max(tlat))])*pi/180) 1], ...
           'FontName','Times','FontSize',14,'Box','On'); ...
   set (H,'EdgeColor','None');
   caxsave = caxis;
   h=cbarf(abs(topo_new-topo),lev_diff);
   caxis(caxsave);
   colim = get(h,'YLim');
   ctck = lev_diff;
   ind = find ((ctck<colim(1)) | (ctck>colim(2)));
   ctck(ind) = [];
   set(h,'FontName','Times','FontSize',14,'YTick',ctck);
   clear C H CF h colim ctck ind;

 elseif (use_ext),

   extcontour(tlon,tlat,abs(topo_new-topo),lev_diff,'fill'); ...
   set(gca,'XLim',[min(min(tlon)) max(max(tlon))], ...
           'YLim',[min(min(tlat)) max(max(tlat))], ...
           'FontName','Times'); ...
   caxis([levels(1) levels(length(lev_diff))]); ...
   colormap(jet(length(lev_diff)-1)); ...
   colorbar;

 else

   pcolor (tlon,tlat,abs(topo_new-topo)); ...
   shading interp; ...
   colormap (jet); ...
   colorbar;

end;

title('Absolute Difference in Topographies');

%---------------------------------------------
%--- Add contours of the final topography. ---
%---------------------------------------------

hold on; ...
if (vnum>4),
   [CS,H] = contour (tlon,tlat,-topo_new,lev_top,'w');
   hlbl = clabel (CS,H);
   set (hlbl,'FontName','Times','FontSize',12,'Color','w');
   clear CS H hlbl;
   caxis(caxsave);
 elseif (use_ext),
   extcontour (tlon,tlat,-topo_new,lev_top, ...
                     'w','Label','FontName','Times');
 else
   contour (tlon,tlat,-topo_new,lev_top,'w');
end;
