function status = put_var1 (ncid,name,index,value);
%
% function status = put_var1 (ncid,name,index,value);
%
% This function puts the given value into a netCDF file.
%
% ------
% Input:
% ------
%
%    ncid.....Identifier for open netCDF file
%    name.....Name of variable in netCDF file.
%    index....Index (possibly multidimensional) of value to extract
%    value....Values to be written.
%
% -------
% Output:
% -------
%
%    status...Exit status.

%-------------------------------------------------------------------------------
% Get identifier for variable.
%-------------------------------------------------------------------------------

varid = mexcdf ('ncvarid',ncid,name);

if (varid<0),
   disp(' ');
   disp([setstr(7),'***Error:  PUT_VAR1 - unable to find variable ', ...
                             setstr(34),name,setstr(34),setstr(7)]);
   disp(' ');
   status = varid;
   return;
end;

%-------------------------------------------------------------------------------
% Put requested value for variable.
%-------------------------------------------------------------------------------

status = mexcdf ('ncvarput1',ncid,varid,index,value);

if (status<0),
   disp(' ');
   disp([setstr(7),'***Error:  PUT_VAR1 - unable to write variable ', ...
                             setstr(34),name,setstr(34),setstr(7)]);
   disp(' ');
   return;
end;
