function redefcdf (ncid,strlen);
%
% function redefcdf (ncid,strlen);
%
% This function defines new variables into a GRIDS netCDF
% file which is already in redefine mode.
%
% ------
% Input:
% ------
%
%    NCID     Identifier for GRIDS netCDF file.
%    STRLEN   Maximum length for constraint string.

%-------------------------------------------------------------------------------
% Define new dimensions.
%-------------------------------------------------------------------------------

%-----------------------------------------
%--- Bound dimension for slope bounds. ---
%-----------------------------------------

bdimid = 'bnddim';

ncid(bdimid) = 2;

%-----------------------------------------------
%--- String dimension for added constraints. ---
%-----------------------------------------------

lenstr = max( [strlen 256] );
sdimid = ['len',num2str(lenstr)];

ncid(sdimid) = lenstr;

%--------------------------------------------------
%--- Unlimited, gradient filter pass dimension. ---
%--------------------------------------------------

dimid = 'grad_pass';

ncid(dimid) = 0;

%-------------------------------------------------------------------------------
% Define new variables.
%-------------------------------------------------------------------------------

%----------------------
%--- Criteria flag. ---
%----------------------

name   = 'crt_flg';
ncid{name} = nclong(dimid);

ncid{name}.long_name = 'Flag for conditioning criterion.';
ncid{name}.option_0 = 'Control reduced slope.';
ncid{name}.option_1 = 'Control slope.';
ncid{name}.option_2 = 'Control both.';
ncid{name}.FillValue_ = -1;

%---------------------------
%--- Slope factor bound. ---
%---------------------------

name   = 'slope_bound';
ncid{name} = ncfloat(dimid,bdimid);

ncid{name}.long_name = 'Maximum allowed value for slope factor.';
ncid{name}.FillValue_ = -1;

%---------------------------------------
%--- Shallow limit for conditioning. ---
%---------------------------------------

name   = 'hshllw';
ncid{name} = ncfloat(dimid);

ncid{name}.long_name = 'Shallowest depth to condition.';
ncid{name}.units = 'meter';
ncid{name}.FillValue_ = 99999;

%------------------------------------
%--- Deep limit for conditioning. ---
%------------------------------------

name   = 'hdeep';
ncid{name} = ncfloat(dimid);

ncid{name}.long_name = 'Deepest depth to condition.';
ncid{name}.units = 'meter';
ncid{name}.FillValue_ = 99999;

%-------------------------------------
%--- Maximum number of iterations. ---
%-------------------------------------

name   = 'itmax';
ncid{name} = nclong(dimid);

ncid{name}.long_name = 'Maximum number of conditioning iterations.';
ncid{name}.FillValue_ = -1;

%-----------------------------------------
%--- Frequency to apply median filter. ---
%-----------------------------------------

name   = 'medfrq';
ncid{name} = nclong(dimid);

ncid{name}.long_name = 'Frequency to apply median filter.';
ncid{name}.FillValue_ = -1;

%-------------------------------
%--- Additional constraints. ---
%-------------------------------

name   = 'addcnst';
ncid{name} = ncchar(dimid,sdimid);

ncid{name}.long_name = 'Additional constraints on search area.';

%-----------------------------
%--- Nesting super-domain. ---
%-----------------------------

name   = 'nestfile';
ncid{name} = ncchar(dimid,sdimid);

ncid{name}.long_name = 'Name of nesting super domain (for BCs).';
