      subroutine cast_stat (npt,nvar,z,t,s,new,news,zbotmin,zbotmax,
     &                              ztopmin,ztopmax,tmin,tmax,smin,smax)
c
c-------------------------------------------------------------------------------
c     This routine returns the statistics for a cast.                          |
c                                                                              |
c     Calls:  none                                                             |
c                                                                              |
c     Arguments:                                                               |
c                                                                              |
c     new..........Logical.  Indicates if these are new statistics.   {input}  |
c                     new = .true.   ->  Initialize min/max variables.         |
c                     new = .false.  ->  Do NOT initialize min/max variables.  |
c     news.........Logical.  Indicates if salinity stats are new.   {input}    |
c                     news = .true.   ->  Initialize min/max variables.        |
c                     news = .false.  ->  Do NOT initialize min/max variables. |
c     npt..........Integer.  Number of points in the vectors.   {input}        |
c     nvar.........Integer.  Number of active vectors.   {input}               |
c     s............Real vector.  Salinity data.   {input}                      |
c     smin, smax...Real.  Salinity minimum & maximum.   {input/output}         |
c     t............Real vector.  Temperature data.   {input}                   |
c     tmin, tmax...Real.  Temperature minimum & maximum.   {input/output}      |
c     z............Real vector.  Depth data.   {input}                         |
c     zbotmin,                                                                 |
c     zbotmax......Real.  Cast bottom minimum & maximum.   {input/output}      |
c     ztopmin,                                                                 |
c     ztopmax......Real.  Cast top minimum & maximum.   {input/output}         |
c-------------------------------------------------------------------------------
c
      integer npt,n,nvar
      real    z(npt),t(npt),s(npt),zbotmin,zbotmax,ztopmin,ztopmax,tmin,
     &        tmax,smin,smax
      logical new,news
c
c=======================================================================
c     Begin executable code.                                           #
c=======================================================================
c
c-----------------------------------------------------------------------
c     If new statistics, initialize min/max variables.  Set beginning  |
c     index accordingly.                                               |
c-----------------------------------------------------------------------
c
      if (new) then
         ztopmin = z(1)
         ztopmax = z(1)
         zbotmin = z(npt)
         zbotmax = z(npt)
         tmin = t(1)
         tmax = t(1)
         new = .false.
      end if
c
      if (news .and. (nvar.eq.3)) then
         smin = s(1)
         smax = s(1)
         news = .false.
      end if
c
c-----------------------------------------------------------------------
c     Loop over all unchecked data.  Look for new maxima & minima.     |
c-----------------------------------------------------------------------
c
      ztopmin = min( ztopmin, z(1) )
      ztopmax = max( ztopmax, z(1) )
      zbotmin = min( zbotmin, z(npt) )
      zbotmax = max( zbotmax, z(npt) )
c
      do 10 n = 1, npt
c
         tmin = min( tmin, t(n) )
         tmax = max( tmax, t(n) )
         if (nvar.eq.3) then
            smin = min( smin, s(n) )
            smax = max( smax, s(n) )
         end if
c
 10   continue
c
      return
      end
