      program cat_hydro
c
c=======================================================================
c                                                                    ===
c  This program reads in hydrographic data in ascii format, reads    ===
c  new data and writes it out in ascii format.                       ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <param_hydro.h>
#include <hydro.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer flen,ios,no_file,stdinp,stdout,newhyd,tmphyd
#ifdef sunfpe
      integer ieeer,my_handler,ieee_handler
#endif
      integer lnblk,no_digit
      real t_nhobs,t_hstrday,t_hendday
      real t_hlng_min,t_hlng_max,t_hlat_min,t_hlat_max
      character*46 fmt
      character*80 fname,outname
      character*1 answer
      logical newdat,ifctd,ifxbt,ifxbts,ifxctd
      parameter (stdinp=5,stdout=6)
c
#ifdef sunfpe
       external   my_handler
c
#endif
      data newdat/.true./
      data ifctd,ifxbt,ifxbts,ifxctd/.false.,.false.,.false.,.false./
c
      no_digit(no_file) = int(log10(float(max(abs(no_file),1))))
     &                     +(1+max(-sign(1,no_file),0))
c
c=======================================================================
c  Begin executable code.
c=======================================================================
#ifdef sunfpe
c
c-----------------------------------------------------------------------
c     Enable floating point error flags.                               |
c-----------------------------------------------------------------------
c
      ieeer = ieee_handler ('set','common',my_handler)
      if (ieeer .ne. 0) write (6,1000)
#endif
c
c-----------------------------------------------------------------------
c  Set I/O units.
c-----------------------------------------------------------------------
c
      inphyd=3
      outhyd=4
      newhyd=10
      tmphyd=99
c
c-----------------------------------------------------------------------
c  Get job parameters from standard input.
c-----------------------------------------------------------------------
c
      write(stdout,10)
  10  format(/,' Concatenation of hydro data already',
     *         ' in HOPS ascii format',/)
c
      no_file = 1
      write(fmt,20) no_digit(no_file)
  20  format('(5x,',1h','Enter name of input file (',1h',',i',i1,',',
     &       1h',') : ',4h',$))
      write(stdout,fmt) no_file
      read(stdinp,30) fname
  30  format(a)
c
c-----------------------------------------------------------------------
c  Open I/O files.
c-----------------------------------------------------------------------
c
c  Attempt to open scratch file.
c
      open(tmphyd,form='formatted',status='scratch',iostat=ios)
c
      do while ((ios.ne.0).and.(tmphyd.lt.1000))
         tmphyd = tmphyd + 1
         open(tmphyd,form='formatted',status='scratch',iostat=ios)
      enddo
c
      if (ios.ne.0) then
         write (stdout,40)
 40      format (/10x,'Unable to open scratch file.  Aborting.'/)
         stop
      endif
c
c  Attempt to open input file.
c
      open(inphyd,file=fname,form='formatted',status='old',iostat=ios)
      if (ios.ne.0) then
         flen = lnblk (fname)
         write (stdout,50) fname(1:flen)
  50     format (/10x,'Unable to open file:'/15x,1h",a,1h"/10x,
     &           'Do you want to try another? (y/n): ',$)
         read (stdinp,30) answer
      endif
c
      do while ( (ios.ne.0) .and. ((answer.eq.'y').or.(answer.eq.'Y')) )
         write(stdout,fmt) no_file
         read(stdinp,30) fname
         open(inphyd,file=fname,form='formatted',status='old',
     &                                                       iostat=ios)
         if (ios.ne.0) then
            flen = lnblk (fname)
            write (stdout,60) fname(1:flen)
            read (stdinp,30) answer
         endif
      enddo
c
      if (ios.ne.0) then
         write (stdout,60)
 60      format (/10x,'Aborting.'/)
         stop
      endif
c
      eof=.false.
c
c-----------------------------------------------------------------------
c  Read in old header - will update stations, start and end time,
c  min and max lat/lon.  Creation date updates automatically.  Store
c  header information in temporary variables.
c  Read in old hydrographic file and store its content.
c-----------------------------------------------------------------------
c
      call read_header(inphyd)
c
      t_nhobs=nhobs
      t_hstrday=hstrday
      t_hendday=hendday
      t_hlng_min=hlng_min
      t_hlng_max=hlng_max
      t_hlat_min=hlat_min
      t_hlat_max=hlat_max
c
      call read_hydro(inphyd)
      do while (.not.eof)
        ifctd=ctd.or.ifctd
        ifxbt=xbt.or.ifxbt
        ifxbts=xbts.or.ifxbts
        ifxctd=xctd.or.ifxctd
c
        call wrt_hydro(tmphyd)
        call read_hydro(inphyd)
      enddo
      close (inphyd)
c
c-----------------------------------------------------------------------
c  Read in new hydrographic files and find their content.
c-----------------------------------------------------------------------
c
      do 90 while (newdat)
c
         no_file = no_file + 1
         write(fmt,20) no_digit(no_file)
         write(stdout,fmt) no_file
         read(stdinp,30) fname
c
         open (inphyd,file=fname,form='formatted',status='old',
     &                                                       iostat=ios)
c
         if (ios.eq.0) then
c
c      -----------------------------
c         Found file, process it.
c      -----------------------------
c
            eof=.false.
c
            call read_header(inphyd)
c
c      --------------------------------
c         Compare header information
c      --------------------------------
c
            t_hstrday=min(hstrday,t_hstrday)
            t_hendday=max(hendday,t_hendday)
            t_hlng_min=min(hlng_min,t_hlng_min)
            t_hlng_max=max(hlng_max,t_hlng_max)
            t_hlat_min=min(hlat_min,t_hlat_min)
            t_hlat_max=max(hlat_max,t_hlat_max)
            t_nhobs=nhobs+t_nhobs
c
c      ------------------------------------------------------
c         Write out hydrographic data into temporary file.
c      ------------------------------------------------------
c
            call read_hydro(inphyd)
            do while (.not.eof)
               ifctd=ctd.or.ifctd
               ifxbt=xbt.or.ifxbt
               ifxbts=xbts.or.ifxbts
               ifxctd=xctd.or.ifxctd
c
               call wrt_hydro(tmphyd)
               call read_hydro(inphyd)
            enddo
            close (inphyd)
c
           else
c
c      ------------------------------------------
c         Unable to open requested input file.
c      ------------------------------------------
c
            flen = lnblk (fname)
            write (stdout,70) fname(1:flen)
  70        format (/10x,'Unable to open file:'/15x,1h",a,1h")
c
         endif
c
c   -------------------------------------------------
c      Determine if another file is to be appended
c   -------------------------------------------------
c
         write(stdout,80)
  80     format(/5x,'Do you want to add another file (y/n)? ',$)
         read(stdinp,30)answer
c
         newdat = (answer.eq.'y') .or. (answer.eq.'Y')
c
 90   continue
c
c-----------------------------------------------------------------------
c  Write final output file.
c-----------------------------------------------------------------------
c
      write(stdout,100)
 100  format(5x,'Enter output filename: ',$)
      read(stdinp,30) outname
c
      write(stdout,110)
110   format(5x,'Enter title for new file: ',$)
      read(stdinp,30) htitle
c
c  Attempt to open output file.
c
      open(outhyd,file=outname,form='formatted',status='new',iostat=ios)
      if (ios.ne.0) then
         flen = lnblk (outname)
         write (stdout,50) outname(1:flen)
         read (stdinp,30) answer
      endif
c
      do while ( (ios.ne.0) .and. ((answer.eq.'y').or.(answer.eq.'Y')) )
         write(stdout,100)
         read(stdinp,30) outname
         open(outhyd,file=outname,form='formatted',status='new',
     &                                                       iostat=ios)
         if (ios.ne.0) then
            flen = lnblk (outname)
            write (stdout,50) outname(1:flen)
            read (stdinp,30) answer
         endif
      enddo
c
      if (ios.ne.0) then
         write (stdout,60)
         stop
      endif
c
      write(stdout,120)
120   format(/10x,'Writing new file ...')
c
      rewind (tmphyd)
      eof=.false.
c
c --- let the new file know what was in any of the old files
c
      ctd=ifctd
      xbt=ifxbt
      xbts=ifxbts
      xctd=ifxctd
c
      hstrday=t_hstrday
      hendday=t_hendday
      hlng_min=t_hlng_min
      hlng_max=t_hlng_max
      hlat_min=t_hlat_min
      hlat_max=t_hlat_max
      nhobs=t_nhobs
c
      call wrt_header(outhyd)
      call read_hydro(tmphyd)
      do while (.not.eof)
         call wrt_hydro(outhyd)
         call read_hydro(tmphyd)
      enddo
c
      close(tmphyd)
      close(outhyd)
c
      write(stdout,130)
130   format(/5x,'Done.'/)
c
#ifdef sunfpe
1000  format (/'CAT_HYDRO - Warning:  ieee_handler cannot set ',
     &        'my_handler'/)
c
#endif
      end
