       function inside (x,y,nb,xb,yb,new)
c
c=======================================================================
c                                                                    ===
c  This function determines if a point is enclosed by the given      ===
c  polygon.                                                          ===
c                                                                    ===
c  ------                                                            ===
c  Input:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     x,y......Longitude & Latitude of point to examine.  (deg)      ===
c     nb.......Number of points in polygon.                          ===
c     xb,yb....Longitudes & Latitudes of polygon.         (deg)      ===
c     new......Flag for new polygon. [0] old  [1] new                ===
c                                                                    ===
c  -------                                                           ===
c  Output:                                                           ===
c  -------                                                           ===
c                                                                    ===
c     inside...Flag indicating if point is inside polygon.           ===
c              [0] point is outside   [1] point is inside.           ===
c                                                                    ===
c  Reference:                                                        ===
c                                                                    ===
c    Reid, C., 1969: A long way from Euclid. Oceanography EMR,       ===
c        page 174.                                                   ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define local variables.
c-----------------------------------------------------------------------
c
      integer k, ke, kp1, kw, nb, nc, new
      integer inside
      real slope, x, xprev, y
      real xb(nb), yb(nb), yc(4)
c
      save nc, xprev, yc
c
      data xprev /0/
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c-----------------------------------------------------------------------
c  No points.
c-----------------------------------------------------------------------
c
      if (nb.le.0) then
        inside=0
        return
      endif
c
c-----------------------------------------------------------------------
c  New set of boundary points.  Find intersections.
c-----------------------------------------------------------------------
c
      if ((new.eq.1).or.(x.ne.xprev)) then
        xprev=x 
        nc=0 
        do k=1,nb 
          kp1=k+1-k*(k/nb) 
          kw=k 
          if (xb(k).eq.xb(kp1)) goto 10
          if (xb(k).gt.xb(kp1)) kw=kp1 
          ke=k+kp1-kw 
          if (x.gt.xb(ke)) goto 10
          if ((x.lt.xb(ke)).and.(x.le.xb(kw))) goto 10
          nc=nc+1 
          slope=(yb(ke)-yb(kw))/(xb(ke)-xb(kw)) 
          yc(nc)=yb(kw)+(x-xb(kw))*slope 
   10     continue 
        enddo
      endif
c
c-----------------------------------------------------------------------
c  Count the number of times that the boundary cuts the meridian thru
c  (x,y) south of (x,y).  An odd count indicates the point is inside,
c  even indicates outside.
c-----------------------------------------------------------------------
c
      inside=0 
      if (nc.gt.0) then
        do k=1,nc 
          if (yc(k).lt.y) then
            inside=1-inside
          endif
        enddo
      endif
c
      return
      end 
