      program minmax
c
c-----------------------------------------------------------------------
c     Global variables.                                                |
c-----------------------------------------------------------------------
c
#include <param_hydro.h>
#include <hydro.h>
c
c-----------------------------------------------------------------------
c     Local variables.                                                 |
c-----------------------------------------------------------------------
c
      real p(mhpts),s(mhpts),t(mhpts),tmin,tmax,smin,smax,
     &     pbotmin,pbotmax,ptopmin,ptopmax
      real clat,clon,lonmin,lonmax,latmin,latmax
c
      integer i,ident,idate,itime,ncast,npmax,npmin,npt
      integer no_digit
#ifdef sunfpe
      integer ieeer,my_handler,ieee_handler
#endif
c
      logical     ifmods,ifunf,ifmed,ifsal,first,firsts
      character*1  answer
      character*66  fmt
      character*80  iname
c
      equivalence (p(1), hdat(1,1))
      equivalence (t(1), hdat(1,2))
      equivalence (s(1), hdat(1,3))
c
#ifdef sunfpe
       external   my_handler
c
#endif
      data ifmods,ifunf/.false.,.false./
      data ifmed,ifsal,first,firsts/.false.,.false.,.true.,.true./
      data ncast,npmax /0,0/
c
      no_digit(i)=int(log10(float(max(abs(i),1))))+(1+max(-sign(1,i),0))
c
c=======================================================================
c     Begin executable code.                                           #
c=======================================================================
#ifdef sunfpe
c
c-----------------------------------------------------------------------
c     Enable floating point error flags.                               |
c-----------------------------------------------------------------------
c
      ieeer = ieee_handler ('set','common',my_handler)
      if (ieeer .ne. 0) write (6,1000)
#endif
c
c-----------------------------------------------------------------------
c     Read basic information to start run.                             |
c-----------------------------------------------------------------------
c
      print 1
      read 2,iname
c
    1 format(1x,'What is the name of the input file  : ',$)
    2 format(a)
c
      print 4
    4 format(1x,'Is this data in the MODS format (y/n): ',$)
      read 2,answer
      if(answer.eq.'Y' .or. answer.eq.'y')ifmods=.true.
c
      if(.not.ifmods)then
         print 5
    5    format(1x,'Is this data in the POEM format (y/n): ',$)
         read 2,answer
         if(answer.eq.'Y' .or. answer.eq.'y')ifmed=.true.
      endif
c
      if(.not.ifmed .and. .not.ifmods)then
         ifunf=.true.
         print 6
    6    format(1x,'Is salinity included in the data (y/n)? ',$)
         read 2,answer
         if(answer.eq.'Y' .or. answer.eq.'y')ifsal=.true.
      endif
c
      if (.not.ifmods) then
         if (ifsal) then
            nhvar=3
           else
            nhvar=2
         endif
      endif
c
c-----------------------------------------------------------------------
c     Open files and read any header information.                      |
c-----------------------------------------------------------------------
c
      if(ifmods)then
         open(unit=1,file=iname,status='old',form='formatted')
      else if(ifunf .or. ifmed)then
         open(unit=1,file=iname,status='old',form='unformatted')
      endif
c
      if(ifmods)call read_header(1)
c
c-----------------------------------------------------------------------
c     Read casts and get running statistics.                           |
c-----------------------------------------------------------------------
c
   10 continue
c
c-----------------------------------------------------------------------
c     Read  a cast.                                                    |
c-----------------------------------------------------------------------
c
      if(ifmods)then
         call read_hydro(1)
         if(eof)goto 999
c
         npt=nhpts
c
         if (first) then
            lonmin = hlng
            lonmax = hlng
            latmin = hlat
            latmax = hlat
            npmax = nhpts
            npmin = nhpts
           else
            lonmin = min( hlng, lonmin )
            lonmax = max( hlng, lonmax )
            latmin = min( hlat, latmin )
            latmax = max( hlat, latmax )
            npmax = max( nhpts, npmax )
            npmin = min( nhpts, npmin )
         end if
      endif
c
      if(ifunf)then
         if(ifsal)then
            read(1,end=999)ident,clat,clon,idate,itime
            read(1)npt,(p(i),t(i),s(i),i=1,npt)
         else
            read(1,end=999)ident,clat,clon,idate,itime
            read(1)npt,(p(i),t(i),i=1,npt)
         endif
         if (first) then
            lonmin = clon
            lonmax = clon
            latmin = clat
            latmax = clat
            npmax = npt
            npmin = npt
           else
            lonmin = min( clon, lonmin )
            lonmax = max( clon, lonmax )
            latmin = min( clat, latmin )
            latmax = max( clat, latmax )
            npmax = max( npt, npmax)
            npmin = min( npt, npmin)
         end if
      endif
c
c
c-----------------------------------------------------------------------
c     Filter temperature and salinity.                                 |
c-----------------------------------------------------------------------
c
      call cast_stat (npt,nhvar,p,t,s,first,firsts,pbotmin,pbotmax,
     &                              ptopmin,ptopmax,tmin,tmax,smin,smax)
      ncast = ncast + 1
c
      goto 10
c
  999 continue
c
c-----------------------------------------------------------------------
c     Report statistics.                                               |
c-----------------------------------------------------------------------
c
      write (fmt,1010) no_digit(ncast),no_digit(npmin),no_digit(npmax)
      write (6,fmt) ncast,npmin,npmax
      write (6,1020) latmin,latmax,lonmin,lonmax,ptopmin,
     &               ptopmax,pbotmin,pbotmax,tmin,tmax
      if (.not.firsts) write (6,1030) smin,smax
      write (6,1040)
c
#ifdef sunfpe
1000  format (/'MINMAX - Warning:  ieee_handler cannot set my_handler'/)
#endif
1010  format ('(/',1h','Number of casts:  ',1h',',i',i2,'/',
     &        1h','Points per cast:  [',1h',',i',i2,',',1h',', ',1h',
     &        ',i',i2,5h,']'))
1020  format (/'Latitude:   [ ',f8.3,', ',f8.3,' ]'/'Longitude:  [ '
     &        ,f8.3,', ',f8.3,' ]'//'Cast top:     [ ',f8.3,', ',f8.3,
     &        ' ]'/'Cast bottom:  [ ',f8.3,', ',f8.3,' ]'/
     &        'Temperature:  [ ',f8.3,', ',f8.3,' ]')
1030  format ('Salinity:     [ ',f8.3,', ',f8.3,' ]')
1040  format (/)
c
      stop
      end
