      subroutine q_init (narr,ind,qbgn,qend,fbgn,fend,err)
c
c-------------------------------------------------------------------------------
c     This routine initializes the active and free space queues.               |
c                                                                              |
c     Calls:  none                                                             |
c                                                                              |
c     Arguments:                                                               |
c                                                                              |
c     err....Logical.  Flag to indicate error status.   {output}               |
c               err = .true.   ->  Error, narr < 1                             |
c               err = .false.  ->  No errors, sucessful initialization.        |
c     fbgn...Integer.  Pointer to the beginning of the free space. {output}    |
c     fend...Integer.  Pointer to the end of the free space.   {output}        |
c     ind....Integer vector.  The indices for the queue and its free space.    |
c                {output}                                                      |
c     narr...Integer.  Maximum number of elements in the vectors.   {input}    |
c     qbgn...Integer.  Pointer to the beginning of the queue.   {output}       |
c     qend...Integer.  Pointer to the end of the queue.   {output}             |
c                                                                              |
c     The "queue" is maintained through a doubly linked list in ind:           |
c                                                                              |
c        ind(*,1):  The position of the element in front.                      |
c        ind(*,2):  The position of the element behind.                        |
c-------------------------------------------------------------------------------
c
      integer narr,ind(narr,2),fbgn,fend,qbgn,qend,ptr
      logical err
c
c=======================================================================
c     Begin executable code.                                           #
c=======================================================================
c
c-----------------------------------------------------------------------
c     See if there are enough elements for a queue at all.             |
c-----------------------------------------------------------------------
c
      if (narr.gt.0) then
c
c-----------------------------------------------------------------------
c        A queue is possible, hence no error.                          |
c-----------------------------------------------------------------------
c
         err = .false.
c
c-----------------------------------------------------------------------
c        Initialize "active" queue as empty.                           |
c-----------------------------------------------------------------------
c
         qbgn = 0
         qend = 0
c
c-----------------------------------------------------------------------
c        Initialize free space queue.                                  |
c-----------------------------------------------------------------------
c
         fbgn = 1
         fend = narr
c
         ind(1,1) = 0
         ind(1,2) = 2
c
         do 10 ptr = 2, narr-1
c
            ind(ptr,1) = ptr - 1
            ind(ptr,2) = ptr + 1
c
 10      continue
c
         ind(narr,1) = narr - 1
         ind(narr,2) = 0
c
        else
c
c-----------------------------------------------------------------------
c        Not enough elements for a queue.                              |
c-----------------------------------------------------------------------
c
         err = .true.
c
      end if
c
      return
      end
