      subroutine rget_val (nq,old,ind,qbgn,qend,nd,data,dptr,nw,work,
     &                                                        val,error)
c
c-------------------------------------------------------------------------------
c     This routine gets the local median value from values in the data vector  |
c     and in the old queue.                                                    |
c                                                                              |
c     Calls:  rinsert                                                          |
c                                                                              |
c     Arguments:                                                               |
c                                                                              |
c     data....Real vector.  The current data values.   {input}                 |
c     dptr....Integer.  Pointer to the "active" data value.   {input}          |
c     error...Logical.  Flag to indicate errors.   {output}                    |
c                error = .true.   ->  Insufficient workspace.                  |
c                error = .false.  ->  No errors.                               |
c     ind.....Integer array.  Pointers for the old queue.   {input}            |
c     nd......Integer.  Number of data points.   {input}                       |
c     nq......Integer.  Number of points in queue vectors.   {input}           |
c     nw......Integer.  Number of points in work space vector.   {input}       |
c     old.....Real vector.  Old values queue.   {input}                        |
c     qbgn....Integer.  Pointer to beginning of queue.   {input}               |
c     qend....Integer.  Pointer to end of queue.   {input}                     |
c     val.....Real.  The median value.   {output}                              |
c     work....Real vector.  Work space for sorting.                            |
c-------------------------------------------------------------------------------
c
      integer nd,nq,nw,dptr,ind(nq,2),qbgn,qend,ptr,i,nin,iend
      real    data(nd),old(nq),val,work(nw),p5
      logical error
c
      parameter (p5=0.5)
c
c=======================================================================
c     Begin executable code.                                           #
c=======================================================================
c
c-----------------------------------------------------------------------
c     Loop through old values, inserting them into sorting array.      |
c-----------------------------------------------------------------------
c
      nin = 0
      ptr = qend
c
      do 10 while (ptr.gt.0)
c
         call rinsert (old(ptr),work,nin,nw,error)
         ptr = ind(ptr,1)
c
 10   continue
c
c-----------------------------------------------------------------------
c     Loop through correct number of new values, inserting into array. |
c-----------------------------------------------------------------------
c
      iend = dptr + nin - 1
c
      do 20 i = dptr+1, iend
c
         call rinsert (data(i),work,nin,nw,error)
c
 20   continue
c
c-----------------------------------------------------------------------
c     Compute median value.                                            |
c-----------------------------------------------------------------------
c
      if ( mod(nin,2) .eq. 1 ) then
c
         ptr = (nin+1)/2
         val = work(ptr)
c
        else
c
         ptr = nin/2
         val = p5 * ( work(ptr) + work(ptr+1) )
c
      end if
c
      return
      end
