      subroutine rhydbase (iunit,day,mon,yr)
c
c=======================================================================
c                                                                    ===
c  This routine reads a cast in the HydroBase format.                ===
c                                                                    ===
c  ------                                                            ===
c  Input:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     iunit...Unit number on which file was opened.   (integer)      ===
c                                                                    ===
c  -------                                                           ===
c  Output:                                                           ===
c  -------                                                           ===
c                                                                    ===
c     day.....Cast day of month.                      (integer)      ===
c     mon.....Cast month.                             (integer)      ===
c     yr......Cast year.                              (integer)      ===
c                                                                    ===
c  Calls:  ALL_LC, LENGTH, NXT_BLNK                                  ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <param_hydro.h>
#include <hydro.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer cntry,cruz,day,depth,iend,ios,istr,iunit,m,mars10,mars1,
     &        mon,mxrd,n,sbgn,send,slen,yr
      integer dat_ind(3)
      integer nxt_blnk
      real    wk(mhflds)
      logical      fnd_dpth,fnd_salt
      character*2  ship
      character*80 line
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c-----------------------------------------------------------------------
c  Read cast header.
c-----------------------------------------------------------------------
c
      read (iunit,50,iostat=ios) cntry,ship,cruz,castid,yr,mon,day,hlat,
     &                           hlng,depth,nhpts,nhvar,mars10,mars1
c
      eof = ios .ne. 0
      if (eof) return
c
      hdpth = float(depth)
      read (iunit,60) line
c
      call all_lc (line,line)
c
c-----------------------------------------------------------------------
c  Parse line for order of data.
c-----------------------------------------------------------------------
c
      call length (line,slen,sbgn,send)
      fnd_dpth = .false.
      fnd_salt = .false.
      iend     = 0
c
      do 10 n = 1, nhvar
c
         istr = min( iend+1, send )
         call length (line(istr:send),slen,sbgn,iend)
         istr = istr + sbgn - 1
         iend = nxt_blnk (line(istr:send)) + istr - 2
         if (iend.lt.istr) iend = send
c
         if ((line(istr:iend).eq.'pr').and.(.not.fnd_dpth)) then
            dat_ind(1) = n
           else if (line(istr:iend).eq.'de') then
            dat_ind(1) = n
            fnd_dpth = .true.
           else if (line(istr:iend).eq.'te') then
            dat_ind(2) = n
           else if (line(istr:iend).eq.'sa') then
            dat_ind(3) = n
            fnd_salt = .true.
         end if
c
 10   continue
c
      if (fnd_salt) then
         nhvar = 3
        else
         nhvar = 2
      end if
c
      mxrd = dat_ind(1)
      do 20 n = 1, nhvar
         mxrd = max( mxrd, dat_ind(n) )
 20   continue
c
c-----------------------------------------------------------------------
c  Read data, moving it to the proper storage.
c-----------------------------------------------------------------------
c
      do 40 m = 1, nhpts
         read (iunit,*) (wk(n), n=1, mxrd)
         do 30 n = 1, nhvar
            hdat(m,n) = wk(dat_ind(n))
 30      continue
 40   continue
c
c-----------------------------------------------------------------------
c  Read terminator string
c-----------------------------------------------------------------------
c
      read (iunit,60) line
c
      return
c
 50   format (i2,1x,a2,i6,2i5,2i3,2f10.3,4i6,i4)
 60   format (a)
c
      end
