      subroutine rq_in (val,narr,work,ind,qbgn,qend,fbgn,fend,err)
c
c-------------------------------------------------------------------------------
c     This routine adds another entry into the queue.  (Real values)           |
c                                                                              |
c     Calls:  none                                                             |
c                                                                              |
c     Arguments:                                                               |
c                                                                              |
c     err....Logical.  Flag to indicate error status.   {output}               |
c               err = .true.   ->  Error, no more room to add elements.        |
c               err = .false.  ->  No errors, sucessfully added element.       |
c     fbgn...Integer.  Pointer to the beginning of the free space.             |
c                {input/output}                                                |
c     fend...Integer.  Pointer to the end of the free space.   {input/output}  |
c     ind....Integer vector.  The indices for the queue and its free space.    |
c                {input/output}                                                |
c     narr...Integer.  Maximum number of elements in the vectors.   {input}    |
c     qbgn...Integer.  Pointer to the beginning of the queue.   {input/output} |
c     qend...Integer.  Pointer to the end of the queue.   {input/output}       |
c     val....Real.  The value to add to the queue.   {input}                   |
c     work...Real vector.  The work space for the queue and its free space.    |
c                {input/output}                                                |
c                                                                              |
c     The "queue" is maintained through a doubly linked list in ind:           |
c                                                                              |
c        ind(*,1):  The position of the element in front.                      |
c        ind(*,2):  The position of the element behind.                        |
c-------------------------------------------------------------------------------
c
      integer narr,ind(narr,2),fbgn,fend,qbgn,qend,ptr
      real    work(narr),val
      logical err
c
c=======================================================================
c     Begin executable code.                                           #
c=======================================================================
c
      if (fbgn.gt.0) then
c
c-----------------------------------------------------------------------
c        Still free space, hence no errors.                            |
c-----------------------------------------------------------------------
c
         err = .false.
c
c-----------------------------------------------------------------------
c        Pull an element from the free space queue. |
c-----------------------------------------------------------------------
c
         ptr = fbgn
         fbgn = ind(ptr,2)
c
         if (fbgn.gt.0) then
            ind(fbgn,1) = 0
           else
            fend = 0
         end if
c
c-----------------------------------------------------------------------
c        Add the element to the active queue.                          |
c-----------------------------------------------------------------------
c
         ind(ptr,1) = qend
         if (qend.gt.0) then
            ind(qend,2) = ptr
           else
            qbgn = ptr
         end if
         qend = ptr
         ind(qend,2) = 0
c
c-----------------------------------------------------------------------
c        Store the value in the active queue.                          |
c-----------------------------------------------------------------------
c
         work(qend) = val
c
        else
c
c-----------------------------------------------------------------------
c        No free space available.                                      |
c-----------------------------------------------------------------------
c
         err = .true.
c
      end if
c
      return
      end
