      subroutine rq_out (val,narr,work,ind,qbgn,qend,fbgn,fend,err)
c
c-------------------------------------------------------------------------------
c     This routine removes an entry from the queue.  (Real values)             |
c                                                                              |
c     Calls:  none                                                             |
c                                                                              |
c     Arguments:                                                               |
c                                                                              |
c     err....Logical.  Flag to indicate error status.   {output}               |
c               err = .true.   ->  Error, empty queue.                         |
c               err = .false.  ->  No errors, sucessfully removed element.     |
c     fbgn...Integer.  Pointer to the beginning of the free space.             |
c                {input/output}                                                |
c     fend...Integer.  Pointer to the end of the free space.   {input/output}  |
c     ind....Integer vector.  The indices for the queue and its free space.    |
c                {input/output}                                                |
c     narr...Integer.  Maximum number of elements in the vectors.   {input}    |
c     qbgn...Integer.  Pointer to the beginning of the queue.   {input/output} |
c     qend...Integer.  Pointer to the end of the queue.   {input/output}       |
c     val....Real.  The value removed from the queue.   {output}               |
c     work...Real vector.  The work space for the queue and its free space.    |
c                {input/output}                                                |
c                                                                              |
c     The "queue" is maintained through a doubly linked list in ind:           |
c                                                                              |
c        ind(*,1):  The position of the element in front.                      |
c        ind(*,2):  The position of the element behind.                        |
c-------------------------------------------------------------------------------
c
      integer narr,ind(narr,2),fbgn,fend,qbgn,qend,ptr
      real    work(narr),val
      logical err
c
c=======================================================================
c     Begin executable code.                                           #
c=======================================================================
c
      if (qbgn.gt.0) then
c
c-----------------------------------------------------------------------
c        Non-empty queue, hence no errors.                             |
c-----------------------------------------------------------------------
c
         err = .false.
c
c-----------------------------------------------------------------------
c        Copy the value from the active queue.                         |
c-----------------------------------------------------------------------
c
         val = work(qbgn)
c
c-----------------------------------------------------------------------
c        Pull an element from the "active" queue.                      |
c-----------------------------------------------------------------------
c
         ptr = qbgn
         qbgn = ind(ptr,2)
c
         if (qbgn.gt.0) then
            ind(qbgn,1) = 0
           else
            qend = 0
         end if
c
c-----------------------------------------------------------------------
c        Add the element to the free space queue.                      |
c-----------------------------------------------------------------------
c
         ind(ptr,1) = fend
         if (fend.gt.0) then
            ind(fend,2) = ptr
           else
            fbgn = ptr
         end if
         fend = ptr
         ind(fend,2) = 0
c
        else
c
c-----------------------------------------------------------------------
c        Empty queue.                                                  |
c-----------------------------------------------------------------------
c
         err = .true.
c
      end if
c
      return
      end
