      subroutine sac_data (in_unit,no_line)
c
c-----------------------------------------------------------------------
c  This routine reads in the data portion of a SACLANT formatted cast  |
c  file.  It removes bad data and adds a surface value if needed.      |
c                                                                      |
c  ------                                                              |
c  Input:                                                              |
c  ------                                                              |
c                                                                      |
c     in_unit...Unit number on which to read data.     (integer)       |
c     no_line...Number of header lines to skip.        (integer)       |
c                                                                      |
c     Common Blocks:                                                   |
c                                                                      |
c     /HYDRO/                                                          |
c                                                                      |
c        hdpth...Water column depth from header.       (real; meters)  |
c        nhobs...Number previously read observations.  (integer)       |
c        nhvar...Number hydrographic variables.        (integer)       |
c                                                                      |
c     /SAC_STUFF/                                                      |
c                                                                      |
c        datpos......Locations of data in file.        (integer vector)|
c                                                                      |
c  -------                                                             |
c  Output:                                                             |
c  -------                                                             |
c                                                                      |
c     Common Blocks:                                                   |
c                                                                      |
c     /HYDRO/                                                          |
c                                                                      |
c        hdat....Hydrographic data.                    (real array)    |
c        hdpth...Water column depth.                   (real; meters)  |
c        nhobs...Number of observations.               (integer)       |
c        nhpts...Number of data points in cast.        (integer)       |
c-----------------------------------------------------------------------
c
c-----------------------------------------------------------------------
c  Global data.
c-----------------------------------------------------------------------
c
#include <param_hydro.h>
#include <hydro.h>
#include <sac_stuff.h>
c
c-----------------------------------------------------------------------
c  Local data.
c-----------------------------------------------------------------------
c
      real    c0,svalid,tvalid
      real    work(mhflds)
      integer ii,in_unit,ios,j,mxrd,n,no_line,xbtshft,xctshft
      logical     sgood,tgood
      character*1 dum
c
      parameter (c0=0.0, svalid=50.0, tvalid=50.0, xbtshft=2000,
     &           xctshft=1000)
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c-----------------------------------------------------------------------
c  Skip header
c-----------------------------------------------------------------------
c
      do 10 n = 1, no_line
         read (1,60) dum
  10  continue
c
c-----------------------------------------------------------------------
c  Read hydrographic data.
c-----------------------------------------------------------------------
c
      mxrd = datpos(1)
      do n = 2, nhvar
         mxrd = max( mxrd, datpos(n) )
      enddo
c
      nhpts = 1
      read (1,*,iostat=ios) (work(n), n=1,mxrd)
c
      do 20 while ( (ios.eq.0) .and. (nhpts.lt.mhpts) )
         do n = 1, nhvar
            hdat(nhpts,n) = work(datpos(n))
         enddo
         nhpts = nhpts + 1
         read (1,*,iostat=ios) (work(n), n=1,mxrd)
  20  continue
c
c-----------------------------------------------------------------------
c  Reset counters and depth.
c-----------------------------------------------------------------------
c
      if (ios.ne.0) then
         nhpts = nhpts - 1
        else
         do n = 1, nhvar
            hdat(nhpts,n) = work(datpos(n))
         enddo
      end if
      nhobs = nhobs + 1
      hdpth = max (hdpth, hdat(nhpts,1))
c
c-----------------------------------------------------------------------
c  Remove bad data.
c-----------------------------------------------------------------------
c
      ii=0
      do 40 j=1,nhpts
         tgood = abs(hdat(j,2)) .lt. tvalid
         sgood = (nhvar.lt.3) .or. (abs(hdat(j,3)).lt.svalid)
         if( tgood .and. sgood) then
            ii=ii+1
            do 30 n = 1, nhvar
               hdat(ii,n)=hdat(j,n)
  30        continue
         endif
  40  continue
      nhpts=ii
c
c-----------------------------------------------------------------------
c  Add top, if necessary.
c-----------------------------------------------------------------------
c
      if (hdat(1,1).ne.c0) then
         nhpts=nhpts+1
         do 50 ii=nhpts,2,-1
         do 50 n = 1, nhvar
           hdat(ii,n)=hdat(ii-1,n)
  50     continue
         hdat(1,1)=c0
      endif
c
c-----------------------------------------------------------------------
c  Echo cast location, reset cast id.
c-----------------------------------------------------------------------
c
      write (6,70) castid,hlat,hlng
c
      if (xbt)  castid = castid + xbtshft
      if (xctd) castid = castid + xctshft
c
      return
c
 60   format (a)
 70   format (5x,'Station: ',i5,5x,'Lat: ',f5.2,5x,'Long: ',f6.2)
c
      end
