      subroutine sac_head (line,done)
c
c=======================================================================
c                                                                    ===
c  This routine parses a line from the header of a SACLANT formatted ===
c  cast data file and extracts the necessary information for the MODS===
c  data format.                                                      ===
c                                                                    ===
c  Warning:  This routine will read the first line of data, but will ===
c            not do anything with it.  It is up to the calling       ===
c            routine to preserve this data.                          ===
c                                                                    ===
c  ------                                                            ===
c  Input:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     line...Newly read in line of data.                 (character) ===
c     done...The current status of the header parsing.   (logical)   ===
c                                                                    ===
c  -------                                                           ===
c  Output:                                                           ===
c  -------                                                           ===
c                                                                    ===
c     done...The updated status of the header parsing.   (logical)   ===
c                                                                    ===
c     Common Blocks:                                                 ===
c                                                                    ===
c     /HYDRO/                                                        ===
c                                                                    ===
c        castid.....Identifier for cast.          (integer)          ===
c        ctd........Flag for CTD data.            (logical)          ===
c        hdpth......Depth of water column.        (real; meters)     ===
c        hlat.......Latitude of the cast.         (real; degrees)    ===
c        hlat_max...Maximum latitude.             (real; degrees)    ===
c        hlat_min...Minimum latitude.             (real; degrees)    ===
c        hlng.......Longitude of the cast.        (real; degrees)    ===
c        hlng_max...Maximum longitude.            (real; degrees)    ===
c        hlng_min...Minimum longitude.            (real; degrees)    ===
c        hstrday....Starting cast time.           (real; Julian day) ===
c        hendday....Ending cast time.             (real; Julian day) ===
c        htime......Time of the cast.             (real; Julian day) ===
c        nhvar......Number of variables in cast.  (integer)          ===
c        xbt........Flag for XBT data.            (logical)          ===
c        xctd.......Flag for XCTD data.           (logical)          ===
c                                                                    ===
c     /SAC_STUFF/                                                    ===
c                                                                    ===
c        any_chain...Flag for any CTD chain data.   (logical)        ===
c        any_ctd.....Flag for any CTD data.         (logical)        ===
c        any_xbt.....Flag for any XBT data.         (logical)        ===
c        any_xctd....Flag for any XCTD data.        (logical)        ===
c        datpos......Locations of data in file.     (integer vector) ===
c        idmax.......Maximum cast id.               (integer)        ===
c        idmin.......Minimum cast id.               (integer)        ===
c                                                                    ===
c  Calls:  ALL_LC, ISNUM, ISTYP, LENGTH, NXT_BLNK                    ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Global data.
c-----------------------------------------------------------------------
c
#include <param_hydro.h>
#include <hydro.h>
#include <sac_stuff.h>
c
c-----------------------------------------------------------------------
c  Local data.
c-----------------------------------------------------------------------
c
      real    c0,day,dfrac,p5,r24,r60,rwk
      integer dlen,iwk1,iwk2,joffset,mon,ptr,sbgn,sbgn2,send,send2
     &        ,slen,slen2,year
      integer nxt_blnk
      logical     done,first,isnum,istyp
      character*1 hemi
      character*3 cmon,mon_ra(12)
      character*5 type
      character*8  fmt
      character*80  dscrptr
      character*(*) line
c
      parameter (c0=0.0, joffset=2440000, p5=0.5, r24=1.0/24.0,
     &           r60=1.0/60.0)
c
      save day,dfrac,first,mon,year,mon_ra
c
      data first  /.true./
      data mon_ra /'jan','feb','mar','apr','may','jun','jul','aug','sep'
     &                                               ,'oct','nov','dec'/
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c-----------------------------------------------------------------------
c  Extract header line descriptor.
c-----------------------------------------------------------------------
c
      iwk2 = len(line)
      iwk1 = 1
      do while ( (line(iwk1:iwk1).eq.'%') .and. (iwk1.lt.iwk2) )
         iwk1 = iwk1 + 1
      enddo
c
      call length (line(iwk1:iwk2),slen,sbgn,send)
      sbgn = sbgn + iwk1 - 1
      send = send + iwk1 - 1
c
      if (slen.gt.0) then
         ptr = nxt_blnk (line(sbgn:send)) + sbgn - 1
         call all_lc (line(sbgn:ptr),dscrptr)
         dlen = ptr - sbgn + 1
        else
         dscrptr(1:1) = ' '
         dlen = 1
      end if
c
      if (dscrptr(1:5).eq.'start') then
         call length (line(ptr:send),slen,sbgn,send2)
         sbgn = sbgn + ptr - 1
         send = send + ptr - 1
         if (slen.gt.0) then
            ptr = nxt_blnk (line(sbgn:send)) + sbgn - 1
            call all_lc (line(sbgn:ptr),dscrptr)
            dlen = ptr - sbgn + 1
           else
            dscrptr(1:1) = ' '
            dlen = 1
         end if
      end if
c
c-----------------------------------------------------------------------
c  Extract data based on the descriptor.
c-----------------------------------------------------------------------
c
      if (dscrptr(1:dlen).eq.'cruise') then
c
c        ------------------------------------
c        --- Extract type and identifier. ---
c        ------------------------------------
c
         ptr = index(line,':') + 1
         call length (line(ptr:send),slen2,sbgn2,send2)
         sbgn2 = sbgn2 + ptr - 1
         htitle = line(sbgn2:send)
c
       else if (dscrptr(1:dlen).eq.'station') then
c
c        ------------------------------------
c        --- Extract type and identifier. ---
c        ------------------------------------
c
         ptr = index(line,':') + 1
         call length (line(ptr:send),slen2,sbgn2,send2)
         sbgn2 = sbgn2 + ptr - 1
         call all_lc (line(sbgn2:send),type)
         ctd  = (type(1:3).eq.'ctd') .or. (type(1:5).eq.'chain')
         xbt  = (type(1:3).eq.'xbt')
         xctd = (type(1:3).eq.'xct')
c
         any_chain = any_chain .or. (type(1:5).eq.'chain')
         any_ctd   = any_ctd   .or. (type(1:3).eq.'ctd')
         any_xbt   = any_xbt   .or. xbt
         any_xctd  = any_xctd  .or. xctd
c
         if (xbt) then
            nhvar=2
            lhfield(3)=.false.
          else
            nhvar=3
            lhfield(3)=.true.
         end if
c
         ptr = index(line,'_') + 1
         slen2 = min ( (send-ptr+1), 5 )
         write (fmt,20) slen2
         read (line(ptr:send),fmt) castid
c
       else if (dscrptr(1:dlen).eq.'date') then
c
c        ---------------------
c        --- Extract date. ---
c        ---------------------
c
         ptr = index(line,':') + 1
         call length (line(ptr:send),slen2,sbgn2,send2)
         sbgn2 = sbgn2 + ptr - 1
c
         read (line(sbgn2:(sbgn2+1)),'(i2)') iwk1
         day = day + float(iwk1)
c
         sbgn2 = sbgn2 + 3
         call all_lc (line(sbgn2:(sbgn2+2)),cmon)
         mon = 1
         do 10 while ( (mon_ra(mon).ne.cmon) .and. (mon.lt.12) )
            mon = mon + 1
  10     continue
c
         sbgn2 = sbgn2 + 4
         read (line(sbgn2:(sbgn2+3)),'(i4)') year
c
       else if (dscrptr(1:dlen).eq.'time') then
c
c        ---------------------
c        --- Extract time. ---
c        ---------------------
c
         ptr = index(line,':') + 1
         ptr = index(line(ptr:send),':') + ptr - 1
         read (line((ptr-2):(ptr-1)),'(i2)') iwk1
         read (line((ptr+1):(ptr+2)),'(i2)') iwk2
c
         dfrac = r24*( float(iwk1) + r60*float(iwk2) )
         day = day + dfrac
c
       else if (dscrptr(1:dlen).eq.'latitude') then
c
c        -------------------------
c        --- Extract latitude. ---
c        -------------------------
c
         ptr = index(line,':') + 1
         call length (line(ptr:send),slen2,sbgn2,send2)
         sbgn2 = sbgn2 + ptr - 1
         ptr = nxt_blnk (line(sbgn2:send)) + sbgn2 - 1
         send2 = ptr - 1
         write (fmt,20) (send2-sbgn2+1)
         read (line(sbgn2:send2),fmt) iwk1
c
         call length (line(ptr:send),slen2,sbgn2,send2)
         sbgn2 = sbgn2 + ptr - 1
         send2 = nxt_blnk(line(sbgn2:send)) + sbgn2 - 3
         ptr = index (line(sbgn2:send2),'.') + sbgn2 - 1
         write (fmt,30) (send2-sbgn2+1),(send2-ptr)
         read (line(sbgn2:send2),fmt) rwk
c
         call all_lc (line(send:send),hemi)
c
         hlat = float(iwk1) + r60*rwk
         if (hemi.eq.'s') hlat = -hlat
c
       else if (dscrptr(1:dlen).eq.'longitude') then
c
c        --------------------------
c        --- Extract longitude. ---
c        --------------------------
c
         ptr = index(line,':') + 1
         call length (line(ptr:send),slen2,sbgn2,send2)
         sbgn2 = sbgn2 + ptr - 1
         ptr = nxt_blnk (line(sbgn2:send)) + sbgn2 - 1
         send2 = ptr - 1
         write (fmt,20) (send2-sbgn2+1)
         read (line(sbgn2:send2),fmt) iwk1
c
         call length (line(ptr:send),slen2,sbgn2,send2)
         sbgn2 = sbgn2 + ptr - 1
         send2 = nxt_blnk(line(sbgn2:send)) + sbgn2 - 3
         ptr = index (line(sbgn2:send2),'.') + sbgn2 - 1
         write (fmt,30) (send2-sbgn2+1),(send2-ptr)
         read (line(sbgn2:send2),fmt) rwk
c
         call all_lc (line(send:send),hemi)
c
         hlng = float(iwk1) + r60*rwk
         if (hemi.eq.'w') hlng = -hlng
c
       else if (dscrptr(1:dlen).eq.'water') then
c
c        ----------------------------
c        --- Extract water depth. ---
c        ----------------------------
c
         ptr = index(line,':') + 1
         call length (line(ptr:send),slen2,sbgn2,send2)
         sbgn2 = sbgn2 + ptr - 1
         if (isnum(line(sbgn2:send))) then
            write (fmt,30) (send-sbgn2+1),0
            read (line(sbgn2:send),fmt) hdpth
          else
            hdpth = c0
         end if
c
       else if (istyp(dscrptr(1:dlen))) then
c
c        ---------------------------------------------
c        --- Extract order in which to parse data. ---
c        ---------------------------------------------
c
         iwk1 = 1
         do while (sbgn.lt.send)
            ptr = nxt_blnk (line(sbgn:send)) + sbgn - 2
            if (ptr.lt.sbgn) ptr = send
            call all_lc (line(sbgn:ptr),dscrptr)
            if ((dscrptr(1:5).eq.'press').or.
     &          (dscrptr(1:5).eq.'depth')) then
               datpos(1) = iwk1
              else if (dscrptr(1:4).eq.'temp') then
               datpos(2) = iwk1
              else if (dscrptr(1:3).eq.'sal') then
               datpos(3) = iwk1
            end if
            iwk1 = iwk1 + 1
            call length (line((ptr+1):send),slen,sbgn,send2)
            sbgn = sbgn + ptr
         end do
c
       else if (isnum(dscrptr(1:dlen))) then
c
c        -------------------------------------------------------
c        --- Finshed parsing, assemble modified Julian date. ---
c        --- Update bounds for MODS header.                  ---
c        -------------------------------------------------------
c
         done = .true.
         call julian (day,mon,year,iwk1,rwk)
         iwk1 = iwk1 - joffset
         if (rwk.gt.p5) iwk1 = iwk1 + 1
         htime = float(iwk1) + dfrac
c
         if (.not.first) then
            hstrday  = min (hstrday,  htime)
            hendday  = max (hendday,  htime)
            hlng_min = min (hlng_min, hlng)
            hlng_max = max (hlng_max, hlng)
            hlat_min = min (hlat_min, hlat)
            hlat_max = max (hlat_max, hlat)
            idmax    = max (idmax, castid)
            idmin    = min (idmin, castid)
          else
            hstrday  = htime
            hendday  = htime
            hlng_min = hlng
            hlng_max = hlng
            hlat_min = hlat
            hlat_max = hlat
            idmax    = castid
            idmin    = castid
            first    = .false.
         end if
c
      end if
c
  20  format ('(i',i2,')')
  30  format ('(f',i2,'.',i2,')')
c
      return
c
c-----------------------------------------------------------------------
c  Initialization entry point.
c-----------------------------------------------------------------------
c
      entry init_sac_head (done)
c
      ctd   = .false.
      day   = c0
      dfrac = c0
      done  = .false.
      hdpth = c0
      xbt   = .false.
      xctd  = .false.
c
      return
      end
