      program selpoly
c
c-----------------------------------------------------------------------
c     This program select casts according to whether or not they are   |
c     contained within a given polygon.                                |
c-----------------------------------------------------------------------
c
c-----------------------------------------------------------------------
c     Global variables.                                                |
c-----------------------------------------------------------------------
c
#include <param_hydro.h>
#include <hydro.h>
c
c-----------------------------------------------------------------------
c     Local variables.                                                 |
c-----------------------------------------------------------------------
c
      integer mxpts
      parameter (mxpts=5000)
c
      real p(mhpts),t(mhpts),s(mhpts),latpoly(mxpts),lonpoly(mxpts)
      real sstmp,sssal,apres,dtemp,wtemp,wvht
      real xlat,xlon
c
      integer id,iday,imon,iyr,ihr,imin,maxc,maxd,npar,idisk,hum
      integer wspd,wdir,sstate,wvdir,ctype,camt,vis,pwthr,i
      integer ip,ia,date,time,ios,method,new,npts
      integer inside
#ifdef sunfpe
      integer ieeer,my_handler,ieee_handler
#endif
c
      character*64 comment(8)
      character*80 iname,oname,pname
      character*1 answer
      logical ifsal,ifmed,ifmods,ifunf,keep
c
      real big
      parameter (big=1.0e+10)
c
      equivalence (p(1), hdat(1,1))
      equivalence (t(1), hdat(1,2))
      equivalence (s(1), hdat(1,3))
      equivalence (xlat, hlat)
      equivalence (xlon, hlng)
c
#ifdef sunfpe
       external   my_handler
c
#endif
      data ifsal,keep/.false.,.false./
      data ifunf,ifmed,ifmods/.false.,.false.,.false./
      data new /1/
c
c=======================================================================
c     Begin executable code.                                           #
c=======================================================================
#ifdef sunfpe
c
c-----------------------------------------------------------------------
c     Enable floating point error flags.                               |
c-----------------------------------------------------------------------
c
      ieeer = ieee_handler ('set','common',my_handler)
      if (ieeer .ne. 0) write (6,1000)
#endif
c
c-----------------------------------------------------------------------
c     Read in run parameters.                                          |
c-----------------------------------------------------------------------
c
      print 1
      read 2,iname
      print 3
      read 2,oname
c
    1 format(1x,'What is the name of the input data file  : ',$)
    2 format(a)
    3 format(1x,'What is the name of the output file : ',$)
    4 format(1x,'What is the name of the input polygon file : ',$)
    5 format(1x,'How do you wish to select stations?'/
     &       4x,'[0] keep stations outside the polygon'/
     &       4x,'[1] keep stations inside the polygon'/
     &       1x,'Enter choice :  ',$)
    6 format(1x,'Is this data in the MODS format (y/n): ',$)
    7 format(1x,'Is this data in the POEM format (y/n): ',$)
    8 format(1x,'Is salinity included in the data (y/n)? ',$)
c
      print 4
      read 2,pname
c
      print 5
      read *,method
c
      print 6
      read 2,answer
      if(answer.eq.'Y' .or. answer.eq.'y')ifmods=.true.
c
      if(.not.ifmods)then
        print 7
        read 2,answer
        if(answer.eq.'Y' .or. answer.eq.'y')ifmed=.true.
      endif
c
      if(.not.ifmed .and. .not.ifmods)then
         ifunf=.true.
         print 8
         read 2,answer
         if(answer.eq.'Y' .or. answer.eq.'y')ifsal=.true.
      endif
c
c-----------------------------------------------------------------------
c     Open data files.  Initialize counters & statistic variables.     |
c-----------------------------------------------------------------------
c
      if(ifmods)then
         open(unit=1,file=iname,status='old',form='formatted')
         open(unit=2,file=oname,status='new',form='formatted')
         open(unit=99,status='scratch',form='formatted')
      else if(ifunf .or. ifmed)then
         open(unit=1,file=iname,status='old',form='unformatted')
         open(unit=2,file=oname,status='new',form='unformatted')
      endif
c
      open (unit=13,file=pname,status='old',form='formatted')
c
      if(ifmods)call read_header(1)
c
c --- re-initialize counters
c
      hstrday=big
      hendday=-big
      hlng_min=big
      hlng_max=-big
      hlat_min=big
      hlat_max=-big
      nhobs=0
c
      lhfield(1)=.true.
      hscle(1)=0.1
      lhfield(2)=.true.
      hscle(2)=0.001
      lhfield(3)=.true.
      hscle(3)=0.001
c
c-----------------------------------------------------------------------
c     Read polygon.                                                    |
c-----------------------------------------------------------------------
c
      npts = 1
      read (13,*,iostat=ios) latpoly(npts),lonpoly(npts)
c
      do 10 while ( (npts.lt.mxpts) .and. (ios.eq.0) )
         npts = npts + 1
         read (13,*,iostat=ios) latpoly(npts),lonpoly(npts)
 10   continue
c
      if (ios.ne.0) npts = npts - 1
c
      close (13)
c
c-----------------------------------------------------------------------
c     Loop while there are unchecked stations in input file.
c-----------------------------------------------------------------------
c
   15 continue
c
c --- read data in MODS ascii format
c
      if(ifmods)then
         call read_hydro(1)
         if(eof)goto 99
      endif
c
c --- read data in unformatted POEM format
c
      if(ifmed)then
         read(1,end=99)id,xlat,xlon,iday,imon,iyr,
     +              ihr,imin,maxc,maxd,ip,npar
         read(1)sstmp,sssal,idisk,wspd,wdir,apres,dtemp,wtemp,hum
         read(1)sstate,wvdir,wvht,ctype,camt,vis,pwthr
         do i = 1, 8
            read(1) comment(i)
         enddo
         read(1)(p(i),t(i),s(i),ia,i=1,ip)
c
c --- read data in unformatted wgl format
c
      else if(ifunf)then
         if(ifsal)then
           read(1,end=99)id,xlat,xlon,date,time
           read(1)ip,(p(i),t(i),s(i),i=1,ip)
         else
           read(1,end=99)id,xlat,xlon,date,time
           read(1)ip,(p(i),t(i),i=1,ip)
         endif
      endif
c
c --- decide if cast is to be kept.
c
      keep = inside (xlon,xlat,npts,lonpoly,latpoly,new) .eq. method
      new  = 0
c
c --- if the data is in the mods format, and we want to write an
c --- accurate header, we must store the data in a temporary file
c --- to be read later to calculate the statistics and then
c --- rewrite the data
c
      if(.not.keep)goto 15
      if(ifmods)then
         hstrday=min(hstrday,htime)
         hendday=max(hendday,htime)
         hlng_min=min(hlng_min,hlng)
         hlng_max=max(hlng_max,hlng)
         hlat_min=min(hlat_min,hlat)
         hlat_max=max(hlat_max,hlat)
         nhobs=nhobs+1
         call wrt_hydro(99)
      endif
c
      if(ifmed)then
         write(2)id,xlat,xlon,iday,imon,iyr,
     +           ihr,imin,maxc,maxd,ip,npar
         write(2)sstmp,sssal,idisk,wspd,wdir,apres,dtemp,wtemp,hum
         write(2)sstate,wvdir,wvht,ctype,camt,vis,pwthr
         do i = 1, 8
            write(2)comment(i)
         enddo
         write(2)(p(i),t(i),s(i),ia,i=1,ip)
c
      else if(ifunf)then
         if(ifsal)then
            write(2)id,xlat,xlon,date,time
            write(2)ip,(p(i),t(i),s(i),i=1,ip)
         else
            write(2)id,xlat,xlon,date,time
            write(2)ip,(p(i),t(i),i=1,ip)
         endif
      endif
c
      goto 15
c
c-----------------------------------------------------------------------
c     End of loop.  Close simply formatted files.  Copy MODS formatted |
c     file to its proper location.                                     |
c-----------------------------------------------------------------------
c
   99 continue
c
      if(.not.ifmods)goto 999
      eof=.false.
c
c --- for POEM or WGL formatted data, we are done.  Must
c --- generate a new header for MODS formatted data.
c
      rewind(99)
c
c --- write the new header
c
      call wrt_header(2)
      do while (.not.eof)
        call read_hydro(99)
        if(eof)goto 999
        call wrt_hydro(2)
      enddo
c
      close (99)
c
  999 continue
c
      close (1)
      close (2)
c
#ifdef sunfpe
1000  format (/'SELECT - Warning:  ieee_handler cannot set my_handler'/)
#endif
      end
