      program smooth_casts
c
c-----------------------------------------------------------------------
c     Global variables.                                                |
c-----------------------------------------------------------------------
c
#include <param_hydro.h>
#include <hydro.h>
c
c-----------------------------------------------------------------------
c     Local variables.                                                 |
c-----------------------------------------------------------------------
c
      integer max_bin,nwk1,nwk2,niwk
      parameter (max_bin=49)
      parameter (nwk1=max_bin, nwk2=(max_bin+1)/2, niwk=max_bin+1)
c
      real p(mhpts),t(mhpts),s(mhpts),wk(mhpts),work(nwk1),work2(nwk2)
      real fnfilt,clat,clon
c
      integer i,nbin,npt,ident,idate,itime,nfilt
      integer npmax
      integer iwrk(niwk)
      integer no_digit
#ifdef sunfpe
      integer ieeer,my_handler,ieee_handler
#endif
c
      logical     ifmods,ifunf,ifmed,ifsal
      character*1  answer,filt_typ
      character*80  iname,oname
      character*126 fmt
c
      equivalence (p(1),  hdat(1,1))
      equivalence (t(1),  hdat(1,2))
      equivalence (s(1),  hdat(1,3))
      equivalence (wk(1), hdat(1,4))
c
#ifdef sunfpe
       external   my_handler
c
#endif
      data ifmods,ifunf/.false.,.false./
      data ifmed,ifsal/.false.,.false./
c
      no_digit(i)=int(log10(float(max(abs(i),1))))+(1+max(-sign(1,i),0))
c
c=======================================================================
c     Begin executable code.                                           #
c=======================================================================
#ifdef sunfpe
c
c-----------------------------------------------------------------------
c     Enable floating point error flags.                               |
c-----------------------------------------------------------------------
c
      ieeer = ieee_handler ('set','common',my_handler)
      if (ieeer .ne. 0) write (6,10000)
#endif
c
c-----------------------------------------------------------------------
c     Read basic information to start run.                             |
c-----------------------------------------------------------------------
c
      print 1
      read 2,iname
      print 3
      read 2,oname
c
    1 format(1x,'What is the name of the input file  : ',$)
    2 format(a)
    3 format(1x,'What is the name of the output file : ',$)
c
      print 4
    4 format(1x,'Is this data in the MODS format (y/n): ',$)
      read 2,answer
      if(answer.eq.'Y' .or. answer.eq.'y')ifmods=.true.
c
      if(.not.ifmods)then
         print 5
    5    format(1x,'Is this data in the POEM format (y/n): ',$)
         read 2,answer
         if(answer.eq.'Y' .or. answer.eq.'y')ifmed=.true.
      endif
c
      if(.not.ifmed .and. .not.ifmods)then
         ifunf=.true.
         print 6
    6    format(1x,'Is salinity included in the data (y/n)? ',$)
         read 2,answer
         if(answer.eq.'Y' .or. answer.eq.'y')ifsal=.true.
      endif
c
      print 7
    7 format (1x,'Use Gaussian (g), Linear (l), or Median (m)',
     &        ' filter? : ',$)
      read 2,answer
      call all_lc (answer,filt_typ)
c
      if ((filt_typ.eq.'g').or.(filt_typ.eq.'l')) then
         print 8
    8    format(1x,'Enter the number of points to filter : ',$)
         read *,nfilt
         fnfilt=float(nfilt)
       else
         write (fmt,9) no_digit(max_bin)
         write (6,fmt) max_bin
    9    format ('(4x,',1h','The filter bin width should be an',1h',
     &        '/4x,',1h','odd integer in the range [ 3, ',3h',i,i2.2,
     &        6h,' ]'/,'1x,',
     &        1h','Enter the bin width for filter : ',4h',$))
         read *,nbin
         if (nbin.gt.max_bin) nbin=max_bin
         print 10
   10    format(1x,'Enter the maximum iterations for filter : ',$)
         read *,nfilt
      end if
c
c-----------------------------------------------------------------------
c     Open files and read any header information.                      |
c-----------------------------------------------------------------------
c
      if(ifmods)then
         open(unit=1,file=iname,status='old',form='formatted')
         open(unit=2,file=oname,status='new',form='formatted')
         open(unit=99,status='scratch',form='formatted')
      else if(ifunf .or. ifmed)then
         open(unit=1,file=iname,status='old',form='unformatted')
         open(unit=2,file=oname,status='new',form='unformatted')
      endif
c
      if(ifmods)call read_header(1)
c
c-----------------------------------------------------------------------
c     Loop over all data, applying a smoothing filter.                 |
c-----------------------------------------------------------------------
c
   20 continue
c
c --- read raw data
c
      if(ifmods)then
         call read_hydro(1)
         if(eof)goto 999
         npt=nhpts
      endif
c
      if(ifunf)then
         if(ifsal)then
            read(1,end=999)ident,clat,clon,idate,itime
            read(1)npt,(p(i),t(i),s(i),i=1,npt)
         else
            read(1,end=999)ident,clat,clon,idate,itime
            read(1)npt,(p(i),t(i),i=1,npt)
         endif
      endif
c
      npmax=npt
c
c --- apply a moving filter to smooth the data
c
      if (filt_typ.eq.'l') then
         call flinear (t,npmax,nfilt)
         call flinear (s,npmax,nfilt)
       elseif (filt_typ.eq.'g') then
         call fgaussian(t,npmax,fnfilt,wk)
         call fgaussian(s,npmax,fnfilt,wk)
       else
         call rmed_filt (npmax,p,t,nbin,nfilt,work,work2,iwrk)
         call rmed_filt (npmax,p,s,nbin,nfilt,work,work2,iwrk)
      end if
c
c --- write smoothed data
c
      if(ifunf)then
         if(ifsal)then
            write(2)ident,clat,clon,idate,itime
            write(2)npt,(p(i),t(i),s(i),i=1,npt)
         else
            write(2)ident,clat,clon,idate,itime
            write(2)npt,(p(i),t(i),i=1,npt)
         endif
      endif
c
      if(ifmods)then
         call wrt_hydro(99)
      endif
c
      goto 20
c
c-----------------------------------------------------------------------
c     For MODS format, rewrite results to final file, with correct     |
c     header.                                                          |
c-----------------------------------------------------------------------
c
  999 continue
c
      if(.not.ifmods)goto 9999
c
      call wrt_header(2)
      rewind(99)
      eof=.false.
c
      do while (.not.eof)
        call read_hydro(99)
        if(eof)goto 9999
        call wrt_hydro(2)
      enddo
c
 9999 continue
c
#ifdef sunfpe
10000 format (/'SMOOTH_CASTS - Warning:  ieee_handler cannot set ',
     &        'my_handler'/)
#endif
      end
