      subroutine whydbase (iunit,day,mon,yr,zisz)
c
c=======================================================================
c                                                                    ===
c  This routine writes a cast in the HydroBase format.               ===
c                                                                    ===
c  ------                                                            ===
c  Input:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     iunit...Unit number on which file was opened.   (integer)      ===
c     day.....Cast day of month.                      (integer)      ===
c     mon.....Cast month.                             (integer)      ===
c     yr......Cast year.                              (integer)      ===
c     zisz....Flag for method of writing depth.       (logical)      ===
c             [.true.]   Write depth as depth.                       ===
c             [.false.]  Write depth as pressure.                    ===
c                                                                    ===
c  Calls:  none                                                      ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <param_hydro.h>
#include <hydro.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer day,iunit,m,mars10,mars1,mon,n,yr
      real    p2z,z2p
      logical      zisz
      character*21 fmt
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c-----------------------------------------------------------------------
c  Compute Marsden squares.
c-----------------------------------------------------------------------
c
c     -------------------------
c     --- 10 degree square. ---
c     -------------------------
c
      if (hlat.ge.0) then
         if (hlng.ge.0) then
            mars10 = 1000
           else
            mars10 = 7000
         end if
        else
         if (hlng.ge.0) then
            mars10 = 3000
           else
            mars10 = 5000
         end if
      end if
c
      mars10 = mars10 + (int(abs(hlat))/10)*100 + int(abs(hlng))/10
c
c     ------------------------
c     --- 1 degree square. ---
c     ------------------------
c
      mars1 = mod(int(abs(hlat)),10)*10 + mod(int(abs(hlng)),10)
c
c-----------------------------------------------------------------------
c  Write cast header.
c-----------------------------------------------------------------------
c
      write (iunit,20) 35,'99',9999,castid,yr,mon,day,hlat,hlng,
     &                 nint(hdpth),nhpts,nhvar+1,mars10,mars1
c
      if (nhvar.gt.2) then
         write (iunit,30) 'pr te sa de'
        else
         write (iunit,30) 'pr te de'
      end if
c
c-----------------------------------------------------------------------
c  Write data.
c-----------------------------------------------------------------------
c
      write (fmt,40) nhvar
c
      do 10 m = 1, nhpts
         if (zisz) then
            hdat(m,nhvar+1) = hdat(m,1)
            hdat(m,1)       = z2p (hdat(m,1),hlat)
           else
            hdat(m,nhvar+1) = p2z (hdat(m,1),hlat)
         end if
         write (iunit,fmt) (hdat(m,n), n=1, nhvar+1)
 10   continue
c
c-----------------------------------------------------------------------
c  Write terminator string
c-----------------------------------------------------------------------
c
      write (iunit,30) '**'
c
      return
c
 20   format (i2,1x,a2,i6,2i5,2i3,2f10.3,4i6,i4)
 30   format (a)
 40   format ('(1x,f8.1,',i2,'(1x,f8.3))')
c
      end
