      subroutine align_mask (bfile,bncid,sfile,sncid,xgdir,error)
c
c=======================================================================
c                                                                    ===
c  This routine aligns the land masks in the GRIDS files.            ===
c                                                                    ===
c  ------                                                            ===
c  Input:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     BFILE...Name of coarse GRIDS netCDF file.           (character)===
c     BNCID...netCDF identifier for coarse GRIDS file.    (integer)  ===
c     SFILE...Name of fine GRIDS netCDF file.             (character)===
c     SNCID...netCDF identifier for fine GRIDS file.      (integer)  ===
c     XGDIR..."Direction" of extraction.                  (integer)  ===
c             [0]  large to small.                                   ===
c             [1]  small to large.                                   ===
c             [2]  large to boundary of small.                       ===
c                                                                    ===
c  Common Blocks:                                                    ===
c                                                                    ===
c  /BGDOMDAT/                                                        ===
c                                                                    ===
c     BNX      number of gridpoints in x-direction   (integer)       ===
c     BNY      number of gridpoints in y-direction   (integer)       ===
c                                                                    ===
c  /SMDOMDAT/                                                        ===
c                                                                    ===
c     SNX      number of gridpoints in x-direction   (integer)       ===
c     SNY      number of gridpoints in y-direction   (integer)       ===
c                                                                    ===
c  -------                                                           ===
c  Output:                                                           ===
c  -------                                                           ===
c                                                                    ===
c     ERROR...Flag to indicate read error.                (logical)  ===
c                                                                    ===
c  ------                                                            ===
c  Calls:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     HOPS:    SUB_SAM_MASK,    SUP_SAM_MASK                         ===
c     netCDF:  NF_GET_VAR_INT,  NF_INQ_VARID,  NF_PUT_VAR_INT        ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <gridsparm.h>
#include <bgdomdat.h>
#include <netcdf.inc>
#include <smdomdat.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer bncid,ip,j,sncid,varid,xgdir
      integer count(2),mbig(imjm),msmall(imjm),mtmp(jmt),start(2)
      logical       error
      character*(*) bfile,sfile
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c-----------------------------------------------------------------------
c  Read Land Masks.
c-----------------------------------------------------------------------
c
c  Large domain.
c
      if (nf_inq_varid (bncid,'landt',varid) .eq. NF_NOERR) then
         if (nf_get_var_int (bncid,varid,mbig) .ne. NF_NOERR) then
            error = .true.
            write (6,900) 'landt',bfile,'masking'
         end if
        else
         error = .true.
         write (6,910) 'landt',bfile,'masking'
      end if
c
c  Small domain.
c
      if ((.not.error) .and. (xgdir.eq.1)) then
         if (nf_inq_varid (sncid,'landt',varid) .eq. NF_NOERR) then
            if (nf_get_var_int (sncid,varid,msmall) .ne. NF_NOERR) then
               error = .true.
               write (6,900) 'landt',sfile,'masking'
            end if
          else
            error = .true.
            write (6,910) 'landt',sfile,'masking'
         end if
      end if
c
c-----------------------------------------------------------------------
c  Align masks.
c-----------------------------------------------------------------------
c
      if (.not. error) then
         if (xgdir.ne.1) then
            call sub_sam_mask (bnx,mbig,snx,msmall)
           else
            call sup_sam_mask (snx,msmall,bnx,mbig)
         end if
      end if
c
c-----------------------------------------------------------------------
c  Write land mask.
c-----------------------------------------------------------------------
c
      if (.not. error) then
c
c  Overwrite small domain land mask.
c
         if (xgdir.eq.0) then
            if (nf_inq_varid (sncid,'landt',varid) .eq. NF_NOERR) then
               if (nf_put_var_int(sncid,varid,msmall) .ne.NF_NOERR) then
                  error = .true.
                  write (6,920) 'landt',sfile,'masking'
               end if
             else
               error = .true.
               write (6,910) 'landt',sfile,'masking'
            end if
c
c  Overwrite small domain boundary land mask.
c
          elseif (xgdir.eq.2) then
            if (nf_inq_varid (sncid,'landt',varid) .eq. NF_NOERR) then
c
c        Southern boundary.
c
               ip = 1
               start(1) = 1
               start(2) = 1
               count(1) = snx
               count(2) = 1
               if (nf_put_vara_int (sncid,varid,start,count,msmall(ip))
     &             .ne. NF_NOERR) then
                  error = .true.
                  write (6,920) 'landt',sfile,'masking'
               end if
c
c        Northern boundary.
c
               ip = 1 + (sny-1)*snx
               start(1) = 1
               start(2) = sny
               count(1) = snx
               count(2) = 1
               if (nf_put_vara_int (sncid,varid,start,count,msmall(ip))
     &             .ne. NF_NOERR) then
                  error = .true.
                  write (6,920) 'landt',sfile,'masking'
               end if
c
               ip = 1 + (sny-2)*snx
               start(1) = 1
               start(2) = sny-1
               count(1) = snx
               count(2) = 1
               if (nf_put_vara_int (sncid,varid,start,count,msmall(ip))
     &             .ne. NF_NOERR) then
                  error = .true.
                  write (6,920) 'landt',sfile,'masking'
               end if
c
c        Western boundary.
c
               do 10 j = 1, sny
                  ip = 1 + (j-1)*snx
                  mtmp(j) = msmall(ip)
  10           continue
               start(1) = 1
               start(2) = 1
               count(1) = 1
               count(2) = sny
               if (nf_put_vara_int (sncid,varid,start,count,mtmp)
     &             .ne. NF_NOERR) then
                  error = .true.
                  write (6,920) 'landt',sfile,'masking'
               end if
c
c        Eastern boundary.
c
               do 20 j = 1, sny
                  ip = j*snx
                  mtmp(j) = msmall(ip)
  20           continue
               start(1) = snx
               start(2) = 1
               count(1) = 1
               count(2) = sny
               if (nf_put_vara_int (sncid,varid,start,count,mtmp)
     &             .ne. NF_NOERR) then
                  error = .true.
                  write (6,920) 'landt',sfile,'masking'
               end if
             else
               error = .true.
               write (6,910) 'landt',sfile,'masking'
            end if
c
c  Overwrite large domain topography in region supported by small domain.
c
          else
            if (nf_inq_varid (bncid,'landt',varid) .eq. NF_NOERR) then
               if (nf_put_var_int(bncid,varid,mbig) .ne. NF_NOERR) then
                  error = .true.
                  write (6,920) 'landt',bfile,'masking'
               end if
             else
               error = .true.
               write (6,910) 'landt',bfile,'masking'
            end if
         end if
      end if
c
      return
c
 900  format (/'***Error:  ALIGN_MASK -- unable to read variable ',a,
     &        ' in file:'/11x,a/11x,'No ',a,' extraction will be done.')
 910  format (/'***Error:  ALIGN_MASK -- unable to find variable ',a,
     &        ' in file:'/11x,a/11x,'No ',a,' extraction will be done.')
 920  format (/'***Error:  ALIGN_MASK -- unable to write variable ',a,
     &        ' to file:'/11x,a/11x,'No ',a,' extraction will be done.')
c
      end
