      subroutine align_thick (bfile,bncid,sfile,sncid,vname,xgdir,error)
c
c=======================================================================
c                                                                    ===
c  This routine aligns the 3D thicknesses in the GRIDS files.        ===
c                                                                    ===
c  ------                                                            ===
c  Input:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     BFILE...Name of coarse GRIDS netCDF file.           (character)===
c     BNCID...netCDF identifier for coarse GRIDS file.    (integer)  ===
c     SFILE...Name of fine GRIDS netCDF file.             (character)===
c     SNCID...netCDF identifier for fine GRIDS file.      (integer)  ===
c     VNAME...Name of actual netCDF variable to extract.  (character)===
c     XGDIR..."Direction" of extraction.                  (integer)  ===
c             [0]  large to small.                                   ===
c             [1]  small to large.                                   ===
c             [2]  large to boundary of small.                       ===
c                                                                    ===
c  Common Blocks:                                                    ===
c                                                                    ===
c  /BGDOMDAT/                                                        ===
c                                                                    ===
c     BNX      number of gridpoints in x-direction   (integer)       ===
c     BNY      number of gridpoints in y-direction   (integer)       ===
c                                                                    ===
c  /SMDOMDAT/                                                        ===
c                                                                    ===
c     SNX      number of gridpoints in x-direction   (integer)       ===
c     SNY      number of gridpoints in y-direction   (integer)       ===
c                                                                    ===
c  -------                                                           ===
c  Output:                                                           ===
c  -------                                                           ===
c                                                                    ===
c     ERROR...Flag to indicate read error.                (logical)  ===
c                                                                    ===
c  ------                                                            ===
c  Calls:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     HOPS:    LENGTH,           SUB_SAM2D,         SUP_SAM2D        ===
c     netCDF:  NF_GET_VAR_REAL,  NF_GET_VARA_REAL,  NF_INQ_DIMID,    ===
c              NF_INQ_DIMLEN,    NF_INQ_VARID,      NF_PUT_VARA_REAL ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <gridsparm.h>
#include <gpconst.h>
#include <bgdomdat.h>
#include <netcdf.inc>
#include <smdomdat.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      real    hbig(imjm),hsmall(imjm),htmp(jmt),s_cst(jmt)
      integer bncid,ip,j,k,keytv,nolvl,nolvs,rcode,sbn,sncid,snd,sln,
     &        varid,varids,xgdir
      integer count(3),start(3)
      logical       error
      character*3   cname
      character*80  messg
      character*(*) bfile,sfile,vname
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c-----------------------------------------------------------------------
c  Determine grid type.
c-----------------------------------------------------------------------
c
      call length (vname,sln,sbn,snd)
      if ((vname(snd:snd).eq.'v') .or. (vname(snd:snd).eq.'V') ) then
         keytv = vgrid
       else
         keytv = tgrid
      end if
c
c-----------------------------------------------------------------------
c  Determine number of vertical levels.
c-----------------------------------------------------------------------
c
c  Large grid.
c
      if (nf_inq_dimid (bncid,'level',varid) .eq. NF_NOERR) then
         if (nf_inq_dimlen (bncid,varid,nolvl) .ne. NF_NOERR) then
            error = .true.
            write (6,900) 'level',bfile,'thickness'
         end if
       else
         error = .true.
         write (6,910) 'level',bfile,'thickness'
      end if
c
c  Small grid.
c
      if (nf_inq_dimid (sncid,'level',varid) .eq. NF_NOERR) then
         if (nf_inq_dimlen (sncid,varid,nolvs) .ne. NF_NOERR) then
            error = .true.
            write (6,900) 'level',sfile,'thickness'
         end if
       else
         error = .true.
         write (6,910) 'level',sfile,'thickness'
      end if
c
c  Comparison.
c
      if (nolvl .ne. nolvs) then
         error = .true.
         write (6,920) nolvl,nolvs,'thickness'
      end if
c
c-----------------------------------------------------------------------
c  Extract any needed metric factors.
c-----------------------------------------------------------------------
c
      if ((.not.error) .and. (xgdir.eq.1)) then
         if (keytv.eq.tgrid) then
            cname = 'cst'
          else
            cname = 'cs'
         end if
         call length (cname,sln,sbn,snd)
         if (nf_inq_varid(sncid,cname(sbn:snd),varid) .eq.NF_NOERR) then
            if (nf_get_var_real (sncid,varid,s_cst) .ne. NF_NOERR) then
               error = .true.
               write (6,930) cname(sbn:snd),sfile,'thickness'
            end if
          else
            error = .true.
            write (6,940) cname(sbn:snd),sfile,'thickness'
         end if
      end if
c
c-----------------------------------------------------------------------
c  Align thicknesses, level-by-level.
c-----------------------------------------------------------------------
c
c-------------------------
c--- Prepare for loop. ---
c-------------------------
c
      k = 0
c
      if (.not.error) then
         if (nf_inq_varid (bncid,vname,varid) .ne. NF_NOERR) then
            error = .true.
            write (6,940) vname,bfile,'thickness'
         end if
      end if
c
      if (.not.error) then
         if (nf_inq_varid (sncid,vname,varids) .ne. NF_NOERR) then
            error = .true.
            write (6,940) vname,sfile,'thickness'
         end if
      end if
c
c-----------------------------
c--- Loop over all levels. ---
c-----------------------------
c
      do 30 while ((k.lt.nolvl) .and. (.not.error))
c
         k        = k + 1
         start(1) = k
         start(2) = 1
         start(3) = 1
         count(1) = 1
c
c   -------------------------
c   --- Read thicknesses. ---
c   -------------------------
c
c     Large domain.
c
         count(2) = bnx
         count(3) = bny
c
         if (nf_get_vara_real (bncid,varid,start,count,hbig) .ne.
     &       NF_NOERR) then
            error = .true.
            write (6,930) vname,bfile,'thickness'
         end if
c
c     Small domain.
c
         count(2) = snx
         count(3) = sny
c
         if ((.not.error) .and. (xgdir.eq.1)) then
            if (nf_get_vara_real (sncid,varids,start,count,hsmall) .ne.
     &          NF_NOERR) then
               error = .true.
               write (6,930) vname,sfile,'thickness'
            end if
         end if
c
c   --------------------------
c   --- Align thicknesses. ---
c   --------------------------
c
         if (.not. error) then
            if (xgdir.ne.1) then
               call sub_sam2d (bnx,hbig,snx,hsmall,keytv)
              else
               call sup_sam2d (snx,hsmall,s_cst,bnx,hbig,keytv)
            end if
         end if
c
c   --------------------------
c   --- Write thicknesses. ---
c   --------------------------
c
         if (.not. error) then
c
c      Overwrite small domain thicknesses.
c
            if (xgdir.eq.0) then
               count(2) = snx
               count(3) = sny
               rcode = nf_put_vara_real(sncid,varids,start,count,hsmall)
               if (rcode .ne. NF_NOERR) then
                  error = .true.
                  messg = nf_strerror (rcode)
                  call length (messg,sln,sbn,snd)
                  write (6,950) vname,sfile,'thickness'
               end if
c
c      Overwrite small domain boundary thicknesses.
c
          elseif (xgdir.eq.2) then
c
c        Southern boundary.
c
               ip = 1
               start(2) = 1
               start(3) = 1
               count(2) = snx
               count(3) = 1
               rcode = nf_put_vara_real(sncid,varids,start,count,hsmall)
               if (rcode .ne. NF_NOERR) then
                  error = .true.
                  messg = nf_strerror (rcode)
                  call length (messg,sln,sbn,snd)
                  write (6,955) vname,sfile,messg(sbn:snd),'thickness'
               end if
c
c        Northern boundary.
c
               ip = 1 + (sny-1)*snx
               start(2) = 1
               start(3) = sny
               count(2) = snx
               count(3) = 1
               if (nf_put_vara_real(sncid,varids,start,count,hsmall(ip))
     &             .ne. NF_NOERR) then
                  error = .true.
                  write (6,950) vname,sfile,'thickness'
               end if
c
               ip = 1 + (sny-2)*snx
               start(2) = 1
               start(3) = sny-1
               count(2) = snx
               count(3) = 1
               if (nf_put_vara_real(sncid,varids,start,count,hsmall(ip))
     &             .ne. NF_NOERR) then
                  error = .true.
                  write (6,950) vname,sfile,'thickness'
               end if
c
c        Western boundary.
c
               do 10 j = 1, sny
                  ip = 1 + (j-1)*snx
                  htmp(j) = hsmall(ip)
  10           continue
               start(2) = 1
               start(3) = 1
               count(2) = 1
               count(3) = sny
               if (nf_put_vara_real (sncid,varids,start,count,htmp)
     &             .ne. NF_NOERR) then
                  error = .true.
                  write (6,950) vname,sfile,'thickness'
               end if
c
c        Eastern boundary.
c
               do 20 j = 1, sny
                  ip = j*snx
                  htmp(j) = hsmall(ip)
  20           continue
               start(2) = snx
               start(3) = 1
               count(2) = 1
               count(3) = sny
               if (nf_put_vara_real (sncid,varids,start,count,htmp)
     &             .ne. NF_NOERR) then
                  error = .true.
                  write (6,950) vname,sfile,'thickness'
               end if
c
c      Overwrite large domain thicknesses in region supported by small domain.
c
             else
               count(2) = bnx
               count(3) = bny
               if (nf_put_vara_real (bncid,varid,start,count,hbig) .ne.
     &             NF_NOERR) then
                  error = .true.
                  write (6,950) vname,bfile,'thickness'
               end if
            end if
         end if
c
  30  continue
c
      return
c
 900  format (/'***Error:  ALIGN_THICK -- unable to read dimension ',a,
     &        ' in file:'/11x,a/11x,'No ',a,' extraction will be done.')
 910  format (/'***Error:  ALIGN_THICK -- unable to find dimension ',a,
     &        ' in file:'/11x,a/11x,'No ',a,' extraction will be done.')
 920  format (/'***Error:  ALIGN_THICK -- Incompatible number of verti',
     &       'cal levels.'/11x,'Number of levels in large domain:  ',i10
     &       /11x,'Number of levels in small domain:  ',i10
     &       /11x,'No ',a,' extraction will be done.')
 930  format (/'***Error:  ALIGN_THICK -- unable to read variable ',a,
     &        ' in file:'/11x,a/11x,'No ',a,' extraction will be done.')
 940  format (/'***Error:  ALIGN_THICK -- unable to find variable ',a,
     &        ' in file:'/11x,a/11x,'No ',a,' extraction will be done.')
 950  format (/'***Error:  ALIGN_THICK -- unable to write variable ',a,
     &        ' to file:'/11x,a/11x,'No ',a,' extraction will be done.')
 955  format (/'***Error:  ALIGN_THICK -- unable to write variable ',a,
     &        ' to file:'/11x,a/11x,1h",a,1h"/11x,'No ',a,
     &        ' extraction will be done.')
c
      end
