      subroutine align_topo (bfile,bncid,sfile,sncid,vname,xgdir,error)
c
c=======================================================================
c                                                                    ===
c  This routine aligns the topographies in the GRIDS files.          ===
c                                                                    ===
c  ------                                                            ===
c  Input:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     BFILE...Name of coarse GRIDS netCDF file.           (character)===
c     BNCID...netCDF identifier for coarse GRIDS file.    (integer)  ===
c     SFILE...Name of fine GRIDS netCDF file.             (character)===
c     SNCID...netCDF identifier for fine GRIDS file.      (integer)  ===
c     VNAME...Name of actual netCDF variable to extract.  (character)===
c     XGDIR..."Direction" of extraction.                  (integer)  ===
c             [0]  large to small.                                   ===
c             [1]  small to large.                                   ===
c             [2]  large to boundary of small.                       ===
c                                                                    ===
c  Common Blocks:                                                    ===
c                                                                    ===
c  /BGDOMDAT/                                                        ===
c                                                                    ===
c     BNX      number of gridpoints in x-direction   (integer)       ===
c     BNY      number of gridpoints in y-direction   (integer)       ===
c                                                                    ===
c  /SMDOMDAT/                                                        ===
c                                                                    ===
c     SNX      number of gridpoints in x-direction   (integer)       ===
c     SNY      number of gridpoints in y-direction   (integer)       ===
c                                                                    ===
c  -------                                                           ===
c  Output:                                                           ===
c  -------                                                           ===
c                                                                    ===
c     ERROR...Flag to indicate read error.                (logical)  ===
c                                                                    ===
c  ------                                                            ===
c  Calls:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     HOPS:    LENGTH,           SUB_SAM2D,     SUP_SAM2D            ===
c     netCDF:  NF_GET_VAR_REAL,  NF_INQ_VARID,  NF_PUT_VAR_REAL      ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <gridsparm.h>
#include <gpconst.h>
#include <bgdomdat.h>
#include <netcdf.inc>
#include <smdomdat.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      real    hbig(imjm),hsmall(imjm),htmp(jmt),s_cst(jmt)
      integer bncid,ip,j,keytv,sbn,sncid,snd,sln,varid,xgdir
      integer count(2),start(2)
      logical       error
      character*3   cname
      character*(*) bfile,sfile,vname
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c-----------------------------------------------------------------------
c  Determine grid type.
c-----------------------------------------------------------------------
c
      if ((vname(1:1).eq.'v') .or. (vname(1:1).eq.'V') ) then
         keytv = vgrid
       else
         keytv = tgrid
      end if
c
c-----------------------------------------------------------------------
c  Read topography.
c-----------------------------------------------------------------------
c
c  Large domain.
c
      if (nf_inq_varid (bncid,vname,varid) .eq. NF_NOERR) then
         if (nf_get_var_real (bncid,varid,hbig) .ne. NF_NOERR) then
            error = .true.
            write (6,900) vname,bfile,'topographic'
         end if
        else
         error = .true.
         write (6,910) vname,bfile,'topographic'
      end if
c
c  Small domain.
c
      if ((.not.error) .and. (xgdir.eq.1)) then
c
c    Topography
c
         if (nf_inq_varid (sncid,vname,varid) .eq. NF_NOERR) then
            if (nf_get_var_real (sncid,varid,hsmall) .ne. NF_NOERR) then
               error = .true.
               write (6,900) vname,sfile,'topographic'
            end if
          else
            error = .true.
            write (6,910) vname,sfile,'topographic'
         end if
c
c    Cosine metric factors
c
         if (keytv.eq.tgrid) then
            cname = 'cst'
          else
            cname = 'cs'
         end if
         call length (cname,sln,sbn,snd)
         if (nf_inq_varid(sncid,cname(sbn:snd),varid) .eq.NF_NOERR) then
            if (nf_get_var_real (sncid,varid,s_cst) .ne. NF_NOERR) then
               error = .true.
               write (6,900) cname(sbn:snd),sfile,'topographic'
            end if
          else
            error = .true.
            write (6,910) cname(sbn:snd),sfile,'topographic'
         end if
c
      end if
c
c-----------------------------------------------------------------------
c  Align topography.
c-----------------------------------------------------------------------
c
      if (.not. error) then
         if (xgdir.ne.1) then
            call sub_sam2d (bnx,hbig,snx,hsmall,keytv)
           else
            call sup_sam2d (snx,hsmall,s_cst,bnx,hbig,keytv)
         end if
      end if
c
c-----------------------------------------------------------------------
c  Write topography.
c-----------------------------------------------------------------------
c
      if (.not. error) then
c
c  Overwrite small domain topography.
c
         if (xgdir.eq.0) then
            if (nf_inq_varid (sncid,vname,varid) .eq. NF_NOERR) then
               if (nf_put_var_real(sncid,varid,hsmall).ne.NF_NOERR) then
                  error = .true.
                  write (6,920) vname,sfile,'topographic'
               end if
             else
               error = .true.
               write (6,910) vname,sfile,'topographic'
            end if
c
c  Overwrite small domain boundary topography.
c
          elseif (xgdir.eq.2) then
            if (nf_inq_varid (sncid,vname,varid) .eq. NF_NOERR) then
c
c        Southern boundary.
c
               ip = 1
               start(1) = 1
               start(2) = 1
               count(1) = snx
               count(2) = 1
               if (nf_put_vara_real (sncid,varid,start,count,hsmall(ip))
     &             .ne. NF_NOERR) then
                  error = .true.
                  write (6,920) vname,sfile,'topographic'
               end if
c
c        Northern boundary.
c
               ip = 1 + (sny-1)*snx
               start(1) = 1
               start(2) = sny
               count(1) = snx
               count(2) = 1
               if (nf_put_vara_real (sncid,varid,start,count,hsmall(ip))
     &             .ne. NF_NOERR) then
                  error = .true.
                  write (6,920) vname,sfile,'topographic'
               end if
c
               ip = 1 + (sny-2)*snx
               start(1) = 1
               start(2) = sny-1
               count(1) = snx
               count(2) = 1
               if (nf_put_vara_real (sncid,varid,start,count,hsmall(ip))
     &             .ne. NF_NOERR) then
                  error = .true.
                  write (6,920) vname,sfile,'topographic'
               end if
c
c        Western boundary.
c
               do 10 j = 1, sny
                  ip = 1 + (j-1)*snx
                  htmp(j) = hsmall(ip)
  10           continue
               start(1) = 1
               start(2) = 1
               count(1) = 1
               count(2) = sny
               if (nf_put_vara_real (sncid,varid,start,count,htmp)
     &             .ne. NF_NOERR) then
                  error = .true.
                  write (6,920) vname,sfile,'topographic'
               end if
c
c        Eastern boundary.
c
               do 20 j = 1, sny
                  ip = j*snx
                  htmp(j) = hsmall(ip)
  20           continue
               start(1) = snx
               start(2) = 1
               count(1) = 1
               count(2) = sny
               if (nf_put_vara_real (sncid,varid,start,count,htmp)
     &             .ne. NF_NOERR) then
                  error = .true.
                  write (6,920) vname,sfile,'topographic'
               end if
c
               if (keytv.eq.vgrid) then
                  do 30 j = 1, sny
                     ip = j*snx-1
                     htmp(j) = hsmall(ip)
  30              continue
                  start(1) = snx-1
                  start(2) = 1
                  count(1) = 1
                  count(2) = sny
                  if (nf_put_vara_real (sncid,varid,start,count,htmp)
     &                .ne. NF_NOERR) then
                     error = .true.
                     write (6,920) vname,sfile,'topographic'
                  end if
               end if
c
             else
               error = .true.
               write (6,910) vname,sfile,'topographic'
            end if
c
c  Overwrite large domain topography in region supported by small domain.
c
          else
            if (nf_inq_varid (bncid,vname,varid) .eq. NF_NOERR) then
               if (nf_put_var_real (bncid,varid,hbig) .ne.NF_NOERR) then
                  error = .true.
                  write (6,920) vname,bfile,'topographic'
               end if
             else
               error = .true.
               write (6,910) vname,bfile,'topographic'
            end if
         end if
      end if
c
      return
c
 900  format (/'***Error:  ALIGN_TOPO -- unable to read variable ',a,
     &        ' in file:'/11x,a/11x,'No ',a,' extraction will be done.')
 910  format (/'***Error:  ALIGN_TOPO -- unable to find variable ',a,
     &        ' in file:'/11x,a/11x,'No ',a,' extraction will be done.')
 920  format (/'***Error:  ALIGN_TOPO -- unable to write variable ',a,
     &        ' to file:'/11x,a/11x,'No ',a,' extraction will be done.')
c
      end
