      subroutine auto_iface (flat,no_lvl,dzt,kc,zc1,favg,fdif,fac,ldf,
     &                                no_x,no_y,f,h,tol,itmax,opt_iface)
c
c-------------------------------------------------------------------------------
c     This routine computes coordinate interface for a pure hybrid system which|
c     is consistent with the flat levels.                                      |
c                                                                              |
c     Calls:  none                                                             |
c                                                                              |
c     Arguments:                                                               |
c                                                                              |
c     dzt......Real array.  The vertical level thicknesses.  (m)   {input}     |
c     f........Real array.  The coordinate interface.  (m)   {output}          |
c     fac......Real.  tanh scaling arguement.   {output}                       |
c     favg.....Real.  The average of coordinate interface extrema.  (m)        |
c                 {output}                                                     |
c     fdif.....Real.  The difference of coordinate interface extrema.  (m)     |
c                 {output}                                                     |
c     h........Real array.  The topography.  (m)   {input}                     |
c     kc.......Integer.  The level at which to interface cartesian & sigma     |
c                levels.   {input}                                             |
c     ldf......Integer.  The leading dimension of f.   {input}                 |
c     no_lvl...Integer.  The total number of vertical levels.   {input}        |
c     no_x.....Integer.  The number of grid points in the x-direction.  {input}|
c     no_y.....Integer.  The number of grid points in the y-direction.  {input}|
c     zc1......Real.  Shallowest interface depth.  (m)   {output}              |
c-------------------------------------------------------------------------------
c
#include <gridsio.h>
#include <gpconst.h>
#include <optzc1.h>
c
      integer kc,no_lvl,k,ldf,no_x,no_y,i,j,itmax,opt_iface
      real    zc1,dzt(no_lvl),favg,fdif,hc,f(ldf,no_y),tol,dsigu,dsigd,
     &        zc1g,h(ldf,no_y),fac
      logical flat,found
c
      external f_fz
c
c=======================================================================
c     Begin executable code.                                           #
c=======================================================================
c
      if (flat) then
c
c-----------------------------------------------------------------------
c        Compute consistent depth of flat interface level.             |
c-----------------------------------------------------------------------
c
         hc = c0
c
         do 10 k = 1, kc
            hc = hc - dzt(k)
 10      continue
c
         write (out_unit,60) hc
c
c-----------------------------------------------------------------------
c        Set interface parameters accordingly.                         |
c-----------------------------------------------------------------------
c
         zc1 = hc
         zc2 = hc
         favg = hc
         fdif = c0
         alpha = c0
         fac = c0
c
        else if (opt_iface.ne.0) then
c
c-----------------------------------------------------------------------
c        Compute target minimum interface depth.                       |
c-----------------------------------------------------------------------
c
         hmin = h(1,1)
         do 20 j = 1, no_y
            do 20 i = 1, no_x
               hmin = max( h(i,j), hmin )
 20      continue
c
         if (opt_iface.eq.1) then
            fmin = zc1
           else
c
            dsigu = dzt(1)
            do 30 k = 2, kc
               dsigu = min( dsigu, dzt(k) )
 30         continue
c
            dsigd = dzt(kc+1)
            do 40 k = kc+2, no_lvl
               dsigd = min( dsigd, dzt(k) )
 40         continue
c
            fmin = hmin / (c1 + dsigu/dsigd)
c
         end if
c
c-----------------------------------------------------------------------
c        Compute corrected zc1.                                        |
c-----------------------------------------------------------------------
c
         zc1g = zc1
c
         call newton (f_fz,zc1g,tol,itmax,zc1,found)
c
         if (.not. found) zc1 = zc1g
c
         write (out_unit,70) fmin,zc1,found
c
         favg = p5 * (zc1 + zc2)
         fdif = p5 * (zc1 - zc2)
         if (fdif .ne. c0) then
            fac = alpha/fdif
           else
            fac = c0
         end if
c
      end if
c
c-----------------------------------------------------------------------
c     Reset coordinate interface.                                      |
c-----------------------------------------------------------------------
c
      do 50 j = 1, no_y
         do 50 i = 1, no_x
            f(i,j) = favg + fdif * tanh(fac*(h(i,j)-href))
 50   continue
#ifdef sunflush
      call flush (out_unit)
#endif
c
      return
c
 60   format ('Resetting hybrid interface depth (hc)'/3x,'hc=',1pg16.8,
     &                                                          '  (m)')
 70   format (/'Resetting double sigma parameter zc1:'/3x,
     &         'Shallowest interface depth:  ',1pg15.8,' (m)'/17x,
     &         'Required zc1:  ',1pg15.8,' (m)'/12x,
     &         'Successful search:  ',l1)
c
      end
