      subroutine bisect (fn,x0,x1,tol,itmax,root,fnd)
c
c=======================================================================
c                                                                    ===
c  This routine find the root of the given function using the        ===
c  bisection algorithm.                                              ===
c                                                                    ===
c  ------                                                            ===
c  Input:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     FN       Name of function to solve.              (double prec.)===
c     X0, X1   Endpoints in search interval.           (double prec.)===
c     TOL      Tolerence in finding root.              (double prec.)===
c     ITMAX    Maximum number of iterations allowed.   (integer)     ===
c                                                                    ===
c  -------                                                           ===
c  Output:                                                           ===
c  -------                                                           ===
c                                                                    ===
c     ROOT     Root of the given function.             (double prec.)===
c     FND      Flag for a "found" root.                (logical)     ===
c                                                                    ===
c  ------                                                            ===
c  Calls:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     FN                                                             ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define local variables.
c-----------------------------------------------------------------------
c
      double precision c0,p5
      parameter (c0=0.0d0, p5=0.5d0)
c
      integer itmax,n
      logical fnd
      double precision f,fm,fp,root,tol,x0,x1,xm,xp
      double precision fn
c
      external fn
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c-----------------------------------------------------------------------
c  Initialize test variables.
c-----------------------------------------------------------------------
c
      fm = fn(x0)
      if (fm.lt.c0) then
         xm = x0
         xp = x1
         fp = fn(xp)
       else
         xm = x1
         xp = x0
         fp = fm
         fm = fn(xm)
      endif
c
      n = 0
      fnd = .false.
c
c-----------------------------------------------------------------------
c  Eliminate simple cases.
c-----------------------------------------------------------------------
c
      if (fp*fm.gt.c0) then
         return
c
       elseif (fp.eq.c0) then
         root = xp
         fnd  = .true.
         return
c
       elseif (fm.eq.c0) then
         root = xm
         fnd  = .true.
         return
      endif
c
c-----------------------------------------------------------------------
c  Find root.
c-----------------------------------------------------------------------
c
      do 10 while ((.not.fnd).and.(n.lt.itmax))
c
         root = p5*(xm+xp)
         f    = fn(root)
c
         fnd = ((abs(xp-root).le.(tol*abs(root))) .and. (abs(f).le.tol))
     &         .or. (f.eq.c0)
         n   = n + 1
c
         if (f.lt.c0) then
            xm = root
            fm = f
          else
            xp = root
            fp = f
         endif
c
  10  continue
c
      return
      end
