      subroutine c2f_dat (gfile)
c
c=======================================================================
c                                                                    ===
c  This routine reads in the basic data needed to start the fine     ===
c  grid computation.                                                 ===
c                                                                    ===
c  ------                                                            ===
c  Input:                                                            ===
c  ------                                                            ===
c                                                                    ===
c  Common Blocks:                                                    ===
c                                                                    ===
c  /C2FIO/                                                           ===
c                                                                    ===
c     STDINP  Unit number from which to read data.      (integer)    ===
c     STDOUT  Unit number on which to write messages.   (integer)    ===
c                                                                    ===
c  -------                                                           ===
c  Output:                                                           ===
c  -------                                                           ===
c                                                                    ===
c  GFILE      Name of previously defined coarse GRIDS                ===
c             file.                                     (character)  ===
c                                                                    ===
c  Common Blocks:                                                    ===
c                                                                    ===
c  /FNE_DAT/                                                         ===
c                                                                    ===
c     IMT_F   Number of grid points in x direction,                  ===
c             fine grid.                                (integer)    ===
c     JMT_F   Number of grid points in y direction,                  ===
c             fine grid.                                (integer)    ===
c     LAT_F   Latitude of center of grid, fine grid.    (real; deg)  ===
c     LON_F   Longitude of center of grid, fine grid.   (real; deg)  ===
c                                                                    ===
c  Calls:  CF_EXIT,  ERRIO                                           ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <c2fio.h>
#include <fne_dat.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer       ios
      character*(*) gfile
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c-----------------------------------------------------------------------
c  Read data.
c-----------------------------------------------------------------------
c
      read (stdinp,*,iostat=ios)  imt_f
      call errio (stdout,'C2F_DAT','reading IMT_F',ios)
c
      read (stdinp,*,iostat=ios)  jmt_f
      call errio (stdout,'C2F_DAT','reading JMT_F',ios)
c
      read (stdinp,*,iostat=ios)  lat_f
      call errio (stdout,'C2F_DAT','reading LAT_F',ios)
c
      read (stdinp,*,iostat=ios)  lon_f
      call errio (stdout,'C2F_DAT','reading LON_F',ios)
c
      read (stdinp,10,iostat=ios) gfile
  10  format (a)
      call errio (stdout,'C2F_DAT','reading GFILE',ios)
c
c-----------------------------------------------------------------------
c  Check domain data.
c-----------------------------------------------------------------------
c
      if (mod(imt_f,6).ne.5) write (stdout,900) imt_f
      if (mod(jmt_f,6).ne.0) write (stdout,910) jmt_f
c
      if ((mod(imt_f,6).ne.5).or.(mod(jmt_f,6).ne.0))
     &   call cf_exit ('C2F_DAT')
c
      return
c
 900  format (/'***Error:  C2F_DAT - (IMT_F+1) must be a multiple of 6.'
     &        /11x,'IMT_F = ',i10)
 910  format (/'***Error:  C2F_DAT - JMT_F must be a multiple of 6.'
     &        /11x,'JMT_F = ',i10)
c
      end
