      subroutine c2f_write
c
c=======================================================================
c                                                                    ===
c  This routine writes the results in a readable form.               ===
c                                                                    ===
c  ------                                                            ===
c  Input:                                                            ===
c  ------                                                            ===
c                                                                    ===
c  Common Blocks:                                                    ===
c                                                                    ===
c  /C2FIO/                                                           ===
c                                                                    ===
c     STDOUT  Unit number on which to write messages.   (integer)    ===
c                                                                    ===
c  /CRS_DAT/                                                         ===
c                                                                    ===
c     COORD     Grid type.                            (integer)      ===
c                  [0] cartesian                                     ===
c                  [1] geographic spherical                          ===
c                  [2] rotated spherical                             ===
c     LATC      Latitude of center of transformation. (real; deg)    ===
c     LONC      Longitude of center of transformation.(real; deg)    ===
c     THETA     Angle grid is rotated WRT East.       (real; deg)    ===
c                                                                    ===
c  /FNE_DAT/                                                         ===
c                                                                    ===
c     DDELX    Needed shift to collocate in x-direction. (real;m|deg)===
c     DDELY    Needed shift to collocate in y-direction. (real;m|deg)===
c     DELX_F   X-offset, grid-trans. centers, fine grid. (real;m|deg)===
c     DELY_F   Y-offset, grid-trans. centers, fine grid. (real;m|deg)===
c     GRIDX_F  Grid spacing in x-direction, fine grid.   (real;m|deg)===
c     GRIDY_F  Grid spacing in y-direction, fine grid.   (real;m|deg)===
c     I_LL_C,                                                        ===
c     J_LL_C   Lower left crnr of fine grid in crs grid. (integer)   ===
c     I_UR_C,                                                        ===
c     J_UR_C   Upper right crnr of fne grid in crs grid. (integer)   ===
c     IMT_FC   Number of nested coarse grid x-points.    (integer)   ===
c     IMT_F   Number of grid points in x direction,                  ===
c             fine grid.                                (integer)    ===
c     JMT_FC   Number of nested coarse grid y-points.    (integer)   ===
c     JMT_F   Number of grid points in y direction,                  ===
c             fine grid.                                (integer)    ===
c     WKSP     Data passing work space size.             (integer)   ===
c                                                                    ===
c  Calls:  ERRIO,  HEADLN,  LENGTH                                   ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <c2fio.h>
#include <crs_dat.h>
#include <fne_dat.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer     ios,sbgn,send,slen
      character*5 untstr
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c-----------------------------------------------------------------------
c  Write date header.
c-----------------------------------------------------------------------
c
      call headln (stdout)
c
c-----------------------------------------------------------------------
c  Write fine grid parameters.
c-----------------------------------------------------------------------
c
      write (stdout,10,iostat=ios)
      call errio (stdout,'C2F_WRITE','writing Fine Grid Parameters',ios)
c
      write (stdout,20,iostat=ios) coord,'COORD',' ',
     &            '[0] cart. [1] geo. sph. [2] rotated sph.'
      call errio (stdout,'C2F_WRITE','writing COORD',ios)
c
      if (coord.eq.0) then
         untstr = '(m)'
        else
         untstr = '(deg)'
      end if
      call length (untstr,slen,sbgn,send)
c
      write (stdout,30,iostat=ios) gridx_f,'DX',untstr(sbgn:send),
     &            'Grid spacing in x-direction.'
      call errio (stdout,'C2F_WRITE','writing DX',ios)
c
      write (stdout,30,iostat=ios) gridy_f,'DX',untstr(sbgn:send),
     &            'Grid spacing in y-direction.'
      call errio (stdout,'C2F_WRITE','writing DY',ios)
c
      write (stdout,30,iostat=ios) lonc,'LONC','(deg)',
     &            'Longitude of center of transformation.'
      call errio (stdout,'C2F_WRITE','writing LONC',ios)
c
      write (stdout,30,iostat=ios) latc,'LATC','(deg)',
     &            'Latitude of center of transformation.'
      call errio (stdout,'C2F_WRITE','writing LATC',ios)
c
      write (stdout,30,iostat=ios) delx_f,'DELX',untstr(sbgn:send),
     &            'X-offset, grid-trans. centers.'
      call errio (stdout,'C2F_WRITE','writing DELX',ios)
c
      write (stdout,30,iostat=ios) dely_f,'DELY',untstr(sbgn:send),
     &            'Y-offset, grid-trans. centers.'
      call errio (stdout,'C2F_WRITE','writing DELY',ios)
c
      write (stdout,30,iostat=ios) theta,'ROTANG','(deg)',
     &            'Angle grid is rotated with respect to East.'
      call errio (stdout,'C2F_WRITE','writing ROTANG',ios)
c
      write (stdout,20,iostat=ios) imt_f,'NO_X',' ',
     &            'Number of grid points in x direction.'
      call errio (stdout,'C2F_WRITE','writing NO_X',ios)
c
      write (stdout,20,iostat=ios) jmt_f,'NO_Y',' ',
     &            'Number of grid points in y direction.'
      call errio (stdout,'C2F_WRITE','writing NO_Y',ios)
c
c-----------------------------------------------------------------------
c  Write Fine grid description in coarse grid units.
c-----------------------------------------------------------------------
c
      write (stdout,40,iostat=ios)
      call errio (stdout,'C2F_WRITE','writing Fine Grid in coarse',ios)
c
      write (stdout,50,iostat=ios) 'IMT_FC = ',imt_fc
      call errio (stdout,'C2F_WRITE','writing IMT_FC',ios)
c
      write (stdout,50,iostat=ios) 'JMT_FC = ',jmt_fc
      call errio (stdout,'C2F_WRITE','writing JMT_FC',ios)
c
      write (stdout,60,iostat=ios)
      call errio (stdout,'C2F_WRITE','writing Corners',ios)
c
      write (stdout,50,iostat=ios) 'I_LL_C = ',i_ll_c
      call errio (stdout,'C2F_WRITE','writing I_LL_C',ios)
c
      write (stdout,50,iostat=ios) 'J_LL_C = ',j_ll_c
      call errio (stdout,'C2F_WRITE','writing J_LL_C',ios)
c
      write (stdout,50,iostat=ios) 'I_UR_C = ',i_ur_c
      call errio (stdout,'C2F_WRITE','writing I_UR_C',ios)
c
      write (stdout,50,iostat=ios) 'J_UR_C = ',j_ur_c
      call errio (stdout,'C2F_WRITE','writing J_UR_C',ios)
c
      write (stdout,70,iostat=ios) wksp
      call errio (stdout,'C2F_WRITE','writing Passing Space',ios)
c
c-----------------------------------------------------------------------
c  Write Alternative positioning.
c-----------------------------------------------------------------------
c
      write (stdout,80,iostat=ios)
      call errio (stdout,'C2F_WRITE','writing Alternative position',ios)
c
      write (stdout,90,iostat=ios)'DELX_C = ',(dble(delx_c)-dble(ddelx))
      call errio (stdout,'C2F_WRITE','writing DELX_C',ios)
c
      write (stdout,90,iostat=ios)'DELY_C = ',(dble(dely_c)-dble(ddely))
      call errio (stdout,'C2F_WRITE','writing DELY_C',ios)
c
      write (stdout,90,iostat=ios)'DELX_F = ',(dble(delx_f)-dble(ddelx))
      call errio (stdout,'C2F_WRITE','writing DELX_F',ios)
c
      write (stdout,90,iostat=ios)'DELY_F = ',(dble(dely_f)-dble(ddely))
      call errio (stdout,'C2F_WRITE','writing DELY_F',ios)
c
      return
c
  10  format (/'Fine Grid Parameters:'/)
  20  format (i10,t16,a,t23,a,t29,a)
  30  format (1pe14.7,t16,a,t23,a,t29,a)
  40  format (//'Fine grid description in coarse grid units::'/3x,
     &        'Size:')
  50  format (6x,a,i10)
  60  format (/3x,'Corners:'/)
  70  format (/3x,'Passing Space:'/6x,'xmdat = ',i10,' * km')
  80  format (//'Alternative positioning:'/)
  90  format (6x,a,1pe14.7)
c
      end
