      subroutine chk_pwndo (blon,blat,tlon,tlat,nx,ny,geo_tlon,geo_tlat,
     &                                                  geo_lon,geo_lat)
c
c-------------------------------------------------------------------------------
c     This checks the user supplied plot window to make sure that neither width|
c     is of zero length.  If one is, its limits are replaced by limits to just |
c     contain both grids.                                                      |
c                                                                              |
c     Calls:  none                                                             |
c                                                                              |
c     Parameters:                                                              |
c                                                                              |
c     blat, blon...........Real.  The latitude & longitude of the lower right  |
c                          corner of the plot window.  (degrees) {input/output}|
c     geo_lat, geo_lon.....Real array.  The geographical latitude & longitudes |
c                          of every UV grid point.  (degrees)   {input}        |
c     geo_tlat, geo_tlon...Real array.  The geographical latitude & longitudes |
c                          of every T grid point.  (degrees)   {input}         |
c     nx, ny...............Integer.  Number of grid points in the x & y        |
c                          directions respectively.  {input}                   |
c     tlat, tlon...........Real.  The latitude & longitude of the upper left   |
c                          corner of the plot window.  (degrees) {input/output}|
c-------------------------------------------------------------------------------
c
#include <gridsparm.h>
#include <gridsio.h>
c
      real tlon,tlat,blon,blat,geo_tlon(imt,jmt),geo_tlat(imt,jmt),
     &     geo_lon(imt,jmt),geo_lat(imt,jmt),lonmin,lonmax,latmin,latmax
      integer nx,ny,i,j
c
c=======================================================================
c     Begin executable code.                                           #
c=======================================================================
c
c-----------------------------------------------------------------------
c     If longitudinal length of the plot window is zero, reset         |
c     reset longitudinal limits to contain UV & T grids.               |
c-----------------------------------------------------------------------
c
      if (blon .eq. tlon) then
c
         lonmin = geo_lon(1,1)
         lonmax = lonmin
c
         do 10 i = 1, nx
c
            lonmin = min (lonmin,geo_lon(i,1),geo_lon(i,ny),
     &                                    geo_tlon(i,1),geo_tlon(i,ny))
            lonmax = max (lonmax,geo_lon(i,1),geo_lon(i,ny),
     &                                    geo_tlon(i,1),geo_tlon(i,ny))
c
 10      continue
c
         do 20 j = 1, ny
c
            lonmin = min (lonmin,geo_lon(1,j),geo_lon(nx,j),
     &                                    geo_tlon(1,j),geo_tlon(nx,j))
            lonmax = max (lonmax,geo_lon(1,j),geo_lon(nx,j),
     &                                    geo_tlon(1,j),geo_tlon(nx,j))
c
 20      continue
c
         tlon = lonmin
         blon = lonmax
c
         write (out_unit,50) 'longitudinal','blon',blon,'tlon',tlon
c
      end if
c
c-----------------------------------------------------------------------
c     If latitudinal length of the plot window is zero, reset          |
c     reset latitudinal limits to contain UV & T grids.                |
c-----------------------------------------------------------------------
c
      if (blat .eq. tlat) then
c
         latmin = geo_lat(1,1)
         latmax = latmin
c
         do 30 i = 1, nx
c
            latmin = min (latmin,geo_lat(i,1),geo_lat(i,ny),
     &                                    geo_tlat(i,1),geo_tlat(i,ny))
            latmax = max (latmax,geo_lat(i,1),geo_lat(i,ny),
     &                                    geo_tlat(i,1),geo_tlat(i,ny))
c
 30      continue
c
         do 40 j = 1, ny
c
            latmin = min (latmin,geo_lat(1,j),geo_lat(nx,j),
     &                                    geo_tlat(1,j),geo_tlat(nx,j))
            latmax = max (latmax,geo_lat(1,j),geo_lat(nx,j),
     &                                    geo_tlat(1,j),geo_tlat(nx,j))
c
 40      continue
c
         blat = latmin
         tlat = latmax
c
         write (out_unit,50) 'latitudinal','blat',blat,'tlat',tlat
c
      end if
#ifdef sunflush
      call flush (out_unit)
#endif
c
      return
c
 50   format (/'Resetting plot windows ',a,' limits:',2(/3x,a,
     &                                                     ' = ',f13.8))
c
      end
