      subroutine chk_tfile (topo_outfile)
c
c=======================================================================
c                                                                    ===
c  This routine checks to see if the topography input and output     ===
c  files are different.                                              ===
c                                                                    ===
c  ------                                                            ===
c  Input:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     TOPO_OUTFILE   Name of the topography output file.   (string)  ===
c                                                                    ===
c  Common Blocks:                                                    ===
c                                                                    ===
c  /GRIDSIO/                                                         ===
c                                                                    ===
c     TOPO_INFILE    Name of the topography input file.    (string)  ===
c                                                                    ===
c  ------                                                            ===
c  Calls:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     HOPS:    GR_EXIT,  LENGTH                                      ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data
c-----------------------------------------------------------------------
c
#include <gridsio.h>
c
c-----------------------------------------------------------------------
c  Define local data
c-----------------------------------------------------------------------
c
      character*(*) topo_outfile
      integer       tibgn,tiend,tilen,tobgn,toend,tolen
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c-----------------------------------------------------------------------
c  Make sure each file is valid.
c-----------------------------------------------------------------------
c
c  Check input file name.
c
      call length (topo_infile,tilen,tibgn,tiend)
c
      if (tilen.lt.1) write (out_unit,10) 'archive topography'
c
c  Check output file name.
c
      call length (topo_outfile,tolen,tobgn,toend)
c
      if (tolen.lt.1) write (out_unit,10) 'GRIDS output'
c
c  Kill process if either is invalid.
c
      if (min(tilen,tolen).lt.1) call gr_exit ('CHK_TFILE')
c
c-----------------------------------------------------------------------
c  Make sure filenames are distinct.
c-----------------------------------------------------------------------
c
      if (topo_infile(tibgn:tiend) .eq. topo_outfile(tobgn:toend)) then
         write (out_unit,20) topo_infile(tibgn:tiend),
     &                       topo_outfile(tobgn:toend)
         call gr_exit ('CHK_TFILE')
      end if
c
      return
c
  10  format (/'***Error:  CHK_TFILE - empty ',a,' netCDF filename')
  20  format (/'***Error:  CHK_TFILE - idential input/output filenames'/
     &        11x,'archive topography file: ',1h",a,1h"/
     &        11x,'GRIDS output file:       ',1h",a,1h")
c
      end
