      subroutine cntr_lbl (no_cl,cint)
c
c=======================================================================
c                                                                    ===
c  This subroutine labels the contour plot if contour levels are not ===
c  individually specified by the user.                               ===
c                                                                    ===
c  ------                                                            ===
c  Input:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     CINT    Contour level.                   (real; m)             ===
c     NO_CL   Number of contour levels used.   (integer)             ===
c                                                                    ===
c  Common Blocks:                                                    ===
c                                                                    ===
c  /CNTLBL/                                                          ===
c                                                                    ===
c     GRFB   Device coordinate of bottom of graph area.   (real)     ===
c     GRFL   Device coordinate of left of graph area.     (real)     ===
c     GRFR   Device coordinate of right of graph area.    (real)     ===
c     GRFT   Device coordinate of top of graph area.      (real)     ===
c     XMAX   World coordinate of right of graph area.     (real)     ===
c     XMIN   World coordinate of left of graph area.      (real)     ===
c     YMAX   World coordinate of top of graph area.       (real)     ===
c     YMIN   World coordinate of bottom of graph area.    (real)     ===
c                                                                    ===
c  ------                                                            ===
c  Calls:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     HOPS:    LENGTH,  NO_DIGIT,  TOP_KEY                           ===
c     NCAR:    CPGETI,  CPGETR,    CPSETI,   PLCHHQ,   SET           ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <gpconst.h>
#include <cntlbl.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      real    c,c7,cint,cmax,cmin,y
      integer n,nline,no_cl,sbgn,send,slen
      integer      no_digit
      character*25 fmt,string
c
      parameter (c7=7.0)
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c-----------------------------------------------------------------------
c  Get contouring data.
c-----------------------------------------------------------------------
c
c  Find contour limits
c
      call cpgeti ('NCL - Number of Contour Levels',nline)
c
      if (nline.lt.1) return
c
      call cpseti ('PAI - Parameter Array Index',1)
      call cpgetr ('CLV - Contour Level Value',cmax)
      cmin = cmax
      do 10 n = 2, nline
         call cpseti ('PAI - Parameter Array Index',n)
         call cpgetr ('CLV - Contour Level Value',c)
         cmax = max (cmax, c)
         cmin = min (cmin, c)
  10  continue
c
c  If NCAR specified the contour interval, get it.
c
      if (no_cl.eq.0) then
         call cpgetr ('CIU - Contour Interval Used',cint)
      end if
c
c-----------------------------------------------------------------------
c  Write minimum, maximum depths and contour interval.
c-----------------------------------------------------------------------
c
c  Set sub-window for providing contour data.
c
      y = grfb + c2*(grft-grfb)/c3
      y = max (y, (grft-p1))
      if (no_cl.le.c0) then
         nline = 3
       else
         nline = 2
      end if
      call set (grfr,grfr+p1,y,grft,c0,c1,c0,float(nline+1),1)
c
c  Provide contour data.
c
      y = float(nline)
      write (fmt,20) no_digit(int(cmax))+2,1
      write (string,fmt) 'Cmax ',cmax,'m'
      call length (string,slen,sbgn,send)
      call plchhq (c0,y,string(sbgn:send),c7,c0,cm1)
c
      if (no_cl .le. c0) then
         write (fmt,20) no_digit(int(cint))+2,1
         write (string,fmt) 'Cint ',cint,'m'
         call length (string,slen,sbgn,send)
         y = y - c1
         call plchhq (c0,y,string(sbgn:send),c7,c0,cm1)
      end if
c
      write (fmt,20) no_digit(int(cmin))+2,1
      write (string,fmt) 'Cmin ',cmin,'m'
      call length (string,slen,sbgn,send)
      y = y - c1
      call plchhq (c0,y,string(sbgn:send),c7,c0,cm1)
c
c-----------------------------------------------------------------------
c  Write dash pattern key and reset plot window.
c-----------------------------------------------------------------------
c
c  Provide pattern key data.
c
      call top_key  (grfl,grfr,grfb,grft)
c
c  Reset window for regular plotting.
c
      call set (grfl,grfr,grfb,grft,xmin,xmax,ymin,ymax,1)
c
      return
c
  20  format ('(a,f',i2,'.',i2,',a)')
c
      end
