      subroutine cont_data (max_cl,no_cl,block_cl,radx,rady,clvl,clmin,
     &                                                            clint)
c
c-------------------------------------------------------------------------------
c     This routine reads the data needed to set up contour plots.              |
c                                                                              |
c     Calls:  vec_read_f                                                       |
c                                                                              |
c     Arguments:                                                               |
c                                                                              |
c     block_cl...Logical.  Indicates whether or not to block the drawing of    |
c                   contour lines through labels.   {output}                   |
c                      block_cl = .true.   =>  block lines through labels.     |
c                      block_cl = .false.  =>  do NOT block.                   |
c     clint......Real.  Contour interval.  (Only used if no_cl < 0)   {output} |
c     clmin......Real.  Minimum contour level.  (Only used if no_cl < 0)       |
c                   {output}                                                   |
c     clvl.......Real array.  User specified contour levels.                   |
c                   (Only used if no_cl > 0)   {output}                        |
c     max_cl.....Integer.  Maximum number of user specified contour lines.     |
c                   {input}                                                    |
c     no_cl......Integer.  Number of user specified contour lines.   {output}  |
c     radx.......Integer.  High/low search radius in x.   {output}             |
c     rady.......Integer.  High/low search radius in y.   {output}             |
c-------------------------------------------------------------------------------
c
#include <gridsio.h>
c
      integer no_cl,max_cl,i,radx,rady
      real    clvl(max_cl),clmin,clint
      logical block_cl
c
c=======================================================================
c     Begin executable code.                                           #
c=======================================================================
c
c-----------------------------------------------------------------------
c     Read number of specified levels, whether or not to block the     |
c     drawing of contour lines through labels and the high/low search  |
c     radii in the x & y directions.                                   |
c-----------------------------------------------------------------------
c
      read (in_unit,*) no_cl
      read (in_unit,*) block_cl
      read (in_unit,*) radx
      read (in_unit,*) rady
c
      write (out_unit,20) no_cl,block_cl,radx,rady
c
      if (no_cl .gt. 0) then
c
c-----------------------------------------------------------------------
c        User specifies each contour level individually.               |
c-----------------------------------------------------------------------
c
         call vec_read_f (clvl,max_cl,no_cl,'contour levels',in_unit,
     &                                                         out_unit)
c
         write (out_unit,30)
c
         do 10 i = 1, no_cl
            write (out_unit,40) i,clvl(i)
 10      continue
c
        else if (no_cl .lt. 0) then
c
c-----------------------------------------------------------------------
c        User specifies contour levels from minimum level and contour  |
c        interval.                                                     |
c-----------------------------------------------------------------------
c
         read (in_unit,*) clmin
         read (in_unit,*) clint
         write (out_unit,50) clmin,clint
c
        else
c
c-----------------------------------------------------------------------
c        Contour levels picked automatically.                          |
c-----------------------------------------------------------------------
c
         write (out_unit,60)
c
      end if
#ifdef sunflush
      call flush (out_unit)
#endif
c
      return
c
 20   format (/3x,'Number of contour levels = ',i10/3x,'Block contour ',
     &        'lines through high/low labels:  ',l1/3x,'High/low search'
     &       ,' radius in x = ',i10/3x,'High/low search radius in y = ',
     &                                                              i10)
 30   format (/3x,'User specified irregular contours.'/5x,'index',7x,
     &                                                      'level')
 40   format (6x,i3,3x,1pg14.7)
 50   format (/3x,'User specified regular contours.'/6x,'Minimum contou'
     &           ,'r level:  ',1pg12.5/6x,'Contour interval:  ',1pg12.5)
 60   format (/3x,'Contour levels automatically picked.')
c
      end
