       subroutine defcdf (fname,coord,no_x,no_y,dx,dy,lonc,latc,delx,
     &                    dely,rotang,no_lvl,hybrid)
c
c=======================================================================
c                                                                    ===
c  This routine creates the GRIDS netCDF output file, defines the    ===
c  netCDF dimensions,  defines  the geometry (coordinates) variables ===
c  and their attributes.                                             ===
c                                                                    ===
c  ------                                                            ===
c  Input:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     COORD    Flag for type of grid.                     (integer)  ===
c                 [0]  cartesian (tangent plane) grid.               ===
c                 [1]  geographic spherical grid.                    ===
c                 [2]  rotated spherical grid.                       ===
c     DELX,                                                          ===
c     DELY     Offset from transformation point to                   ===
c              grid center.                               (real)     ===
c     DX       Mean grid spacing in x-direction.          (real)     ===
c     DY       Mean grid spacing in y-direction.          (real)     ===
c     FNAME    Name for NETCDF output file.               (character)===
c     HYBRID   Switch for terrain following coordinates.  (logical)  ===
c     LATC     Transformation central latitude.           (real)     ===
c     LONC     Transformation central longitude.          (real)     ===
c     NO_LVL   Number of vertical levels.                 (integer)  ===
c     NO_X     Number of gridpoints in x-direction.       (integer)  ===
c     NO_Y     Number of gridpoints in y-direction.       (integer)  ===
c     ROTANG   Domain rotation angle.                     (real)     ===
c                                                                    ===
c  Common Blocks:                                                    ===
c                                                                    ===
c  /GRIDSIO/                                                         ===
c                                                                    ===
c     TOPO_INFILE   Name of topography archive file.   (character)   ===
c                                                                    ===
c  /TITLES/                                                          ===
c                                                                    ===
c     CNTR_TTL   Title of the contour plot.           (character)    ===
c     GRD_TTL    Title of the grid plot.              (character)    ===
c     STP_TTL    Title of the step topography plot.   (character)    ===
c                                                                    ===
c  /VERSION/                                                         ===
c                                                                    ===
c     MODEL   The name of the model or code.   (character)           ===
c     VNUM    The current version number.      (character)           ===
c                                                                    ===
c  -------                                                           ===
c  Output:                                                           ===
c  -------                                                           ===
c                                                                    ===
c  Common Blocks:                                                    ===
c                                                                    ===
c  /GRIDSIO/                                                         ===
c                                                                    ===
c     NCOUTID   Identifier number for netCDF output file.  (integer) ===
c     NCSTAT    Status flag for netCDF output file.        (integer) ===
c                                                                    ===
c  ------                                                            ===
c  Calls:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     HOPS:    GR_EXIT,         LENGTH                               ===
c     netCDF:  NF_CREATE,       NF_DEF_DIM,       NF_DEF_VAR,        ===
c              NF_ENDDEF,       NF_INQ_VARID,     NF_PUT_ATT_TEXT,   ===
c              NF_PUT_VAR_INT,  NF_PUT_VAR_REAL,  NF_PUT_VAR_TEXT    ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data
c-----------------------------------------------------------------------
c
#include <gridsparm.h>
#include <gridsio.h>
#include <netcdf.inc>
#include <titles.h>
#include <version.h>
c
c-----------------------------------------------------------------------
c  Define local data
c-----------------------------------------------------------------------
c
      real
     &        delx,dely,dx,dy,latc,lonc,rotang
      integer ax2dim,ax3dim,coord,levdim,no_x,no_y,no_lvl,sbgn,send,
     &        slen,sysdim,tg2did,tlatdim,tlondim,varid,vg2did,vlatdim,
     &        vlondim
      integer tgrd2d(3),tgrd3d(4),vgrd2d(3),vgrd3d(4)
      logical     hybrid
      character*1  dum
      character*44  stamp
      character*256 wkstr
      character*(*) fname
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c-----------------------------------------------------------------------
c  Create netCDF file.
c-----------------------------------------------------------------------
c
c  Make sure supplied name is valid.
c
      call length (fname,slen,sbgn,send)
c
      if (slen.lt.1) then
         write (out_unit,5)
         call gr_exit ('DEFCDF')
      end if
c
c  Create netCDF file.
c
      if (nf_create(fname(sbgn:send),NF_CLOBBER,ncoutid) .eq. NF_NOERR)
     &                                                              then
         ncstat = 1
       else
         write (out_unit,10) fname(sbgn:send)
         call gr_exit ('DEFCDF')
      end if
c
c-----------------------------------------------------------------------
c  Define the dimensions of the netCDF fields.
c-----------------------------------------------------------------------
c
      if (nf_def_dim (ncoutid,'tlat',no_y,tlatdim) .ne. NF_NOERR) then
         write (out_unit,20) 'tlat'
         call gr_exit ('DEFCDF')
      end if
c
      if (nf_def_dim (ncoutid,'tlon',no_x,tlondim) .ne. NF_NOERR) then
         write (out_unit,20) 'tlon'
         call gr_exit ('DEFCDF')
      end if
c
      if (nf_def_dim (ncoutid,'vlat',no_y,vlatdim) .ne. NF_NOERR) then
         write (out_unit,20) 'vlat'
         call gr_exit ('DEFCDF')
      end if
c
      if (nf_def_dim (ncoutid,'vlon',no_x,vlondim) .ne. NF_NOERR) then
         write (out_unit,20) 'vlon'
         call gr_exit ('DEFCDF')
      end if
c
      if (nf_def_dim (ncoutid,'level',no_lvl,levdim) .ne. NF_NOERR) then
         write (out_unit,20) 'level'
         call gr_exit ('DEFCDF')
      end if
c
      if (nf_def_dim (ncoutid,'axis2',2,ax2dim) .ne. NF_NOERR) then
         write (out_unit,20) 'axis2'
         call gr_exit ('DEFCDF')
      end if
c
      if (nf_def_dim (ncoutid,'axis3',3,ax3dim) .ne. NF_NOERR) then
         write (out_unit,20) 'axis3'
         call gr_exit ('DEFCDF')
      end if
c
      if (hybrid) then
         if (nf_def_dim (ncoutid,'system',2,sysdim) .ne. NF_NOERR) then
            write (out_unit,20) 'system'
            call gr_exit ('DEFCDF')
         end if
      end if
c
c-----------------------------------------------------------------------
c  Define dimension vectors for tracer and velocity type variables.
c-----------------------------------------------------------------------
c
      tgrd2d(1) = ax2dim
      tgrd2d(2) = tlondim
      tgrd2d(3) = tlatdim
c
      tgrd3d(1) = ax3dim
      tgrd3d(2) = levdim
      tgrd3d(3) = tlondim
      tgrd3d(4) = tlatdim
c
      vgrd2d(1) = ax2dim
      vgrd2d(2) = vlondim
      vgrd2d(3) = vlatdim
c
      vgrd3d(1) = ax3dim
      vgrd3d(2) = levdim
      vgrd3d(3) = vlondim
      vgrd3d(4) = vlatdim
c
c-----------------------------------------------------------------------
c  Define titles and scalar variables and their attributes in the
c  netCDF file.
c-----------------------------------------------------------------------
c
c-----------------------------------------------------------------------
c  Put global title to netCDF file.
c-----------------------------------------------------------------------
c
      wkstr = 'Grid definition for PE model'
      call length (wkstr,slen,sbgn,send)
      if (nf_put_att_text (ncoutid,NF_GLOBAL,'title',slen,
     &                     wkstr(sbgn:send)) .ne. NF_NOERR) then
         write (out_unit,20) 'NF_GLOBAL:title'
         call gr_exit ('DEFCDF')
      end if
c
      call length (fname,slen,sbgn,send)
      if (nf_put_att_text (ncoutid,NF_GLOBAL,'name',slen,
     &                     fname(sbgn:send)) .ne. NF_NOERR) then
         write (out_unit,20) 'NF_GLOBAL:name'
         call gr_exit ('DEFCDF')
      end if
c
      call get_date (stamp)
      call length (stamp,slen,sbgn,send)
      if (slen.gt.0) then
         if (nf_put_att_text (ncoutid,NF_GLOBAL,'creation_date',slen,
     &                        stamp(sbgn:send)) .ne. NF_NOERR) then
            write (out_unit,20) 'NF_GLOBAL:creation_date'
            call gr_exit ('DEFCDF')
         end if
      end if
c
      call length (model,slen,sbgn,send)
      if (nf_put_att_text (ncoutid,NF_GLOBAL,'type',slen,
     &                     model(sbgn:send)) .ne. NF_NOERR) then
         write (out_unit,20) 'NF_GLOBAL:type'
         call gr_exit ('DEFCDF')
      end if
c
      call length (vnum,slen,sbgn,send)
      if (nf_put_att_text (ncoutid,NF_GLOBAL,'version',slen,
     &                     vnum(sbgn:send)) .ne. NF_NOERR) then
         write (out_unit,20) 'NF_GLOBAL:version'
         call gr_exit ('DEFCDF')
      end if
c
      call length (topo_infile,slen,sbgn,send)
      if (nf_put_att_text (ncoutid,NF_GLOBAL,'topo_infile',slen,
     &                     topo_infile(sbgn:send)) .ne. NF_NOERR) then
         write (out_unit,20) 'NF_GLOBAL:topo_infile'
         call gr_exit ('DEFCDF')
      end if
c
      wkstr = 'positive east'
      call length (wkstr,slen,sbgn,send)
      if (nf_put_att_text (ncoutid,NF_GLOBAL,'longitude_convention',
     &                     slen,wkstr(sbgn:send)) .ne. NF_NOERR) then
         write (out_unit,20) 'NF_GLOBAL:longitude_convention'
         call gr_exit ('DEFCDF')
      end if
c
      wkstr = 'positive north'
      call length (wkstr,slen,sbgn,send)
      if (nf_put_att_text (ncoutid,NF_GLOBAL,'latitude_convention',
     &                     slen,wkstr(sbgn:send)) .ne. NF_NOERR) then
         write (out_unit,20) 'NF_GLOBAL:latitude_convention'
         call gr_exit ('DEFCDF')
      end if
c
      wkstr = 'positive above sea-level'
      call length (wkstr,slen,sbgn,send)
      if (nf_put_att_text (ncoutid,NF_GLOBAL,'vertical_convention',slen,
     &                     wkstr(sbgn:send)) .ne. NF_NOERR) then
         write (out_unit,20) 'NF_GLOBAL:vertical_convention'
         call gr_exit ('DEFCDF')
      end if
c
      call length (grd_ttl,slen,sbgn,send)
      if (nf_put_att_text (ncoutid,NF_GLOBAL,'grid_title',slen,
     &                     grd_ttl(sbgn:send)) .ne. NF_NOERR) then
         write (out_unit,20) 'NF_GLOBAL:grid_title'
         call gr_exit ('DEFCDF')
      end if
c
      call length (cntr_ttl,slen,sbgn,send)
      if (nf_put_att_text (ncoutid,NF_GLOBAL,'topo_title',slen,
     &                     cntr_ttl(sbgn:send)) .ne. NF_NOERR) then
         write (out_unit,20) 'NF_GLOBAL:topo_title'
         call gr_exit ('DEFCDF')
      end if
c
      call length (stp_ttl,slen,sbgn,send)
      if (nf_put_att_text (ncoutid,NF_GLOBAL,'vert_title',slen,
     &                     stp_ttl(sbgn:send)) .ne. NF_NOERR) then
         write (out_unit,20) 'NF_GLOBAL:vert_title'
         call gr_exit ('DEFCDF')
      end if
c
c-----------------------------------------------------------------------
c  Define PE model parameters.
c-----------------------------------------------------------------------
c
      if (nf_def_var(ncoutid,'imt',NF_INT,0,0,varid) .ne. NF_NOERR) then
         write (out_unit,20) 'imt'
         call gr_exit ('DEFCDF')
      end if
      wkstr = 'Number of tracer points in the x-direction'
      call length (wkstr,slen,sbgn,send)
      if (nf_put_att_text (ncoutid,varid,'long_name',slen,
     &                     wkstr(sbgn:send)) .ne. NF_NOERR) then
         write (out_unit,20) 'imt:long_name'
         call gr_exit ('DEFCDF')
      end if
c
      if (nf_def_var(ncoutid,'jmt',NF_INT,0,0,varid) .ne. NF_NOERR) then
         write (out_unit,20) 'jmt'
         call gr_exit ('DEFCDF')
      end if
      wkstr = 'Number of tracer points in the y-direction'
      call length (wkstr,slen,sbgn,send)
      if (nf_put_att_text (ncoutid,varid,'long_name',slen,
     &                     wkstr(sbgn:send)) .ne. NF_NOERR) then
         write (out_unit,20) 'jmt:long_name'
         call gr_exit ('DEFCDF')
      end if
c
      if (nf_def_var(ncoutid,'km',NF_INT,0,0,varid) .ne. NF_NOERR) then
         write (out_unit,20) 'km'
         call gr_exit ('DEFCDF')
      end if
      wkstr = 'Number of vertical levels'
      call length (wkstr,slen,sbgn,send)
      if (nf_put_att_text (ncoutid,varid,'long_name',slen,
     &                     wkstr(sbgn:send)) .ne. NF_NOERR) then
         write (out_unit,20) 'km:long_name'
         call gr_exit ('DEFCDF')
      end if
c
c-----------------------------------------------------------------------
c  Define model domain parameters.
c-----------------------------------------------------------------------
c
      if (nf_def_var (ncoutid,'coord',NF_INT,0,0,varid) .ne. NF_NOERR)
     &                                                              then
         write (out_unit,20) 'coord'
         call gr_exit ('DEFCDF')
      end if
      wkstr = 'Flag for type of horizontal grid'
      call length (wkstr,slen,sbgn,send)
      if (nf_put_att_text (ncoutid,varid,'long_name',slen,
     &                     wkstr(sbgn:send)) .ne. NF_NOERR) then
         write (out_unit,20) 'coord:long_name'
         call gr_exit ('DEFCDF')
      end if
      wkstr = 'Cartesian (tangent plane) grid'
      call length (wkstr,slen,sbgn,send)
      if (nf_put_att_text (ncoutid,varid,'option_0',slen,
     &                     wkstr(sbgn:send)) .ne. NF_NOERR) then
         write (out_unit,20) 'coord:option_0'
         call gr_exit ('DEFCDF')
      end if
      wkstr = 'Unrotated spherical grid'
      call length (wkstr,slen,sbgn,send)
      if (nf_put_att_text (ncoutid,varid,'option_1',slen,
     &                     wkstr(sbgn:send)) .ne. NF_NOERR) then
         write (out_unit,20) 'coord:option_1'
         call gr_exit ('DEFCDF')
      end if
      wkstr = 'Rotated spherical grid'
      call length (wkstr,slen,sbgn,send)
      if (nf_put_att_text (ncoutid,varid,'option_2',slen,
     &                     wkstr(sbgn:send)) .ne. NF_NOERR) then
         write (out_unit,20) 'coord:option_2'
         call gr_exit ('DEFCDF')
      end if
c
      if (nf_def_var (ncoutid,'rlngd',NF_FLOAT,0,0,varid) .ne. NF_NOERR)
     &                                                              then
         write (out_unit,20) 'rlngd'
         call gr_exit ('DEFCDF')
      end if
      wkstr = 'Transformation centroid longitude'
      call length (wkstr,slen,sbgn,send)
      if (nf_put_att_text (ncoutid,varid,'long_name',slen,
     &                     wkstr(sbgn:send)) .ne. NF_NOERR) then
         write (out_unit,20) 'rlngd:long_name'
         call gr_exit ('DEFCDF')
      end if
      wkstr = 'degrees_east'
      call length (wkstr,slen,sbgn,send)
      if (nf_put_att_text (ncoutid,varid,'units',slen,
     &                     wkstr(sbgn:send)) .ne. NF_NOERR) then
         write (out_unit,20) 'rlngd:units'
         call gr_exit ('DEFCDF')
      end if
c
      if (nf_def_var (ncoutid,'rlatd',NF_FLOAT,0,0,varid) .ne. NF_NOERR)
     &                                                              then
         write (out_unit,20) 'rlatd'
         call gr_exit ('DEFCDF')
      end if
      wkstr = 'Transformation centroid latitude'
      call length (wkstr,slen,sbgn,send)
      if (nf_put_att_text (ncoutid,varid,'long_name',slen,
     &                     wkstr(sbgn:send)) .ne. NF_NOERR) then
         write (out_unit,20) 'rlatd:long_name'
         call gr_exit ('DEFCDF')
      end if
      wkstr = 'degrees_north'
      call length (wkstr,slen,sbgn,send)
      if (nf_put_att_text (ncoutid,varid,'units',slen,
     &                     wkstr(sbgn:send)) .ne. NF_NOERR) then
         write (out_unit,20) 'rlatd:units'
         call gr_exit ('DEFCDF')
      end if
c
      if (nf_def_var (ncoutid,'delx',NF_FLOAT,0,0,varid) .ne. NF_NOERR)
     &                                                              then
         write (out_unit,20) 'delx'
         call gr_exit ('DEFCDF')
      end if
      wkstr = 'X-offset from transformation point to grid center'
      call length (wkstr,slen,sbgn,send)
      if (nf_put_att_text (ncoutid,varid,'long_name',slen,
     &                     wkstr(sbgn:send)) .ne. NF_NOERR) then
         write (out_unit,20) 'delx:long_name'
         call gr_exit ('DEFCDF')
      end if
      if (coord.ne.0) then
         wkstr = 'degrees'
       else
         wkstr = 'meters'
      end if
      call length (wkstr,slen,sbgn,send)
      if (nf_put_att_text (ncoutid,varid,'units',slen,
     &                     wkstr(sbgn:send)) .ne. NF_NOERR) then
         write (out_unit,20) 'delx:units'
         call gr_exit ('DEFCDF')
      end if
c
      if (nf_def_var (ncoutid,'dely',NF_FLOAT,0,0,varid) .ne. NF_NOERR)
     &                                                              then
         write (out_unit,20) 'dely'
         call gr_exit ('DEFCDF')
      end if
      wkstr = 'Y-offset from transformation point to grid center'
      call length (wkstr,slen,sbgn,send)
      if (nf_put_att_text (ncoutid,varid,'long_name',slen,
     &                     wkstr(sbgn:send)) .ne. NF_NOERR) then
         write (out_unit,20) 'dely:long_name'
         call gr_exit ('DEFCDF')
      end if
      if (coord.ne.0) then
         wkstr = 'degrees'
       else
         wkstr = 'meters'
      end if
      call length (wkstr,slen,sbgn,send)
      if (nf_put_att_text (ncoutid,varid,'units',slen,
     &                     wkstr(sbgn:send)) .ne. NF_NOERR) then
         write (out_unit,20) 'dely:units'
         call gr_exit ('DEFCDF')
      end if
c
      if (nf_def_var (ncoutid,'thetad',NF_FLOAT,0,0,varid) .ne.
     &                                                    NF_NOERR) then
         write (out_unit,20) 'thetad'
         call gr_exit ('DEFCDF')
      end if
      wkstr = 'Domain rotation angle'
      call length (wkstr,slen,sbgn,send)
      if (nf_put_att_text (ncoutid,varid,'long_name',slen,
     &                     wkstr(sbgn:send)) .ne. NF_NOERR) then
         write (out_unit,20) 'thetad:long_name'
         call gr_exit ('DEFCDF')
      end if
      wkstr = 'degrees'
      call length (wkstr,slen,sbgn,send)
      if (nf_put_att_text (ncoutid,varid,'units',slen,
     &                     wkstr(sbgn:send)) .ne. NF_NOERR) then
         write (out_unit,20) 'thetad:units'
         call gr_exit ('DEFCDF')
      end if
c
      if (nf_def_var (ncoutid,'meandx',NF_FLOAT,0,0,varid) .ne.
     &                                                    NF_NOERR) then
         write (out_unit,20) 'meandx'
         call gr_exit ('DEFCDF')
      end if
      wkstr = 'Mean x-grid spacing'
      call length (wkstr,slen,sbgn,send)
      if (nf_put_att_text (ncoutid,varid,'long_name',slen,
     &                     wkstr(sbgn:send)) .ne. NF_NOERR) then
         write (out_unit,20) 'meandx:long_name'
         call gr_exit ('DEFCDF')
      end if
      if (coord.ne.0) then
         wkstr = 'degrees'
       else
         wkstr = 'meters'
      end if
      call length (wkstr,slen,sbgn,send)
      if (nf_put_att_text (ncoutid,varid,'units',slen,
     &                     wkstr(sbgn:send)) .ne. NF_NOERR) then
         write (out_unit,20) 'meandx:units'
         call gr_exit ('DEFCDF')
      end if
c
      if (nf_def_var (ncoutid,'meandy',NF_FLOAT,0,0,varid) .ne.
     &                                                    NF_NOERR) then
         write (out_unit,20) 'meandy'
         call gr_exit ('DEFCDF')
      end if
      wkstr = 'Mean y-grid spacing'
      call length (wkstr,slen,sbgn,send)
      if (nf_put_att_text (ncoutid,varid,'long_name',slen,
     &                     wkstr(sbgn:send)) .ne. NF_NOERR) then
         write (out_unit,20) 'meandy:long_name'
         call gr_exit ('DEFCDF')
      end if
      if (coord.ne.0) then
         wkstr = 'degrees'
       else
         wkstr = 'meters'
      end if
      call length (wkstr,slen,sbgn,send)
      if (nf_put_att_text (ncoutid,varid,'units',slen,
     &                     wkstr(sbgn:send)) .ne. NF_NOERR) then
         write (out_unit,20) 'meandy:units'
         call gr_exit ('DEFCDF')
      end if
c
c-----------------------------------------------------------------------
c  Define double vertical coordinate transformation parameters.
c-----------------------------------------------------------------------
c
      if (nf_def_var (ncoutid,'hybrid',ncchar,0,0,varid) .ne. NF_NOERR)
     &                                                              then
         write (out_unit,20) 'hybrid'
         call gr_exit ('DEFCDF')
      end if
      wkstr = 'Flag for type of vertical coordinate system'
      call length (wkstr,slen,sbgn,send)
      if (nf_put_att_text (ncoutid,varid,'long_name',slen,
     &                     wkstr(sbgn:send)) .ne. NF_NOERR) then
         write (out_unit,20) 'hybrid:long_name'
         call gr_exit ('DEFCDF')
      end if
      wkstr = 'Terrain following coordinate system'
      call length (wkstr,slen,sbgn,send)
      if (nf_put_att_text (ncoutid,varid,'option_T',slen,
     &                     wkstr(sbgn:send)) .ne. NF_NOERR) then
         write (out_unit,20) 'hybrid:option_T'
         call gr_exit ('DEFCDF')
      end if
      wkstr = 'Flat (pressure) level coordinate system'
      call length (wkstr,slen,sbgn,send)
      if (nf_put_att_text (ncoutid,varid,'option_F',slen,
     &                     wkstr(sbgn:send)) .ne. NF_NOERR) then
         write (out_unit,20) 'hybrid:option_F'
         call gr_exit ('DEFCDF')
      end if
c
      if (hybrid) then
c
         if (nf_def_var (ncoutid,'kc',NF_INT,0,0,varid) .ne. NF_NOERR)
     &                                                              then
            write (out_unit,20) 'kc'
            call gr_exit ('DEFCDF')
         end if
         wkstr = 'Number of levels in upper system'
         call length (wkstr,slen,sbgn,send)
         if (nf_put_att_text (ncoutid,varid,'long_name',slen,
     &                        wkstr(sbgn:send)) .ne. NF_NOERR) then
            write (out_unit,20) 'kc:long_name'
            call gr_exit ('DEFCDF')
         end if
c
         if (nf_def_var (ncoutid,'flat',ncchar,0,0,varid) .ne. NF_NOERR)
     &                                                              then
            write (out_unit,20) 'flat'
            call gr_exit ('DEFCDF')
         end if
         wkstr = 'Flag for type of terrain following system'
         call length (wkstr,slen,sbgn,send)
         if (nf_put_att_text (ncoutid,varid,'long_name',slen,
     &                        wkstr(sbgn:send)) .ne. NF_NOERR) then
            write (out_unit,20) 'flat:long_name'
            call gr_exit ('DEFCDF')
         end if
         wkstr = 'Hybrid-sigma levels'
         call length (wkstr,slen,sbgn,send)
         if (nf_put_att_text (ncoutid,varid,'option_T',slen,
     &                        wkstr(sbgn:send)) .ne. NF_NOERR) then
            write (out_unit,20) 'flat:option_T'
            call gr_exit ('DEFCDF')
         end if
         wkstr = 'Double-sigma levels'
         call length (wkstr,slen,sbgn,send)
         if (nf_put_att_text (ncoutid,varid,'option_F',slen,
     &                        wkstr(sbgn:send)) .ne. NF_NOERR) then
            write (out_unit,20) 'flat:option_F'
            call gr_exit ('DEFCDF')
         end if
c
         if (nf_def_var (ncoutid,'opt_lvl',ncchar,0,0,varid) .ne.
     &                                                    NF_NOERR) then
            write (out_unit,20) 'opt_lvl'
            call gr_exit ('DEFCDF')
         end if
         wkstr = 'Flag for optimizing vertical levels'
         call length (wkstr,slen,sbgn,send)
         if (nf_put_att_text (ncoutid,varid,'long_name',slen,
     &                        wkstr(sbgn:send)) .ne. NF_NOERR) then
            write (out_unit,20) 'opt_lvl:long_name'
            call gr_exit ('DEFCDF')
         end if
         wkstr = 'Optimize vertical levels'
         call length (wkstr,slen,sbgn,send)
         if (nf_put_att_text (ncoutid,varid,'option_T',slen,
     &                        wkstr(sbgn:send)) .ne. NF_NOERR) then
            write (out_unit,20) 'opt_lvl:option_T'
            call gr_exit ('DEFCDF')
         end if
         wkstr = 'Do not optimize vertical levels'
         call length (wkstr,slen,sbgn,send)
         if (nf_put_att_text (ncoutid,varid,'option_F',slen,
     &                        wkstr(sbgn:send)) .ne. NF_NOERR) then
            write (out_unit,20) 'opt_lvl:option_F'
            call gr_exit ('DEFCDF')
         end if
c
         if (nf_def_var (ncoutid,'zc1',NF_FLOAT,0,0,varid) .ne.
     &                                                    NF_NOERR) then
            write (out_unit,20) 'zc1'
            call gr_exit ('DEFCDF')
         end if
         wkstr = 'Minimum depth of the coordinate interface'
         call length (wkstr,slen,sbgn,send)
         if (nf_put_att_text (ncoutid,varid,'long_name',slen,
     &                        wkstr(sbgn:send)) .ne. NF_NOERR) then
            write (out_unit,20) 'zc1:long_name'
            call gr_exit ('DEFCDF')
         end if
         wkstr = 'meter'
         call length (wkstr,slen,sbgn,send)
         if (nf_put_att_text (ncoutid,varid,'units',slen,
     &                        wkstr(sbgn:send)) .ne. NF_NOERR) then
            write (out_unit,20) 'zc1:units'
            call gr_exit ('DEFCDF')
         end if
c
         if (nf_def_var (ncoutid,'zc2',NF_FLOAT,0,0,varid) .ne.
     &                                                    NF_NOERR) then
            write (out_unit,20) 'zc2'
            call gr_exit ('DEFCDF')
         end if
         wkstr = 'Maximum depth of the coordinate interface'
         call length (wkstr,slen,sbgn,send)
         if (nf_put_att_text (ncoutid,varid,'long_name',slen,
     &                        wkstr(sbgn:send)) .ne. NF_NOERR) then
            write (out_unit,20) 'zc2:long_name'
            call gr_exit ('DEFCDF')
         end if
         wkstr = 'meter'
         call length (wkstr,slen,sbgn,send)
         if (nf_put_att_text (ncoutid,varid,'units',slen,
     &                        wkstr(sbgn:send)) .ne. NF_NOERR) then
            write (out_unit,20) 'zc2:units'
            call gr_exit ('DEFCDF')
         end if
c
         if (nf_def_var (ncoutid,'zref',NF_FLOAT,0,0,varid) .ne.
     &                                                    NF_NOERR) then
            write (out_unit,20) 'zref'
            call gr_exit ('DEFCDF')
         end if
         wkstr = 'Reference depth for coordinate interface'
         call length (wkstr,slen,sbgn,send)
         if (nf_put_att_text (ncoutid,varid,'long_name',slen,
     &                        wkstr(sbgn:send)) .ne. NF_NOERR) then
            write (out_unit,20) 'zref:long_name'
            call gr_exit ('DEFCDF')
         end if
         wkstr = 'meter'
         call length (wkstr,slen,sbgn,send)
         if (nf_put_att_text (ncoutid,varid,'units',slen,
     &                        wkstr(sbgn:send)) .ne. NF_NOERR) then
            write (out_unit,20) 'zref:units'
            call gr_exit ('DEFCDF')
         end if
c
         if (nf_def_var (ncoutid,'zslope',NF_FLOAT,0,0,varid) .ne.
     &                                                    NF_NOERR) then
            write (out_unit,20) 'zslope'
            call gr_exit ('DEFCDF')
         end if
         wkstr = 'Slope parameter of the coordinate interface'
         call length (wkstr,slen,sbgn,send)
         if (nf_put_att_text (ncoutid,varid,'long_name',slen,
     &                        wkstr(sbgn:send)) .ne. NF_NOERR) then
            write (out_unit,20) 'zslope:long_name'
            call gr_exit ('DEFCDF')
         end if
c
         if (nf_def_var (ncoutid,'sig_bnd',NF_FLOAT,0,0,varid) .ne.
     &                                                    NF_NOERR) then
            write (out_unit,20) 'sig_bnd'
            call gr_exit ('DEFCDF')
         end if
         wkstr = 'Upper bound for sigma level optimization'
         call length (wkstr,slen,sbgn,send)
         if (nf_put_att_text (ncoutid,varid,'long_name',slen,
     &                        wkstr(sbgn:send)) .ne. NF_NOERR) then
            write (out_unit,20) 'sig_bnd:long_name'
            call gr_exit ('DEFCDF')
         end if
c
         if (nf_def_var (ncoutid,'zc1_tol',NF_FLOAT,0,0,varid) .ne.
     &                                                    NF_NOERR) then
            write (out_unit,20) 'zc1_tol'
            call gr_exit ('DEFCDF')
         end if
         wkstr = 'Tolerance for correcting zc1'
         call length (wkstr,slen,sbgn,send)
         if (nf_put_att_text (ncoutid,varid,'long_name',slen,
     &                        wkstr(sbgn:send)) .ne. NF_NOERR) then
            write (out_unit,20) 'zc1_tol:long_name'
            call gr_exit ('DEFCDF')
         end if
c
         if (nf_def_var (ncoutid,'zc1_itmax',NF_INT,0,0,varid) .ne.
     &                                                    NF_NOERR) then
            write (out_unit,20) 'zc1_itmax'
            call gr_exit ('DEFCDF')
         end if
         wkstr = 'Maximum no. of iterations to correct zc1'
         call length (wkstr,slen,sbgn,send)
         if (nf_put_att_text (ncoutid,varid,'long_name',slen,
     &                        wkstr(sbgn:send)) .ne. NF_NOERR) then
            write (out_unit,20) 'zc1_itmax:long_name'
            call gr_exit ('DEFCDF')
         end if
c
         if (nf_def_var (ncoutid,'opt_iface',NF_INT,0,0,varid) .ne.
     &                                                    NF_NOERR) then
            write (out_unit,20) 'opt_iface'
            call gr_exit ('DEFCDF')
         end if
         wkstr = 'Flag to reset interface parameter ZC1'
         call length (wkstr,slen,sbgn,send)
         if (nf_put_att_text (ncoutid,varid,'long_name',slen,
     &                        wkstr(sbgn:send)) .ne. NF_NOERR) then
            write (out_unit,20) 'opt_iface:long_name'
            call gr_exit ('DEFCDF')
         end if
         wkstr = 'Leave ZC1 as input value'
         call length (wkstr,slen,sbgn,send)
         if (nf_put_att_text (ncoutid,varid,'option_0',slen,
     &                        wkstr(sbgn:send)) .ne. NF_NOERR) then
            write (out_unit,20) 'opt_iface:option_0'
            call gr_exit ('DEFCDF')
         end if
         wkstr = 'Minimum interface depth = input ZC1'
         call length (wkstr,slen,sbgn,send)
         if (nf_put_att_text (ncoutid,varid,'option_1',slen,
     &                        wkstr(sbgn:send)) .ne. NF_NOERR) then
            write (out_unit,20) 'opt_iface:option_1'
            call gr_exit ('DEFCDF')
         end if
         wkstr = 'Optimize CFL over shallowest topography'
         call length (wkstr,slen,sbgn,send)
         if (nf_put_att_text (ncoutid,varid,'option_2',slen,
     &                        wkstr(sbgn:send)) .ne. NF_NOERR) then
            write (out_unit,20) 'opt_iface:option_2'
            call gr_exit ('DEFCDF')
         end if
c
      end if
c
c-----------------------------------------------------------------------
c  Define geometry variables and their attributes in the netCDF file.
c-----------------------------------------------------------------------
c
c-----------------------------------------------------------------------
c  Define thicknesses for the flat reference levels.
c-----------------------------------------------------------------------
c
      if (nf_def_var (ncoutid,'hz',NF_FLOAT,1,levdim,varid) .ne.
     &                                                    NF_NOERR) then
         write (out_unit,20) 'hz'
         call gr_exit ('DEFCDF')
      end if
      wkstr = 'Thicknesses of the flat grid vertical boxes'
      call length (wkstr,slen,sbgn,send)
      if (nf_put_att_text (ncoutid,varid,'long_name',slen,
     &                     wkstr(sbgn:send)) .ne. NF_NOERR) then
         write (out_unit,20) 'hz:long_name'
         call gr_exit ('DEFCDF')
      end if
      wkstr = 'meter'
      call length (wkstr,slen,sbgn,send)
      if (nf_put_att_text (ncoutid,varid,'units',slen,
     &                     wkstr(sbgn:send)) .ne. NF_NOERR) then
         write (out_unit,20) 'hz:units'
         call gr_exit ('DEFCDF')
      end if
c
c-----------------------------------------------------------------------
c  Define horizontal grid spacings.
c-----------------------------------------------------------------------
c
      if (nf_def_var (ncoutid,'dxt',NF_FLOAT,1,tlondim,varid) .ne.
     &                                                    NF_NOERR) then
         write (out_unit,20) 'dxt'
         call gr_exit ('DEFCDF')
      end if
      wkstr = 'Zonal spacing between tracer points'
      call length (wkstr,slen,sbgn,send)
      if (nf_put_att_text (ncoutid,varid,'long_name',slen,
     &                     wkstr(sbgn:send)) .ne. NF_NOERR) then
         write (out_unit,20) 'dxt:long_name'
         call gr_exit ('DEFCDF')
      end if
      wkstr = 'meter'
      call length (wkstr,slen,sbgn,send)
      if (nf_put_att_text (ncoutid,varid,'units',slen,
     &                     wkstr(sbgn:send)) .ne. NF_NOERR) then
         write (out_unit,20) 'dxt:units'
         call gr_exit ('DEFCDF')
      end if
c
      if (nf_def_var (ncoutid,'dyt',NF_FLOAT,1,tlatdim,varid) .ne.
     &                                                    NF_NOERR) then
         write (out_unit,20) 'dyt'
         call gr_exit ('DEFCDF')
      end if
      wkstr = 'Meridional spacing between tracer points'
      call length (wkstr,slen,sbgn,send)
      if (nf_put_att_text (ncoutid,varid,'long_name',slen,
     &                     wkstr(sbgn:send)) .ne. NF_NOERR) then
         write (out_unit,20) 'dyt:long_name'
         call gr_exit ('DEFCDF')
      end if
      wkstr = 'meter'
      call length (wkstr,slen,sbgn,send)
      if (nf_put_att_text (ncoutid,varid,'units',slen,
     &                     wkstr(sbgn:send)) .ne. NF_NOERR) then
         write (out_unit,20) 'dyt:units'
         call gr_exit ('DEFCDF')
      end if
c
      if (nf_def_var (ncoutid,'dxu',NF_FLOAT,1,vlondim,varid) .ne.
     &                                                    NF_NOERR) then
         write (out_unit,20) 'dxu'
         call gr_exit ('DEFCDF')
      end if
      wkstr = 'Zonal spacing between velocity points'
      call length (wkstr,slen,sbgn,send)
      if (nf_put_att_text (ncoutid,varid,'long_name',slen,
     &                     wkstr(sbgn:send)) .ne. NF_NOERR) then
         write (out_unit,20) 'dxu:long_name'
         call gr_exit ('DEFCDF')
      end if
      wkstr = 'meter'
      call length (wkstr,slen,sbgn,send)
      if (nf_put_att_text (ncoutid,varid,'units',slen,
     &                     wkstr(sbgn:send)) .ne. NF_NOERR) then
         write (out_unit,20) 'dxu:units'
         call gr_exit ('DEFCDF')
      end if
c
      if (nf_def_var (ncoutid,'dyu',NF_FLOAT,1,vlatdim,varid) .ne.
     &                                                    NF_NOERR) then
         write (out_unit,20) 'dyu'
         call gr_exit ('DEFCDF')
      end if
      wkstr = 'Meridional spacing between velocity points'
      call length (wkstr,slen,sbgn,send)
      if (nf_put_att_text (ncoutid,varid,'long_name',slen,
     &                     wkstr(sbgn:send)) .ne. NF_NOERR) then
         write (out_unit,20) 'dyu:long_name'
         call gr_exit ('DEFCDF')
      end if
      wkstr = 'meter'
      call length (wkstr,slen,sbgn,send)
      if (nf_put_att_text (ncoutid,varid,'units',slen,
     &                     wkstr(sbgn:send)) .ne. NF_NOERR) then
         write (out_unit,20) 'dyu:units'
         call gr_exit ('DEFCDF')
      end if
c
c-----------------------------------------------------------------------
c  Define metric coefficients.
c-----------------------------------------------------------------------
c
      if (nf_def_var (ncoutid,'cs',NF_FLOAT,1,vlatdim,varid) .ne.
     &                                                    NF_NOERR) then
         write (out_unit,20) 'cs'
         call gr_exit ('DEFCDF')
      end if
      wkstr = 'Cosine metric factors at velocity points'
      call length (wkstr,slen,sbgn,send)
      if (nf_put_att_text (ncoutid,varid,'long_name',slen,
     &                     wkstr(sbgn:send)) .ne. NF_NOERR) then
         write (out_unit,20) 'cs:long_name'
         call gr_exit ('DEFCDF')
      end if
c
      if (nf_def_var (ncoutid,'tng',NF_FLOAT,1,vlatdim,varid) .ne.
     &                                                    NF_NOERR) then
         write (out_unit,20) 'tng'
         call gr_exit ('DEFCDF')
      end if
      wkstr = 'Tangent metric factors at velocity points'
      call length (wkstr,slen,sbgn,send)
      if (nf_put_att_text (ncoutid,varid,'long_name',slen,
     &                     wkstr(sbgn:send)) .ne. NF_NOERR) then
         write (out_unit,20) 'tng:long_name'
         call gr_exit ('DEFCDF')
      end if
c
      if (nf_def_var (ncoutid,'cst',NF_FLOAT,1,vlatdim,varid) .ne.
     &                                                    NF_NOERR) then
         write (out_unit,20) 'cst'
         call gr_exit ('DEFCDF')
      end if
      wkstr = 'Cosine metric factors at tracer points'
      call length (wkstr,slen,sbgn,send)
      if (nf_put_att_text (ncoutid,varid,'long_name',slen,
     &                     wkstr(sbgn:send)) .ne. NF_NOERR) then
         write (out_unit,20) 'cst:long_name'
         call gr_exit ('DEFCDF')
      end if
c
c-----------------------------------------------------------------------
c  Define velocity rotation angle.
c-----------------------------------------------------------------------
c
      if (nf_def_var (ncoutid,'lrotang',NF_FLOAT,2,vgrd2d(2),varid) .ne.
     &                                                    NF_NOERR) then
         write (out_unit,20) 'lrotang'
         call gr_exit ('DEFCDF')
      end if
      wkstr = 'Local rotation angle at velocity points'
      call length (wkstr,slen,sbgn,send)
      if (nf_put_att_text (ncoutid,varid,'long_name',slen,
     &                     wkstr(sbgn:send)) .ne. NF_NOERR) then
         write (out_unit,20) 'lrotang:long_name'
         call gr_exit ('DEFCDF')
      end if
      wkstr = 'degrees'
      call length (wkstr,slen,sbgn,send)
      if (nf_put_att_text (ncoutid,varid,'units',slen,
     &                     wkstr(sbgn:send)) .ne. NF_NOERR) then
         write (out_unit,20) 'lrotang:units'
         call gr_exit ('DEFCDF')
      end if
c
c-----------------------------------------------------------------------
c  Define 2D grid positions at tracer and velocity points.  These
c  fields are used in the visualization modules.
c-----------------------------------------------------------------------
c
      if (nf_def_var (ncoutid,'tgrid2',NF_FLOAT,3,tgrd2d,tg2did) .ne.
     &                                                    NF_NOERR) then
         write (out_unit,20) 'tgrid2'
         call gr_exit ('DEFCDF')
      end if
      wkstr = '2D grid positions at tracer points'
      call length (wkstr,slen,sbgn,send)
      if (nf_put_att_text (ncoutid,tg2did,'long_name',slen,
     &                     wkstr(sbgn:send)) .ne. NF_NOERR) then
         write (out_unit,20) 'tgrid2:long_name'
         call gr_exit ('DEFCDF')
      end if
      wkstr = '1: longitude, 2: latitude'
      call length (wkstr,slen,sbgn,send)
      if (nf_put_att_text (ncoutid,tg2did,'axis',slen,
     &                     wkstr(sbgn:send)) .ne. NF_NOERR) then
         write (out_unit,20) 'tgrid2:axis'
         call gr_exit ('DEFCDF')
      end if
      wkstr = 'degrees_east, degrees_north'
      call length (wkstr,slen,sbgn,send)
      if (nf_put_att_text (ncoutid,tg2did,'units',slen,
     &                     wkstr(sbgn:send)) .ne. NF_NOERR) then
         write (out_unit,20) 'tgrid2:units'
         call gr_exit ('DEFCDF')
      end if
c
      if (nf_def_var (ncoutid,'vgrid2',NF_FLOAT,3,vgrd2d,vg2did) .ne.
     &                                                    NF_NOERR) then
         write (out_unit,20) 'vgrid2'
         call gr_exit ('DEFCDF')
      end if
      wkstr = '2D grid positions at velocity points'
      call length (wkstr,slen,sbgn,send)
      if (nf_put_att_text (ncoutid,vg2did,'long_name',slen,
     &                     wkstr(sbgn:send)) .ne. NF_NOERR) then
         write (out_unit,20) 'vgrid2:long_name'
         call gr_exit ('DEFCDF')
      end if
      wkstr = '1: longitude, 2: latitude'
      call length (wkstr,slen,sbgn,send)
      if (nf_put_att_text (ncoutid,vg2did,'axis',slen,
     &                     wkstr(sbgn:send)) .ne. NF_NOERR) then
         write (out_unit,20) 'vgrid2:axis'
         call gr_exit ('DEFCDF')
      end if
      wkstr = 'degrees_east, degrees_north'
      call length (wkstr,slen,sbgn,send)
      if (nf_put_att_text (ncoutid,vg2did,'units',slen,
     &                     wkstr(sbgn:send)) .ne. NF_NOERR) then
         write (out_unit,20) 'vgrid2:units'
         call gr_exit ('DEFCDF')
      end if
c
c-----------------------------------------------------------------------
c  Define bathymetry at the tracer points.
c-----------------------------------------------------------------------
c
      if (nf_def_var (ncoutid,'tbath',NF_FLOAT,2,tgrd2d(2),varid) .ne.
     &                                                    NF_NOERR) then
         write (out_unit,20) 'tbath'
         call gr_exit ('DEFCDF')
      end if
      wkstr = 'Bathymetry at tracer points'
      call length (wkstr,slen,sbgn,send)
      if (nf_put_att_text (ncoutid,varid,'long_name',slen,
     &                     wkstr(sbgn:send)) .ne. NF_NOERR) then
         write (out_unit,20) 'tbath:long_name'
         call gr_exit ('DEFCDF')
      end if
      wkstr = 'meter'
      call length (wkstr,slen,sbgn,send)
      if (nf_put_att_text (ncoutid,varid,'units',slen,
     &                     wkstr(sbgn:send)) .ne. NF_NOERR) then
         write (out_unit,20) 'tbath:units'
         call gr_exit ('DEFCDF')
      end if
      wkstr = 'bathymetry, scalar'
      call length (wkstr,slen,sbgn,send)
      if (nf_put_att_text (ncoutid,varid,'field',slen,
     &                     wkstr(sbgn:send)) .ne. NF_NOERR) then
         write (out_unit,20) 'tbath:field'
         call gr_exit ('DEFCDF')
      end if
      wkstr = 'tgrid2'
      call length (wkstr,slen,sbgn,send)
      if (nf_put_att_text (ncoutid,varid,'positions',slen,
     &                     wkstr(sbgn:send)) .ne. NF_NOERR) then
         write (out_unit,20) 'tbath:positions'
         call gr_exit ('DEFCDF')
      end if
c
c-----------------------------------------------------------------------
c  Define bathymetry at the velocity points.
c-----------------------------------------------------------------------
c
      if (nf_def_var (ncoutid,'vbath',NF_FLOAT,2,vgrd2d(2),varid) .ne.
     &                                                    NF_NOERR) then
         write (out_unit,20) 'vbath'
         call gr_exit ('DEFCDF')
      end if
      wkstr = 'Bathymetry at velocity points'
      call length (wkstr,slen,sbgn,send)
      if (nf_put_att_text (ncoutid,varid,'long_name',slen,
     &                     wkstr(sbgn:send)) .ne. NF_NOERR) then
         write (out_unit,20) 'vbath:long_name'
         call gr_exit ('DEFCDF')
      end if
      wkstr = 'meter'
      call length (wkstr,slen,sbgn,send)
      if (nf_put_att_text (ncoutid,varid,'units',slen,
     &                     wkstr(sbgn:send)) .ne. NF_NOERR) then
         write (out_unit,20) 'vbath:units'
         call gr_exit ('DEFCDF')
      end if
      wkstr = 'vel_bathymetry, scalar'
      call length (wkstr,slen,sbgn,send)
      if (nf_put_att_text (ncoutid,varid,'field',slen,
     &                     wkstr(sbgn:send)) .ne. NF_NOERR) then
         write (out_unit,20) 'vbath:field'
         call gr_exit ('DEFCDF')
      end if
      wkstr = 'vgrid2'
      call length (wkstr,slen,sbgn,send)
      if (nf_put_att_text (ncoutid,varid,'positions',slen,
     &                     wkstr(sbgn:send)) .ne. NF_NOERR) then
         write (out_unit,20) 'vbath:positions'
         call gr_exit ('DEFCDF')
      end if
c
c-----------------------------------------------------------------------
c  Define auxillary topography variables and coordinate interface.
c-----------------------------------------------------------------------
c
      if (hybrid) then
c
c  Define raw topography.
c
         if (nf_def_var (ncoutid,'raw_bath',NF_FLOAT,2,tgrd2d(2),varid)
     &                                               .ne. NF_NOERR) then
            write (out_unit,20) 'raw_bath'
            call gr_exit ('DEFCDF')
         end if
         wkstr = 'Raw bathymetry at tracer points'
         call length (wkstr,slen,sbgn,send)
         if (nf_put_att_text (ncoutid,varid,'long_name',slen,
     &                        wkstr(sbgn:send)) .ne. NF_NOERR) then
            write (out_unit,20) 'raw_bath:long_name'
            call gr_exit ('DEFCDF')
         end if
         wkstr = 'meter'
         call length (wkstr,slen,sbgn,send)
         if (nf_put_att_text (ncoutid,varid,'units',slen,
     &                        wkstr(sbgn:send)) .ne. NF_NOERR) then
            write (out_unit,20) 'raw_bath:units'
            call gr_exit ('DEFCDF')
         end if
         wkstr = 'raw_bathymetry, scalar'
         call length (wkstr,slen,sbgn,send)
         if (nf_put_att_text (ncoutid,varid,'field',slen,
     &                        wkstr(sbgn:send)) .ne. NF_NOERR) then
            write (out_unit,20) 'raw_bath:field'
            call gr_exit ('DEFCDF')
         end if
         wkstr = 'tgrid2'
         call length (wkstr,slen,sbgn,send)
         if (nf_put_att_text (ncoutid,varid,'positions',slen,
     &                        wkstr(sbgn:send)) .ne. NF_NOERR) then
            write (out_unit,20) 'raw_bath:positions'
            call gr_exit ('DEFCDF')
         end if
c
c  Define target topography.
c
         if (nf_def_var (ncoutid,'trg_bath',NF_FLOAT,2,tgrd2d(2),varid)
     &                                               .ne. NF_NOERR) then
            write (out_unit,20) 'trg_bath'
            call gr_exit ('DEFCDF')
         end if
         wkstr = 'Target bathymetry at tracer points'
         call length (wkstr,slen,sbgn,send)
         if (nf_put_att_text (ncoutid,varid,'long_name',slen,
     &                        wkstr(sbgn:send)) .ne. NF_NOERR) then
            write (out_unit,20) 'trg_bath:long_name'
            call gr_exit ('DEFCDF')
         end if
         wkstr = 'meter'
         call length (wkstr,slen,sbgn,send)
         if (nf_put_att_text (ncoutid,varid,'units',slen,
     &                        wkstr(sbgn:send)) .ne. NF_NOERR) then
            write (out_unit,20) 'trg_bath:units'
            call gr_exit ('DEFCDF')
         end if
         wkstr = 'trg_bathymetry, scalar'
         call length (wkstr,slen,sbgn,send)
         if (nf_put_att_text (ncoutid,varid,'field',slen,
     &                        wkstr(sbgn:send)) .ne. NF_NOERR) then
            write (out_unit,20) 'trg_bath:field'
            call gr_exit ('DEFCDF')
         end if
         wkstr = 'tgrid2'
         call length (wkstr,slen,sbgn,send)
         if (nf_put_att_text (ncoutid,varid,'positions',slen,
     &                        wkstr(sbgn:send)) .ne. NF_NOERR) then
            write (out_unit,20) 'trg_bath:positions'
            call gr_exit ('DEFCDF')
         end if
c
c  Define coordinate interface.
c
         if (nf_def_var (ncoutid,'interface',NF_FLOAT,2,tgrd2d(2),varid)
     &                                               .ne. NF_NOERR) then
            write (out_unit,20) 'interface'
            call gr_exit ('DEFCDF')
         end if
         wkstr = 'Coordinate interface at tracer points'
         call length (wkstr,slen,sbgn,send)
         if (nf_put_att_text (ncoutid,varid,'long_name',slen,
     &                        wkstr(sbgn:send)) .ne. NF_NOERR) then
            write (out_unit,20) 'interface:long_name'
            call gr_exit ('DEFCDF')
         end if
         wkstr = 'meter'
         call length (wkstr,slen,sbgn,send)
         if (nf_put_att_text (ncoutid,varid,'units',slen,
     &                        wkstr(sbgn:send)) .ne. NF_NOERR) then
            write (out_unit,20) 'interface:units'
            call gr_exit ('DEFCDF')
         end if
         wkstr = 'interface, scalar'
         call length (wkstr,slen,sbgn,send)
         if (nf_put_att_text (ncoutid,varid,'field',slen,
     &                        wkstr(sbgn:send)) .ne. NF_NOERR) then
            write (out_unit,20) 'interface:field'
            call gr_exit ('DEFCDF')
         end if
         wkstr = 'tgrid2'
         call length (wkstr,slen,sbgn,send)
         if (nf_put_att_text (ncoutid,varid,'positions',slen,
     &                        wkstr(sbgn:send)) .ne. NF_NOERR) then
            write (out_unit,20) 'interface:positions'
            call gr_exit ('DEFCDF')
         end if
c
c  Define (vgrid) coordinate interface.
c
         if (nf_def_var (ncoutid,'viface',NF_FLOAT,2,tgrd2d(2),varid)
     &                                               .ne. NF_NOERR) then
            write (out_unit,20) 'viface'
            call gr_exit ('DEFCDF')
         end if
         wkstr = 'Coordinate interface at velocity points'
         call length (wkstr,slen,sbgn,send)
         if (nf_put_att_text (ncoutid,varid,'long_name',slen,
     &                        wkstr(sbgn:send)) .ne. NF_NOERR) then
            write (out_unit,20) 'viface:long_name'
            call gr_exit ('DEFCDF')
         end if
         wkstr = 'meter'
         call length (wkstr,slen,sbgn,send)
         if (nf_put_att_text (ncoutid,varid,'units',slen,
     &                        wkstr(sbgn:send)) .ne. NF_NOERR) then
            write (out_unit,20) 'viface:units'
            call gr_exit ('DEFCDF')
         end if
         wkstr = 'vel_interface, scalar'
         call length (wkstr,slen,sbgn,send)
         if (nf_put_att_text (ncoutid,varid,'field',slen,
     &                        wkstr(sbgn:send)) .ne. NF_NOERR) then
            write (out_unit,20) 'viface:field'
            call gr_exit ('DEFCDF')
         end if
         wkstr = 'vgrid2'
         call length (wkstr,slen,sbgn,send)
         if (nf_put_att_text (ncoutid,varid,'positions',slen,
     &                        wkstr(sbgn:send)) .ne. NF_NOERR) then
            write (out_unit,20) 'viface:positions'
            call gr_exit ('DEFCDF')
         end if
c
c  Define "hydrostatic consistency factor".
c
         vgrd2d(1) = sysdim
         if (nf_def_var (ncoutid,'hcf',NF_FLOAT,3,vgrd2d,varid) .ne.
     &                                                    NF_NOERR) then
            write (out_unit,20) 'hcf'
            call gr_exit ('DEFCDF')
         end if
         wkstr = 'Hydrostatic consistency factor'
         call length (wkstr,slen,sbgn,send)
         if (nf_put_att_text (ncoutid,varid,'long_name',slen,
     &                        wkstr(sbgn:send)) .ne. NF_NOERR) then
            write (out_unit,20) 'hcf:long_name'
            call gr_exit ('DEFCDF')
         end if
         wkstr = 'upper; lower'
         call length (wkstr,slen,sbgn,send)
         if (nf_put_att_text (ncoutid,varid,'system',slen,
     &                        wkstr(sbgn:send)) .ne. NF_NOERR) then
            write (out_unit,20) 'hcf:system'
            call gr_exit ('DEFCDF')
         end if
         wkstr = 'hcf, scalar'
         call length (wkstr,slen,sbgn,send)
         if (nf_put_att_text (ncoutid,varid,'field',slen,
     &                        wkstr(sbgn:send)) .ne. NF_NOERR) then
            write (out_unit,20) 'hcf:field'
            call gr_exit ('DEFCDF')
         end if
         wkstr = 'vgrid2'
         call length (wkstr,slen,sbgn,send)
         if (nf_put_att_text (ncoutid,varid,'positions',slen,
     &                wkstr(sbgn:send)) .ne. NF_NOERR) then
            write (out_unit,20) 'hcf:positions'
            call gr_exit ('DEFCDF')
         end if
         vgrd2d(1)=ax2dim
c
       else
c
c  Define step "topography".
c
         if (nf_def_var (ncoutid,'kmt',NF_INT,2,tgrd2d(2),varid) .ne.
     &                                                    NF_NOERR) then
            write (out_unit,20) 'kmt'
            call gr_exit ('DEFCDF')
         end if
         wkstr = 'Step topography levels at tracer points'
         call length (wkstr,slen,sbgn,send)
         if (nf_put_att_text (ncoutid,varid,'long_name',slen,
     &                        wkstr(sbgn:send)) .ne. NF_NOERR) then
            write (out_unit,20) 'kmt:long_name'
            call gr_exit ('DEFCDF')
         end if
         wkstr = 'step topography, scalar'
         call length (wkstr,slen,sbgn,send)
         if (nf_put_att_text (ncoutid,varid,'field',slen,
     &                        wkstr(sbgn:send)) .ne. NF_NOERR) then
            write (out_unit,20) 'kmt:field'
            call gr_exit ('DEFCDF')
         end if
         wkstr = 'tgrid2'
         call length (wkstr,slen,sbgn,send)
         if (nf_put_att_text (ncoutid,varid,'positions',slen,
     &                        wkstr(sbgn:send)) .ne. NF_NOERR) then
            write (out_unit,20) 'kmt:positions'
            call gr_exit ('DEFCDF')
         end if
c
      end if
c
c-----------------------------------------------------------------------
c  Define vertical thicknesses.
c-----------------------------------------------------------------------
c
c  At tracer points.
c
      if (nf_def_var (ncoutid,'dzt',NF_FLOAT,3,tgrd3d(2),varid) .ne.
     &                                                    NF_NOERR) then
         write (out_unit,20) 'dzt'
         call gr_exit ('DEFCDF')
      end if
      wkstr = '3D tracer box thicknesses'
      call length (wkstr,slen,sbgn,send)
      if (nf_put_att_text (ncoutid,varid,'long_name',slen,
     &                     wkstr(sbgn:send)) .ne. NF_NOERR) then
         write (out_unit,20) 'dzt:long_name'
         call gr_exit ('DEFCDF')
      end if
      wkstr = 'meter'
      call length (wkstr,slen,sbgn,send)
      if (nf_put_att_text (ncoutid,varid,'units',slen,
     &                     wkstr(sbgn:send)) .ne. NF_NOERR) then
         write (out_unit,20) 'dzt:units'
         call gr_exit ('DEFCDF')
      end if
c
c  At velocity points.
c
      if (nf_def_var (ncoutid,'dzv',NF_FLOAT,3,vgrd3d(2),varid) .ne.
     &                                                    NF_NOERR) then
         write (out_unit,20) 'dzv'
         call gr_exit ('DEFCDF')
      end if
      wkstr = '3D velocity box thicknesses'
      call length (wkstr,slen,sbgn,send)
      if (nf_put_att_text (ncoutid,varid,'long_name',slen,
     &                     wkstr(sbgn:send)) .ne. NF_NOERR) then
         write (out_unit,20) 'dzv:long_name'
         call gr_exit ('DEFCDF')
      end if
      wkstr = 'meter'
      call length (wkstr,slen,sbgn,send)
      if (nf_put_att_text (ncoutid,varid,'units',slen,
     &                     wkstr(sbgn:send)) .ne. NF_NOERR) then
         write (out_unit,20) 'dzv:units'
         call gr_exit ('DEFCDF')
      end if
c
c-----------------------------------------------------------------------
c  Leave definition mode.
c-----------------------------------------------------------------------
c
      if (nf_enddef (ncoutid) .eq. NF_NOERR) then
         ncstat = 2
       else
         write (out_unit,30) fname
         call gr_exit ('DEFCDF')
      end if
c
c-----------------------------------------------------------------------
c  Write out titles and scalar variables into netCDF file.
c-----------------------------------------------------------------------
c
c-----------------------------------------------------------------------
c  Write out PE model parameters.
c-----------------------------------------------------------------------
c
      if (nf_inq_varid (ncoutid,'imt',varid) .ne. NF_NOERR) then
         write (out_unit,40) 'imt'
         call gr_exit ('DEFCDF')
      end if
      if (nf_put_var_int (ncoutid,varid,no_x) .ne. NF_NOERR) then
         write (out_unit,50) 'imt'
         call gr_exit ('DEFCDF')
      end if
c
      if (nf_inq_varid (ncoutid,'jmt',varid) .ne. NF_NOERR) then
         write (out_unit,40) 'jmt'
         call gr_exit ('DEFCDF')
      end if
      if (nf_put_var_int (ncoutid,varid,no_y) .ne. NF_NOERR) then
         write (out_unit,50) 'jmt'
         call gr_exit ('DEFCDF')
      end if
c
      if (nf_inq_varid (ncoutid,'km',varid) .ne. NF_NOERR) then
         write (out_unit,40) 'km'
         call gr_exit ('DEFCDF')
      end if
      if (nf_put_var_int (ncoutid,varid,no_lvl) .ne. NF_NOERR) then
         write (out_unit,50) 'km'
         call gr_exit ('DEFCDF')
      end if
c
c-----------------------------------------------------------------------
c  Write out model domain parameters.
c-----------------------------------------------------------------------
c
      if (nf_inq_varid (ncoutid,'coord',varid) .ne. NF_NOERR) then
         write (out_unit,40) 'coord'
         call gr_exit ('DEFCDF')
      end if
      if (nf_put_var_int (ncoutid,varid,coord) .ne. NF_NOERR) then
         write (out_unit,50) 'coord'
         call gr_exit ('DEFCDF')
      end if
c
      if (nf_inq_varid (ncoutid,'rlngd',varid) .ne. NF_NOERR) then
         write (out_unit,40) 'rlngd'
         call gr_exit ('DEFCDF')
      end if
      if (nf_put_var_real (ncoutid,varid,lonc) .ne. NF_NOERR) then
         write (out_unit,50) 'rlngd'
         call gr_exit ('DEFCDF')
      end if
c
      if (nf_inq_varid (ncoutid,'rlatd',varid) .ne. NF_NOERR) then
         write (out_unit,40) 'rlatd'
         call gr_exit ('DEFCDF')
      end if
      if (nf_put_var_real (ncoutid,varid,latc) .ne. NF_NOERR) then
         write (out_unit,50) 'rlatd'
         call gr_exit ('DEFCDF')
      end if
c
      if (nf_inq_varid (ncoutid,'delx',varid) .ne. NF_NOERR) then
         write (out_unit,40) 'delx'
         call gr_exit ('DEFCDF')
      end if
      if (nf_put_var_real (ncoutid,varid,delx) .ne. NF_NOERR) then
         write (out_unit,50) 'delx'
         call gr_exit ('DEFCDF')
      end if
c
      if (nf_inq_varid (ncoutid,'dely',varid) .ne. NF_NOERR) then
         write (out_unit,40) 'dely'
         call gr_exit ('DEFCDF')
      end if
      if (nf_put_var_real (ncoutid,varid,dely) .ne. NF_NOERR) then
         write (out_unit,50) 'dely'
         call gr_exit ('DEFCDF')
      end if
c
      if (nf_inq_varid (ncoutid,'thetad',varid) .ne. NF_NOERR) then
         write (out_unit,40) 'thetad'
         call gr_exit ('DEFCDF')
      end if
      if (nf_put_var_real (ncoutid,varid,rotang) .ne. NF_NOERR) then
         write (out_unit,50) 'thetad'
         call gr_exit ('DEFCDF')
      end if
c
      if (nf_inq_varid (ncoutid,'meandx',varid) .ne. NF_NOERR) then
         write (out_unit,40) 'meandx'
         call gr_exit ('DEFCDF')
      end if
      if (nf_put_var_real (ncoutid,varid,dx) .ne. NF_NOERR) then
         write (out_unit,50) 'meandx'
         call gr_exit ('DEFCDF')
      end if
c
      if (nf_inq_varid (ncoutid,'meandy',varid) .ne. NF_NOERR) then
         write (out_unit,40) 'meandy'
         call gr_exit ('DEFCDF')
      end if
      if (nf_put_var_real (ncoutid,varid,dy) .ne. NF_NOERR) then
         write (out_unit,50) 'meandy'
         call gr_exit ('DEFCDF')
      end if
c
c-----------------------------------------------------------------------
c  Write vertical level parameters.
c-----------------------------------------------------------------------
c
      if (nf_inq_varid (ncoutid,'hybrid',varid) .ne. NF_NOERR) then
         write (out_unit,40) 'hybrid'
         call gr_exit ('DEFCDF')
      end if
      write (dum,60) hybrid
      if (nf_put_var_text (ncoutid,varid,dum) .ne. NF_NOERR) then
         write (out_unit,50) 'hybrid'
         call gr_exit ('DEFCDF')
      end if
c
      return
c
  5   format (/'*** Error:  DEFCDF - invalid (empty) file name')
 10   format (/'*** Error:  DEFCDF - unable to create output netCDF ',
     &                                                       'file: ',a)
 20   format (/'*** Error:  DEFCDF - unable to define variable: ',
     &                                                       1h',a,2h'.)
 30   format (/'*** Error:  DEFCDF - unable end definition of netCDF '
     &                                                      ,'file: ',a)
 40   format (/'*** Error:  DEFCDF - unable to find variable: ',
     &        1h',a,2h'.)
 50   format (/'*** Error:  DEFCDF - unable to write variable: ',
     &        1h',a,2h'.)
 60   format (l1)
c
      end
