      function depth (lon,lat,ier)
c
c=======================================================================
c                                                                    ===
c  Computes depth from archive bathimetry data.  A failed attempt    ===
c  to compute the depth returns a value of 20,000.0.                 ===
c                                                                    ===
c  ------                                                            ===
c  Input:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     LON     Longitude at which to compute depth.        (deg; real)===
c     LAT     Latitude at which to compute depth.         (deg; real)===
c                                                                    ===
c  -------                                                           ===
c  Output:                                                           ===
c  -------                                                           ===
c                                                                    ===
c     DEPTH   Topographic depth.                          (m; real)  ===
c     IER     Error flag.  [0] no error  [other] error.   (integer)  ===
c                                                                    ===
c  ------                                                            ===
c  Calls:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     HOPS:    DEPTH_INIT,  GETSQUARE                                ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <gpconst.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      real c180,c1mx,c1my,c360,depth,dlat,dlon,lat,latbgn,latend,lon,
     &     lonbgn,lonend,spval,wklat,wklon,x,y
      real    b(2,2)
      integer ier,ilat,ilon,nlat,nlon,topid
      logical   first,latok,lonok,periodic,topo_ok
c
      parameter (c180=180.0, c360=360.0, spval=20000.0)
c
      save first,topid,nlon,lonbgn,dlon,lonend,nlat,latbgn,dlat,latend,
     &                                                          periodic
c
      data first /.true./
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c-----------------------------------------------------------------------
c  On first pass, initialize topography archive data.
c-----------------------------------------------------------------------
c
      if (first) then
         call depth_init (topid,nlon,lonbgn,dlon,lonend,nlat,latbgn,
     &                                             dlat,latend,periodic)
         first = .false.
      end if
c
c-----------------------------------------------------------------------
c  Map latitude to archive range.
c-----------------------------------------------------------------------
c
      wklat = lat
c
      do 10 while (wklat .lt. latbgn)
         wklat  =  wklat + c180
 10   continue
c
      do 20 while (wklat .gt. latend)
         wklat = wklat - c180
 20   continue
c
      latok = (wklat.ge.latbgn) .and. (wklat.le.latend)
c
c-----------------------------------------------------------------------
c  Map longitude to archive range.
c-----------------------------------------------------------------------
c
      wklon = lon
c
      do 30 while (wklon .gt. lonend)
         wklon = wklon - c360
 30   continue
c
      do 40 while (wklon .lt. lonbgn)
         wklon  =  wklon + c360
 40   continue
c
      lonok = (wklon.ge.lonbgn) .and. ( (wklon.le.lonend) .or. periodic)
c
c-----------------------------------------------------------------------
c  Extract topography or set to special value.
c-----------------------------------------------------------------------
c
      if ( latok .and. lonok ) then
c
c-----------------------------------------------------------------------
c  Set indices for extraction and weights for interpolation.
c-----------------------------------------------------------------------
c
         ilon = int((wklon-lonbgn)/dlon) + 1
         x    = (wklon-lonbgn)/dlon - float(ilon-1)
         c1mx = c1 - x
c
         ilat = int((wklat-latbgn)/dlat) + 1
         y    = (wklat-latbgn)/dlat - float(ilat-1)
         c1my = c1 - y
c
c-----------------------------------------------------------------------
c  Extract topographic data.
c-----------------------------------------------------------------------
c
         call getsquare (ilon,ilat,topid,nlon,b,topo_ok)
c
         if (topo_ok) then
            depth = (b(1,1)*c1mx + b(2,1)*x)*c1my +
     &              (b(1,2)*c1mx + b(2,2)*x)*y
           else
            depth = spval
         end if
c
       else
c
         depth = spval
c
      endif
c
      return
      end
