      program extract_grids
c
c=======================================================================
c                                                                    ===
c  This program aligns the topography and land masks between two     ===
c  GRIDS files for nesting.                                          ===
c                                                                    ===
c  ------                                                            ===
c  Calls:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     HOPS:    ALIGN_MASK,  ALIGN_TOPO,  LENGTH,  XG_PARAM           ===
c     netCDF:  NF_CLOSE                                              ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <netcdf.inc>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer bncid,sbgn,send,slen,sncid,xgdir,xgvar
#ifdef sunfpe
     &        ,ieeer,my_handler,ieee_handler
#endif
      logical      err
      character*80 bfile,sfile
c
#ifdef sunfpe
      external my_handler
c
#endif
      data err /.false./
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
#ifdef sunfpe
c-----------------------------------------------------------------------
c  Enable floating point error flags.
c-----------------------------------------------------------------------
c
      ieeer = ieee_handler ('set','common',my_handler)
      if (ieeer .ne. 0) write (6,10)
c
#endif
c-----------------------------------------------------------------------
c  Read job control and grid parameters.
c-----------------------------------------------------------------------
c
      call xg_param (bfile,bncid,sfile,sncid,xgdir,xgvar,err)
c
c-----------------------------------------------------------------------
c  Extract topography & 3D thicknesses.
c-----------------------------------------------------------------------
c
      if ((.not.err) .and. (xgvar.ne.1)) then
         call align_topo (bfile,bncid,sfile,sncid,'tbath',xgdir,err)
         call align_topo (bfile,bncid,sfile,sncid,'interface',xgdir,err)
         call align_topo (bfile,bncid,sfile,sncid,'vbath',xgdir,err)
         call align_topo (bfile,bncid,sfile,sncid,'viface',xgdir,err)
         call align_thick (bfile,bncid,sfile,sncid,'dzt',xgdir,err)
         call align_thick (bfile,bncid,sfile,sncid,'dzv',xgdir,err)
      end if
c
c-----------------------------------------------------------------------
c  Extract land mask.
c-----------------------------------------------------------------------
c
      if ((.not.err) .and. (xgvar.ne.0)) then
         call align_mask (bfile,bncid,sfile,sncid,xgdir,err)
      end if
c
c-----------------------------------------------------------------------
c  Close netCDF files.
c-----------------------------------------------------------------------
c
      if (nf_close (bncid) .ne. NF_NOERR) then
         call length (bfile,slen,sbgn,send)
         write (6,20) bfile(sbgn:send)
      end if
c
      if (nf_close (sncid) .ne. NF_NOERR) then
         call length (sfile,slen,sbgn,send)
         write (6,20) sfile(sbgn:send)
      end if
c
      stop
c
#ifdef sunfpe
 10   format (/'+++Warning:  ieee_handler cannot set my_handler'/)
#endif
 20   format (/'+++Warning:  EXTRACT_GRIDS - unable to close file:'/13x,
     &        1h",a,1h")
c
      end
