      subroutine f_fz (zc1,f,fz)
c
c=======================================================================
c                                                                    ===
c  This routine supplies a Newton iteration with the object function ===
c  and the derivative with respect to zc1 for the optimization of zc1===
c                                                                    ===
c  ------                                                            ===
c  Input:                                                            ===
c  ------                                                            ===
c                                                                    ===
c  ZC1   The current guess for zc1.                      (real*8; m) ===
c                                                                    ===
c  Common Blocks:                                                    ===
c                                                                    ===
c  /DBL_SIG/                                                         ===
c                                                                    ===
c     ZC2     The lower limit for the interface.   (real; m)         ===
c     HREF    The reference depth for switching.   (real; m)         ===
c     ALPHA   The slope parameter.                 (real)            ===
c                                                                    ===
c  /MIN_DEPTH/                                                       ===
c                                                                    ===
c     FMIN   The desired minimum depth for the interface.  (real; m) ===
c     HMIN   The minimum topographic depth.                (real; m) ===
c                                                                    ===
c  -------                                                           ===
c  Output:                                                           ===
c  -------                                                           ===
c                                                                    ===
c  F     The objective function evaluated at zc1.        (real*8; m) ===
c  FZ    The derivative of f wrt zc1 evaluated at zc1.   (real*8)    ===
c                                                                    ===
c  Calls:  none                                                      ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <optzc1.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      double precision arg,cd0,cd1,dalpha,dfmin,dhmin,dhref,dzc2,f,fac,
     &                 favg,fdif,fz,pd5,sech,tanh,zc1
c
      parameter (cd0=0.0d0, cd1=1.0d0, pd5=0.5d0)
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c-----------------------------------------------------------------------
c  Convert basic parameters.
c-----------------------------------------------------------------------
c
      dalpha = dble(alpha)
      dfmin  = dble(fmin)
      dhmin  = dble(hmin)
      dhref  = dble(href)
      dzc2   = dble(zc2)
c
c-----------------------------------------------------------------------
c  Set basic groupings.
c-----------------------------------------------------------------------
c
      favg = pd5*(zc1+dzc2)
      fdif = pd5*(dzc2-zc1)
c
      if (fdif.ne.cd0) then
         fac = dalpha/fdif
        else
         fac = cd0
      endif
c
c-----------------------------------------------------------------------
c  Compute hyperbolic functions.
c-----------------------------------------------------------------------
c
      arg = fac*(dhmin-dhref)
      sech = cd1/cosh(arg)
      tanh = sech*sinh(arg)
c
c-----------------------------------------------------------------------
c  Compute Newton iterate functions.
c-----------------------------------------------------------------------
c
      f = favg + fdif*tanh - dfmin
      fz = pd5*(cd1 - tanh + arg*sech*sech)
c
      return
      end
