      subroutine filt_step (kmt)
c
c=======================================================================
c                                                                    ===
c  This subroutine filters the step topography.                      ===
c                                                                    ===
c  ------                                                            ===
c  Input:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     KMT   Number of active vertical levels.   (integer array)      ===
c                                                                    ===
c  -------                                                           ===
c  Output:                                                           ===
c  -------                                                           ===
c                                                                    ===
c     KMT   Filtered number of active levels.   (integer array)      ===
c                                                                    ===
c  ------                                                            ===
c  Calls:                                                            ===
c  ------                                                            ===
c                                                                    ===
#if defined fsmed && defined fsmen
c     HOPS:    GET_CURR_FILT,  GR_EXIT,       ILOCAL_MEAN,           ===
c              ILOCAL_MEDIAN,  LENGTH                                ===
# elif defined fsmed
c     HOPS:    GET_CURR_FILT,  GR_EXIT,       ILOCAL_MEDIAN,         ===
c              LENGTH                                                ===
# elif defined fsmen
c     HOPS:    GET_CURR_FILT,  GR_EXIT,       ILOCAL_MEAN,           ===
c              LENGTH                                                ===
# else
c     none                                                           ===
#endif
#if defined fsmed | defined fsmen
c     netCDF:  NF_ENDDEF,      NF_INQ_VARID,  NF_PUT_ATT_TEXT,       ===
c              NF_REDEF                                              ===
#endif
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <gridsparm.h>
#include <gridsio.h>
#if defined fsmed | defined fsmen
#  include <netcdf.inc>
#endif
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer kmt(imt,jmt)
#if defined fsmed | defined fsmen
      integer no_filt,max_filt,sbgn,sbn,send,slen,sln,snd,varid
      logical      ever
      character*18 filtname
      character*128 dumm
#endif
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
#ifdef fsmed
c-----------------------------------------------------------------------
c  Initialize loop control variables.
c-----------------------------------------------------------------------
c
      no_filt = 0
      ever = .true.
      read (in_unit,30) max_filt
c
c-----------------------------------------------------------------------
c  Replace each element of kmt with the local median of the element and
c  its nearest neighbors in physical space.  Do this process until no
c  more changes occur.
c-----------------------------------------------------------------------
c
      do 10 while (ever .and. (no_filt .lt. max_filt))
c
         call ilocal_median (kmt,ever)
         no_filt = no_filt + 1
c
  10  continue
c
c-----------------------------------------------------------------------
c  Echo type of filtering to output unit.  Report number of iterations
c  used.  Indicate if failed to reach steady state.
c-----------------------------------------------------------------------
c
      write (out_unit,50) no_filt,max_filt
      if (ever) write (out_unit,40)
c
      if ( (no_filt.gt.1) .or. (ever.and.(max_filt.gt.0)) ) then
         write (dumm,70) 'Median',no_filt
         call length (dumm,slen,sbgn,send)
         if (nf_inq_varid (ncoutid,'kmt',varid) .ne. NF_NOERR) then
            write (out_unit,80) 'kmt'
            call gr_exit ('FILT_STEP')
         end if
         call get_curr_filt ('kmt',filtname)
         if (nf_redef (ncoutid) .ne. NF_NOERR) then
            write (out_unit,90) 'enter'
            call gr_exit ('FILT_STEP')
         end if
         call length (filtname,sln,sbn,snd)
         if (nf_put_att_text (ncoutid,varid,filtname(sbn:snd),slen,
     &                              dumm(sbgn:send)) .ne. NF_NOERR) then
            write (out_unit,100) 'kmt:'//filtname(sbn:snd)
            call gr_exit ('FILT_STEP')
         end if
         if (nf_enddef (ncoutid) .ne. NF_NOERR) then
            write (out_unit,90) 'exit'
            call gr_exit ('FILT_STEP')
         end if
      end if
c
#endif
#ifdef fsmen
c-----------------------------------------------------------------------
c  Initialize loop control variables,
c-----------------------------------------------------------------------
c
      no_filt = 0
      ever = .true.
      read (in_unit,30) max_filt
c
c-----------------------------------------------------------------------
c  Replace each element of kmt with the local integrated mean of the
c  element and its nearest neighbors in physical space.  Do this process
c  until no more changes occur.
c-----------------------------------------------------------------------
c
      do 20 while (ever .and. (no_filt .lt. max_filt))
c
         call ilocal_mean (kmt,ever)
         no_filt = no_filt + 1
c
  20  continue
c
c-----------------------------------------------------------------------
c  Echo type of filtering to output unit.  Report number of iterations
c  used.  Indicate if failed to reach steady state.
c-----------------------------------------------------------------------
c
      write (out_unit,60) no_filt,max_filt
      if (ever) write (out_unit,40)
c
      if ( (no_filt.gt.1) .or. (ever.and.(max_filt.gt.0)) ) then
         write (dumm,70) 'Mean',no_filt
         call length (dumm,slen,sbgn,send)
         if (nf_inq_varid (ncoutid,'kmt',varid) .ne. NF_NOERR) then
            write (out_unit,80) 'kmt'
            call gr_exit ('FILT_STEP')
         end if
         call get_curr_filt ('kmt',filtname)
         if (nf_redef (ncoutid) .ne. NF_NOERR) then
            write (out_unit,90) 'enter'
            call gr_exit ('FILT_STEP')
         end if
         call length (filtname,sln,sbn,snd)
         if (nf_put_att_text (ncoutid,varid,filtname(sbn:snd),slen,
     &                              dumm(sbgn:send)) .ne. NF_NOERR) then
            write (out_unit,100) 'kmt:'//filtname(sbn:snd)
            call gr_exit ('FILT_STEP')
         end if
         if (nf_enddef (ncoutid) .ne. NF_NOERR) then
            write (out_unit,90) 'exit'
            call gr_exit ('FILT_STEP')
         end if
      end if
c
#endif
#ifdef sunflush
      call flush (out_unit)
#endif
      return
c
#if defined fsmed | defined fsmen
  30  format (i4)
  40  format (/'+++ Warning:  FILT_STEP - Maximum number of iterations'
     &        ,' reached'/26x,'without attaining steady state.')
#endif
#ifdef fsmed
  50  format (/'Step topography filtered by weighted median with neares'
     &      ,'t neighbors.'/3x,'Process repeated until no changes occur'
     &     ,'.'/3x,i4,' iterations.'/3x,'Maximum allowed iterations:  ',
     &        i4)
#endif
#ifdef fsmen
  60  format (/'Step topography filtered by integrated mean with neares'
     &       ,'t neighbors.'/3x,'Process repeated until no changes occu'
     &    ,'r.'/3x,i4,' iterations.'/3x,'Maximum allowed iterations:  ',
     &        i4)
#endif
#if defined fsmed | defined fsmen
  70  format (a,' filter:  NFILT ',i4)
  80  format (/'***Error:  FILT_STEP - unable to find variable ',1h",a,
     &        1h")
  90  format (/'***Error:  FILT_STEP - unable to ',a,' definition mode')
 100  format (/'***Error:  FILT_STEP - unable to write attribute ',1h",
     &        a,1h")
#endif
c
      end
