      subroutine flat_top (kbgn,kend,sig_st,bnd,dsig,sigma)
c
c=======================================================================
c                                                                    ===
c  This routine finds the "optimal" sigma levels in a sigma system   ===
c  with a flat top.                                                  ===
c                                                                    ===
c  ------                                                            ===
c  Input:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     bnd......Upper bound on sigma/dsigma.   (real)                 ===
c     kbgn.....Starting sigma level.          (integer)              ===
c     kend.....Ending sigma level.            (integer)              ===
c     sig_st...Initial sigma value.           (real)                 ===
c                                                                    ===
c  -------                                                           ===
c  Output:                                                           ===
c  -------                                                           ===
c                                                                    ===
c     dsig.....Sigma thicknesses.             (real array)           ===
c     sigma....Sigma values.                  (real array)           ===
c                                                                    ===
c  ------                                                            ===
c  Calls:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     BISECT,  FLTSUM                                                ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global variables.
c-----------------------------------------------------------------------
c
#include <gpconst.h>
#ifdef spread_corr
# include <fltsum.h>
#endif
c
c-----------------------------------------------------------------------
c  Define local variables.
c-----------------------------------------------------------------------
c
      integer k,kbgn,kend
#ifdef spread_corr
      integer itmax
#endif
      logical fnd
      real    bnd,ratio,sig_st,dsigsum
#ifndef spread_corr
      real    rdenom
#endif
      real             dsig(kbgn:kend),sigma(kbgn:kend)
#ifdef spread_corr
      double precision cd1,cd2,dbnd,dratio0,dratio,drdenom,dtol
      double precision fltsum
c
      parameter (cd1=1.0d0, cd2=2.0d0, dtol=1.0d-8, itmax=20000)
c
      external fltsum
#endif
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c-----------------------------------------------------------------------
c  Compute sigma thicknesses.
c-----------------------------------------------------------------------
c
#ifndef spread_corr
      rdenom = c1/(c2*bnd+c1)
      ratio  = (c2*bnd-c1)*rdenom
c
      dsig(kend) = c2*rdenom
#else
c
c  If dbnd == norder - 0.5,  want evenly spaced levels.
c
      dbnd    = bnd
      drdenom = cd1/(cd2*dbnd+cd1)
      dratio0 = (cd2*dbnd-cd1)*drdenom
      scalfac = cd2*drdenom
      norder  = kend - kbgn
c
      call bisect (fltsum,dratio0,cd1,dtol,itmax,dratio,fnd)
      if (fnd) then
         ratio = dratio
         write (6,2) dratio0,cd1,dratio
   2     format (/3x,'Ratio bounds:',2(2x,f11.8)/3x,'Ratio:',2x,f11.8)
       else
         write (6,5) itmax
   5     format (/'FLAT_TOP: No convergence after ',i10,' iterations')
         ratio = dratio0
      endif
c
      dsig(kend) = scalfac
#endif
c
      do 10 k = (kend-1), kbgn, -1
         dsig(k) = ratio * dsig(k+1)
 10   continue
c
#ifdef spread_corr
      if (.not.fnd) then
#endif
c  Reset top thickness so sum of sigma thicknesses is one.
c
      dsig(kbgn) = dsig(kbgn)/dsig(kend)
c
#ifdef spread_corr
      endif
c
#endif
c-----------------------------------------------------------------------
c  Compute sigma levels from sigma thicknesses.
c-----------------------------------------------------------------------
c
      sigma(kbgn) = sig_st + p5*dsig(kbgn)
      dsigsum     = dsig(kbgn)
c
      do 20 k = (kbgn+1), kend
         sigma(k) = sigma(k-1) + p5*(dsig(k)+dsig(k-1))
         dsigsum  = dsigsum + dsig(k)
 20   continue
      write (6,30) dsigsum
 30   format (3x,'Sum of sigma thicknesses:',2x,f11.8)
c
      return
      end
