      subroutine get_curr_filt (varname,filtname)
c
c=======================================================================
c                                                                    ===
c  This routine returns the currently available filter attribute for ===
c  the requested variable.                                           ===
c                                                                    ===
c  ------                                                            ===
c  Input:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     VARNAME....Name of netCDF variable.             (character)    ===
c                                                                    ===
c  Common Blocks:                                                    ===
c                                                                    ===
c  /GRIDSIO/                                                         ===
c                                                                    ===
c     NCOUTID....Identifier for netCDF output file.   (integer)      ===
c                                                                    ===
c  -------                                                           ===
c  Output:                                                           ===
c  -------                                                           ===
c                                                                    ===
c     FILTNAME...Currently available filter name.     (character)    ===
c                                                                    ===
c  ------                                                            ===
c  Calls:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     HOPS:    GR_EXIT                                               ===
c     netCDF:  NF_GET_ATT_TEXT,  NF_INQ_VARID                        ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <gridsio.h>
#include <netcdf.inc>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer      nchar,nfilt,varid
      character*19  fmt
      character*128 dummy
      character*(*) filtname,varname
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c-----------------------------------------------------------------------
c  Get variable identifier.
c-----------------------------------------------------------------------
c
      if (nf_inq_varid (ncoutid,varname,varid) .ne. NF_NOERR) then
         write (out_unit,20) varname
         call gr_exit ('GET_CURR_FILT')
      end if
c
c-----------------------------------------------------------------------
c  Loop through list of filters until first unused one is found.
c-----------------------------------------------------------------------
c
      nfilt = 0
      nchar = 1
      write (fmt,30) nchar
      write (filtname,fmt) nfilt
c
      do 10 while (nf_get_att_text (ncoutid,varid,filtname,dummy) .eq.
     &                                                         NF_NOERR)
         nfilt = nfilt + 1
         nchar = int(log10(float(nfilt))) + 1
         write (fmt,30) nchar
         write (filtname,fmt) nfilt
 10   continue
c
      return
c
 20   format (/'***Error:  GET_CURR_FILT - unable to find variable ',1h"
     &        ,a,1h",' in GRIDS output file.')
 30   format ('(',1h','filter_',1h',',i',i2,')')
c
      end
