      subroutine get_sigma (no_lvl,kc,optimum,dzt,c,alpha,flat,sigma,
     &                                                          vrt_err)
c
c=======================================================================
c                                                                    ===
c  This routine computes the sigma levels from the supplied model    ===
c  levels.                                                           ===
c                                                                    ===
c  ------                                                            ===
c  Input:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     alpha.....Slope parameter for tanh interface.   (real)         ===
c     c.........Bound for upper sigma factor.         (real)         ===
c     dzt.......Vertical model level thicknesses.     (real array; m)===
c     flat......Indicates whether interface is flat.  (logical)      ===
c                  [.true. ]  defined flat.                          ===
c                  [.false.]  NOT defined flat.                      ===
c     kc........Number of levels in upper system.     (integer)      ===
c     no_lvl....Number of model levels.               (integer)      ===
c     optimum...Whether to "optimize" sigma levels.   (logical)      ===
c                  [.true. ]  "optimize" levels.                     ===
c                  [.false.]  do NOT "optimize".                     ===
c                                                                    ===
c  -------                                                           ===
c  Output:                                                           ===
c  -------                                                           ===
c                                                                    ===
c     dzt.......Sigma thicknesses.                    (real array)   ===
c     sigma.....Vertical sigma levels.                (real)         ===
c     vrt_err...Whether a nonpositive thickness.      (logical)      ===
c                  [.true. ]  Bad thickness found.                   ===
c                  [.false.]  No bad thicknesses.                    ===
c                                                                    ===
c  Calls:  CHK_LEV,  FLAT_TOP,  VAR_TOP                              ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global variables.
c-----------------------------------------------------------------------
c
#include <gridsparm.h>
#include <gpconst.h>
c
c-----------------------------------------------------------------------
c  Define local variables.
c-----------------------------------------------------------------------
c
      integer k,kc,nlvl2,no_lvl
      real    alpha,c,clow,fac,sum
      real    dzt(mx_lvl),sigma(mx_lvl)
      logical flat,optimum,vrt_err
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c-----------------------------------------------------------------------
c  Compute sigma levels in upper system.
c-----------------------------------------------------------------------
c
      if (kc .gt. 0) then
c
         if (optimum .and. (.not. flat)) then
c
            call flat_top (1,kc,c0,c,dzt(1),sigma(1))
c
           else
c
            call chk_lev (no_lvl,dzt,1,kc,vrt_err)
c
            sum = dzt(1)
            do 20 k = 2, kc
               sum = sum + dzt(k)
 20         continue
            fac = p5/sum
c
            sigma(1) = dzt(1)*fac
            do 30 k = 2, kc
               sigma(k) = sigma(k-1) + (dzt(k)+dzt(k-1))*fac
 30         continue
c
            if (.not. flat) then
c
               fac = c1/sum
               do 35 k = 1, kc
                  dzt(k) = dzt(k)*fac
 35            continue
c
            end if
c
         end if
c
      end if
c
c-----------------------------------------------------------------------
c  Compute sigma levels.
c-----------------------------------------------------------------------
c
      if (kc .lt. no_lvl) then
c
         if (optimum) then
c
            if (.not. flat) then
               nlvl2 = no_lvl - kc
               call var_top (alpha,nlvl2,clow,dzt(kc+1),sigma(kc+1))
              else
               call flat_top (kc+1,no_lvl,c1,c,dzt(kc+1),sigma(kc+1))
            end if
c
           else
c
            call chk_lev (no_lvl,dzt,kc+1,no_lvl,vrt_err)
c
            sum = dzt(kc+1)
            do 50 k = kc+2, no_lvl
               sum = sum + dzt(k)
 50         continue
            fac = c1/sum
c
            dzt(kc+1) = dzt(kc+1)*fac
            sigma (kc+1) = c1 + dzt(kc+1)*p5
            do 60 k = kc+2, no_lvl
               dzt(k) = dzt(k)*fac
               sigma(k) = sigma(k-1) + (dzt(k)+dzt(k-1))*p5
 60         continue
c
         end if
c
      end if
c
      return
      end
