      subroutine getsquare (ilon,ilat,topid,nlon,topo,ok)
c
c=======================================================================
c                                                                    ===
c  This routine reads in topography from the archive file.           ===
c                                                                    ===
c  ------                                                            ===
c  Input:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     ILON    "Western" index of desired box.          (integer)     ===
c     ILAT    "Southern" index of desired box.         (integer)     ===
c     TOPID   Identifier for topography variable.      (integer)     ===
c     NLON    Maximum number of longitudinal points.   (integer)     ===
c                                                                    ===
c  Common Blocks:                                                    ===
c                                                                    ===
c  /GRIDSIO/                                                         ===
c                                                                    ===
c     NCTINID   ID for netCDF input topography file.   (integer)     ===
c                                                                    ===
c  -------                                                           ===
c  Output:                                                           ===
c  -------                                                           ===
c                                                                    ===
c     TOPO   Topographic depth.                        (real; m)     ===
c     OK     Exit flag.                                (logical)     ===
c               [.true.]  no error                                   ===
c               [.false.] error                                      ===
c                                                                    ===
c  ------                                                            ===
c  Calls:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     netCDF:  NF_GET_VARA_REAL                                      ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data
c-----------------------------------------------------------------------
c
#include <gridsio.h>
#include <netcdf.inc>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer ilat,ilon,nlon,topid
      integer count(2),start(2)
      logical ok
      real    topo(2,2),wk(2)
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c-----------------------------------------------------------------------
c  Set starting locations.
c-----------------------------------------------------------------------
c
      start(1) = ilon
      start(2) = ilat
c
      if (ilon.lt.nlon) then
         count(1) = 2
        else
         count(1) = 1
      end if
      count(2) = 2
c
c-----------------------------------------------------------------------
c  Look for specified topography variable and read it if there.
c-----------------------------------------------------------------------
c
      if (ilon.lt.nlon) then
         ok = nf_get_vara_real (nctinid,topid,start,count,topo) .eq.
     &                                                          NF_NOERR
       else
         ok = nf_get_vara_real (nctinid,topid,start,count,wk) .eq.
     &                                                          NF_NOERR
         topo(1,1) = wk(1)
         topo(1,2) = wk(2)
         start(1)  = 1
         ok = (nf_get_vara_real (nctinid,topid,start,count,wk) .eq.
     &                                                NF_NOERR) .and. ok
         topo(2,1) = wk(1)
         topo(2,2) = wk(2)
      end if
c
      return
      end
