      subroutine gr_exit (name)
c
c=======================================================================
c                                                                    ===
c  This routine gently terminates the program execution.             ===
c                                                                    ===
c  ------                                                            ===
c  Input:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     NAME......Name of the calling routine.   (string)              ===
c                                                                    ===
c  Common Blocks:                                                    ===
c                                                                    ===
c  /GRIDSIO/                                                         ===
c                                                                    ===
c     CSTSTAT   Status flag for coast line data file.      (integer) ===
c     CSTUNIT   Unit number: ASCII coastline data file.    (integer) ===
c     NCCSTID   Identifier: netCDF input coastline file.   (integer) ===
c     NCOUTID   Identifier number for netCDF output file.  (integer) ===
c     NCSTAT    Status flag for netCDF output file.        (integer) ===
c     NCTINID   Identifier for netCDF input topo. file.    (integer) ===
c     TOPSTAT   Status flag for topography archive file.   (integer) ===
c                                                                    ===
c  ------                                                            ===
c  Calls:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     HOPS:    LENGTH                                                ===
c     netCDF:  NF_ABORT,  NF_CLOSE                                   ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data
c-----------------------------------------------------------------------
c
#include <gridsio.h>
#include <netcdf.inc>
c
c-----------------------------------------------------------------------
c  Define local data
c-----------------------------------------------------------------------
c
      integer clen,cbgn,cend
      logical       opnd
      character*(*) name
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c-----------------------------------------------------------------------
c  Abort or close the netCDF file as needed.
c-----------------------------------------------------------------------
c
      if (ncstat.eq.1) then
         if (nf_abort (ncoutid) .ne. NF_NOERR) then
            write (out_unit,10)
         end if
       else if (ncstat.eq.2) then
         if (nf_close (ncoutid) .ne. NF_NOERR) then
            write (out_unit,20)
         end if
      end if
c
c-----------------------------------------------------------------------
c  Close open data files.
c-----------------------------------------------------------------------
c
c  Close coastline data file.
c
      if (cststat.eq.1) then
         if (nf_close (nccstid) .ne. NF_NOERR) then
            write (out_unit,20)
         end if
       else
         inquire (unit=cstunit, opened=opnd)
         if (opnd) close (cstunit)
      end if
c
c  Close topography archive file.
c
      if (topstat.eq.1) then
         if (nf_close (nctinid) .ne. NF_NOERR) then
            write (out_unit,20)
         end if
      end if
c
c-----------------------------------------------------------------------
c  Write final message and end program.
c-----------------------------------------------------------------------
c
      call length (name,clen,cbgn,cend)
c
      if (clen.lt.5) then
         write (out_unit,30) name(cbgn:cend)
       elseif (name((cend-4):cend).eq.' DONE') then
         write (out_unit,40) name(cbgn:cend)
       else
         write (out_unit,30) name(cbgn:cend)
      end if
c
      stop
c
  10  format (/'+++Warning:  unable to abort netCDF file.')
  20  format (/'+++Warning:  unable to close netCDF file.')
  30  format (/'*** Error:  GRIDS abnormally terminated in routine: ',a)
  40  format (/a)
c
      end
