      program grids
c
c=======================================================================
c                                                                    ===
c  This program produces either a rotated spherical grid or a QG     ===
c  grid and the associated grid parameters for the primitive equation===
c  (MOM) code as well as a plot of the resulting grid.  The program  ===
c  will then compute topography either from an archived topography   ===
c  file, or from a previously computed file.                         ===
c                                                                    ===
c  ------                                                            ===
c  Calls:                                                            ===
c  ------                                                            ===
c                                                                    ===
#ifndef sunfpe
# ifndef noplot
c     HOPS:    CHK_PWNDO,  CPP_TELL,     GET_DATA,   GR_EXIT,        ===
c              HEADLN,     HYB_SYS,      NEW_DEPTH,  OPN_TFILE,      ===
c              PE_GRID,    PLT_CLOS,     PLT_GRID,   PLT_HCF,        ===
c              PLT_INIT,   PLT_INVALID,  PLT_STEP,   PLT_TOPO,       ===
c              PRV_DEPTH,  STEP_SYS                                  ===
# else
c     HOPS:    CHK_PWNDO,  CPP_TELL,   GET_DATA,   GR_EXIT,          ===
c              HEADLN,     HYB_SYS,    NEW_DEPTH,  OPN_TFILE,        ===
c              PE_GRID,    PRV_DEPTH,  STEP_SYS                      ===
# endif
#else
# ifndef noplot
c     HOPS:    CHK_PWNDO,  CPP_TELL,     GET_DATA,    GR_EXIT,       ===
c              HEADLN,     HYB_SYS,      MY_HANDLER,  NEW_DEPTH,     ===
c              OPN_TFILE,  PE_GRID,      PLT_CLOS,    PLT_GRID,      ===
c              PLT_INIT,   PLT_INVALID,  PLT_STEP,    PLT_TOPO,      ===
c              PLT_HCF,    PRV_DEPTH,    STEP_SYS                    ===
# else
# endif
c     HOPS:    CHK_PWNDO,  CPP_TELL,  GET_DATA,    GR_EXIT,          ===
c              HEADLN,     HYB_SYS,   MY_HANDLER,  NEW_DEPTH,        ===
c              OPN_TFILE,  PE_GRID,   PRV_DEPTH,   STEP_SYS          ===
#endif
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data
c-----------------------------------------------------------------------
c
#include <gridsparm.h>
#include <gridsio.h>
#include <gpconst.h>
#include <dom.h>
#include <hcfmap.h>
#include <hstat.h>
#include <topmap.h>
c
c-----------------------------------------------------------------------
c  Define local data
c-----------------------------------------------------------------------
c
      integer antind,no_cl,hno_cl,kc,no_lvl
#ifdef sunfpe
     &        ,ieeer,my_handler,ieee_handler
#endif
      integer kmt(imt,jmt)
      real
     &      tlat,blon,blat,clmin,clint,hclmin,hclint
      real
     &      topog(imt,jmt),clvl(max_cl),hclvl(max_cl),hcf(imt,jmt,2),
     &        dzt(mx_lvl)
      logical new_topo,top_err,hybrid,plot_grid,target,pltbad,
     &             cont_top,plot_step,block_cl,hblock_cl,optimum,vrt_err
      character*80 gridfile
c
#ifdef sunfpe
      external my_handler
c
#endif
      data kmt /imjm*0/
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
#ifdef sunfpe
c-----------------------------------------------------------------------
c  Enable floating point error flags.
c-----------------------------------------------------------------------
c
      ieeer = ieee_handler ('set','common',my_handler)
      if (ieeer .ne. 0) write (out_unit,10)
c
#endif
c-----------------------------------------------------------------------
c  Write date & time header for echo file.
c-----------------------------------------------------------------------
c
      call headln (out_unit)
      call cpp_tell (out_unit)
c
c-----------------------------------------------------------------------
c  Get grid size, rotation and plotting information.
c-----------------------------------------------------------------------
c
      call get_data (gridfile,tlon,tlat,blon,blat,hybrid,kc,
     &              optimum,no_lvl,dzt,new_topo,target,no_cl,clvl,clmin,
     &              clint,block_cl,hno_cl,hclvl,hclmin,hclint,hblock_cl,
     &                                     plot_grid,cont_top,plot_step)
c
c-----------------------------------------------------------------------
c  Compute & write out PE grid information.  Check plot window.
c-----------------------------------------------------------------------
c
      call pe_grid (geo_tlon,geo_tlat,geo_lon,geo_lat)
c
c
      call chk_pwndo (blon,blat,tlon,tlat,no_x,no_y,geo_tlon,geo_tlat,
     &                                                  geo_lon,geo_lat)
c
c-----------------------------------------------------------------------
c  Compute topography at T grid points.
c-----------------------------------------------------------------------
c
      if (new_topo) then
         call opn_tfile (top_err)
         if (.not.top_err)
     &      call new_depth (geo_tlon,geo_tlat,hybrid,topog,top_err)
       else
         call prv_depth (hybrid,target,topog,top_err)
      end if
c
c-----------------------------------------------------------------------
c  Compute & write vertical grid information.
c-----------------------------------------------------------------------
c
      if (hybrid) then
         call hyb_sys (topog,no_x,no_y,kc,no_lvl,dzt,top_err,hcf,hcf_max
     &                              ,hcf_min,optimum,vrt_err,kmt,pltbad)
        else
         call step_sys (no_lvl,dzt,topog,kmt,top_err,vrt_err)
      end if
c
#ifndef noplot
c-----------------------------------------------------------------------
c  Plot resultant grid and topography (if successful).
c-----------------------------------------------------------------------
c
c  Initialize plotting.
c
      call plt_init (antind)
c
c  Plot grid lines.
c
      call plt_grid (tlat,blon,blat,plot_grid,antind)
c
c  Contour Topography.
c
      call plt_topo (tlat,blon,blat,topog,top_err,no_cl,clvl,
     &                     clmin,clint,block_cl,cont_top,antind)
c
c  Plot Hydrostatic Consistency Factor or Step Topography.
c
      if ((.not. (top_err.or.vrt_err)) .and. plot_step) then
         if (hybrid) then
            call plt_hcf (tlat,blon,blat,hcf,hno_cl,hclvl,hclmin,hclint,
     &                    hblock_cl,antind)
           else
            call plt_step (tlat,blon,blat,kmt,antind)
         end if
      end if
c
c  Plot any locations of invalid vertical coordinates.
c
      call plt_invalid (tlat,blon,blat,kmt,hybrid,pltbad,antind)
c
c  Close plotting.
c
      call plt_clos
c
#endif
c-----------------------------------------------------------------------
c  Successful termination.
c-----------------------------------------------------------------------
c
      call gr_exit ('GRIDS DONE')
c
      stop
c
#ifdef sunfpe
 10   format (/'+++ Warning:  ieee_handler cannot set my_handler'/)
#endif
c
      end
