      subroutine hcf_key (grfl,grfr,grfb,grft,sys)
c
c=======================================================================
c                                                                    ===
c  This provides a key for the dash patterns on the hydrostatic      ===
c  consistency factor plot.                                          ===
c                                                                    ===
c  ------                                                            ===
c  Input:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     GRFB   Device coordinate of bottom of graph area.   (real)     ===
c     GRFL   Device coordinate of left of graph area.     (real)     ===
c     GRFR   Device coordinate of right of graph area.    (real)     ===
c     GRFT   Device coordinate of top of graph area.      (real)     ===
c     SYS    String to indicate which vertical system.    (string)   ===
c                                                                    ===
c  ------                                                            ===
c  Calls:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     NCAR:    DASHDB,  LINED,  PLCHHQ,  SET,  SFLUSH                ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <gpconst.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      real    grfb,grfl,grfr,grft,y
      integer     dash,short_dash,solid
      character*5  ltc1,p5lt,sys
      character*15 c0le,gec1,gtc2,lec2,lep5
c
      parameter (short_dash=43690, dash=61680, solid=65535,
     &           gec1 = '$PRL$-$PRU$ 1.0', c0le = '0 $PRL$+$PRU$',
     &  lep5 = '$PRL$+$PRU$ 0.5', p5lt = '0.5 <', ltc1 = '< 1.0',
     &  lec2 = '$PRL$+$PRU$ 2', gtc2 = '> 2')
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c-----------------------------------------------------------------------
c  Set sub-window for providing pattern key data.
c-----------------------------------------------------------------------
c
      y = grfb + (grft-grfb)/c3
      y = min (y, (grfb+p1))
      call set (grfr,grfr+p1,grfb,y,c0,c1,c0,c5,1)
c
c-----------------------------------------------------------------------
c  Determine horizontal label positionings and initial vertical
c  positioning.
c-----------------------------------------------------------------------
c
      call plchhq (p5,c4,'Key',c5,c0,c0)
c
c-----------------------------------------------------------------------
c  Write key for the range greater than 2.
c-----------------------------------------------------------------------
c
      call dashdb (short_dash)
      call lined (p25,c3,p75,c3)
      call plchhq (p8,c3,gtc2,c5,c0,cm1)
c
c-----------------------------------------------------------------------
c  Write key for the range [0.0, 2.0].
c-----------------------------------------------------------------------
c
      call plchhq (p1*p5,c2,c0le,c5,c0,cm1)
      call dashdb (solid)
      call lined (p25,c2,p75,c2)
      call plchhq (p8,c2,lec2,c5,c0,cm1)
c
      call sflush
c
c-----------------------------------------------------------------------
c  Set sub-window for indicating which vertical system.
c-----------------------------------------------------------------------
c
      y = grfb + c2*(grft-grfb)/c3
      y = max (y, (grft-p1))
      call set (grfr,grfr+p1,y,grft,c0,c1,c0,c3,1)
c
c-----------------------------------------------------------------------
c  Write indicator for which vertical system.
c-----------------------------------------------------------------------
c
      call plchhq (p5,c2,sys,c10,c0,c0)
      call plchhq (p5,c1,'System',c10,c0,c0)
c
      call sflush
c
      return
      end
