      subroutine hcf_stat (hcf,ldh,no_x,no_y,out_unit,k,hcf_max,hcf_min)
c
c-------------------------------------------------------------------------------
c     This routine determines the minimum, maximum, median and mean values for |
c     the hydrostatic consistency factor.                                      |
c                                                                              |
c     Calls:  heap_sort                                                        |
c                                                                              |
c     Arguments:                                                               |
c                                                                              |
c     hcf........Real array.  The hydrostatic consistency factor.  {input}     |
c     hcf_max....Real.  Maximum value of hcf.   {output}                       |
c     hcf_min....Real.  Minimum value of hcf.   {output}                       |
c     k..........Integer.  Indicates whether working with upper or lower       |
c                   system.   {input}                                          |
c                      k = 1  =>  upper system.                                |
c                      k = 2  =>  lower system.                                |
c     ldh........Integer.  The leading dimension of hcf.   {input}             |
c     no_x.......Integer.  The number of grid points in x direction.   {input} |
c     no_y.......Integer.  The number of grid points in y direction.   {input} |
c     out_unit...Integer.  The unit number on which to write results.   {input}|
c-------------------------------------------------------------------------------
c
#include <gridsparm.h>
#include <gpconst.h>
c
      integer ldh,no_x,no_y,out_unit,i,j,nxy,k,index
      real    hcf(ldh,no_y),hcf_max,hcf_min,hcf_avg,hcf_med,spval,
     &            wk(imjm)
      character*5 sys(2)
c
      double precision sum,cd0
c
      parameter (spval = -1.0, cd0 = 0.0d0)
c
      save sys
c
      data sys /'upper','lower'/
c
c=======================================================================
c     Begin executable code.                                           #
c=======================================================================
c
c-----------------------------------------------------------------------
c     Initialize active point counter,accumulator and first element of |
c     work array.  (This last is a ward against the case of all special|
c     values for the consistency factor.)                              |
c-----------------------------------------------------------------------
c
      nxy = 0
      sum = cd0
      wk(1) = c0
c
c-----------------------------------------------------------------------
c     Create sorted list & accumulate sum of non-special values, while |
c     protecting against a list of length zero.                        |
c-----------------------------------------------------------------------
c
      do 10 j = 1, no_y
         do 10 i = 1, no_x
c
            if (hcf(i,j) .ne. spval) then
c
               nxy = nxy + 1
               wk(nxy) = hcf(i,j)
               sum = sum + dble ( hcf(i,j) )
c
            end if
c
 10   continue
c
      nxy = max(nxy,1)
c
      call heap_sort (nxy,wk)
c
c-----------------------------------------------------------------------
c     Compute the maximum, minimum, mean and median.                   |
c-----------------------------------------------------------------------
c
      hcf_min = wk(1)
      hcf_max = wk(nxy)
      hcf_avg = real(sum) / float(nxy)
c
      index = (nxy+1)/2
c
      if (mod(nxy,2) .ne. 0) then
         hcf_med = wk(index)
        else
         hcf_med = p5 * ( wk(index) + wk(index+1) )
      end if
c
c-----------------------------------------------------------------------
c     Write the results.                                               |
c-----------------------------------------------------------------------
c
      write (out_unit,20) sys(k),hcf_min,hcf_avg,hcf_med,hcf_max
#ifdef sunflush
      call flush (out_unit)
#endif
c
      return
c
 20   format (/'Maximal hydrostatic consistency factor (',a5,') :'
     &        /3x,'Minimum = ',1pg15.8/6x,'Mean = ',1pg15.8/4x,'Median',
     &                            ' = ',1pg15.8/3x,'Maximum = ',1pg15.8)
c
      end
