      subroutine hcntr_lbl (no_cl,cint,nsys)
c
c=======================================================================
c                                                                    ===
c  This subroutine labels the contour plot of the hydrostatic        ===
c  consistency factor.                                               ===
c                                                                    ===
c  ------                                                            ===
c  Input:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     cint    Contour level.  (only valid if no_cl < 0)   (real)     ===
c     nsys    Flag to indicate which vertical system.     (integer)  ===
c                [1]  =>  upper system.                              ===
c                [2]  =>  lower system.                              ===
c     no_cl   Number of contour levels used.              (integer)  ===
c                                                                    ===
c  Common Blocks:                                                    ===
c                                                                    ===
c  /CNTLBL/                                                          ===
c                                                                    ===
c     GRFB   Device coordinate of bottom of graph area.   (real)     ===
c     GRFL   Device coordinate of left of graph area.     (real)     ===
c     GRFR   Device coordinate of right of graph area.    (real)     ===
c     GRFT   Device coordinate of top of graph area.      (real)     ===
c     XMAX   World coordinate of right of graph area.     (real)     ===
c     XMIN   World coordinate of left of graph area.      (real)     ===
c     YMAX   World coordinate of top of graph area.       (real)     ===
c     YMIN   World coordinate of bottom of graph area.    (real)     ===
c                                                                    ===
c  ------                                                            ===
c  Calls:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     HOPS:    HCF_KEY,  LENGTH,  NO_DIGIT                           ===
c     NCAR:    CPGETI,   CPGETR,  CPSETI,    PLCHHQ,  SET            ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <gpconst.h>
#include <cntlbl.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      real    c,c7,cint,cmax,cmin,y,ybot,ytop
      integer n,nline,no_cl,nsys,sbgn,send,slen
      integer     no_digit
      character*5  sys(2)
      character*27 fmt,string
c
      parameter (c7=7.0)
c
      data sys / 'Upper', 'Lower' /
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c-----------------------------------------------------------------------
c  Get contouring data.
c-----------------------------------------------------------------------
c
c  Find contour limits
c
      call cpgeti ('NCL - Number of Contour Levels',nline)
c
      if (nline.ge.1) then
         call cpseti ('PAI - Parameter Array Index',1)
         call cpgetr ('CLV - Contour Level Value',cmax)
         cmin = cmax
         do 10 n = 2, nline
            call cpseti ('PAI - Parameter Array Index',n)
            call cpgetr ('CLV - Contour Level Value',c)
            cmax = max (cmax, c)
            cmin = min (cmin, c)
  10     continue
      end if
c
c  If NCAR specified the contour interval, get it.
c
      if ((no_cl.eq.0).and.(nline.ge.1)) then
         call cpgetr ('CIU - Contour Interval Used',cint)
      end if
c
c-----------------------------------------------------------------------
c  Write minimum, maximum depths and contour interval.
c-----------------------------------------------------------------------
c
c  Set sub-window for providing contour data.
c
      if (nline.ge.1) then
         ytop = grfb + c2*(grft-grfb)/c3
         ytop = min (ytop, p5*(grft+grfb+p1))
         ybot = grfb + (grft-grfb)/c3
         ybot = max (ybot, p5*(grft+grfb-p1))
         if (no_cl.le.c0) then
            nline = 3
          else
            nline = 2
         end if
         call set (grfr,grfr+p1,ybot,ytop,c0,c1,c0,float(nline+1),1)
c
c  Provide contour data.
c
         y = float(nline)
         write (fmt,20) no_digit(int(cmax))+2,1
         write (string,fmt) 'Cmax ',cmax
         call length (string,slen,sbgn,send)
         call plchhq (c0,y,string(sbgn:send),c7,c0,cm1)
c
         if (no_cl .le. c0) then
            write (fmt,20) no_digit(int(cint))+2,1
            write (string,fmt) 'Cint ',cint
            call length (string,slen,sbgn,send)
            y = y - c1
            call plchhq (c0,y,string(sbgn:send),c7,c0,cm1)
         end if
c
         write (fmt,20) no_digit(int(cmin))+2,1
         write (string,fmt) 'Cmin ',cmin
         call length (string,slen,sbgn,send)
         y = y - c1
         call plchhq (c0,y,string(sbgn:send),c7,c0,cm1)
      end if
c
c-----------------------------------------------------------------------
c     Write key for dash patterns, reset plot window.                  |
c-----------------------------------------------------------------------
c
c  Provide pattern key data.
c
      call hcf_key (grfl,grfr,grfb,grft,sys(nsys))
c
c  Reset window for regular plotting.
c
      call set (grfl,grfr,grfb,grft,xmin,xmax,ymin,ymax,1)
c
      return
c
  20  format ('(a,f',i2,'.',i2,')')
c
      end
