      subroutine heap_sort (n,vector)
c
c-------------------------------------------------------------------------------
c     This routines sorts the given vector in ascending order using the        |
c     Heapsort algorithm.                                                      |
c                                                                              |
c     Calls:  none                                                             |
c                                                                              |
c     Arguments:                                                               |
c                                                                              |
c     n........Integer.  The number of elements in vector.   {input}           |
c     vector...Real vector.  The vector to be sorted.   {input/output}         |
c                 on input:   contains the unsorted vector.                    |
c                 on output:  contains the sorted vector.                      |
c                                                                              |
c     This code taken from Numerical Recipes.                                  |
c-------------------------------------------------------------------------------
c
      integer n,l,ir,i,j
      real    vector(n),elem
c
c=======================================================================
c     Begin executable code.                                           #
c=======================================================================
c
c-----------------------------------------------------------------------
c     Initialize indices for tree creation and sorting.  Protect the   |
c     trivial vector.                                                  |
c-----------------------------------------------------------------------
c
      l = n/2 + 1
      ir = n
      if (ir .le. 1) elem = vector(1)
c
      do 20 while (ir .gt. 1)
c
         if (l .gt. 1) then
c
c-----------------------------------------------------------------------
c           Still creating tree.                                       |
c-----------------------------------------------------------------------
c
            l = l - 1
            elem = vector(l)
c
           else
c
c-----------------------------------------------------------------------
c           Sorting tree.  Root of tree is largest element.  Clear it. |
c-----------------------------------------------------------------------
c
            elem = vector(ir)
            vector(ir) = vector(1)
            ir = ir - 1
c
         end if
c
c-----------------------------------------------------------------------
c        Sift element elem to its proper level.                        |
c-----------------------------------------------------------------------
c
         i = l
         j = l + l
c
         do 10 while (j .le. ir)
c
            if (j .lt. ir) then
c
c-----------------------------------------------------------------------
c              Compare to greater branch.                              |
c-----------------------------------------------------------------------
c
               if (vector(j) .lt. vector(j+1)) j = j + 1
c
            end if
c
            if (elem .lt. vector(j)) then
c
c-----------------------------------------------------------------------
c              Move elem deeper in tree.                               |
c-----------------------------------------------------------------------
c
               vector(i) = vector(j)
               i = j
               j = j + j
c
              else
c
c-----------------------------------------------------------------------
c              Found proper location, get out of loop.                 |
c-----------------------------------------------------------------------
c
               j = ir + 1
c
            end if
c
 10      continue
c
c-----------------------------------------------------------------------
c        Put elem into its proper location.                            |
c-----------------------------------------------------------------------
c
         vector(i) = elem
c
 20   continue
c
c-----------------------------------------------------------------------
c     Finished sorting, replace smallest element.                      |
c-----------------------------------------------------------------------
c
      vector(1) = elem
c
      return
      end
