      subroutine hinit_cpack (hcf,ldh,imt,jmt,rwksp,dimr,iwksp,dimi,
     &                            no_cl,clvl,clmin,clint,block_cl,mapsp,
     &                                                   lmap,radx,rady)
c
c-------------------------------------------------------------------------------
c     This routine initializes the NCAR contouring package CONPACK for the     |
c     hydrostatic consistency factor.                                          |
c                                                                              |
c     Calls:       set_dash                                                    |
c     NCAR Calls:  cpgeti, cpgetr, cppkcl, cprect, cprset, cpsetc, cpseti,     |
c                  cpsetr                                                      |
c                                                                              |
c     Arguments:                                                               |
c                                                                              |
c     block_cl...Logical.  Flag to indicate whether or not to block the drawing|
c                   of contour lines through high/low labels.   {input}        |
c                      .true.   =>  block lines                                |
c                      .false.  =>  do NOT block                               |
c     clint......Real.  Contour interval.  (meters)  (only active if no_cl < 0)|
c                   {input}                                                    |
c     clmin......Real.  Minimum contour level.  (meters)  (only active if      |
c                   no_cl < 0)   {input}                                       |
c     clvl.......Real array.  Contour levels.  (meters)  (only active if       |
c                   no_cl > 0)  {input}                                        |
c     dimi.......Integer.  The dimension of the integer workspace array.       |
c                   {input}                                                    |
c     dimr.......Integer.  The dimension of the real workspace array.   {input}|
c     hcf........Real array.  The hydrostatic consistency factor.   {input}    |
c     imt, jmt...Integer.  The number of row and column elements in the hcf    |
c                   array.   {input}                                           |
c     iwksp......Integer array.  The integer workspace array.   {output}       |
c     ldh........Integer.  The leading dimension of the hcf array.   {input}   |
c     no_cl......Integer.  Number of contour levels.   {input}                 |
c     radx.......Integer.  High/low search radius in x.   {input}              |
c     rady.......Integer.  High/low search radius in y.   {input}              |
c     rwksp......Real array.  The real workspace array.   {output}             |
c-------------------------------------------------------------------------------
c
#include <gpconst.h>
c
      logical block_cl
      integer dimi,dimr,imt,jmt,ldh,iwksp(dimi),no_cl,i,lmap,mapsp(lmap)
     &        ,ncl,radx,rady
      real    hcf(ldh,jmt),rwksp(dimr),clvl(no_cl),clmin,clint,clmax
     &            ,level,spval
      character*8 label
c
      parameter (spval = cm1)
c
c=======================================================================
c     Begin executable code.                                           #
c=======================================================================
c
c-----------------------------------------------------------------------
c     Initialize internal variables to their default states.           |
c-----------------------------------------------------------------------
c
      call cprset ()
c
c-----------------------------------------------------------------------
c     Set mapping to user defined, set coordinate system and block     |
c     any CONPACK calls to the subroutine SET.                         |
c-----------------------------------------------------------------------
c
      call cpseti ('MAP - Mapping flag',1)
      call cpsetr ('XC1 - X coordinate at index 1',c1)
      call cpsetr ('XCM - X coordinate at index M',float(imt))
      call cpsetr ('YC1 - Y coordinate at index 1',c1)
      call cpsetr ('YCN - Y coordinate at index N',float(jmt))
      call cpseti ('SET - Do-SET-call flag',0)
c
c-----------------------------------------------------------------------
c     Set special value for no data areas.  Turn on drawing of edges of|
c     same areas.                                                      |
c-----------------------------------------------------------------------
c
      call cpsetr ('SPV - Special value',spval)
      call cpseti ('PAI - Parameter array index',-2)
      call cpseti ('CLU - Contour level use flags',1)
c
c-----------------------------------------------------------------------
c     Set high/low label information.                                  |
c-----------------------------------------------------------------------
c
      call cpsetc ('HIT - High label text string','H$B$$ZDVU$$E$')
      call cpsetc ('LOT - Low label text string','L$B$$ZDVU$$E$')
      call cpsetr ('HLS - High/low label size',0.009)
      call cpsetr ('HLW - High/low white space width',0.0025)
      call cpseti ('HLX - High/low search radius in x',radx)
      call cpseti ('HLY - High/low search radius in y',rady)
      call cpsetc ('ILT - Informational Label Text string',' ')
c
c-----------------------------------------------------------------------
c     Pick contour levels, if desired.                                 |
c-----------------------------------------------------------------------
c
      if (no_cl .gt. 0) then
c
c-----------------------------------------------------------------------
c        User specifies contour levels individually.                   |
c-----------------------------------------------------------------------
c
         call cpseti ('CLS - Contour level selection flag',0)
         call cpseti ('NCL - Number of contour levels',no_cl)
         do 10 i = 1, no_cl
            call cpseti ('PAI - Parameter array index',i)
            call cpsetr ('CLV - Contour level values',clvl(i))
            call cpseti ('CLU - Contour level use flags',3)
            write (label,30) clvl(i)
            call cpsetc ('LLT - Line label text string',label)
            call set_dash (clvl(i),c2)
 10      continue
c
        else if (no_cl .lt. 0) then
c
c-----------------------------------------------------------------------
c        User specifies minimum contour level and contour interval.    |
c-----------------------------------------------------------------------
c
         clmax = clmin + clint * (abs(no_cl) - 1)
c
         call cpsetr ('CMN - Contour minimum',clmin)
         call cpsetr ('CIS - Contour interval specifier',clint)
         call cpsetr ('CMX - Contour maximum',clmax)
         call cpseti ('CLS - Contour level selection flag',abs(no_cl))
c
      end if
c
c-----------------------------------------------------------------------
c     Initialize CONPACK for rectangular gridded data.                 |
c-----------------------------------------------------------------------
c
      call cprect (hcf,ldh,imt,jmt,rwksp,dimr,iwksp,dimi)
c
c-----------------------------------------------------------------------
c     Initialize area map to exclude contours from high/low labels.    |
c-----------------------------------------------------------------------
c
      if (block_cl) call arinam (mapsp,lmap)
c
c-----------------------------------------------------------------------
c     If levels are not individually set, set dash pattern now.        |
c-----------------------------------------------------------------------
c
      if (no_cl .le. 0) then
c
         call cppkcl (hcf,rwksp,iwksp)
         call cpgeti ('NCL - Number of contour levels',ncl)
         do 20 i = 1, ncl
            call cpseti ('PAI - Parameter array index',i)
            call cpgetr ('CLV - Contour level values',level)
            call set_dash (level,c2)
 20      continue
c
      end if
c
      return
c
 30   format (f8.4)
c
      end
