      subroutine ilocal_mean (kmt,ever)
c
c=======================================================================
c                                                                    ===
c  This subroutine filters the step topography.  This particular     ===
c  version filters by taking the integrated mean of the value and    ===
c  its nearest neighbors.                                            ===
c                                                                    ===
c  ------                                                            ===
c  Input:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     KMT    Number of active vertical levels.       (integer array) ===
c                                                                    ===
c  Common Blocks:                                                    ===
c                                                                    ===
c  /DOM/                                                             ===
c                                                                    ===
c     NO_X   Number of elements in x direction.      (integer)       ===
c     NO_Y   Number of elements in y direction.      (integer)       ===
c                                                                    ===
c  -------                                                           ===
c  Output:                                                           ===
c  -------                                                           ===
c                                                                    ===
c     EVER   Indicates changes to KMT.               (logical)       ===
c               [.true.]  => an element was changed                  ===
c               [.false.] => no element was changed                  ===
c     KMT    Filtered number of vertical levels.     (integer array) ===
c                                                                    ===
c  ------                                                            ===
c  Calls:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     HOPS:    ICOND_REP                                             ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <gridsparm.h>
#include <gpconst.h>
#include <dom.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer i,ival,j,nxm1,nym1
      integer kmt(imt,jmt),wk(imt,jmt)
      real    val
      logical ever
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c-----------------------------------------------------------------------
c  Set penultimate pointers.
c-----------------------------------------------------------------------
c
      nxm1 = no_x - 1
      nym1 = no_y - 1
c
c-----------------------------------------------------------------------
c  Copy data, initialize flag.
c-----------------------------------------------------------------------
c
      do 10 i = 1, no_x
         do 10 j = 1, no_y
            wk(i,j) = kmt(i,j)
 10   continue
c
      ever = .false.
c
c-----------------------------------------------------------------------
c  Find integrated means in first column.
c-----------------------------------------------------------------------
c
      val = float ( wk(1,1) + wk(1,2) + wk(2,1) + wk(2,2) )*p25
      ival = int (val + p5)
      call icond_rep (kmt(1,1),ival,ever)
c
      do 20 i = 2, nxm1
         val = p25*( float(wk(i,1) + wk(i,2)) + p5*float( wk(i-1,1) +
     &               wk(i-1,2) + wk(i+1,1) + wk(i+1,2)) )
         ival = int (val + p5)
         call icond_rep (kmt(i,1),ival,ever)
 20   continue
c
      val = float (wk(no_x,1) + wk(no_x,2) + wk(nxm1,1) +wk(nxm1,2))*p25
      ival = int (val + p5)
      call icond_rep (kmt(no_x,1),ival,ever)
c
c-----------------------------------------------------------------------
c  Find integrated means in central columns.
c-----------------------------------------------------------------------
c
      do 40 j = 2, nym1
c
         val = p25*( float(wk(1,j) + wk(2,j)) + p5*float( wk(1,j-1) +
     &               wk(2,j-1) + wk(1,j+1) + wk(2,j+1)) )
         ival = int (val + p5)
         call icond_rep (kmt(1,j),ival,ever)
c
         do 30 i = 2, nxm1
c
            val = p25*( float(wk(i,j)) + p5*(
     &             float( wk(i,j-1) +wk(i-1,j) + wk(i+1,j) + wk(i,j+1) )
     &       + p5*float(wk(i-1,j-1)+wk(i-1,j+1)+wk(i+1,j-1)+wk(i+1,j+1))
     &        ))
            ival = int (val + p5)
            call icond_rep (kmt(i,j),ival,ever)
c
 30      continue
c
         val = p25*( float(wk(no_x,j) + wk(nxm1,j)) + p5*float(
     &        wk(no_x,j-1) + wk(nxm1,j-1) +wk(no_x,j+1) +wk(nxm1,j+1)) )
         ival = int (val + p5)
         call icond_rep (kmt(no_x,j),ival,ever)
c
 40   continue
c
c-----------------------------------------------------------------------
c  Find means in last column.
c-----------------------------------------------------------------------
c
      val = float( wk(1,no_y) + wk(1,nym1) +wk(2,no_y) +wk(2,nym1) )*p25
      ival = int (val + p5)
      call icond_rep (kmt(1,no_y),ival,ever)
c
      do 50 i = 2, nxm1
         val = p25*( float(wk(i,no_y)+wk(i,nym1)) +p5*float(wk(i-1,no_y)
     &              + wk(i-1,nym1) + wk(i+1,no_y) + wk(i+1,nym1)) )
         ival = int (val + p5)
         call icond_rep (kmt(i,no_y),ival,ever)
 50   continue
c
      val = float (wk(no_x,no_y) + wk(no_x,nym1) + wk(nxm1,no_y) +
     &                                                wk(nxm1,nym1))*p25
      ival = int (val + p5)
      call icond_rep (kmt(no_x,no_y),ival,ever)
c
      return
      end
