      subroutine ilocal_median (kmt,ever)
c
c=======================================================================
c                                                                    ===
c  This subroutine filters the step topography.  This particular     ===
c  version filters by taking the median of the value and its nearest ===
c  neighbors.  The grid points are given the same weighting as in    ===
c  the integral mean.  That is:  center points are listed 4 times,   ===
c  side points twice and corner points once.                         ===
c                                                                    ===
c  ------                                                            ===
c  Input:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     KMT    Number of active vertical levels.       (integer array) ===
c                                                                    ===
c  Common Blocks:                                                    ===
c                                                                    ===
c  /DOM/                                                             ===
c                                                                    ===
c     NO_X   Number of elements in x direction.      (integer)       ===
c     NO_Y   Number of elements in y direction.      (integer)       ===
c                                                                    ===
c  -------                                                           ===
c  Output:                                                           ===
c  -------                                                           ===
c                                                                    ===
c     EVER   Indicates changes to KMT.               (logical)       ===
c               [.true.]  => an element was changed                  ===
c               [.false.] => no element was changed                  ===
c     KMT    Filtered number of vertical levels.     (integer array) ===
c                                                                    ===
c  ------                                                            ===
c  Calls:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     HOPS:    IBOX_LOAD_VEC,  ICOND_REP                             ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <gridsparm.h>
#include <gridsio.h>
#include <gpconst.h>
#include <dom.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer i,ival,j,nxm1,nym1
      integer kmt(imt,jmt),wk(imt,jmt),wkvec(16)
      real    val
      logical error,ever
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c-----------------------------------------------------------------------
c  Set penultimate pointers.
c-----------------------------------------------------------------------
c
      nxm1 = no_x - 1
      nym1 = no_y - 1
c
c-----------------------------------------------------------------------
c  Copy data, initialize error flag and value change flag.
c-----------------------------------------------------------------------
c
      do 10 i = 1, no_x
         do 10 j = 1, no_y
            wk(i,j) = kmt(i,j)
 10   continue
      error = .false.
      ever = .false.
c
c-----------------------------------------------------------------------
c  Find medians in first column.
c-----------------------------------------------------------------------
c
      call ibox_load_vec (wk,wkvec,1,1,1,1,error)
      val = float ( wkvec(2) + wkvec(3) )*p5
      ival = int (val + p5)
      call icond_rep (kmt(1,1),ival,ever)
c
      do 20 i = 2, nxm1
         call ibox_load_vec (wk,wkvec,i-1,i,1,1,error)
         val = float( wkvec(4) + wkvec(5) )*p5
         ival = int (val + p5)
         call icond_rep (kmt(i,1),ival,ever)
 20   continue
c
      call ibox_load_vec (wk,wkvec,nxm1,nxm1,1,1,error)
      val = float ( wkvec(2) + wkvec(3) )*p5
      ival = int (val + p5)
      call icond_rep (kmt(no_x,1),ival,ever)
c
c-----------------------------------------------------------------------
c  Find medians in central columns.
c-----------------------------------------------------------------------
c
      do 40 j = 2, nym1
c
         call ibox_load_vec (wk,wkvec,1,1,j-1,j,error)
         val = float( wkvec(4) + wkvec(5) )*p5
         ival = int (val + p5)
         call icond_rep (kmt(1,j),ival,ever)
c
         do 30 i = 2, nxm1
            call ibox_load_vec (wk,wkvec,i-1,i,j-1,j,error)
            val = float( wkvec(8) + wkvec(9) ) * p5
            ival = int (val + p5)
            call icond_rep (kmt(i,j),ival,ever)
 30      continue
c
         call ibox_load_vec (wk,wkvec,nxm1,nxm1,j-1,j,error)
         val = float( wkvec(4) + wkvec(5) )*p5
         ival = int (val + p5)
         call icond_rep (kmt(no_x,j),ival,ever)
c
 40   continue
c
c-----------------------------------------------------------------------
c  Find medians in last column.
c-----------------------------------------------------------------------
c
      call ibox_load_vec (wk,wkvec,1,1,nym1,nym1,error)
      val = float ( wkvec(2) + wkvec(3) )*p5
      ival = int (val + p5)
      call icond_rep (kmt(1,no_y),ival,ever)
c
      do 50 i = 2, nxm1
         call ibox_load_vec (wk,wkvec,i-1,i,nym1,nym1,error)
         val = float( wkvec(4) + wkvec(5) )*p5
         ival = int (val + p5)
         call icond_rep (kmt(i,no_y),ival,ever)
 50   continue
c
      call ibox_load_vec (wk,wkvec,nxm1,nxm1,nym1,nym1,error)
      val = float ( wkvec(2) + wkvec(3) )*p5
      ival = int (val + p5)
      call icond_rep (kmt(no_x,no_y),ival,ever)
c
      if (error) write (out_unit,60)
#ifdef sunflush
      call flush (out_unit)
#endif
c
      return
c
 60   format (/'+++ Warning:  ILOCAL_MEDIAN -  error while loading ',
     &        'small work vector'/31x,'for median smoothing.')
c
      end
