      subroutine massage_topo (hybrid,target,topog,ldt,imt,jmt)
c
c=======================================================================
c                                                                    ===
c  This routine is a user supplied routine to massage the given      ===
c  topography.                                                       ===
c                                                                    ===
c  ------                                                            ===
c  Input:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     HYBRID     Whether "hybrid" or flat levels.     (logical)      ===
c     IMT, JMT   The dimensions of the data.          (integer)      ===
c     LDT        Leading dimension of TOPOG.          (integer)      ===
c     TARGET     Whether making "target" topography.  (logical)      ===
c     TOPOG      The original topography.             (real array; m)===
c                                                                    ===
c  -------                                                           ===
c  Output:                                                           ===
c  -------                                                           ===
c                                                                    ===
c     TOPOG      The filtered topography.             (real array; m)===
c                                                                    ===
c  ------                                                            ===
c  Calls:                                                            ===
c  ------                                                            ===
c                                                                    ===
#if defined ftmed && defined ftshap
c     HOPS:    GET_CURR_FILT,  GR_EXIT,       LENGTH,                ===
c              RLOCAL_MEDIAN,  SHAP_FILT                             ===
# elif defined ftmed
c     HOPS:    GET_CURR_FILT,  GR_EXIT,       LENGTH,                ===
c              RLOCAL_MEDIAN                                         ===
# elif defined ftshap
c     HOPS:    GET_CURR_FILT,  GR_EXIT,       LENGTH,                ===
c              SHAP_FILT                                             ===
# else
c     HOPS:    GET_CURR_FILT,  GR_EXIT,       LENGTH                 ===
#endif
c     netCDF:  NF_ENDDEF,      NF_INQ_VARID,  NF_PUT_ATT_TEXT,       ===
c              NF_REDEF                                              ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <gridsio.h>
#ifdef ftclip
#  include <gpconst.h>
#endif
#include <netcdf.inc>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer imt,jmt,ldt,sbgn,send,slen,varid
#ifdef ftclip
     &        ,i,j
#endif
#if defined ftmed | defined ftshap
     &        ,no_filt,max_filt
#endif
#ifdef ftshap
     &        ,filt_ord
#endif
      real topog(ldt,jmt)
#ifdef ftclip
     &     ,hshllw,hdeep
#endif
#if defined ftmed || defined ftclip
      logical ever
#endif
      logical      hybrid,target
      character*18 filtname
      character*128 dumm
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
#ifdef ftshap
c-----------------------------------------------------------------------
c  Read in the filter order and number of times to apply it.
c-----------------------------------------------------------------------
c
      read (in_unit,*) filt_ord
      read (in_unit,*) max_filt
c
c-----------------------------------------------------------------------
c  Shapiro filter the topography the indicated number of times.
c-----------------------------------------------------------------------
c
      do 10 no_filt = 1, max_filt
c
         call shap_filt (topog,ldt,imt,jmt,filt_ord)
c
  10  continue
c
c-----------------------------------------------------------------------
c  Echo filter characteristics.
c-----------------------------------------------------------------------
c
      write (out_unit,50) filt_ord,max_filt
c
      if (max_filt.gt.0) then
         write (dumm,60) filt_ord,max_filt
         call length (dumm,slen,sbgn,send)
         if (nf_inq_varid (ncoutid,'tbath',varid) .ne. NF_NOERR) then
            write (out_unit,120) 'tbath'
            call gr_exit ('MASSAGE_TOPO')
         end if
         call get_curr_filt ('tbath',filtname)
         if (nf_redef (ncoutid) .ne. NF_NOERR) then
            write (out_unit,130) 're-enter'
            call gr_exit ('MASSAGE_TOPO')
         end if
         if (nf_put_att_text (ncoutid,varid,filtname,slen,
     &                              dumm(sbgn:send)) .ne. NF_NOERR) then
            write (out_unit,140) 'tbath:'//filtname
            call gr_exit ('MASSAGE_TOPO')
         end if
         if (hybrid.and.target) then
            if (nf_inq_varid (ncoutid,'trg_bath',varid) .ne. NF_NOERR)
     &                                                              then
               write (out_unit,120) 'trg_bath'
               call gr_exit ('MASSAGE_TOPO')
            end if
            call get_curr_filt ('trg_bath',filtname)
            if (nf_put_att_text (ncoutid,varid,filtname,slen,
     &                              dumm(sbgn:send)) .ne. NF_NOERR) then
               write (out_unit,140) 'tbath:'//filtname
               call gr_exit ('MASSAGE_TOPO')
            end if
         end if
         if (nf_enddef (ncoutid) .ne. NF_NOERR) then
            write (out_unit,130) 'exit'
            call gr_exit ('MASSAGE_TOPO')
         end if
      end if
c
#endif
#ifdef ftclip
c-----------------------------------------------------------------------
c  Read in the desired maximum and minimum allowed depths.
c-----------------------------------------------------------------------
c
      read (in_unit,*) hshllw
      read (in_unit,*) hdeep
c
c-----------------------------------------------------------------------
c  Clip the topography to the desired limits.  Echo input.
c-----------------------------------------------------------------------
c
      ever = .false.
c
      do 20 j = 1, jmt
         do 20 i = 1, imt
            ever = ever .or. (topog(i,j).gt.hshllw) .or.
     &                       (topog(i,j).lt.hdeep)
            topog(i,j) = min (topog(i,j),hshllw)
            topog(i,j) = max (topog(i,j),hdeep)
  20  continue
c
      write (out_unit,70) hshllw,hdeep
c
      if (ever) then
         write (dumm,80) hshllw,hdeep
         call length (dumm,slen,sbgn,send)
         if (nf_inq_varid (ncoutid,'tbath',varid) .ne. NF_NOERR) then
            write (out_unit,120) 'tbath'
            call gr_exit ('MASSAGE_TOPO')
         end if
         call get_curr_filt ('tbath',filtname)
         if (nf_redef (ncoutid) .ne. NF_NOERR) then
            write (out_unit,130) 're-enter'
            call gr_exit ('MASSAGE_TOPO')
         end if
         if (nf_put_att_text (ncoutid,varid,filtname,slen,
     &                              dumm(sbgn:send)) .ne. NF_NOERR) then
            write (out_unit,140) 'tbath:'//filtname
            call gr_exit ('MASSAGE_TOPO')
         end if
         if (hybrid.and.target) then
            if (nf_inq_varid (ncoutid,'trg_bath',varid) .ne. NF_NOERR)
     &                                                              then
               write (out_unit,120) 'trg_bath'
               call gr_exit ('MASSAGE_TOPO')
            end if
            call get_curr_filt ('trg_bath',filtname)
            if (nf_put_att_text (ncoutid,varid,filtname,slen,
     &                              dumm(sbgn:send)) .ne. NF_NOERR) then
               write (out_unit,140) 'tbath:'//filtname
               call gr_exit ('MASSAGE_TOPO')
            end if
         end if
         if (nf_enddef (ncoutid) .ne. NF_NOERR) then
            write (out_unit,130) 'exit'
            call gr_exit ('MASSAGE_TOPO')
         end if
      end if
c
#endif
#ifdef ftmed
c-----------------------------------------------------------------------
c  Initialize loop control variables.
c-----------------------------------------------------------------------
c
      no_filt = 0
      ever = .true.
      read (in_unit,*) max_filt
c
c-----------------------------------------------------------------------
c  Replace each element of kmt with the local median of the element
c  and its nearest neighbors in physical space.  Do this process
c  until no more changes occur.
c-----------------------------------------------------------------------
c
      do 30 while (ever .and. (no_filt .lt. max_filt))
c
         call rlocal_median (topog,ever)
         no_filt = no_filt + 1
c
  30  continue
c
c-----------------------------------------------------------------------
c  Echo type of filtering to output unit.  Report number of
c  iterations used.  Indicate if failed to reach steady state.
c-----------------------------------------------------------------------
c
      write (out_unit,90) no_filt,max_filt
      if (ever) write (out_unit,100)
#ifdef sunflush
      call flush (out_unit)
#endif
c
      if ( (no_filt.gt.1) .or. (ever.and.(max_filt.gt.0)) ) then
         write (dumm,110) no_filt
         call length (dumm,slen,sbgn,send)
         if (nf_inq_varid (ncoutid,'tbath',varid) .ne. NF_NOERR) then
            write (out_unit,120) 'tbath'
            call gr_exit ('MASSAGE_TOPO')
         end if
         call get_curr_filt ('tbath',filtname)
         if (nf_redef (ncoutid) .ne. NF_NOERR) then
            write (out_unit,130) 're-enter'
            call gr_exit ('MASSAGE_TOPO')
         end if
         if (nf_put_att_text (ncoutid,varid,filtname,slen,
     &                              dumm(sbgn:send)) .ne. NF_NOERR) then
            write (out_unit,140) 'tbath:'//filtname
            call gr_exit ('MASSAGE_TOPO')
         end if
         if (hybrid.and.target) then
            if (nf_inq_varid (ncoutid,'trg_bath',varid) .ne. NF_NOERR)
     &                                                              then
               write (out_unit,120) 'trg_bath'
               call gr_exit ('MASSAGE_TOPO')
            end if
            call get_curr_filt ('trg_bath',filtname)
            if (nf_put_att_text (ncoutid,varid,filtname,slen,
     &                              dumm(sbgn:send)) .ne. NF_NOERR) then
               write (out_unit,140) 'tbath:'//filtname
               call gr_exit ('MASSAGE_TOPO')
            end if
         end if
         if (nf_enddef (ncoutid) .ne. NF_NOERR) then
            write (out_unit,130) 'exit'
            call gr_exit ('MASSAGE_TOPO')
         end if
      end if
c
#endif
#if defined ftclip & defined lnext
c-----------------------------------------------------------------------
c  Re-clip the topography to the desired limits.
c-----------------------------------------------------------------------
c
      do 40 j = 1, jmt
         do 40 i = 1, imt
            topog(i,j) = max( min( topog(i,j), hshllw) , hdeep )
  40  continue
c
#endif
      return
c
#ifdef ftshap
  50  format (/'Topography filtered by alternating direction Shapiro'
     &      ,' Filter.'/3x,'Filter order:  ',i4/3x,'Number of applicati'
     &      ,'ons:  ',i4)
  60  format ('Shapiro filter:  ORDER ',i4,',  NFILT ',i4)
#endif
#ifdef ftclip
  70  format (/'Topography clipped to prescribed maximum & minimum.'/3x,
     &        'minimum depth = ',1pg15.8, '  (m)'/3x,'maximum depth = ',
     &                                                  1pg15.8,'  (m)')
  80  format ('Clipped:  HSHLLW ',f8.1,',  HDEEP ',f8.1)
#endif
#ifdef ftmed
  90  format (/'Topography filtered by weighted median with neares'
     &      ,'t neighbors.'/3x,'Process repeated until no changes occur'
     &     ,'.'/3x,i4,' iterations.'/3x,'Maximum allowed iterations:  ',
     &        i4)
 100  format (/'+++ Warning:  MASSAGE_TOPO:'/3x,'maximum number of '
     &        ,'iterations reached without attaining steady state.')
 110  format ('Median filter:  NFILT ',i4)
#endif
 120  format (/'***Error:  MASSAGE_TOPO - unable to find variable ',1h",
     &        a,1h")
 130  format (/'***Error:  MASSAGE_TOPO - unable to ',a,' definition'
     &        ,' mode.')
 140  format (/'***Error:  MASSAGE_TOPO - unable to find attribute ',
     &        1h",a,1h")
c
      end
