      subroutine max_slope (ipt,jpt,ldh,no_x,no_y,h,slope)
c
c-------------------------------------------------------------------------------
c     This subroutine computes the maximum of the absolute value of the slope  |
c     in the x or y direction at the given point.                              |
c                                                                              |
c     Calls:  none                                                             |
c                                                                              |
c     Arguments:                                                               |
c                                                                              |
c     h.......Real array.  Topography at T-grid points.  (cm)   {input}        |
c     ipt.....Integer.  X-grid coordinate of the point in question.   {input}  |
c     jpt.....Integer.  Y-grid coordinate of the point in question.   {input}  |
c     ldh.....Integer.  The leading dimension of h.   {input}                  |
c     no_x....Integer.  Number of x grid points.   {input}                     |
c     no_y....Integer.  Number of y grid points.   {input}                     |
c     slope...Real.  The maximum absolute slope.  (cm)   {output}              |
c                                                                              |
c     Note:                                                                    |
c                                                                              |
c        Only the numerator of the slope is evaluated, since the denominator   |
c        would cancel with a dx or dy which would multiply the slope.          |
c-------------------------------------------------------------------------------
c
#include <gpconst.h>
c
      integer ipt,jpt,ldh,no_x,no_y
      real    h(ldh,no_y),slope,dhx,dhy,h1,h2,c1p5
      logical testi,testj
c
      parameter (c1p5 = 1.5)
c
c=======================================================================
c     Begin executable code.                                           #
c=======================================================================
c
c-----------------------------------------------------------------------
c     Determine if point of interest is contained within T-grid.       |
c-----------------------------------------------------------------------
c
      testi = ipt .lt. no_x
      testj = jpt .lt. no_y
c
c-----------------------------------------------------------------------
c     Depending upon location of point, compute maximum absolute slope.|
c-----------------------------------------------------------------------
c
      if (testi .and. testj) then
c
c-----------------------------------------------------------------------
c        Point contained within T-grid.                                |
c-----------------------------------------------------------------------
c
         h1 = p5 * (h(ipt,jpt) + h(ipt,jpt+1))
         h2 = p5 * (h(ipt+1,jpt) + h(ipt+1,jpt+1))
         dhx = abs ( h2 - h1 )
c
         h1 = p5 * (h(ipt,jpt) + h(ipt+1,jpt))
         h2 = p5 * (h(ipt,jpt+1) + h(ipt+1,jpt+1))
         dhy = abs ( h2 - h1 )
c
        else if (testi) then
c
c-----------------------------------------------------------------------
c        Point 1 above T-grid.                                         |
c-----------------------------------------------------------------------
c
         h1 = c1p5*h(ipt,jpt) - p5*h(ipt,jpt-1)
         h2 = c1p5*h(ipt+1,jpt) - p5*h(ipt+1,jpt-1)
         dhx = abs ( h2 - h1 )
c
         h1 = p5 * (h(ipt,jpt) + h(ipt+1,jpt))
         h2 = p5 * (h(ipt,jpt-1) + h(ipt+1,jpt-1))
         dhy = p5 * abs ( h1 - h2 )
c
        else if (testj) then
c
c-----------------------------------------------------------------------
c        Point 1 to right of T-grid.                                   |
c-----------------------------------------------------------------------
c
         h1 = p5 * (h(ipt,jpt) + h(ipt,jpt+1))
         h2 = p5 * (h(ipt-1,jpt) + h(ipt-1,jpt+1))
         dhx = p5 * abs ( h1 - h2 )
c
         h1 = c1p5*h(ipt,jpt) - p5*h(ipt-1,jpt)
         h2 = c1p5*h(ipt,jpt+1) - p5*h(ipt-1,jpt+1)
         dhy = abs ( h2 - h1 )
c
        else
c
c-----------------------------------------------------------------------
c        Top right corner.                                             |
c-----------------------------------------------------------------------
c
         dhx = p5 * abs ( h(ipt,jpt) - h(ipt-1,jpt) )
         dhy = p5 * abs ( h(ipt,jpt) - h(ipt,jpt-1) )
c
      end if
c
      slope = max ( dhx , dhy )
c
      return
      end
