      subroutine newton (f_fprime,xguess,tol,itmax,x,found)
c
c=======================================================================
c                                                                    ===
c  This routine performs Newton iteration to find the solution to    ===
c  the scalar equation F(x) = 0.                                     ===
c                                                                    ===
c  ------                                                            ===
c  Input:                                                            ===
c  ------                                                            ===
c                                                                    ===
c  F_FPRIME   Evaluates F(x) and Fx(x).  Declared                    ===
c             external in the calling routine.           (subroutine)===
c                subroutine f_fprime (x,f,fp)                        ===
c                  input:                                            ===
c                   X    The current guess for x.   (real)           ===
c                  output:                                           ===
c                   F    Objective function at x.   (real)           ===
c                   FP   Derivative of f wrt x @ x. (real)           ===
c  ITMAX      Maximum allowed number of iterations.      (integer)   ===
c  TOL        Tolerance for the Newton iteration.        (real)      ===
c  XGUESS     The initial guess to x.                    (real)      ===
c                                                                    ===
c  -------                                                           ===
c  Output:                                                           ===
c  -------                                                           ===
c                                                                    ===
c  FOUND   Flag to indicate whether solution was found.   (logical)  ===
c          [.true. ]  solution was found.                            ===
c          [.false.]  solution was NOT found.                        ===
c  X       The solution to F(x) = 0.                      (real)     ===
c                                                                    ===
c  Calls:  F_FPRIME                                                  ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      real             tol,x,xguess
      double precision cd1,delta,dtol,f,fp,xwork
      integer          itmax,n
      logical found
c
      external f_fprime
      parameter (cd1=1.0d0)
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c-----------------------------------------------------------------------
c  Make initial pass.
c-----------------------------------------------------------------------
c
      xwork = dble(xguess)
      dtol  = dble(tol)
      n=1
c
      call f_fprime (xwork,f,fp)
c
      delta = f/fp
      xwork = xwork - delta
c
c-----------------------------------------------------------------------
c  Loop until solution is found or maximum iteration is reached.
c-----------------------------------------------------------------------
c
      do 10 while ( ((abs(delta).gt.dtol*max(abs(xwork),cd1))
     &                    .or.(abs(f).gt.dtol))   .and.   (n.lt.itmax) )
c
         n = n + 1
c
         call f_fprime (xwork,f,fp)
c
         delta = f/fp
         xwork = xwork - delta
c
 10   continue
c
c-----------------------------------------------------------------------
c  Transfer working variable to output variable.  Test to see if the
c  solution was found.
c-----------------------------------------------------------------------
c
      x = real(xwork)
      found = (abs(delta).le.dtol*max(abs(xwork),cd1)) .and.
     &        (abs(f).le.dtol)
c
      if (.not. found) write (6,20) delta,max(abs(xwork),cd1),f,tol
c
      return
c
 20   format (/'***Newton failure'/3x,'delta=',1pg15.8/
     &        3x,'max(abs(xwork),c1)=',1pg15.8
     &        /3x,'f=',1pg15.8/3x,'tol=',1pg15.8)
c
      end
