      subroutine plot_cst (type,antind,lonmin,lonmax,latmin,latmax)
c
c=======================================================================
c                                                                    ===
c  This routine adds a filled-coastline to the plot.                 ===
c                                                                    ===
c  ------                                                            ===
c  Input:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     TYPE     Type of coastline to add.           (string)          ===
c               "Land"     Separating land                           ===
c                          from ocean.                               ===
c               "Lake"     Defining land-locked                      ===
c                          lakes.                                    ===
c               "Island"   Defining islands                          ===
c                          within lakes.                             ===
c               "Pond"     Defining ponds within                     ===
c                          islands within lakes.                     ===
c     ANTIND   Index for antarctica.               (integer)         ===
c     LONMIN   Minimum longitude.                  (real; degrees E) ===
c     LONMAX   Maximum longitude.                  (real; degrees E) ===
c     LATMIN   Minimum latitude.                   (real; degrees N) ===
c     LATMAX   Maximum latitude.                   (real; degrees N) ===
c                                                                    ===
c  Common Blocks:                                                    ===
c                                                                    ===
c  /CNTLBL/                                                          ===
c                                                                    ===
c     GRFB   Device coordinate of bottom of graph area.   (real)     ===
c     GRFL   Device coordinate of left of graph area.     (real)     ===
c     GRFR   Device coordinate of right of graph area.    (real)     ===
c     GRFT   Device coordinate of top of graph area.      (real)     ===
c                                                                    ===
c  /GRIDSIO/                                                         ===
c                                                                    ===
c     NCCSTID   Identifier: netCDF input coastline file.   (integer) ===
c                                                                    ===
c  ------                                                            ===
c  Calls:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     HOPS:    ALL_LC,           GR_EXIT,           LENGTH           ===
c     NCAR:    GFA                                                   ===
c     netCDF:  NF_GET_VARA_INT,  NF_GET_VARA_REAL,  NF_INQ_DIMID,    ===
c              NF_INQ_DIMLEN,    NF_INQ_VARID                        ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <gridsparm.h>
#include <gridsio.h>
#include <cntlbl.h>
#include <netcdf.inc>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer antind,boxid,cstid,dimid,indid,m,n,ncst,nuse,tbgn,tend,
     &        tlen
      integer count(2),index(2),start(2)
      logical first
      real    bl2x,bl2y,ml2x,ml2y,latmax,latmin,lonmax,lonmin,tol,xnew,
     &        xold,ynew,yold
      real         box(4),clat(mxcst),clon(mxcst)
      character*80  lctype
      character*(*) type
c
      save first,bl2x,bl2y,ml2x,ml2y,tol
c
      data first /.true./
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c-----------------------------------------------------------------------
c  Save transformation.
c-----------------------------------------------------------------------
c
      if (first) then
         ml2x  = (grfr-grfl) / (lonmax-lonmin)
         bl2x  = grfr - ml2x*lonmax
         ml2y  = (grft-grfb) / (latmax-latmin)
         bl2y  = grft - ml2x*latmax
         tol   = 2.0**(-22.0)
         first = .false.
      endif
c
c-----------------------------------------------------------------------
c  Ensure type is lower case.
c-----------------------------------------------------------------------
c
      call all_lc (type,lctype)
      call length (lctype,tlen,tbgn,tend)
c
c-----------------------------------------------------------------------
c  Look for number of coasts.  If not found, assume this coastal type
c  is not present in the current file.
c-----------------------------------------------------------------------
c
      if (nf_inq_dimid (nccstid,'n'//lctype(tbgn:tend),dimid) .ne.
     &                                                  NF_NOERR) return
c
      if (nf_inq_dimlen (nccstid,dimid,ncst) .ne. NF_NOERR) then
         write (out_unit,900) 'read dimension','n'//lctype(tbgn:tend)
         call gr_exit ('PLOT_CST')
      end if
c
c-----------------------------------------------------------------------
c  Get variable identifiers.
c-----------------------------------------------------------------------
c
c  Get bounding box identifier.
c
      if (nf_inq_varid (nccstid,lctype(tbgn:tend)//'box',boxid) .ne.
     &                                                    NF_NOERR) then
         write (out_unit,900) 'find variable',lctype(tbgn:tend)//'box'
         call gr_exit ('PLOT_CST')
      end if
c
c  Get coastline index identifier.
c
      if (nf_inq_varid (nccstid,lctype(tbgn:tend)//'index',indid) .ne.
     &                                                    NF_NOERR) then
         write (out_unit,900) 'find variable',lctype(tbgn:tend)//'index'
         call gr_exit ('PLOT_CST')
      end if
c
c  Get coastline identifier.
c
      if (nf_inq_varid (nccstid,lctype(tbgn:tend),cstid) .ne.
     &                                                    NF_NOERR) then
         write (out_unit,900) 'find variable',lctype(tbgn:tend)
         call gr_exit ('PLOT_CST')
      end if
c
c-----------------------------------------------------------------------
c  Loop over all coasts, adding potential candidates to plot.
c-----------------------------------------------------------------------
c
      do 10 n = 1, ncst
c
c  Get bounding box.
c
         start(1) = 1
         start(2) = n
         count(1) = 4
         count(2) = 1
c
         if (nf_get_vara_real (nccstid,boxid,start,count,box) .ne.
     &                                                    NF_NOERR) then
            write (out_unit,900) 'read variable',
     &                           lctype(tbgn:tend)//'box'
            call gr_exit ('PLOT_CST')
         end if
c
c  If bounding box is compatible with plot window, add coastline.
c
         if (.not.((box(2).lt.lonmin).or.(box(1).gt.lonmax).or.
     &            (box(4).lt.latmin).or.(box(3).gt.latmax) ) ) then
c
c    Get location of nth coast.
c
            count(1) = 2
c
            if (nf_get_vara_int (nccstid,indid,start,count,index) .ne.
     &                                                    NF_NOERR) then
               write (out_unit,900) 'read variable',
     &                              lctype(tbgn:tend)//'index'
               call gr_exit ('PLOT_CST')
            end if
c
c    Get nth coast.
c
            start(1) = 1
            start(2) = index(1) + 1
            count(1) = 1
            count(2) = index(2)
c
            if (nf_get_vara_real (nccstid,cstid,start,count,clon) .ne.
     &                                                    NF_NOERR) then
               write (out_unit,900) 'read variable',
     &                              lctype(tbgn:tend)//' (lon)'
               call gr_exit ('PLOT_CST')
            end if
c
            start(1) = 2
c
            if (nf_get_vara_real (nccstid,cstid,start,count,clat) .ne.
     &                                                    NF_NOERR) then
               write (out_unit,900) 'read variable',
     &                              lctype(tbgn:tend)//' (lat)'
               call gr_exit ('PLOT_CST')
            end if
c
c    If drawing antarctica, close it in the XY plane.
c
            if (n.eq.antind) then
               clon(index(2)+1) = 180.0
               clon(index(2)+2) = -180.0
               clat(index(2)+1) = -90.0
               clat(index(2)+2) = -90.0
               index(2)         = index(2) + 2
            end if
c
c    Try removing duplicate points.
c
            nuse = 1
            xold = ml2x*clon(nuse) + bl2x
            yold = ml2y*clat(nuse) + bl2y
c
            do 5 m = 2, index(2)
               xnew = ml2x*clon(m) + bl2x
               ynew = ml2y*clat(m) + bl2y
               if (sqrt((xnew-xold)**2 + (ynew-yold)**2).gt.tol) then
                  nuse       = nuse + 1
                  clon(nuse) = clon(m)
                  clat(nuse) = clat(m)
                  xold       = xnew
                  yold       = ynew
               end if
   5        continue
c
c    Draw filled coastline.
c
            call gfa (nuse,clon,clat)
            call curve (clon,clat,nuse)
c
         end if
c
  10  continue
c
      return
c
 900  format (/'***Error:  PLOT_CST - unable to ',a,2h ",a,1h")
c
      end
