      subroutine plt_grid (tlat,blon,blat,plot_grid,antind)
c
c=======================================================================
c                                                                    ===
c  This routine plots the PE grid.                                   ===
c                                                                    ===
c  ------                                                            ===
c  Input:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     ANTIND       Index for antarctica.               (integer)     ===
c     BLON, BLAT   Longitude & latitude of the                       ===
c                  lower right corner of the plot.  (real; deg)      ===
c     PLOT_GRID    Flag for plotting PE grid.       (logical)        ===
c     TLAT         Latitude of the upper left                        ===
c                  corner of the plot.              (real; deg)      ===
c                                                                    ===
c  Common Blocks:                                                    ===
c                                                                    ===
c  /DOM/                                                             ===
c                                                                    ===
c     NO_X   Number of elements in x direction.   (integer)          ===
c     NO_Y   Number of elements in y direction.   (integer)          ===
c                                                                    ===
c  /TITLES/                                                          ===
c                                                                    ===
c     GRD_TTL   Title of the grid plot.   (string)                   ===
c                                                                    ===
c  /TOPMAP/                                                          ===
c                                                                    ===
c     GEO_TLAT   Latitude of T gridpoints.         (real array; deg) ===
c     GEO_TLON   Longitude of T gridpoints.        (real array; deg) ===
c     TLON       Longitude: top left corner.       (real; deg)       ===
c                                                                    ===
c  ------                                                            ===
c  Calls:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     HOPS:    SET_FRAME_GEO                                         ===
c     NCAR:    CURVE,         FRAME                                  ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <gridsparm.h>
#include <gridsio.h>
#include <dom.h>
#include <titles.h>
#include <topmap.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer antind,i,j
      logical plot_grid
      real    blat,blon,tlat
      real x(ijmx),xrng(2),y(ijmx),yrng(2)
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c-----------------------------------------------------------------------
c  Save plot limits.
c-----------------------------------------------------------------------
c
      xrng(1) = tlon
      xrng(2) = blon
      yrng(1) = blat
      yrng(2) = tlat
c
c-----------------------------------------------------------------------
c  Plot PE grid.
c-----------------------------------------------------------------------
c
      if (plot_grid) then
c
         call set_frame_geo (xrng,yrng,grd_ttl,' ',antind)
c
         do 20 i = 1, no_x
            do 10 j = 1, no_y
               x(j) = geo_tlon(i,j)
               y(j) = geo_tlat(i,j)
  10        continue
            call curve ( x, y, no_y )
  20     continue
c
         do 40 j = 1, no_y
            do 30 i = 1, no_x
               x(i) = geo_tlon(i,j)
               y(i) = geo_tlat(i,j)
  30        continue
            call curve ( x, y, no_x )
  40     continue
c
         call frame
c
      end if
c
#ifdef sunflush
      call flush (out_unit)
#endif
c
      return
      end
