      subroutine plt_hcf (tlat,blon,blat,hcf,hno_cl,hclvl,hclmin,hclint,
     &                    hblock_cl,antind)
c
c=======================================================================
c                                                                    ===
c  This routine contours the  hydrostatic consistency factor.        ===
c                                                                    ===
c  ------                                                            ===
c  Input:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     ANTIND       Index for antarctica.               (integer)     ===
c     BLON, BLAT   Longitude & latitude of the                       ===
c                  lower right corner of the plot.     (real; deg)   ===
c     HBLOCK_CL    Flag for blocking contour lines                   ===
c                  through level markers.              (logical)     ===
c     HCF          Hydrostatic consistency factor.     (real array)  ===
c     HCLINT       Contour level interval.             (real)        ===
c     HCLMIN       Minimum contour level.              (real)        ===
c     HCLVL        Contour levels                      (real vector) ===
c     HNO_CL       Number of contour levels.           (integer)     ===
c     TLAT         Latitude of the upper left                        ===
c                  corner of the plot.                 (real; deg)   ===
c                                                                    ===
c  Common Blocks:                                                    ===
c                                                                    ===
c  /DOM/                                                             ===
c                                                                    ===
c     NO_X   Number of elements in x direction.   (integer)          ===
c     NO_Y   Number of elements in y direction.   (integer)          ===
c                                                                    ===
c  /HCFMAP/                                                          ===
c                                                                    ===
c     GEO_LAT   Latitude of UV gridpoints.         (real array; deg) ===
c     GEO_LON   Longitude of UV gridpoints.        (real array; deg) ===
c                                                                    ===
c  /SEARCH/                                                          ===
c                                                                    ===
c     HRADX   High/Low search radius in X-direction.   (integer)     ===
c     HRADY   High/Low search radius in Y-direction.   (integer)     ===
c                                                                    ===
c  /TITLES/                                                          ===
c                                                                    ===
c     STP_TTL   Title of the HCF topography plot.   (string)         ===
c                                                                    ===
c  /TOPMAP/                                                          ===
c                                                                    ===
c     TLON       Longitude: top left corner.       (real; deg)       ===
c                                                                    ===
c  ------                                                            ===
c  Calls:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     HOPS:    HCNTR_LBL,  HINIT_CPACK,  SET_FRAME_GEO,  TOP_BOX     ===
c     NCAR:    CPCLDM,     CPCLDR,       CPDRPL,         CPGETI,     ===
c              CPLBAM,     CPLBDR,       FRAME                       ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <gridsparm.h>
#include <gridsio.h>
#include <dom.h>
#include <hcfmap.h>
#include <search.h>
#include <titles.h>
#include <topmap.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer antind,iwu,hno_cl,lmap,n,rwu
      integer iwksp(dimi),mapsp(dimm)
      logical hblock_cl
      real    blon,blat,hclint,hclmin,tlat
      real hcf(imt,jmt,2),hclvl(max_cl),rwksp(dimr),xrng(2),yrng(2)
c
      external cpdrpl
c
      data lmap /dimm/
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c-----------------------------------------------------------------------
c  Save plot limits.
c-----------------------------------------------------------------------
c
      xrng(1) = tlon
      xrng(2) = blon
      yrng(1) = blat
      yrng(2) = tlat
c
c-----------------------------------------------------------------------
c  Contour hydrostatic consistency factor or draw step levels.
c-----------------------------------------------------------------------
c
      do 10 n = 1, 2
c
         call set_frame_geo (xrng,yrng,stp_ttl,' ',antind)
c
         uv_flag = .true.
         call top_box (geo_lon,geo_lat,imt,no_x,no_y)
         call hinit_cpack (hcf(1,1,n),imt,no_x,no_y,rwksp,dimr,
     &                      iwksp,dimi,hno_cl,hclvl,hclmin,hclint,
     &                           hblock_cl,mapsp,lmap,hradx,hrady)
c
         call cplbdr (hcf(1,1,n),rwksp,iwksp)
         if (hblock_cl) then
            call cplbam (hcf(1,1,n),rwksp,iwksp,mapsp)
            call cpcldm (hcf(1,1,n),rwksp,iwksp,mapsp,cpdrpl)
           else
            call cpcldr (hcf(1,1,n),rwksp,iwksp)
         end if
         call hcntr_lbl (hno_cl,hclint,n)
         call cpgeti ('RWU -- Real Workspace Usage',rwu)
         call cpgeti ('IWU -- Integer Workspace Usage',iwu)
         if (rwu .gt. dimr) write (out_unit,20) rwu,dimr
         if (iwu .gt. dimi) write (out_unit,30) iwu,dimi
c
         call frame
c
  10  continue
c
#ifdef sunflush
      call flush (out_unit)
c
#endif
      return
c
  20  format (/'+++ Warning:  PLT_HCF - Possible error in CONPACK'
     &       /25x,'Used ',i10,' elements in real workspace.'
     &       /25x,'Allocated ',i10,' elements in real workspace.')
  30  format (/'+++ Warning:  PLT_HCF - Possible error in CONPACK'
     &         /25x,'Used ',i10,' elements in integer workspace.'
     &          /25x,'Allocated ',i10,' elements in integer workspace.')
c
      end
