      subroutine plt_init (antind)
c
c=======================================================================
c                                                                    ===
c  This routine performs the necessary tasks to initialize the       ===
c  plotting routines.                                                ===
c                                                                    ===
c  ------                                                            ===
c  Input:                                                            ===
c  ------                                                            ===
c                                                                    ===
c  Common Blocks:                                                    ===
c                                                                    ===
c  /GRIDSIO/                                                         ===
c                                                                    ===
c     CST_FILE   Name of coastline netCDF file.            (string)  ===
c     CSTUNIT    Unit number: ASCII coastline data file.   (integer) ===
c                                                                    ===
c  /PLTNCAR/                                                         ===
c                                                                    ===
c     ESC_CHAR  Escape character to be used in NCAR.  (string)       ===
c                                                                    ===
c  -------                                                           ===
c  Output:                                                           ===
c  -------                                                           ===
c                                                                    ===
c     ANTIND   Index for antarctica.                       (integer) ===
c                                                                    ===
c  Common Blocks:                                                    ===
c                                                                    ===
c  /GRIDSIO/                                                         ===
c                                                                    ===
c     CSTSTAT   Status flag for coast line data file.      (integer) ===
c     NCCSTID   Identifier: netCDF input coastline file.   (integer) ===
c                                                                    ===
c  ------                                                            ===
c  Calls:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     HOPS:    LENGTH                                                ===
c     NCAR:    GSCR,            OPNGKS,   PCSETC                     ===
c     netCDF:  NF_GET_ATT_INT,  NF_OPEN                              ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <gridsparm.h>
#include <gpconst.h>
#include <gridsio.h>
#include <pltncar.h>
#include <netcdf.inc>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer antind,ios,nlong,sbgn,send,slen
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c-----------------------------------------------------------------------
c  Initialize plotting package.
c-----------------------------------------------------------------------
c
      call opngks
c
c-----------------------------------------------------------------------
c  Initialize the coloring scheme.
c-----------------------------------------------------------------------
c
c  Set background color to white.
c
      call gscr (1,0,c1,c1,c1)
c
c  Set foreground color to black.
c
      call gscr (1,1,c0,c0,c0)
c
c  Set land color to light gray.
c
      call gscr (1,2,p9,p9,p9)
c
c-----------------------------------------------------------------------
c  Set graphic string code.
c-----------------------------------------------------------------------
c
      call pcsetc ('FC - Function Code delimiter',esc_char)
c
c-----------------------------------------------------------------------
c  Open coastline dataset.
c-----------------------------------------------------------------------
c
c  Make sure supplied name is valid.
c
      call length (cst_file,slen,sbgn,send)
c
      if (slen.lt.1) then
         write (out_unit,900)
         return
      end if
c
c  Open coastline file.
c
      if (nf_open(cst_file(sbgn:send),NF_NOWRITE,nccstid) .eq. NF_NOERR)
     &                                                              then
         cststat = 1
       else
         open (cstunit, file=cst_file(sbgn:send), status='old',
     &         form='formatted', access='sequential', iostat=ios)
         if (ios.eq.0) then
            cststat = -1
          else
            write (out_unit,910) cst_file(sbgn:send)
         end if
         return
      end if
c
c  Determine longest allowed coastline.
c
      if (nf_get_att_int (nccstid,NF_GLOBAL,'max_coast',nlong) .eq.
     &                                                    NF_NOERR) then
         if (nclong.gt.mxcst) then
            write (out_unit,920) cst_file(sbgn:send),nclong,mxcst
            cststat = 0
            return
         end if
       else
         write (out_unit,930) cst_file(sbgn:send)
         cststat = 0
         return
      end if
c
c  Determine location of antarctica.
c
      if (nf_get_att_int (nccstid,NF_GLOBAL,'antarctica',antind) .ne.
     &                                                    NF_NOERR) then
         antind = 0
      end if
c
      return
c
 900  format (/'+++Warning:  PLT_INIT - blank filename for coastline ',
     &         'dataset.')
 910  format (/'+++Warning:  PLT_INIT - unable to open coastline data',
     &         'file:'/13x,1h",a,1h")
 920  format (/'+++Warning:  PLT_INIT - insufficient space for ',
     &         'coastlines in file:'/13x,1h",a,1h"/13x,'longest coast:',
     &         i10/13x,'Max. allowed size (MXCST):',i10)
 930  format (/'+++Warning:  PLT_INIT - unable to read coastline data',
     &         'file:'/13x,1h",a,1h")
c
      end
