      subroutine plt_invalid (tlat,blon,blat,kmt,hybrid,pltbad,antind)
c
c=======================================================================
c                                                                    ===
c  This routine plots the locations where the vertical coordinate    ===
c  system becomes invalid.                                           ===
c                                                                    ===
c  ------                                                            ===
c  Input:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     ANTIND       Index for antarctica.             (integer)       ===
c     BLON, BLAT   Longitude & latitude of the                       ===
c                  lower right corner of the plot.   (real; deg)     ===
c     HYBRID       Flag for terrain coord. sys.      (logical)       ===
c     KMT          Number of active vertical levels. (integer array) ===
c     PLTBAD       Plot bad points or not.           (logical)       ===
c     TLAT         Latitude of the upper left                        ===
c                  corner of the plot.               (real; deg)     ===
c                                                                    ===
c  Common Blocks:                                                    ===
c                                                                    ===
c  /DOM/                                                             ===
c                                                                    ===
c     NO_X   Number of elements in x direction.   (integer)          ===
c     NO_Y   Number of elements in y direction.   (integer)          ===
c                                                                    ===
c  /TOPMAP/                                                          ===
c                                                                    ===
c     GEO_TLON   Longitude of T gridpoints.        (real array; deg) ===
c     GEO_TLAT   Latitude of T gridpoints.         (real array; deg) ===
c     TLON       Longitude: top left corner.       (real; deg)       ===
c                                                                    ===
c  ------                                                            ===
c  Calls:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     HOPS:    SET_FRAME_GEO,  STEP_LINES                            ===
c     NCAR:    FRAME                                                 ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <gridsparm.h>
#include <gridsio.h>
#include <dom.h>
#include <topmap.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer antind
      integer kmt(imt,jmt)
      logical hybrid,pltbad
      real    blat,blon,tlat
      real xrng(2),yrng(2)
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c-----------------------------------------------------------------------
c  Save plot limits.
c-----------------------------------------------------------------------
c
      xrng(1) = tlon
      xrng(2) = blon
      yrng(1) = blat
      yrng(2) = tlat
c
c-----------------------------------------------------------------------
c  Plot the locations of any bad points.
c-----------------------------------------------------------------------
c
      if (hybrid.and.pltbad) then
         call set_frame_geo (xrng,yrng,'Locations of invalid vertical'
     &                       //' coordinate systems',' ',antind)
         call step_lines (imt,no_x,no_y,kmt,geo_tlon,geo_tlat)
         call frame
      end if
c
#ifdef sunflush
      call flush (out_unit)
c
#endif
      return
      end
