      subroutine plt_step (tlat,blon,blat,kmt,antind)
c
c=======================================================================
c                                                                    ===
c  This routine joins points of constant step topography level.      ===
c                                                                    ===
c  ------                                                            ===
c  Input:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     ANTIND       Index for antarctica.             (integer)       ===
c     BLON, BLAT   Longitude & latitude of the                       ===
c                  lower right corner of the plot.   (real; deg)     ===
c     KMT          Number of active vertical levels. (integer array) ===
c     TLAT         Latitude of the upper left                        ===
c                  corner of the plot.               (real; deg)     ===
c                                                                    ===
c  Common Blocks:                                                    ===
c                                                                    ===
c  /DOM/                                                             ===
c                                                                    ===
c     NO_X   Number of elements in x direction.   (integer)          ===
c     NO_Y   Number of elements in y direction.   (integer)          ===
c                                                                    ===
c  /TITLES/                                                          ===
c                                                                    ===
c     STP_TTL   Title of the step topography plot.   (string)        ===
c                                                                    ===
c  /TOPMAP/                                                          ===
c                                                                    ===
c     GEO_TLAT   Latitude of T gridpoints.         (real array; deg) ===
c     GEO_TLON   Longitude of T gridpoints.        (real array; deg) ===
c     TLON       Longitude: top left corner.       (real; deg)       ===
c                                                                    ===
c  ------                                                            ===
c  Calls:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     HOPS:    SET_FRAME_GEO,  STEP_LINES                            ===
c     NCAR:    FRAME                                                 ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <gridsparm.h>
#include <gridsio.h>
#include <dom.h>
#include <titles.h>
#include <topmap.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer antind
      integer kmt(imt,jmt)
      real    blat,blon,tlat
      real xrng(2),yrng(2)
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c-----------------------------------------------------------------------
c  Save plot limits.
c-----------------------------------------------------------------------
c
      xrng(1) = tlon
      xrng(2) = blon
      yrng(1) = blat
      yrng(2) = tlat
c
c-----------------------------------------------------------------------
c  Plot the step topography.
c-----------------------------------------------------------------------
c
      call set_frame_geo (xrng,yrng,stp_ttl,' ',antind)
      call step_lines (imt,no_x,no_y,kmt,geo_tlon,geo_tlat)
      call frame
c
#ifdef sunflush
      call flush (out_unit)
c
#endif
      return
      end
