      subroutine plt_topo (tlat,blon,blat,topog,top_err,no_cl,clvl,
     &                     clmin,clint,block_cl,cont_top,antind)
c
c=======================================================================
c                                                                    ===
c  This routine contours the topography.                             ===
c                                                                    ===
c  ------                                                            ===
c  Input:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     ANTIND       Index for antarctica.            (integer)        ===
c     BLOCK_CL     Flag for blocking contour lines                   ===
c                  through level markers.           (logical)        ===
c     BLON, BLAT   Longitude & latitude of the                       ===
c                  lower right corner of the plot.  (real; deg)      ===
c     CLINT        Contour level interval.          (real; m)        ===
c     CLMIN        Minimum contour level.           (real; m)        ===
c     CLVL         Contour levels                   (real vector; m) ===
c     CONT_TOP     Flag for contouring topography.  (logical)        ===
c     NO_CL        Number of contour levels.        (integer)        ===
c     TLAT         Latitude of the upper left                        ===
c                  corner of the plot.              (real; deg)      ===
c     TOP_ERR      Flag for topography error.       (logical)        ===
c     TOPOG        Topography at T grid points.     (real array; m)  ===
c                                                                    ===
c  Common Blocks:                                                    ===
c                                                                    ===
c  /DOM/                                                             ===
c                                                                    ===
c     NO_X   Number of elements in x direction.   (integer)          ===
c     NO_Y   Number of elements in y direction.   (integer)          ===
c                                                                    ===
c  /SEARCH/                                                          ===
c                                                                    ===
c     RADX   High/Low search radius in X-direction.   (integer)      ===
c     RADY   High/Low search radius in Y-direction.   (integer)      ===
c                                                                    ===
c  /TITLES/                                                          ===
c                                                                    ===
c     CNTR_TTL   Title of the topography contour plot.   (string)    ===
c                                                                    ===
c  /TOPMAP/                                                          ===
c                                                                    ===
c     GEO_TLAT   Latitude of T gridpoints.         (real array; deg) ===
c     GEO_TLON   Longitude of T gridpoints.        (real array; deg) ===
c     TLON       Longitude: top left corner.       (real; deg)       ===
c                                                                    ===
c  ------                                                            ===
c  Calls:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     HOPS:    CNTR_LBL,  INIT_CPACK,  SET_FRAME_GEO,  TOP_BOX       ===
c     NCAR:    CPCLDM,    CPCLDR,      CPDRPL,         CPGETI,       ===
c              CPLBAM,    CPLBDR,      FRAME                         ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <gridsparm.h>
#include <gridsio.h>
#include <dom.h>
#include <hcfmap.h>
#include <search.h>
#include <titles.h>
#include <topmap.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer antind,rwu,iwu,no_cl,lmap
      integer iwksp(dimi),mapsp(dimm)
      logical block_cl,cont_top,top_err
      real    blat,blon,clint,clmin,tlat
      real clvl(no_cl),rwksp(dimr),topog(imt,jmt),xrng(2),yrng(2)
c
      external cpdrpl
c
      data lmap /dimm/
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c-----------------------------------------------------------------------
c  Save plot limits.
c-----------------------------------------------------------------------
c
      xrng(1) = tlon
      xrng(2) = blon
      yrng(1) = blat
      yrng(2) = tlat
c
c-----------------------------------------------------------------------
c  Contour topography, if computed successfully.
c-----------------------------------------------------------------------
c
      if ((.not. top_err) .and. cont_top) then
c
         uv_flag = .false.
         call set_frame_geo (xrng,yrng,cntr_ttl,' ',antind)
         call top_box (geo_tlon,geo_tlat,imt,no_x,no_y)
         call init_cpack (topog,imt,no_x,no_y,rwksp,dimr,iwksp,dimi,
     &                       no_cl,clvl,clmin,clint,block_cl,mapsp,lmap,
     &                                                        radx,rady)
         call cplbdr (topog,rwksp,iwksp)
         if (block_cl) then
            call cplbam (topog,rwksp,iwksp,mapsp)
            call cpcldm (topog,rwksp,iwksp,mapsp,cpdrpl)
           else
            call cpcldr (topog,rwksp,iwksp)
         end if
         call cntr_lbl (no_cl,clint)
         call cpgeti ('RWU -- Real Workspace Usage',rwu)
         call cpgeti ('IWU -- Integer Workspace Usage',iwu)
         call frame
         if (rwu .gt. dimr) write (out_unit,20) rwu,dimr
         if (iwu .gt. dimi) write (out_unit,30) iwu,dimi
c
        else
c
         if (top_err) write (out_unit,10)
c
      end if
c
#ifdef sunflush
      call flush (out_unit)
#endif
c
      return
c
 10   format (/'+++ Warning:  PLT_TOPO - Error occurred while computing'
     &        ,' topography.'/25x,'No contour map will be produced.')
 20   format (/'+++ Warning:  PLT_TOPO - Possible error in CONPACK'
     &       /25x,'Used ',i10,' elements in real workspace.'
     &       /25x,'Allocated ',i10,' elements in real workspace.')
 30   format (/'+++ Warning:  PLT_TOPO - Possible error in CONPACK'
     &         /25x,'Used ',i10,' elements in integer workspace.'
     &          /25x,'Allocated ',i10,' elements in integer workspace.')
c
      end
