      subroutine pos_inq (ncid,ncname,varname,compact,origin,delta)
c
c=======================================================================
c                                                                    ===
c  This routine determines the coordinate data.                      ===
c                                                                    ===
c  ------                                                            ===
c  Input:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     NCID      NetCDF file identifier.                 (integer)    ===
c     NCNAME    NetCDF file name.                       (character)  ===
c     VARNAME   Variable name.                          (character)  ===
c     COMPACT   Flag for compact or explicit storage.   (logical)    ===
c                                                                    ===
c  -------                                                           ===
c  Output:                                                           ===
c  -------                                                           ===
c                                                                    ===
c     ORIGIN    Coordinate starting value.              (real; deg)  ===
c     DELTA     Coordinate step size.                   (real; deg)  ===
c                                                                    ===
c  ------                                                            ===
c  Calls:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     HOPS:    GR_EXIT,           LENGTH                             ===
c     netCDF:  NF_GET_VARA_REAL,  NF_INQ_DIMLEN,  NF_INQ_VARDIMID,   ===
c              NF_INQ_VARID                                          ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <gridsio.h>
#include <netcdf.inc>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer n,ncid,ndim,sbgn,send,slen,varid
      integer count(2),dims(NF_MAX_VAR_DIMS),start(2)
      real    delta,origin,vold
      real    vals(2)
      logical       compact
      character*(*) ncname,varname
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c-----------------------------------------------------------------------
c  Get variable identifier.
c-----------------------------------------------------------------------
c
      if (nf_inq_varid (ncid,varname,varid) .ne. NF_NOERR) then
         call length (ncname,slen,sbgn,send)
         write (out_unit,20) varname,ncname(sbgn:send)
         call gr_exit ('POS_INQ')
      end if
c
c-----------------------------------------------------------------------
c  Read coordinate data depending upon storage type.
c-----------------------------------------------------------------------
c
      if (compact) then
c
c  Read compact storage data.
c
         if (index(varname,'lon').ne.0) then
            start(1) = 1
           else
            start(1) = 2
         end if
         start(2) = 1
         count(1) = 1
         count(2) = 2
c
         if (nf_get_vara_real (ncid,varid,start,count,vals)
     &                                               .ne. NF_NOERR) then
            call length (ncname,slen,sbgn,send)
            write (out_unit,30) varname,ncname(sbgn:send)
            call gr_exit ('POS_INQ')
         end if
c
         origin = vals(1)
         delta  = vals(2)
c
       else
c
c  Read explicit storage data.  Determine length of data.
c
         if (nf_inq_vardimid (ncid,varid,dims) .ne. NF_NOERR) then
            call length (ncname,slen,sbgn,send)
            write (out_unit,40) varname,ncname(sbgn:send)
            call gr_exit ('POS_INQ')
         end if
c
         if (nf_inq_dimlen (ncid,dims(1),ndim) .ne. NF_NOERR) then
            call length (ncname,slen,sbgn,send)
            write (out_unit,50) dims(1),ncname(sbgn:send)
            call gr_exit ('POS_INQ')
         end if
c
c  Get first value and first guess of spacing.
c
         start(1) = 1
         count(1) = 2
         if (nf_get_vara_real (ncid,varid,start,count,vals)
     &                                               .ne. NF_NOERR) then
            call length (ncname,slen,sbgn,send)
            write (out_unit,30) varname,ncname(sbgn:send)
            call gr_exit ('POS_INQ')
         end if
c
         origin = vals(1)
         delta  = abs(vals(2)-vals(1))
         vold   = abs(vals(2)+vals(1))
c
c  Compute spacing based on difference of smallest values.
c
         do 10 n = 2, (ndim-1)
c
            start(1) = n
            if (nf_get_vara_real (ncid,varid,start,count,vals)
     &                                               .ne. NF_NOERR) then
               call length (ncname,slen,sbgn,send)
               write (out_unit,30) varname,ncname(sbgn:send)
               call gr_exit ('POS_INQ')
            end if
c
            if (abs(vals(2)+vals(1)).lt.vold) then
               delta  = abs(vals(2)-vals(1))
               vold   = abs(vals(2)+vals(1))
            end if
c
 10      continue
c
      end if
c
      return
c
 20   format ('*** Error:  POS_INQ - unable to find variable ',1h",
     &        a,1h"/12x,'in file ',1h",a,2h".)
 30   format ('*** Error:  POS_INQ - unable to read variable ',1h",
     &        a,1h"/12x,'in file ',1h",a,2h".)
 40   format ('*** Error:  POS_INQ - unable to inquire about',
     &        ' variable ',1h",a,1h"/12x,'in file ',1h",a,2h".)
 50   format ('*** Error:  POS_INQ - unable to inquire about',
     &        ' dimension ',i10/12x,'in file ',1h",a,2h".)
c
      end
