      subroutine prv_depth (hybrid,target,topog,top_err)
c
c=======================================================================
c                                                                    ===
c  This routine massages a previously created topography data file.  ===
c                                                                    ===
c  ------                                                            ===
c  Input:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     HYBRID    Flag for step or sigma system.            (logical)  ===
c     TARGET    Flag for producing "target" topography.   (logical)  ===
c                                                                    ===
c  Common Blocks:                                                    ===
c                                                                    ===
c  /DOM/                                                             ===
c                                                                    ===
c     NO_X   Number of elements in x direction.   (integer)          ===
c     NO_Y   Number of elements in y direction.   (integer)          ===
c                                                                    ===
c  /GRIDSIO/                                                         ===
c                                                                    ===
c     NCOUTID   Identifier number for netCDF output file.  (integer) ===
c                                                                    ===
c  -------                                                           ===
c  Output:                                                           ===
c  -------                                                           ===
c                                                                    ===
c     TOP_ERR   Error flag.                      (logical)           ===
c     TOPOG     Topography at T-grid.            (real array; m)     ===
c                                                                    ===
c  Common Blocks:                                                    ===
c                                                                    ===
c  /TPMED/                                                           ===
c                                                                    ===
c     HMED   The median topographic depth.  (real; m)                ===
c                                                                    ===
c  /TPSTT/                                                           ===
c                                                                    ===
c     HMAX   Maximum depth.  (real; m)                               ===
c     HMIN   Minimum depth.  (real; m)                               ===
c                                                                    ===
c  ------                                                            ===
c  Calls:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     HOPS:    GR_EXIT,           MASSAGE_TOPO,  SET_VGRID,          ===
c              TOPO_STAT                                             ===
c     netCDF:  NF_GET_VARA_REAL,  NF_INQ_VARID,  NF_PUT_VARA_REAL    ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data
c-----------------------------------------------------------------------
c
#include <gridsparm.h>
#include <gridsio.h>
#include <gpconst.h>
#include <netcdf.inc>
#include <dom.h>
#include <tpmed.h>
#include <tpstt.h>
c
c-----------------------------------------------------------------------
c  Define local data
c-----------------------------------------------------------------------
c
      integer j,varid,varidt
      integer count(2),start(2)
      logical hybrid,target,top_err
      real    hmen,hrms
      real topog(imt,jmt)
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c-----------------------------------------------------------------------
c  Read topography row by row until done reading or an error occurs.
c  Check for error, end of file or incorrect number of elements.
c-----------------------------------------------------------------------
c
      top_err = .false.
      if (nf_inq_varid (ncoutid,'tbath',varid) .ne. NF_NOERR) then
         top_err = .true.
         write (out_unit,30) 'tbath'
      end if
c
      if (.not. top_err) then
c
         start(1) = 1
         count(1) = no_x
         count(2) = 1
c
         do 10 j = 1, no_y
c
            start(2) = j
            if (nf_get_vara_real (ncoutid,varid,start,count,topog(1,j))
     &                                               .ne. NF_NOERR) then
               top_err = .true.
               write (out_unit,40) j
            end if
c
  10     continue
c
      end if
c
c-----------------------------------------------------------------------
c  If no errors during read, work on & write topography.
c-----------------------------------------------------------------------
c
      if (.not. top_err) then
c
         call massage_topo (hybrid,target,topog,imt,no_x,no_y)
c
         call topo_stat (topog,hmen,hmed,hrms)
c
         if (hybrid.and.target)  then
            if (nf_inq_varid (ncoutid,'trg_bath',varidt) .ne. NF_NOERR)
     &                                                              then
               write (out_unit,50) 'trg_bath'
               call gr_exit ('PRV_DEPTH')
            end if
         end if
c
         do 20 j = 1, no_y
c
            start(2) = j
            if (nf_put_vara_real (ncoutid,varid,start,count,topog(1,j))
     &                                               .ne. NF_NOERR) then
               write (out_unit,60) 'tbath',j
               call gr_exit ('PRV_DEPTH')
            end if
c
            if (hybrid.and.target) then
               if (nf_put_vara_real (ncoutid,varidt,start,count,
     &                                   topog(1,j)) .ne. NF_NOERR) then
                  write (out_unit,60) 'trg_bath',j
                  call gr_exit ('PRV_DEPTH')
               end if
            end if
c
  20     continue
c
      end if
c
c-----------------------------------------------------------------------
c  Write bathymetry at the velocity points.
c-----------------------------------------------------------------------
c
      call set_vgrid (no_x,no_y,topog,ncoutid,'vbath',out_unit)
c
#ifdef sunflush
      call flush (out_unit)
c
#endif
      return
c
 30   format (/'+++ Warning:  PRV_DEPTH failed find variable ',a)
 40   format (/'+++ Warning:  PRV_DEPTH failed to extract topography in'
     &                                                   ,' row j=',i10)
 50   format (/'*** Error:  PRV_DEPTH failed find variable ',a)
 60   format (/'*** Error:  PRV_DEPTH failed to write ',a,' at row j='
     &                                                             ,i10)
c
      end
