      subroutine rescale_thick (no_lvl,flat,dzt,kc,fac,favg,fdif,href)
c
c-------------------------------------------------------------------------------
c     This routine rescales the sigma thicknesses to their median values.      |
c                                                                              |
c     Calls:  none                                                             |
c                                                                              |
c     Arguments:                                                               |
c                                                                              |
c     dzt.......Real vector.  Median model thicknesses.  (m)   {output}        |
c     fac.......Real.  Scale factor for argument of tanh interface.  (1/m)     |
c                  {input}                                                     |
c     favg......Real.  Average of interface bounds.  (m)   {input}             |
c     fdif......Real.  Negative difference between interface bounds.  (m)      |
c     flat......Logical.  Indicates whether coordinate interface is flat.      |
c                  {input}                                                     |
c     href......Real.  Reference depth for tanh interface.  (m)   {input}      |
c     no_lvl....Integer.  The number of vertical levels.  {input}              |
c                                                                              |
c     Common Blocks:                                                           |
c                                                                              |
c     /tpmed/                                                                  |
c                                                                              |
c        hmed...Real.  The median topographic depth.  (m)   {input}            |
c-------------------------------------------------------------------------------
c
#include <gpconst.h>
c
      integer no_lvl,kc,k
      logical flat
      real    dzt(no_lvl),fac,favg,fdif,href,fmed,hmf
c
#include <tpmed.h>
c
c=======================================================================
c     Begin executable code.                                           #
c=======================================================================
c
c-----------------------------------------------------------------------
c     Get median interface depth.                                      |
c-----------------------------------------------------------------------
c
      fmed = favg + fdif * tanh ( fac*(hmed-href) )
c
c-----------------------------------------------------------------------
c     Rescale sigma thicknesses to median thicknesses.                 |
c-----------------------------------------------------------------------
c
      if (flat) then
         hmf = c1
        else
         hmf = fmed*cm1
      end if
c
      do 10 k = 1, kc
         dzt(k) = dzt(k)*hmf
 10   continue
c
      hmf = (fmed - hmed)
      do 20 k = kc+1, no_lvl
         dzt(k) = dzt(k) * hmf
 20   continue
c
      return
      end
