      subroutine rlocal_median (topog,ever)
c
c=======================================================================
c                                                                    ===
c  This subroutine filters the topography.  This particular version  ===
c  filters by taking the median of the value and its nearest         ===
c  neighbors.   The grid points are given the same weighting as in   ===
c  the integral mean.  That is:  center points are listed 4 times,   ===
c  side points twice and corner points once.                         ===
c                                                                    ===
c  ------                                                            ===
c  Input:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     TOPOG   The original topography.                  (real array) ===
c                                                                    ===
c  Common Blocks:                                                    ===
c                                                                    ===
c  /DOM/                                                             ===
c                                                                    ===
c     NO_X   Number of elements in x direction.   (integer)          ===
c     NO_Y   Number of elements in y direction.   (integer)          ===
c                                                                    ===
c  -------                                                           ===
c  Output:                                                           ===
c  -------                                                           ===
c                                                                    ===
c     EVER    Indicates whether any value was changed.  (logical)    ===
c                [.true.]  => TOPOG was changed.                     ===
c                [.false.] => TOPOG was not changed.                 ===
c     TOPOG   The filtered topography.                  (real array) ===
c                                                                    ===
c  ------                                                            ===
c  Calls:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     HOPS:    RBOX_LOAD_VEC,  RCOND_REP,  SET_EDGE                  ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <gridsparm.h>
#include <gridsio.h>
#include <gpconst.h>
#include <dom.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer i,j,nxm1,nym1
      logical error,ever
      real    val
      real topog(imt,jmt),wk(imt,jmt),wkvec(16)
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c-----------------------------------------------------------------------
c  Set penultimate pointers.
c-----------------------------------------------------------------------
c
      nxm1 = no_x - 1
      nym1 = no_y - 1
c
c-----------------------------------------------------------------------
c  Copy data, initialize error flag and value change flag.
c-----------------------------------------------------------------------
c
      do 10 i = 1, no_x
         do 10 j = 1, no_y
            wk(i,j) = topog(i,j)
 10   continue
      error = .false.
      ever = .false.
c
#ifndef lnext
c-----------------------------------------------------------------------
c  Find medians in first column.
c-----------------------------------------------------------------------
c
      call rbox_load_vec (wk,wkvec,1,1,1,1,error)
      val = ( wkvec(2) + wkvec(3) )*p5
      call rcond_rep (topog(1,1),val,ever)
c
      do 20 i = 2, nxm1
         call rbox_load_vec (wk,wkvec,i-1,i,1,1,error)
         val = ( wkvec(4) + wkvec(5) )*p5
         call rcond_rep (topog(i,1),val,ever)
 20   continue
c
      call rbox_load_vec (wk,wkvec,nxm1,nxm1,1,1,error)
      val = ( wkvec(2) + wkvec(3) )*p5
      call rcond_rep (topog(no_x,1),val,ever)
c
#endif
c-----------------------------------------------------------------------
c  Find medians in central columns.
c-----------------------------------------------------------------------
c
      do 40 j = 2, nym1
c
#ifndef lnext
         call rbox_load_vec (wk,wkvec,1,1,j-1,j,error)
         val = ( wkvec(4) + wkvec(5) )*p5
         call rcond_rep (topog(1,j),val,ever)
c
#endif
         do 30 i = 2, nxm1
            call rbox_load_vec (wk,wkvec,i-1,i,j-1,j,error)
            val = ( wkvec(8) + wkvec(9) ) * p5
            call rcond_rep (topog(i,j),val,ever)
 30      continue
c
#ifndef lnext
         call rbox_load_vec (wk,wkvec,nxm1,nxm1,j-1,j,error)
         val = ( wkvec(4) + wkvec(5) )*p5
         call rcond_rep (topog(no_x,j),val,ever)
c
#endif
 40   continue
c
#ifndef lnext
c-----------------------------------------------------------------------
c  Find medians in last column.
c-----------------------------------------------------------------------
c
      call rbox_load_vec (wk,wkvec,1,1,nym1,nym1,error)
      val = ( wkvec(2) + wkvec(3) )*p5
      call rcond_rep (topog(1,no_y),val,ever)
c
      do 50 i = 2, nxm1
         call rbox_load_vec (wk,wkvec,i-1,i,nym1,nym1,error)
         val = ( wkvec(4) + wkvec(5) )*p5
         call rcond_rep (topog(i,no_y),val,ever)
 50   continue
c
      call rbox_load_vec (wk,wkvec,nxm1,nxm1,nym1,nym1,error)
      val = ( wkvec(2) + wkvec(3) )*p5
      call rcond_rep (topog(no_x,no_y),val,ever)
c
# else
c-----------------------------------------------------------------------
c  Apply linear extrapolation of interior to edges.
c-----------------------------------------------------------------------
c
      call set_edge (topog)
c
#endif
c-----------------------------------------------------------------------
c  Check for errors.
c-----------------------------------------------------------------------
c
      if (error) write (out_unit,60)
#ifdef sunflush
      call flush (out_unit)
#endif
c
      return
c
 60   format (/'+++ Warning:  RLOCAL_MEDIAN - error while loading small'
     &        /30x,'work vector for median smoothing.')
c
      end
