      subroutine set_edge (topog)
c
c=======================================================================
c                                                                    ===
c  This routine linearly extrapolates the interior topography to the ===
c  edges.  It assumes CONSTANT dx, dy (as does GRIDS)                ===
c                                                                    ===
c                                                                    ===
c  ------                                                            ===
c  Input:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     TOPOG   The original topography.                  (real array) ===
c                                                                    ===
c  Common Blocks:                                                    ===
c                                                                    ===
c  /DOM/                                                             ===
c                                                                    ===
c     NO_X   Number of elements in x direction.   (integer)          ===
c     NO_Y   Number of elements in y direction.   (integer)          ===
c                                                                    ===
c  -------                                                           ===
c  Output:                                                           ===
c  -------                                                           ===
c                                                                    ===
c     TOPOG   The edge extrapolated topography.         (real array) ===
c                                                                    ===
c  ------                                                            ===
c  Calls:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     HOPS:    RBOX_LOAD_VEC,  RCOND_REP,  SET_EDGE                  ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <gridsparm.h>
#include <gpconst.h>
#include <dom.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer i,j,nxm1,nxm2,nym1,nym2
      real    topog(imt,jmt)
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c-----------------------------------------------------------------------
c  Set penultimate pointers.
c-----------------------------------------------------------------------
c
      nxm1 = no_x - 1
      nym1 = no_y - 1
c
      nxm2 = no_x - 2
      nym2 = no_y - 2
c
c-----------------------------------------------------------------------
c  Extrapolate in X-direction.
c-----------------------------------------------------------------------
c
      do 10 j = 2, nym1
         topog(1,j)    = topog(2,j) + (topog(2,j)-topog(3,j))
         topog(no_x,j) = topog(nxm1,j) + (topog(nxm1,j)-topog(nxm2,j))
  10  continue
c
c-----------------------------------------------------------------------
c  Extrapolate in Y-direction.
c-----------------------------------------------------------------------
c
      do 20 i = 1, no_x
         topog(i,1)    = topog(i,2) + (topog(i,2)-topog(i,3))
         topog(i,no_y) = topog(i,nym1) + (topog(i,nym1)-topog(i,nym2))
  20  continue
c
      return
      end
