      subroutine set_frame_geo (xrng,yrng,ttlln1,ttlln2,antind)
c
c=======================================================================
c                                                                    ===
c  This routines sets up the background for a geographic plot.       ===
c                                                                    ===
c  ------                                                            ===
c  Input:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     XRNG     Data range for x-coordinate axis.   (real vector)     ===
c     YRNG     Data range for y-coordinate axis.   (real vector)     ===
c     TTLLN1   Plot title  (first line).           (string)          ===
c     TTLLN2   Plot title  (second line).          (string)          ===
c     TTLLN3   Plot title  (third line).           (string)          ===
c     ANTIND   Index for antarctica.               (integer)         ===
c                                                                    ===
c  Common Blocks:                                                    ===
c                                                                    ===
c  /GRIDSIO/                                                         ===
c                                                                    ===
c     CSTSTAT   Status flag for coast line data file.      (integer) ===
c                                                                    ===
c  -------                                                           ===
c  Output:                                                           ===
c  -------                                                           ===
c                                                                    ===
c  Common Blocks:                                                    ===
c                                                                    ===
c  /CNTLBL/                                                          ===
c                                                                    ===
c     GRFB   Device coordinate of bottom of graph area.   (real)     ===
c     GRFL   Device coordinate of left of graph area.     (real)     ===
c     GRFR   Device coordinate of right of graph area.    (real)     ===
c     GRFT   Device coordinate of top of graph area.      (real)     ===
c     XMAX   World coordinate of right of graph area.     (real)     ===
c     XMIN   World coordinate of left of graph area.      (real)     ===
c     YMAX   World coordinate of top of graph area.       (real)     ===
c     YMIN   World coordinate of bottom of graph area.    (real)     ===
c                                                                    ===
c  /PLTNCAR/                                                         ===
c                                                                    ===
c     CHSIZE   Size for writing characters.        (real)            ===
c                                                                    ===
c  ------                                                            ===
c  Calls:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     HOPS:    DRAW_MAP,   GCIRCLE,  GET_DATE,  LENGTH,  SETLLSTR,   ===
c              SET_LLTICK                                            ===
c     NCAR:    DASHDB,     LINE,     LINED,     PLCHHQ,  SET,        ===
c              SFLUSH                                                ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <gridsio.h>
#include <cntlbl.h>
#include <pltncar.h>
#include <version.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      real    c0,c1,c2,c3,c4,c5,c6,c60,c90,c999,p02,p1,p5,p75,p8,p9
      parameter (c0=0.0, c1=1.0, c2=2.0, c3=3.0, c4=4.0, c5=5.0, c6=6.0,
     &           c60=60.0, c90=90.0, c999=999.0, p02=0.02, p1=0.1,
     &           p5=0.5, p75=0.75, p8=0.8, p9=0.9)
c
      integer antind,di,i,ind,ist,sbgn,sbn2,sbn3,send,
     &        slen,sln2,sln3,snd2,snd3
      real    bear,ddist,dgrid,distx,disty,
     &     midpt,s,tksize,x0,x1,y0,y1
      real xrng(2),yrng(2)
      real         gcircle
      character*44  date_str
      character*(*) ttlln1,ttlln2
      character*128 tklbl
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c-----------------------------------------------------------------------
c  Determine plot window.
c-----------------------------------------------------------------------
c
c  Set maximum default size.
c
      grfb = p1
      grfl = p1
      grft = p9
      grfr = p9
c
c  Determine physical size of data window.
c
      midpt = p5*(yrng(1)+yrng(2))
      ddist = gcircle (xrng(1),midpt,xrng(2),midpt,distx,bear)
c
      midpt = p5*(xrng(1)+xrng(2))
      ddist = gcircle (midpt,yrng(1),midpt,yrng(2),disty,bear)
c
c  Reset plot window to reflect physical size.
c
      if ((distx*(grft-grfb)).gt.(disty*(grfr-grfl))) then
         midpt = p5*(grfb+grft)
         ddist = p5*(grft-grfb)*(disty*(grfr-grfl))/(distx*(grft-grfb))
         grfb  = midpt - ddist
         grft  = midpt + ddist
       elseif (disty.gt.distx) then
         midpt = p5*(grfl+grfr)
         ddist = p5*(grfr-grfl)*(distx*(grft-grfb))/(disty*(grfr-grfl))
         grfl  = midpt - ddist
         grfr  = midpt + ddist
      end if
c
c-----------------------------------------------------------------------
c  Set character size.
c-----------------------------------------------------------------------
c
      chsize = p02
c
      call length (ttlln1,slen,sbgn,send)
      if (slen.gt.0) then
         chsize = min ( chsize, (p9*(c1-p1)/float(slen)) )
      end if
c
      call length (ttlln2,slen,sbgn,send)
      if (slen.gt.0) then
         chsize = min ( chsize, (p9*(c1-p1)/float(slen)) )
      end if
c
      call get_date (date_str)
      call length (date_str,slen,sbgn,send)
      if (slen.gt.0) then
         chsize = min ( chsize, (p9*(c1-p1)/float(slen)) )
      end if
c
c-----------------------------------------------------------------------
c  Draw axis and ticks.
c-----------------------------------------------------------------------
c
c  Initialize mapping.
c
      call set (grfl,grfr,grfb,grft,xrng(1),xrng(2),yrng(1),yrng(2),1)
c
c  Draw axes & label.
c
      call line ( xrng(1), yrng(1), xrng(1), yrng(2) )
      call line ( xrng(1), yrng(2), xrng(2), yrng(2) )
      call line ( xrng(2), yrng(2), xrng(2), yrng(1) )
      call line ( xrng(2), yrng(1), xrng(1), yrng(1) )
c
c-----------------------------------------------------------------------
c  Draw coastline.
c-----------------------------------------------------------------------
c
      if (cststat .eq. 1) then
         call fill_map (xrng,yrng,antind)
       elseif (cststat .eq. -1) then
         call draw_map
      end if
c
c-----------------------------------------------------------------------
c  Draw grid.
c-----------------------------------------------------------------------
c
c  Draw longitudinal grid lines.
c
      call set_lltick (xrng,grfl,grfr,dgrid,x0,x1,ist,ind,di)
c
      call dashdb (4369)
c
      do 10 i = ist, ind, di
         s = dgrid*float(i)
         call lined ( s, yrng(1), s, yrng(2) )
  10  continue
c
      call dashdb (65535)
c
c  Set size for labelling longitudinal grid lines.
c
      if (dgrid.ge.p75) then
         tksize = min( chsize, p1/float(7))
       elseif (dgrid.ge.p75/c60) then
         tksize = min( chsize, p1/float(11))
       else
         tksize = min( chsize, p1/float(15))
      end if
c
c  Label longitudinal grid lines.
c
      call set (c0,c1,(grfb-p1),grfb,x0,x1,c0,c1,1)
c
      do 20 i = ist, ind, di
         s = dgrid*float(i)
         call setllstr (s,'E','W',tklbl)
         call length (tklbl,slen,sbgn,send)
         call plchhq (s,c1,tklbl(sbgn:send)//' ',tksize,c90,c1)
  20  continue
c
      call set (grfl,grfr,grfb,grft,xrng(1),xrng(2),yrng(1),yrng(2),1)
c
c  Draw latitudinal grid lines.
c
      call set_lltick (yrng,grfb,grft,dgrid,y0,y1,ist,ind,di)
c
      call dashdb (4369)
c
      do 30 i = ist, ind, di
         s = dgrid*float(i)
         call lined ( xrng(1), s, xrng(2), s )
  30  continue
c
      call dashdb (65535)
c
c  Set size for labelling longitudinal grid lines.
c
      if (dgrid.ge.p75) then
         tksize = min( chsize, p1/float(6))
       elseif (dgrid.ge.p75/c60) then
         tksize = min( chsize, p1/float(10))
       else
         tksize = min( chsize, p1/float(14))
      end if
c
c  Label latitudinal grid lines.
c
      call set ((grfl-p1),grfl,c0,c1,c0,c1,y0,y1,1)
c
      do 40 i = ist, ind, di
         s = dgrid*float(i)
         call setllstr (s,'N','S',tklbl)
         call length (tklbl,slen,sbgn,send)
         call plchhq (c1,s,tklbl(sbgn:send)//' ',tksize,c0,c1)
  40  continue
c
      call set (grfl,grfr,grfb,grft,xrng(1),xrng(2),yrng(1),yrng(2),1)
c
c-----------------------------------------------------------------------
c  Write labels.
c-----------------------------------------------------------------------
c
c  Write title.
c
      call length (ttlln1,slen,sbgn,send)
      call length (ttlln2,sln2,sbn2,snd2)
      call length (date_str,sln3,sbn3,snd3)
      if (sln3.gt.0) then
         call set (p1,c1,p9,c1,c0,c2,c0,c6,1)
         call plchhq (c0,c5,ttlln1(sbgn:send),chsize,c0,-c1)
         call plchhq (c0,c3,ttlln2(sbn2:snd2),chsize,c0,-c1)
         call plchhq (c0,c1,date_str(sbn3:snd3),chsize,c0,-c1)
c         date_str = ' '
       elseif (sln2.gt.0) then
         call set (p1,c1,p9,c1,c0,c2,c0,c4,1)
         call plchhq (c0,c3,ttlln1(sbgn:send),chsize,c0,-c1)
         call plchhq (c0,c1,ttlln2(sbn2:snd2),chsize,c0,-c1)
c         ttlln2 = ' '
       else
         call set (p1,c1,p9,c1,c0,c2,c0,c2,1)
         call plchhq (c0,c1,ttlln1(sbgn:send),chsize,c0,-c1)
c         ttlln1 = ' '
      end if
c
c-----------------------------------------------------------------------
c  Draw logo.
c-----------------------------------------------------------------------
c
c      call veritas (clrflg)
c
c-----------------------------------------------------------------------
c  Record version number.
c-----------------------------------------------------------------------
c
      y0 = grfb + (grft-grfb)/c3
      y0 = min (y0, (grfb+p1))
      call set (grfr,grfr+p1,grfb,y0,c0,c1,c0,c5,1)
      call length (vnum,slen,sbgn,send)
      tklbl = 'Version '//vnum(sbgn:send)
      call length (tklbl,slen,sbgn,send)
      call plchhq (p5,c1,tklbl(sbgn:send),c5,c0,c0)
c
c-----------------------------------------------------------------------
c  Reset window for plotting.
c-----------------------------------------------------------------------
c
      call set (grfl,grfr,grfb,grft,xrng(1),xrng(2),yrng(1),yrng(2),1)
c
      xmin = xrng(1)
      xmax = xrng(2)
      ymin = yrng(1)
      ymax = yrng(2)
c
c-----------------------------------------------------------------------
c  Clear plot buffers.
c-----------------------------------------------------------------------
c
      call sflush
c
      return
      end
