      subroutine set_vgrid (nx,ny,tfld,ncid,varnam,stdout)
c
c=======================================================================
c                                                                    ===
c  This routine averages the given T-grid field to its               ===
c  V-grid equivalent, and then writes the result to the netCDF file. ===
c                                                                    ===
c  ------                                                            ===
c  Input:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     NX       Number of grid points in x-direction.   (integer)     ===
c     NY       Number of grid points in y-direction.   (integer)     ===
c     TFLD     T-grid field.                           (real array)  ===
c     NCID     NetCDF file identifier.                 (integer)     ===
c     VARNAM   Name of V-grid field in netCDF file.    (string)      ===
c     STDOUT   Unit number for standard output.        (integer)     ===
c                                                                    ===
c  ------                                                            ===
c  Calls:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     HOPS:    GR_EXIT,       T2VGRD                                 ===
c     netCDF:  NF_INQ_VARID,  NF_PUT_VARA_REAL                       ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data
c-----------------------------------------------------------------------
c
#include <gridsparm.h>
#include <gpconst.h>
#include <netcdf.inc>
c
c-----------------------------------------------------------------------
c  Define local data
c-----------------------------------------------------------------------
c
      integer j,ncid,nx,ny,stdout,varid
      integer count(2),start(2)
      real          tfld(imt,jmt),vfld(imt,jmt)
      character*(*) varnam
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c-----------------------------------------------------------------------
c  Average T-grid field onto V-grid
c-----------------------------------------------------------------------
c
      call t2vgrd (imt,nx,ny,tfld,vfld)
c
c-----------------------------------------------------------------------
c  Write V-grid field to netCDF file
c-----------------------------------------------------------------------
c
c  Find variable in netCDF file.
c
      if (nf_inq_varid (ncid,varnam,varid) .ne. NF_NOERR) then
         write (stdout,900) varnam
         call gr_exit ('SET_VGRID')
      end if
c
c  Write variable to netCDF file.
c
         start(1) = 1
         count(1) = nx
         count(2) = 1
c
      do 10 j = 1, ny
c
         start(2) = j
c
         if (nf_put_vara_real (ncid,varid,start,count,vfld(1,j))
     &                                               .ne. NF_NOERR) then
            write (stdout,910) varnam,j
            call gr_exit ('SET_VGRID')
         end if
c
  10  continue
c
      return
c
 900  format (/'*** Error:  SET_VGRID failed find variable ',a)
 910  format (/'*** Error:  SET_VGRID failed to write ',a,' at row j='
     &                                                             ,i10)
c
      end
