      subroutine step_lines (lda,imt,jmt,kmt,geo_tlon,geo_tlat)
c
c=======================================================================
c                                                                    ===
c  This routine draws lines between adjacent points with equal       ===
c  numbers of vertical levels.                                       ===
c                                                                    ===
c  ------                                                            ===
c  Input:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     GEO_TLAT   The latitudes of t grid points.   (real array; deg) ===
c     GEO_TLON   The longitudes of t grid points.  (real array; deg) ===
c     IMT        Number of x-points.               (integer)         ===
c     JMT        Number of y-points.               (integer)         ===
c     KMT        Number of levels at a point.      (integer array)   ===
c     LDA        Leading dimension of arrays.      (integer)         ===
c                                                                    ===
c  ------                                                            ===
c  Calls:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     HOPS:    EQVEC                                                 ===
c     NCAR:    FRSTPT,  VECTOR                                       ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer i,imm1,imt,j,jmm1,jmt,lda
      integer kmt(lda,jmt)
      real    geo_tlat(lda,jmt),geo_tlon(lda,jmt)
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
      imm1 = imt - 1
      jmm1 = jmt - 1
c
      do 20 i = 1, imm1
         if (kmt(i,1).ne.0) then
            call frstpt (geo_tlon(i,1),geo_tlat(i,1))
            call vector (geo_tlon(i,1),geo_tlat(i,1))
            call eqvec (lda,imt,jmt,kmt,geo_tlon,geo_tlat,i,1,i+1,1)
            call eqvec (lda,imt,jmt,kmt,geo_tlon,geo_tlat,i,1,i+1,2)
         end if
         do 10 j = 2, jmm1
            if (kmt(i,j).ne.0) then
               call frstpt (geo_tlon(i,j),geo_tlat(i,j))
               call vector (geo_tlon(i,j),geo_tlat(i,j))
               call eqvec (lda,imt,jmt,kmt,geo_tlon,geo_tlat,i,j,i,j-1)
               call eqvec(lda,imt,jmt,kmt,geo_tlon,geo_tlat,i,j,i+1,j-1)
               call eqvec (lda,imt,jmt,kmt,geo_tlon,geo_tlat,i,j,i+1,j)
               call eqvec(lda,imt,jmt,kmt,geo_tlon,geo_tlat,i,j,i+1,j+1)
            end if
 10      continue
c
         if (kmt(i,jmt).ne.0) then
            call frstpt (geo_tlon(i,jmt),geo_tlat(i,jmt))
            call vector (geo_tlon(i,jmt),geo_tlat(i,jmt))
            call eqvec (lda,imt,jmt,kmt,geo_tlon,geo_tlat,i,jmt,i,jmm1)
            call eqvec(lda,imt,jmt,kmt,geo_tlon,geo_tlat,i,jmt,i+1,jmm1)
            call eqvec (lda,imt,jmt,kmt,geo_tlon,geo_tlat,i,jmt,i+1,jmt)
         end if
 20   continue
c
      do 30 j = 2, jmt
         if (kmt(imt,j).ne.0) then
            call frstpt (geo_tlon(imt,j),geo_tlat(imt,j))
            call vector (geo_tlon(imt,j),geo_tlat(imt,j))
            call eqvec (lda,imt,jmt,kmt,geo_tlon,geo_tlat,imt,j,imt,j-1)
         end if
 30   continue
c
      return
      end
