      subroutine sub_sam2d (ldfb,f_big,ldfs,f_small,keytv)
c
c=======================================================================
c                                                                    ===
c  This routine sub-samples the big 2D field onto the small 2D field.===
c                                                                    ===
c  ------                                                            ===
c  Input:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     F_BIG     Big 2D field from which to sample.   (real array)    ===
c     LDFB      Leading dimension of f_big.          (integer)       ===
c     LDFS      Leading dimension of f_small.        (integer)       ===
c     KEYTV     Flag for T or V grid.                (integer)       ===
c                                                                    ===
c  Common Blocks:                                                    ===
c                                                                    ===
c  /BGDOMDAT/                                                        ===
c                                                                    ===
c     BCRD     coordinate type                       (integer)       ===
c     BDLX     x-offset grid-trans. centers          (real; m | deg) ===
c     BDLY     y-offset grid-trans. centers          (real; m | deg) ===
c     BDX      grid spacing in the x-direction       (real; m | deg) ===
c     BDY      grid spacing in the y-direction       (real; m | deg) ===
c     BLAT     transformation centroid latitude      (real; degrees) ===
c     BLON     transformation centroid longitude     (real; degrees) ===
c     BNX      number of gridpoints in x-direction   (integer)       ===
c     BNY      number of gridpoints in y-direction   (integer)       ===
c     BTHETA   domain rotation angle                 (real; degrees) ===
c                                                                    ===
c  /SMDOMDAT/                                                        ===
c                                                                    ===
c     SCRD     coordinate type                       (integer)       ===
c     SDLX     x-offset grid-trans. centers          (real; m | deg) ===
c     SDLY     y-offset grid-trans. centers          (real; m | deg) ===
c     SDX      grid spacing in the x-direction       (real; m | deg) ===
c     SDY      grid spacing in the y-direction       (real; m | deg) ===
c     SLAT     transformation centroid latitude      (real; degrees) ===
c     SLON     transformation centroid longitude     (real; degrees) ===
c     SNX      number of gridpoints in x-direction   (integer)       ===
c     SNY      number of gridpoints in y-direction   (integer)       ===
c     STHETA   domain rotation angle                 (real; degrees) ===
c                                                                    ===
c  -------                                                           ===
c  Output:                                                           ===
c  -------                                                           ===
c                                                                    ===
c     F_SMALL   Small 2D field to sample.            (real array)    ===
c                                                                    ===
c  ------                                                            ===
c  Calls:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     HOPS:  BES2D,  LL2XY,  XY2LL                                   ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <gpconst.h>
#include <bgdomdat.h>
#include <smdomdat.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer i,j,keytv,ldfb,ldfs,nxbm1,nybm1
      real    lat,lon,x,y
      real f_big(ldfb,bny),f_small(ldfs,sny)
      real bes2d
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c-----------------------------------------------------------------------
c  Compute the penultimate grid points for the big grid (used to
c  prevent out of bounds errors).
c-----------------------------------------------------------------------
c
      nxbm1 = bnx - 1
      nybm1 = bny - 1
c
c-----------------------------------------------------------------------
c  Loop for every point in the small array, f_small.
c-----------------------------------------------------------------------
c
      do 10 j = 1, sny
         do 10 i = 1, snx
c
c-----------------------------------------------------------------------
c  Convert each gridpoint in the small grid to an (x,y) in the big
c  grid units.
c-----------------------------------------------------------------------
c
         x = float(i)
         y = float(j)
         if (keytv.eq.vgrid) then
            x = x + p5
            y = y + p5
         end if
c
         call xy2ll (x,y,scrd,snx,sny,sdx,sdy,slon,slat,sdlx,sdly,
     &                                                   stheta,lon,lat)
         call ll2xy (lon,lat,bcrd,bnx,bny,bdx,bdy,blon,blat,bdlx,bdly,
     &                                                       btheta,x,y)
c
         if (keytv.eq.vgrid) then
            x = x - p5
            y = y - p5
         end if
c
c-----------------------------------------------------------------------
c  Bi-cubicly interpolate data from the big grid to the indicated point.
c-----------------------------------------------------------------------
c
         f_small(i,j) = bes2d (x,y,f_big,bnx,bny)
c
 10   continue
c
      return
      end
