      subroutine sup_sam2d (ldfs,f_small,cs,ldfb,f_big,keytv)
c
c=======================================================================
c                                                                    ===
c  This routine super samples the big 2D field onto the small        ===
c  2D field.                                                         ===
c                                                                    ===
c  ------                                                            ===
c  Input:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     CS        Cosine metric factors.               (real vector)   ===
c     F_SMALL   Small 2D field to sample.            (real array)    ===
c     LDFB      Leading dimension of f_big.          (integer)       ===
c     LDFS      Leading dimension of f_small.        (integer)       ===
c     KEYTV     Flag for T or V grid.                (integer)       ===
c                                                                    ===
c  Common Blocks:                                                    ===
c                                                                    ===
c  /BGDOMDAT/                                                        ===
c                                                                    ===
c     BCRD     coordinate type                       (integer)       ===
c     BDLX     x-offset grid-trans. centers          (real; m | deg) ===
c     BDLY     y-offset grid-trans. centers          (real; m | deg) ===
c     BDX      grid spacing in the x-direction       (real; m | deg) ===
c     BDY      grid spacing in the y-direction       (real; m | deg) ===
c     BLAT     transformation centroid latitude      (real; degrees) ===
c     BLON     transformation centroid longitude     (real; degrees) ===
c     BNX      number of gridpoints in x-direction   (integer)       ===
c     BNY      number of gridpoints in y-direction   (integer)       ===
c     BTHETA   domain rotation angle                 (real; degrees) ===
c                                                                    ===
c  /SMDOMDAT/                                                        ===
c                                                                    ===
c     SCRD     coordinate type                       (integer)       ===
c     SDLX     x-offset grid-trans. centers          (real; m | deg) ===
c     SDLY     y-offset grid-trans. centers          (real; m | deg) ===
c     SDX      grid spacing in the x-direction       (real; m | deg) ===
c     SDY      grid spacing in the y-direction       (real; m | deg) ===
c     SLAT     transformation centroid latitude      (real; degrees) ===
c     SLON     transformation centroid longitude     (real; degrees) ===
c     SNX      number of gridpoints in x-direction   (integer)       ===
c     SNY      number of gridpoints in y-direction   (integer)       ===
c     STHETA   domain rotation angle                 (real; degrees) ===
c                                                                    ===
c  -------                                                           ===
c  Output:                                                           ===
c  -------                                                           ===
c                                                                    ===
c     F_BIG     Big 2D field from which to sample.   (real array)    ===
c                                                                    ===
c  Calls:  LL2XY,  XY2LL                                             ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <gridsparm.h>
#include <gpconst.h>
#include <bgdomdat.h>
#include <smdomdat.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer di,dind,dist,dj,djnd,djst,i,i_ll,i_ur,ix,j,j_ll,j_ur,jy,
     &        keytv,ldfb,ldfs
      real    area,da,lat,lon,r6,x,y
      real  cs(jmt),f_big(ldfb,bny),f_small(ldfs,sny)
c
      parameter (r6=p5/c3)
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c-----------------------------------------------------------------------
c  Compute the index bounds for the super-sampled region in the large
c  domain.
c-----------------------------------------------------------------------
c
      x = p5*float(snx+1)
      y = p5*float(sny+1)
c
      call xy2ll (x,y,scrd,snx,sny,sdx,sdy,slon,slat,
     &                                         sdlx,sdly,stheta,lon,lat)
      call ll2xy (lon,lat,bcrd,bnx,bny,bdx,bdy,blon,blat,bdlx,bdly,
     &                                                       btheta,x,y)
c
      ix = nint(x)
      jy = nint(y-r6)
c
      i_ll = ix - nint(float(snx+1)*r6) + 1
      j_ll = jy - nint(float(sny)*r6) + 1
c
      i_ur = ix + nint(float(snx+1)*r6) - 1
      j_ur = jy + nint(float(sny)*r6) - 1
c
      if (keytv.eq.tgrid) then
         dist = -1
         dind =  1
         djst = -1
         djnd =  1
       else
         dist = 0
         dind = 2
         djst = 0
         djnd = 2
         i_ur = i_ur - 1
      end if
c
c-----------------------------------------------------------------------
c  Super-sample small array, f_small, into large array f_big.
c-----------------------------------------------------------------------
c
      do 20 j = j_ll, j_ur
      do 20 i = i_ll, i_ur
c
         ix = (i-i_ll+1)*3
         jy = (j-j_ll+1)*3
c
         f_big(i,j) = c0
         area       = c0
c
         do 10 dj = djst, djnd
         do 10 di = dist, dind
            da         = cs(jy+dj)*sdx*sdy
            f_big(i,j) = f_big(i,j) + f_small(ix+di,jy+dj)*da
            area       = area + da
 10      continue
c
         f_big(i,j) = f_big(i,j)/area
c
 20   continue
c
      return
      end
