      subroutine sup_sam_mask (ldfs,f_small,ldfb,f_big)
c
c=======================================================================
c                                                                    ===
c  This routine super samples the small 2D mask onto the big         ===
c  2D mask.                                                          ===
c                                                                    ===
c  ------                                                            ===
c  Input:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     f_small...Small 2D field to sample.            (integer array) ===
c     ldfb......Leading dimension of f_big.          (integer)       ===
c     ldfs......Leading dimension of f_small.        (integer)       ===
c                                                                    ===
c  Common Blocks:                                                    ===
c                                                                    ===
c  /BGDOMDAT/                                                        ===
c                                                                    ===
c     BCRD     coordinate type                       (integer)       ===
c     BDLX     x-offset grid-trans. centers          (real; m | deg) ===
c     BDLY     y-offset grid-trans. centers          (real; m | deg) ===
c     BDX      grid spacing in the x-direction       (real; m | deg) ===
c     BDY      grid spacing in the y-direction       (real; m | deg) ===
c     BLAT     transformation centroid latitude      (real; degrees) ===
c     BLON     transformation centroid longitude     (real; degrees) ===
c     BNX      number of gridpoints in x-direction   (integer)       ===
c     BNY      number of gridpoints in y-direction   (integer)       ===
c     BTHETA   domain rotation angle                 (real; degrees) ===
c                                                                    ===
c  /SMDOMDAT/                                                        ===
c                                                                    ===
c     SCRD     coordinate type                       (integer)       ===
c     SDLX     x-offset grid-trans. centers          (real; m | deg) ===
c     SDLY     y-offset grid-trans. centers          (real; m | deg) ===
c     SDX      grid spacing in the x-direction       (real; m | deg) ===
c     SDY      grid spacing in the y-direction       (real; m | deg) ===
c     SLAT     transformation centroid latitude      (real; degrees) ===
c     SLON     transformation centroid longitude     (real; degrees) ===
c     SNX      number of gridpoints in x-direction   (integer)       ===
c     SNY      number of gridpoints in y-direction   (integer)       ===
c     STHETA   domain rotation angle                 (real; degrees) ===
c                                                                    ===
c  -------                                                           ===
c  Output:                                                           ===
c  -------                                                           ===
c                                                                    ===
c     f_big.....Big 2D field from which to sample.   (integer array) ===
c                                                                    ===
c  Calls:  LL2XY,  XY2LL                                             ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <gpconst.h>
#include <bgdomdat.h>
#include <smdomdat.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer count,di,dj,i,i_ll,i_ur,ix,j,j_ll,j_ur,jy,ldfb,ldfs,
     &        min_spprt
      integer f_big(ldfb,bny),f_small(ldfs,sny)
      real    lat,lon,r6,x,y
c
      parameter (min_spprt=4, r6=p5/c3)
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c-----------------------------------------------------------------------
c  Compute the index bounds for the super-sampled region in the large
c  domain.
c-----------------------------------------------------------------------
c
      x = p5*float(snx+1)
      y = p5*float(sny+1)
c
      call xy2ll (x,y,scrd,snx,sny,sdx,sdy,slon,slat,
     &                                         sdlx,sdly,stheta,lon,lat)
      call ll2xy (lon,lat,bcrd,bnx,bny,bdx,bdy,blon,blat,bdlx,bdly,
     &                                                       btheta,x,y)
c
      ix = nint(x)
      jy = nint(y-r6)
c
      i_ll = ix - nint(float(snx+1)*r6) + 1
      j_ll = jy - nint(float(sny)*r6) + 1
c
      i_ur = ix + nint(float(snx+1)*r6) - 1
      j_ur = jy + nint(float(sny)*r6) - 1
c
c-----------------------------------------------------------------------
c  Super-sample small array, f_small, into large array f_big.
c-----------------------------------------------------------------------
c
      do 20 j = j_ll, j_ur
      do 20 i = i_ll, i_ur
c
         ix = (i-i_ll+1)*3
         jy = (j-j_ll+1)*3
c
         count = 0
c
         do 10 dj = -1, 1
         do 10 di = -1, 1
            count = count + f_small(ix+di,jy+dj)
 10      continue
c
         if (count.ge.min_spprt) then
            f_big(i,j) = 1
           else
            f_big(i,j) = 0
         end if
c
 20   continue
c
      return
      end
