      subroutine topo_stat (topog,hmean,hmed,hrms)
c
c=======================================================================
c                                                                    ===
c  This routine computes the minimum, maximum and mean depths and    ===
c  writes the results.                                               ===
c                                                                    ===
c  ------                                                            ===
c  Input:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     TOPOG   The ocean depth at tracer grid points.  (real array; m)===
c                                                                    ===
c  Common Blocks                                                     ===
c                                                                    ===
c  /DOM/                                                             ===
c                                                                    ===
c     NO_X    Number of elements in x direction.      (integer)      ===
c     NO_Y    Number of elements in y direction.      (integer)      ===
c                                                                    ===
c  -------                                                           ===
c  Output:                                                           ===
c  -------                                                           ===
c                                                                    ===
c     HMEAN   Real.  Mean depth.                      (real; m)      ===
c     HMED    Real.  Median depth.                    (real; m)      ===
c     HRMS    Real.  Root mean square depth.          (real; m)      ===
c                                                                    ===
c  Common Blocks                                                     ===
c                                                                    ===
c                                                                    ===
c  /TPSTT/                                                           ===
c                                                                    ===
c     HMAX    Maximum depth.                          (real; m)      ===
c     HMIN    Minimum depth.                          (real; m)      ===
c                                                                    ===
c  ------                                                            ===
c  Calls:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     HOPS:    HEAP_SORT                                             ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <gridsparm.h>
#include <gridsio.h>
#include <gpconst.h>
#include <dom.h>
#include <tpstt.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer i,index,j,nxy
      real    hmean,hmed,hrms,hscl
      real             topog(imt,jmt),wk(imjm)
      double precision cd0,cd1,dh,rdhmax,rnxy,sum,sum2
c
      parameter (cd0=0.0d0, cd1=1.0d0)
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c-----------------------------------------------------------------------
c  Create sorted list of topography values.
c-----------------------------------------------------------------------
c
      nxy = 0
c
      do 10 j = 1, no_y
         do 10 i = 1, no_x
            nxy = nxy + 1
            wk(nxy) = topog(i,j)
 10   continue
c
      call heap_sort (nxy,wk)
c
c-----------------------------------------------------------------------
c  Pick maximum, minimum and median values from sorted list.
c-----------------------------------------------------------------------
c
      hmin = wk(1)
      hmax = wk(nxy)
c
      if (mod(nxy,2) .ne. 0) then
c
         index = (nxy+1)/2
         hmed = wk(index)
c
        else
c
         index = nxy/2
         hmed = p5 * ( wk(index) + wk(index+1) )
c
      end if
c
c-----------------------------------------------------------------------
c  Initialize for summed statistical quantities.
c-----------------------------------------------------------------------
c
      sum = cd0
      sum2 = cd0
      hscl = max(abs(hmax), abs(hmin))
      rdhmax = cd1 / dble(hscl)
      rnxy = cd1 / dble(nxy)
c
c-----------------------------------------------------------------------
c  Compute mean and root mean square depths, protecting against
c  overflow and loss of precision.
c-----------------------------------------------------------------------
c
      do 20 j = 1, no_y
         do 20 i = 1, no_x
c
            dh = dble(topog(i,j)) * rdhmax
            sum = sum + dh * rnxy
            sum2 = sum2 + dh * dh * rnxy
c
 20   continue
c
      hmean = hscl * real(sum)
      hrms = hscl * sqrt ( real(sum2) )
c
c-----------------------------------------------------------------------
c  Write results (in meters).
c-----------------------------------------------------------------------
c
      write (out_unit,30) hmax,hmean,hmed,hmin
#ifdef sunflush
      call flush (out_unit)
#endif
c
      return
c
 30   format (/'Topography statistics:'/3x,'shallowest depth = ',1pg15.8
     &       ,' (m)'/5x,'mean  depth = ',1pg15.8,' (m)'/4x,'median '
     &  ,'depth = ',1pg15.8,' (m)'/3x,'deepest depth = ',1pg15.8,' (m)')
c
      end
