      subroutine uv_depth (ipt,jpt,ldh,no_x,no_y,h,hij)
c
c-------------------------------------------------------------------------------
c     This routine determines the bottom depth of the given uv-grid point.     |
c                                                                              |
c     Calls:  none                                                             |
c                                                                              |
c     Arguments:                                                               |
c                                                                              |
c     h......Real array.  The topography at T-grid points.  (cm)   {input}     |
c     hij....Real.  The bottom depth at the given uv-grid point.  (cm) {output}|
c     ipt....Integer.  X-coordinate of desired uv-grid point.   {input}        |
c     jpt....Integer.  Y-coordinate of desired uv-grid point.   {input}        |
c     ldh....Integer.  Leading dimension of h.   {input}                       |
c     no_x...Integer.  Number of grid points in x direction.   {input}         |
c     no_y...Integer.  Number of grid points in y direction.   {input}         |
c-------------------------------------------------------------------------------
c
#include <gpconst.h>
c
      integer ipt,jpt,ldh,no_x,no_y
      real    h(ldh,no_y),hij
      logical testi,testj
c
c=======================================================================
c     Begin executable code.                                           #
c=======================================================================
c
c-----------------------------------------------------------------------
c     Determine if desired point is contained within T-grid.           |
c-----------------------------------------------------------------------
c
      testi = ipt .lt. no_x
      testj = jpt .lt. no_y
c
c-----------------------------------------------------------------------
c     Determine bottom depth of desired uv-grid point.                 |
c-----------------------------------------------------------------------
c
      if (testi .and. testj) then
c
         hij = p25 * (h(ipt,jpt) + h(ipt,jpt+1) + h(ipt+1,jpt) +
     &                                                   h(ipt+1,jpt+1))
c
        else if (testi) then
c
         hij = p5 * (h(ipt,jpt) + h(ipt+1,jpt))
c
        else if (testj) then
c
         hij = p5 * (h(ipt,jpt) + h(ipt,jpt+1))
c
        else
c
         hij = h(ipt,jpt)
c
      end if
c
      return
      end
