      subroutine var_top (alpha,no_lvl,bnd,dsig,sigma)
c
c=======================================================================
c                                                                    ===
c  This routine selects the "optimum" sigma levels when the          ===
c  coordinate interface varies in the horizontal.  The sigma         ===
c  levels selected are for the centers of the tracer boxes.          ===
c                                                                    ===
c  ------                                                            ===
c  Input:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     alpha....Coordinate interface slope parameter.   (real)        ===
c                                                                    ===
c  -------                                                           ===
c  Output:                                                           ===
c  -------                                                           ===
c                                                                    ===
c     dsig.....The sigma thicknesses selected.         (real vector) ===
c     bnd......The upper bound for sigma/dsigma.       (real)        ===
c     no_lvl...The number of sigma levels to select.   (integer)     ===
c     sigma....The sigma levels selected.              (real vector) ===
c                                                                    ===
c  Calls:  none                                                      ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global variables.
c-----------------------------------------------------------------------
c
#include <gpconst.h>
c
c-----------------------------------------------------------------------
c  Define local variables.
c-----------------------------------------------------------------------
c
      integer no_lvl,k
      real    a_k,alpha,bnd,rdenom,ratio,pwr
      real dsig(no_lvl),sigma(no_lvl)
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c-----------------------------------------------------------------------
c  Take action depending upon the value of the slope parameter
c-----------------------------------------------------------------------
c
      if (alpha.ne.c1) then
c
c   -----------------------------------------
c   --- Set upper bound for sigma/dsigma. ---
c   -----------------------------------------
c
         pwr = c1/float(no_lvl)
         a_k = alpha**pwr
         bnd = (c1+a_k)*(c1-alpha)*p5/(c1-a_k)
c
c   ---------------------------------
c   --- Compute the sigma levels. ---
c   ---------------------------------
c
         rdenom = c1/(c2*bnd+c1-alpha)
         ratio  = (c2*bnd+alpha-c1)*rdenom
         rdenom = c2*rdenom
c
         dsig(1)  = rdenom * (ratio**(no_lvl-1))
         sigma(1) = c1 + p5*dsig(1)
c
         do 10 k = 2, no_lvl
            dsig(k)  = rdenom * ( ratio**(no_lvl-k) )
            sigma(k) = sigma(k-1) + p5*(dsig(k)+dsig(k-1))
 10      continue
c
        else
c
c   ---------------------------------
c   --- Set evenly spaced levels. ---
c   ---------------------------------
c
         bnd    = float(no_lvl)
         ratio  = c1/float(no_lvl)
c
         dsig(1)  = ratio
         sigma(1) = c1 + p5*dsig(1)
c
         do 20 k = 2, no_lvl
            dsig(k)  = ratio
            sigma(k) = sigma(k-1) + p5*(dsig(k)+dsig(k-1))
 20      continue
c
      end if
c
      return
      end
