      subroutine vec_read_f (vector,max_elem,no_elem,vec_id,in_unit,
     &                                                         out_unit)
c
c-------------------------------------------------------------------------------
c     This subroutine reads in a 1D vector with free format.  If the number of |
c     elements exceeds the maximum allowed, the maximum is read and a warning  |
c     message is issued.                                                       |
c                                                                              |
c     Calls:  none                                                             |
c                                                                              |
c     Arguments:                                                               |
c                                                                              |
c     in_unit....Integer.  Unit number from which data is read.   {input}      |
c     max_elem...Integer.  Maximum number of elements allowed.   {input}       |
c     no_elem....Integer.  Number of elements to read.   {input/output}        |
c     out_unit...Integer.  Unit number on which to write warning message.      |
c                   {input}                                                    |
c     vec_id.....Character.  Identifier for vector being read. Used for        |
c                   warning message.   {input}                                 |
c     vector.....Real array.  Desired 1D vector of data.   {output}            |
c-------------------------------------------------------------------------------
c
      character*(*) vec_id
      integer       max_elem,no_elem,in_unit,out_unit,n
      real    vector(max_elem),dum
c
c=======================================================================
c     Begin executable code.                                           #
c=======================================================================
c
c-----------------------------------------------------------------------
c     Determine whether or not the number of levels to be read will fit|
c     in the vector.                                                   |
c-----------------------------------------------------------------------
c
      if (no_elem .le. max_elem) then
c
c-----------------------------------------------------------------------
c        An acceptable number of values, read them.                    |
c-----------------------------------------------------------------------
c
         do 10 n = 1, no_elem
            read (in_unit,*) vector(n)
 10      continue
c
        else
c
c-----------------------------------------------------------------------
c        User specified too many values.  Use the first max_elem of    |
c        them and flush the rest.                                      |
c-----------------------------------------------------------------------
c
         do 20 n = 1, max_elem
            read (in_unit,*) vector(n)
 20      continue
c
         do 30 n = max_elem+1, no_elem
            read (in_unit,*) dum
 30      continue
c
c-----------------------------------------------------------------------
c        Write warning message and reset number of elements.           |
c-----------------------------------------------------------------------
c
         write (out_unit,40) vec_id,no_elem,max_elem,max_elem
         no_elem = max_elem
c
      end if
#ifdef sunflush
      call flush (out_unit)
#endif
c
      return
c
 40   format (/'***Warning.  Too many elements for ',a/3x,'User ',
     &        'specified ',i10,3x,'elements'/3x,'Maximum number of ',
     & 'elements allowed = ',i10/3x,'Only first ',i10,' elements used.')
c
      end
