      subroutine vert_flat (no_x,no_y,no_lvl,dz)
c
c=======================================================================
c                                                                    ===
c  This routine writes the explicit 3D thickness for a flat          ===
c  vertical coordinate system.                                       ===
c                                                                    ===
c  ------                                                            ===
c  Input:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     DZ        Vertical level thicknesses.          (real vector; m)===
c     NO_LVL    Total number of vertical levels.     (integer)       ===
c     NO_X      Number of grid points in x dir.      (integer)       ===
c     NO_Y      Number of grid points in y dir.      (integer)       ===
c                                                                    ===
c  Common Blocks:                                                    ===
c                                                                    ===
c  /GRIDSIO/                                                         ===
c                                                                    ===
c     NCOUTID   Identifier number for netCDF output file.  (integer) ===
c                                                                    ===
c  ------                                                            ===
c  Calls:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     HOPS:    GR_EXIT                                               ===
c     netCDF:  NF_INQ_VARID,  NF_PUT_VARA_REAL                       ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data
c-----------------------------------------------------------------------
c
#include <gridsparm.h>
#include <gridsio.h>
#include <netcdf.inc>
c
c-----------------------------------------------------------------------
c  Define local data
c-----------------------------------------------------------------------
c
      integer i,j,no_lvl,no_x,no_y,varidt,varidv
      integer count(3),start(3)
      real    dz(mx_lvl)
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
      start(1) = 1
      count(1) = no_lvl
      count(2) = 1
      count(3) = 1
c
      if (nf_inq_varid (ncoutid,'dzt',varidt) .ne.NF_NOERR) then
         write (out_unit,900) 'dzt'
         call gr_exit ('VERT_FLAT')
      end if
c
      if (nf_inq_varid (ncoutid,'dzv',varidv) .ne.NF_NOERR) then
         write (out_unit,900) 'dzv'
         call gr_exit ('VERT_FLAT')
      end if
c
      do 10 j = 1, no_y
      do 10 i = 1, no_x
c
         start(2) = i
         start(3) = j
c
         if (nf_put_vara_real (ncoutid,varidt,start,count,dz)
     &                                               .ne. NF_NOERR) then
            write (out_unit,910) 'dzt',i,j
            call gr_exit ('VERT_FLAT')
         end if
c
         if (nf_put_vara_real (ncoutid,varidv,start,count,dz)
     &                                               .ne. NF_NOERR) then
            write (out_unit,910) 'dzv',i,j
            call gr_exit ('VERT_FLAT')
         end if
c
  10  continue
c
      return
c
 900  format (/'*** Error:  VERT_FLAT - unable to find variable ',1h",
     &        a,1h")
 910  format (/'*** Error:  VERT_FLAT - unable to write variable ',1h",
     &        a,1h",' at position (',i10,', ',i10,')')
c
      end
