      subroutine vert_sigma (no_x,no_y,kc,no_lvl,f,h,dsigma)
c
c=======================================================================
c                                                                    ===
c  This routine writes the explicit 3D thickness for a sigma-type    ===
c  vertical coordinate system.                                       ===
c                                                                    ===
c  ------                                                            ===
c  Input:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     DSIGMA    Vertical level thicknesses.          (real vector)   ===
c     F         Coordinate interface over T-grid.    (real array; cm)===
c     H         Topography at T-grid points.         (real array; cm)===
c     KC        Level at which to interface upper                    ===
c               & lower systems.                     (integer)       ===
c     NO_LVL    Total number of vertical levels.     (integer)       ===
c     NO_X      Number of grid points in x dir.      (integer)       ===
c     NO_Y      Number of grid points in y dir.      (integer)       ===
c                                                                    ===
c  Common Blocks:                                                    ===
c                                                                    ===
c  /GRIDSIO/                                                         ===
c                                                                    ===
c     NCOUTID   Identifier number for netCDF output file.  (integer) ===
c                                                                    ===
c  ------                                                            ===
c  Calls:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     HOPS:    GR_EXIT,           T2VGRD                             ===
c     netCDF:  NF_GET_VARA_REAL,  NF_INQ_VARID,  NF_PUT_VARA_REAL    ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data
c-----------------------------------------------------------------------
c
#include <gridsparm.h>
#include <gpconst.h>
#include <gridsio.h>
#include <netcdf.inc>
c
c-----------------------------------------------------------------------
c  Define local data
c-----------------------------------------------------------------------
c
      integer i,j,k,kc,no_lvl,no_x,no_y,varidt,varidv
      integer count(3),start(3)
      real    hmf
      real dsigma(mx_lvl),dz(mx_lvl),f(imt,jmt),h(imt,jmt),
     &     tfld(imjm),vfld(imjm)
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c-----------------------------------------------------------------------
c  Construct & write thicknesses over T-grid.
c-----------------------------------------------------------------------
c
      start(1) = 1
      count(1) = no_lvl
      count(2) = 1
      count(3) = 1
c
      if (nf_inq_varid (ncoutid,'dzt',varidt) .ne.NF_NOERR) then
         write (out_unit,900) 'dzt'
         call gr_exit ('VERT_SIGMA')
      end if
c
      do 40 j = 1, no_y
      do 40 i = 1, no_x
c
c  ------------------------------
c  --- Construct thicknesses. ---
c  ------------------------------
c
         do 10 k = 1, kc
            dz(k) = -dsigma(k)*f(i,j)
  10     continue
c
         hmf = f(i,j) - h(i,j)
c
         do 20 k = kc+1, no_lvl
            dz(k) = dsigma(k)*hmf
  20     continue
c
c  --------------------------
c  --- Write thicknesses. ---
c  --------------------------
c
         start(2) = i
         start(3) = j
c
         if (nf_put_vara_real (ncoutid,varidt,start,count,dz)
     &                                               .ne. NF_NOERR) then
            write (out_unit,910) 'dzt',i,j
            call gr_exit ('VERT_SIGMA')
         end if
c
  40  continue
c
c-----------------------------------------------------------------------
c  Construct & write thicknesses over V-grid.
c-----------------------------------------------------------------------
c
c-------------------------
c--- Synchronize File. ---
c-------------------------
c
      if (nf_sync (ncoutid) .ne. NF_NOERR) then
         write (out_unit,920)
         call gr_exit ('VERT_SIGMA')
      end if
c
c---------------------------------------------
c--- Construct & write V-grid thicknesses. ---
c---------------------------------------------
c
      if (nf_inq_varid (ncoutid,'dzv',varidv) .ne.NF_NOERR) then
         write (out_unit,900) 'dzv'
         call gr_exit ('VERT_SIGMA')
      end if
c
      start(2) = 1
      start(3) = 1
      count(1) = 1
      count(2) = no_x
      count(3) = no_y
c
      do 50 k = 1, no_lvl
c
c   -------------------------------------------------
c   --- Read T-grid thicknesses on current level. ---
c   -------------------------------------------------
c
         start(1) = k
c
         if (nf_get_vara_real (ncoutid,varidt,start,count,tfld)
     &                                               .ne. NF_NOERR) then
            write (out_unit,930) 'dzt',k
            call gr_exit ('VERT_SIGMA')
         end if
c
c   ------------------------------------------------------
c   --- Construct V-grid thicknesses on current level. ---
c   ------------------------------------------------------
c
         call t2vgrd (no_x,no_x,no_y,tfld,vfld)
c
c   --------------------------------------------------
c   --- Write V-grid thicknesses on current level. ---
c   --------------------------------------------------
c
         if (nf_put_vara_real (ncoutid,varidv,start,count,vfld)
     &                                               .ne. NF_NOERR) then
            write (out_unit,930) 'dzv',k
            call gr_exit ('VERT_SIGMA')
         end if
c
  50  continue
c
      return
c
 900  format (/'*** Error:  VERT_SIGMA - unable to find variable ',1h",
     &        a,1h")
 910  format (/'*** Error:  VERT_SIGMA - unable to write variable ',1h",
     &        a,1h",' at position (',i10,', ',i10,')')
 920  format (/'*** Error:  VERT_SIGMA - unable to synchronize output ',
     &        'netCDF file.')
 930  format (/'*** Error:  VERT_SIGMA - unable to read variable ',1h",
     &        a,1h",' at level ',i10)
c
      end
