      subroutine wrt_lvl (optimum,no_lvl,kc,sigma,fac,favg,fdif,href)
c
c-------------------------------------------------------------------------------
c     This routine writes the sigma levels at the centers of the T-boxes and   |
c     the corresponding depths over the minimum, median and maximum topographic|
c     depths.                                                                  |
c                                                                              |
c     Calls:  none                                                             |
c                                                                              |
c     Arguments:                                                               |
c                                                                              |
c     fac.......Real.  Scale factor for argument of tanh interface.  (1/m)     |
c                  {input}                                                     |
c     favg......Real.  Average of interface bounds.  (m)   {input}             |
c     fdif......Real.  Negative difference between interface bounds.  (m)      |
c                  {input}                                                     |
c     href......Real.  Reference depth for tanh interface.  (m)   {input}      |
c     kc........Integer.  The number of levels in the upper system.   {input}  |
c     no_lvl....Integer.  The number of vertical levels.  {input}              |
c     optimum...Logical.  Indicates whether optimal sigma levels were chosen.  |
c                  optimum = .true.   =>  optimal levels were chosen.   {input}|
c                  optimum = .false.  =>  optimal levels were NOT chosen.      |
c     sigma.....Real vector.  The sigma levels at the centers of the boxes.    |
c                  {input}                                                     |
c                                                                              |
c     Common Blocks:                                                           |
c                                                                              |
c     /tpmed/                                                                  |
c                                                                              |
c        hmed...Real.  The median topographic depth.  (m)   {input}            |
c                                                                              |
c     /tpstt/                                                                  |
c                                                                              |
c        hmax...Real.  The maximum topographic depth.  (m)   {input}           |
c        hmin...Real.  The minimum topographic depth.  (m)   {input}           |
c-------------------------------------------------------------------------------
c
#include <gridsparm.h>
#include <gridsio.h>
#include <gpconst.h>
c
      integer no_lvl,kc,k
      logical optimum
      real    sigma(no_lvl),fac,favg,
     &     fdif,href,fmin,fmed,fmax,zmin,zmed,zmax
c
#include <tpmed.h>
#include <tpstt.h>
c
c=======================================================================
c     Begin executable code.                                           #
c=======================================================================
c
c-----------------------------------------------------------------------
c     Get minimum, median and maximum interface depths.                |
c-----------------------------------------------------------------------
c
      fmin = favg + fdif * tanh ( fac*(hmax-href) )
      fmed = favg + fdif * tanh ( fac*(hmed-href) )
      fmax = favg + fdif * tanh ( fac*(hmin-href) )
c
c-----------------------------------------------------------------------
c     Get sigma levels at T-box centers.  Record the values            |
c-----------------------------------------------------------------------
c
      if (optimum) then
c
         write (out_unit,40)
         do 10 k = 1, no_lvl
            if (optimum) write (out_unit,50) sigma(k)
 10      continue
c
      endif
c
c-----------------------------------------------------------------------
c     Write the depths of the sigma levels over the minimum, median and|
c     maximum topographic depths.                                      |
c-----------------------------------------------------------------------
c
      write (out_unit,60)
c
      do 20 k = 1, kc
c
         zmin = sigma(k)*fmin
         zmed = sigma(k)*fmed
         zmax = sigma(k)*fmax
         write (out_unit,70) k,zmin,zmed,zmax
c
 20   continue
c
      do 30 k = kc+1, no_lvl
c
         zmin = fmin + (sigma(k)-c1) * (hmax - fmin)
         zmed = fmed + (sigma(k)-c1) * (hmed - fmed)
         zmax = fmax + (sigma(k)-c1) * (hmin - fmax)
         write (out_unit,70) k,zmin,zmed,zmax
c
 30   continue
#ifdef sunflush
      call flush (out_unit)
#endif
c
      return
c
 40   format (/'Optimal sigma levels (centers of T-boxes):'/)
 50   format (3x,f10.8)
 60   format (/'Depths of sigma levels (m):'//3x,'Level',9x,'Minimum',
     &                                      12x,'Median',11x,'Maximum'/)
 70   format (i10,3(3x,1pg15.8))
c
      end
