       function acor (xj,yj,tj,xi,yi,ti)
c
c=======================================================================
c                                                                    ===
c  This routine computes the analytical correlation (covariance)     ===
c  function.   A table may  replace this  if there are  suitable     ===
c  estimates of the correlation function.   It uses Cartesian or     ===
c  spherical coordinates.                                            ===
c                                                                    ===
c  On input:                                                         ===
c                                                                    ===
c     XJ       zonal position of point J (km or degrees)             ===
c     YJ       meridional position of point J (km or degrees)        ===
c     TJ       time of point J (days)                                ===
c     XI       zonal position of point I (km or degrees)             ===
c     YI       meridional position of point I (km or degrees)        ===
c     TI       time of point I (days)                                ===
c                                                                    ===
c  On output:                                                        ===
c                                                                    ===
c     ACOR     normalized correlation, [1,-1].                       ===
c                                                                    ===
c  Required common blocks:                                           ===
c                                                                    ===
c     CORSCL                                                         ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <corscl.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
       real acor,a2,bearing,b2,c0,c1,c2,delt,dkm,elim,phi,p5,r,rx,ry,ti,
     &      tj,xi,xp,yi,yp,xj,yj
       real gcircle
       parameter (c0=0.0,c1=1.0,p5=0.5)
       data elim /15./
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c-----------------------------------------------------------------------
c  Rotated or non-rotated, time-displaced, Cartesian or spherical,
c  isotropic (symmetric: circular)  or  anisotropic (asymmetric:
c  elliptical) Gaussian Correlation.
c-----------------------------------------------------------------------
c
       if (icorr.eq.1) then
         delt=tj-ti
         if (ccoor.eq.0) then
           xp=(xj-xi)
           yp=(yj-yi)
         elseif ((ccoor.eq.1).or.(ccoor.eq.2)) then
           r=gcircle(xi,yi,xj,yj,dkm,bearing)
           phi=bearing*deg2rad
           xp=dkm*cos(phi)
           yp=dkm*sin(phi)
         endif
         rx=xp*cosang+yp*sinang+uphse*delt
         ry=yp*cosang-xp*sinang+vphse*delt
         a2=(rx*rx)/(xzero*xzero)+(ry*ry)/(yzero*yzero)
         b2=-p5*((rx*rx)/(xdcay*xdcay)+(ry*ry)/(ydcay*ydcay))
         c2=-p5*(delt*delt)/(tdcay*tdcay)
         if (abs(b2+c2).gt.elim) then
           acor=c0
         else
           acor=(c1-a2)*exp(b2+c2)
         endif
c
c-----------------------------------------------------------------------
c  Other possible analytical correlation to be include later.
c-----------------------------------------------------------------------
c
       else
       endif
       return
       end
