      function bes1d(x,f1,f2,f3,f4,ibry)
c
c=======================================================================
c                                                                    ===
c  This function performs a 1-d  cubic Bessel interpolation at       ===
c  the point X given the value of function at four consecutive       ===
c  points (F1,F2,F3,F4).   The value of the function at X lies       ===
c  between F2 and F3.  This routine is call by  BES2D  several       ===
c  times to achive two-dimensional interpolation.                    ===
c                                                                    ===
c     On Input:                                                      ===
c                                                                    ===
c     F1,F2,F3,F4  field to interpolate from (real)                  ===
c     X            position a wich the field is interpolated (grid   ===
c                  units; real)                                      ===
c     IBRY         pointer that indicates if the point is at         ===
c                  boundary of the raw two-dimensional field         ===
c                  that interpolates from                            ===
c                                                                    ===
c     On Output:                                                     ===
c                                                                    ===
c     BES1D        interpolated value (real)                         ===
c                                                                    ===
c     Calls:          none                                           ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c 
      integer ibry
      real a0,a1,a2,a3,bes1d,f1,f2,f3,f4,fp0,fp1,x
c
c-----------------------------------------------------------------------
c  Begin executable code.
c-----------------------------------------------------------------------
c
      if(ibry.eq.0) then
        fp0=0.5*(f3-f1)
        fp1=0.5*(f4-f2)
      elseif(ibry.eq.1) then
        fp0=0.5*(-3.*f2+4.*f3-f4)
        fp1=0.5*(f4-f2)
      elseif(ibry.eq.2) then
        fp0=0.5*(f3-f1)
        fp1=0.5*(3.*f3-4.*f2+f1)
      endif
      a0=f2
      a1=fp0
      a2=3.*f3-fp1-3.*a0-2.*a1
      a3=f3-a0-a1-a2
c
c-----------------------------------------------------------------------
c  Interpolate F(X) with a cubic polynomial.
c-----------------------------------------------------------------------
c
      bes1d=a0+x*(a1+x*(a2+a3*x))
      return
      end
