      function bes2d(x,y,f,im,jm)
c
c=======================================================================
c                                                                    ===
c  This routine performs a 16-point cubic bessel interpolation at    ===
c  the grid locations X and Y from a regularly grided 2-D field F.   ===
c                                                                    ===
c     On Input:                                                      ===
c                                                                    ===
c     F        field to interpolate from (real array)                ===
c     IM, JM   first and second dimensions of F (integer)            ===
c     X, Y     position a wich the field is interpolated (grid       ===
c              units; real)                                          ===
c                                                                    ===
c     On Output:                                                     ===
c                                                                    ===
c     BES2D    interpolated value (real)                             ===
c                                                                    ===
c     Calls:      BES1D                                              ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer i1,i2,i3,i4,ibry,im,ix,iy,j1,j2,j3,j4,jbry,jm
      real bes1d,bes2d,f1,f2,f3,f4,s,t,x,y
      real f(im,jm)
c
c-----------------------------------------------------------------------
c  Begin executable code.
c-----------------------------------------------------------------------
c
c-----------------------------------------------------------------------
c  Find the grid coordinates of lower left corner of the box that
c  contains the point to interpolate
c-----------------------------------------------------------------------
c
      ix=int(x)
      iy=int(y)
c
c-----------------------------------------------------------------------
c  Get the indices for the 4 x 4 raw data window
c-----------------------------------------------------------------------
c
      ibry=0
      jbry=0
      i1=ix-1
      i2=ix
      i3=ix+1
      i4=ix+2
      j1=iy-1
      j2=iy
      j3=iy+1
      j4=iy+2
c
c-----------------------------------------------------------------------
c  Check left and right boundaries
c-----------------------------------------------------------------------
c
      if(x.lt.2.) then
        ibry=1
        i1=2
      elseif(x.gt.float(im-1)) then
        ibry=2
        i4=im-1
      endif
c
c-----------------------------------------------------------------------
c  Check bottom and top boundaries
c-----------------------------------------------------------------------
c
      if(y.lt.2.) then
        jbry=1
        j1=2
      elseif(y.gt.float(jm-1)) then
        jbry=2
        j4=jm-1
      endif
c
c-----------------------------------------------------------------------
c  Achive the two-dimendional interpolation by a series one-dimensional
c  interpolations
c-----------------------------------------------------------------------
c
      s=x-ix
      t=y-iy
      f1=bes1d(t,f(i1,j1),f(i1,j2),f(i1,j3),f(i1,j4),jbry)
      f2=bes1d(t,f(i2,j1),f(i2,j2),f(i2,j3),f(i2,j4),jbry)
      f3=bes1d(t,f(i3,j1),f(i3,j2),f(i3,j3),f(i3,j4),jbry)
      f4=bes1d(t,f(i4,j1),f(i4,j2),f(i4,j3),f(i4,j4),jbry)
      bes2d=bes1d(s,f1,f2,f3,f4,ibry)
      return
      end
