      subroutine defcdf
c
c=======================================================================
c                                                                    ===
c  This routine defines output NetCDF file.                          ===
c                                                                    ===
c  Calls:                                                            ===
c                                                                    ===
c    NCAPT, NCAPTC, NCCRE, NCDDEF, NCENDF, NCPOPT, NCVDEF, NCVID,    ===
c    NCVPT, NCVPT1   (NetCDF library)                                ===
c    EXITUS, GET_DATE, LNBLK                                         ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <param.h>
#include <clima.h>
#include <corscl.h>
#include <domdat.h>
#include <hydobs.h>
#include <inppar.h>
#include <netcdf.inc>
#include <oagrid.h>
#include <oa_netcdf.h>
#include <obscor.h>
#include <version.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer ax2dim,ax3dim,dbgn,dend,g2did,g3did,latdim,ldate,levdim,
     *        lmod,londim,lvnum,m,mbgn,mend,mskid,n,sbgn,send,slen,
     *        timdim,vartyp,vbgn,vend,xindx,yindx,zindx
      integer count(3),fdim(4),fdim2(2),start(3)
      real c0,c1,jul_off,km2m,scl,spv
      real wrk(mlev)
      character*44  date_str
      character*120 history
      character*256 wkstr
      parameter (c0=0.0,c1=1.0,jul_off=2440000.0,km2m=1000.0,
     *           spv=1.0e+35,xindx=1,yindx=2,zindx=3)
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c  Create netCDF file.
c
      call ncpopt(ncverbos)
      call length (fname(1),slen,sbgn,send)
      ncoutid=nccre(fname(1)(sbgn:send),ncclob,rcode)
      if(rcode.ne.0) then
        write(iprt,900) fname(1)(sbgn:send)
        call exitus('DEFCDF')
      endif
c
c  Create history attribute label.
c
      call get_date(date_str)
      call length (date_str,ldate,dbgn,dend)
      call length (model,lmod,mbgn,mend)
      call length (vnum,lvnum,vbgn,vend)
      if(ldate.gt.0) then
        history=model(mbgn:mend)//', Version '//vnum(vbgn:vend)//', '
     &          //date_str(dbgn:dend)
      else
        history=model(mbgn:mend)//', Version '//vnum(vbgn:vend)
      endif
c
c  Define netCDF dimensions.
c
      londim=ncddef(ncoutid,'lon',im,rcode)
      latdim=ncddef(ncoutid,'lat',jm,rcode)
      levdim=ncddef(ncoutid,'level',nlev,rcode)
      timdim=ncddef(ncoutid,'time',ncunlim,rcode)
      if(lmsk) ax2dim=ncddef(ncoutid,'axis2',2,rcode)
      ax3dim=ncddef(ncoutid,'axis3',3,rcode)
c
c  Set single or double precision.
c
      vartyp=ncfloat
c     vartyp=ncdouble
c
c  Define global title.
c
      call length (title,slen,sbgn,send)
      call ncaptc (ncoutid,ncglobal,'title',ncchar,slen,
     *             title(sbgn:send),rcode)
      call length (fname(1),slen,sbgn,send)
      call ncaptc (ncoutid,ncglobal,'out_file',ncchar,slen,
     *             fname(1)(sbgn:send),rcode)
      call length (fname(3),slen,sbgn,send)
      call ncaptc (ncoutid,ncglobal,'hyd_file',ncchar,slen,
     *             fname(3)(sbgn:send),rcode)
      if((iclima.eq.1).or.(iclima.eq.2)) then
        call length (fname(4),slen,sbgn,send)
        call ncaptc (ncoutid,ncglobal,'clm_file',ncchar,slen,
     *               fname(4)(sbgn:send),rcode)
      endif
      if(igrids.ne.0) then
        call length (fname(5),slen,sbgn,send)
        call ncaptc (ncoutid,ncglobal,'grd_file',ncchar,slen,
     *               fname(5)(sbgn:send),rcode)
      endif
      call ncaptc (ncoutid,ncglobal,'type',ncchar,lmod,model(mbgn:mend),
     *             rcode)
      call ncaptc (ncoutid,ncglobal,'version',ncchar,lvnum,
     *             vnum(vbgn:vend),rcode)
      call length (history,slen,sbgn,send)
      call ncaptc (ncoutid,ncglobal,'history',ncchar,slen,
     *             history(sbgn:send),rcode)
c
c-----------------------------------------------------------------------
c  Define parameters.
c-----------------------------------------------------------------------
c
c  Observations and climatology input format type.
c
      varid = ncvdef (ncoutid,'ihfrmt',nclong,0,0,rcode)
      wkstr = 'input format type for hydrographic data'
      call length (wkstr,slen,sbgn,send)
      call ncaptc (ncoutid,varid,'long_name',ncchar,slen,
     *             wkstr(sbgn:send),rcode)
      wkstr = 'unformatted - z, T, S, Dyn H'
      call length (wkstr,slen,sbgn,send)
      call ncaptc (ncoutid,varid,'option_0',ncchar,slen,
     *             wkstr(sbgn:send),rcode)
      wkstr = 'unformatted - z, T, S'
      call length (wkstr,slen,sbgn,send)
      call ncaptc (ncoutid,varid,'option_1',ncchar,slen,
     *             wkstr(sbgn:send),rcode)
      wkstr = 'unformatted - z, T'
      call length (wkstr,slen,sbgn,send)
      call ncaptc (ncoutid,varid,'option_2',ncchar,slen,
     *             wkstr(sbgn:send),rcode)
      wkstr = 'unformatted - z, Dyn H'
      call length (wkstr,slen,sbgn,send)
      call ncaptc (ncoutid,varid,'option_3',ncchar,slen,
     *             wkstr(sbgn:send),rcode)
      wkstr = 'unformatted - z, any oceanic field'
      call length (wkstr,slen,sbgn,send)
      call ncaptc (ncoutid,varid,'option_4',ncchar,slen,
     *             wkstr(sbgn:send),rcode)
      wkstr = 'unformatted - any field (a single value)'
      call length (wkstr,slen,sbgn,send)
      call ncaptc (ncoutid,varid,'option_5',ncchar,slen,
     *             wkstr(sbgn:send),rcode)
      wkstr = 'formatted - HOPS hydrography format'
      call length (wkstr,slen,sbgn,send)
      call ncaptc(ncoutid,varid,'option_6',ncchar,slen,
     *             wkstr(sbgn:send),rcode)
c
      if((iclima.eq.1).or.(iclima.eq.2)) then
        varid = ncvdef (ncoutid,'icfrmt',nclong,0,0,rcode)
        wkstr = 'input format type for climatology data'
        call length (wkstr,slen,sbgn,send)
        call ncaptc (ncoutid,varid,'long_name',ncchar,slen,
     *               wkstr(sbgn:send),rcode)
        wkstr = 'unformatted - z, T, S, Dyn H'
        call length (wkstr,slen,sbgn,send)
        call ncaptc (ncoutid,varid,'option_0',ncchar,slen,
     *               wkstr(sbgn:send),rcode)
        wkstr = 'unformatted - z, T, S'
        call length (wkstr,slen,sbgn,send)
        call ncaptc (ncoutid,varid,'option_1',ncchar,slen,
     *               wkstr(sbgn:send),rcode)
        wkstr = 'unformatted - z, T'
        call length (wkstr,slen,sbgn,send)
        call ncaptc (ncoutid,varid,'option_2',ncchar,slen,
     *               wkstr(sbgn:send),rcode)
        wkstr = 'unformatted - z, Dyn H'
        call length (wkstr,slen,sbgn,send)
        call ncaptc (ncoutid,varid,'option_3',ncchar,slen,
     *               wkstr(sbgn:send),rcode)
        wkstr = 'unformatted - z, any oceanic field'
        call length (wkstr,slen,sbgn,send)
        call ncaptc (ncoutid,varid,'option_4',ncchar,slen,
     *               wkstr(sbgn:send),rcode)
        wkstr = 'unformatted - any field (a single value)'
        call length (wkstr,slen,sbgn,send)
        call ncaptc (ncoutid,varid,'option_5',ncchar,slen,
     *               wkstr(sbgn:send),rcode)
        wkstr = 'formatted - HOPS hydrography format'
        call length (wkstr,slen,sbgn,send)
        call ncaptc (ncoutid,varid,'option_6',ncchar,slen,
     *               wkstr(sbgn:send),rcode)
      endif
c
c  Mean field computation switch.
c
      varid = ncvdef (ncoutid,'iclima',nclong,0,0,rcode)
      wkstr = 'mean field computation switch'
      call length (wkstr,slen,sbgn,send)
      call ncaptc (ncoutid,varid,'long_name',ncchar,slen,
     *             wkstr(sbgn:send),rcode)
      wkstr = 'use only hydrography observations'
      call length (wkstr,slen,sbgn,send)
      call ncaptc (ncoutid,varid,'option_0',ncchar,slen,
     *             wkstr(sbgn:send),rcode)
      wkstr = 'use only climatology observations'
      call length (wkstr,slen,sbgn,send)
      call ncaptc (ncoutid,varid,'option_1',ncchar,slen,
     *             wkstr(sbgn:send),rcode)
      wkstr = 'use both hydrography and climatology observations'
      call length (wkstr,slen,sbgn,send)
      call ncaptc (ncoutid,varid,'option_2',ncchar,slen,
     *             wkstr(sbgn:send),rcode)
      wkstr = 'use global hydrography mean (a single value)'
      call length (wkstr,slen,sbgn,send)
      call ncaptc (ncoutid,varid,'option_3',ncchar,slen,
     *             wkstr(sbgn:send),rcode)
c
c  OA coordinates type.
c
      varid = ncvdef (ncoutid,'coord',nclong,0,0,rcode)
      wkstr = 'OA computation coordinates switch'
      call length (wkstr,slen,sbgn,send)
      call ncaptc (ncoutid,varid,'long_name',ncchar,slen,
     *             wkstr(sbgn:send),rcode)
      wkstr = 'Cartesian'
      call length (wkstr,slen,sbgn,send)
      call ncaptc (ncoutid,varid,'option_0',ncchar,slen,
     *             wkstr(sbgn:send),rcode)
      wkstr = 'unrotated spherical'
      call length (wkstr,slen,sbgn,send)
      call ncaptc (ncoutid,varid,'option_1',ncchar,slen,
     *             wkstr(sbgn:send),rcode)
      wkstr = 'rotated spherical'
      call length (wkstr,slen,sbgn,send)
      call ncaptc (ncoutid,varid,'option_2',ncchar,slen,
     *             wkstr(sbgn:send),rcode)
c
c  Geometry parameters.
c
      varid = ncvdef (ncoutid,'dx',vartyp,0,0,rcode)
      wkstr = 'zonal grid spacing'
      call length (wkstr,slen,sbgn,send)
      call ncaptc (ncoutid,varid,'long_name',ncchar,slen,
     *             wkstr(sbgn:send),rcode)
      if(coord.eq.0) then
        wkstr = 'meter'
      elseif((coord.eq.1).or.(coord.eq.2)) then
        wkstr = 'degrees'
      endif
      call length (wkstr,slen,sbgn,send)
      call ncaptc (ncoutid,varid,'units',ncchar,slen,wkstr(sbgn:send),
     &             rcode)
c
      varid = ncvdef (ncoutid,'dy',vartyp,0,0,rcode)
      wkstr = 'meridional grid spacing'
      call length (wkstr,slen,sbgn,send)
      call ncaptc (ncoutid,varid,'long_name',ncchar,slen,
     *             wkstr(sbgn:send),rcode)
      if(coord.eq.0) then
        wkstr = 'meter'
      elseif((coord.eq.1).or.(coord.eq.2)) then
        wkstr = 'degrees'
      endif
      call length (wkstr,slen,sbgn,send)
      call ncaptc (ncoutid,varid,'units',ncchar,slen,wkstr(sbgn:send),
     &             rcode)
c
      varid = ncvdef (ncoutid,'rlngd',vartyp,0,0,rcode)
      wkstr = 'Transformation centroid longitude'
      call length (wkstr,slen,sbgn,send)
      call ncaptc (ncoutid,varid,'long_name',ncchar,slen,
     *             wkstr(sbgn:send),rcode)
      wkstr = 'degrees_east'
      call length (wkstr,slen,sbgn,send)
      call ncaptc (ncoutid,varid,'units',ncchar,slen,wkstr(sbgn:send),
     &             rcode)
c
      varid = ncvdef (ncoutid,'rlatd',vartyp,0,0,rcode)
      wkstr = 'Transformation centroid latitude'
      call length (wkstr,slen,sbgn,send)
      call ncaptc (ncoutid,varid,'long_name',ncchar,slen,
     *             wkstr(sbgn:send),rcode)
      wkstr = 'degrees_north'
      call length (wkstr,slen,sbgn,send)
      call ncaptc (ncoutid,varid,'units',ncchar,slen,wkstr(sbgn:send),
     &             rcode)
c
      varid = ncvdef (ncoutid,'delx',vartyp,0,0,rcode)
      wkstr = 'Longitudinal offset from transformation point to grid '//
     &        'center'
      call length (wkstr,slen,sbgn,send)
      call ncaptc (ncoutid,varid,'long_name',ncchar,slen,
     *             wkstr(sbgn:send),rcode)
      if(coord.eq.0) then
        wkstr = 'meter'
      elseif((coord.eq.1).or.(coord.eq.2)) then
        wkstr = 'degrees'
      endif
      call length (wkstr,slen,sbgn,send)
      call ncaptc (ncoutid,varid,'units',ncchar,slen,wkstr(sbgn:send),
     &             rcode)
c
      varid = ncvdef (ncoutid,'dely',vartyp,0,0,rcode)
      wkstr = 'Latitudinal offset from transformation point to grid '//
     &        'center'
      call length (wkstr,slen,sbgn,send)
      call ncaptc (ncoutid,varid,'long_name',ncchar,slen,
     *             wkstr(sbgn:send),rcode)
      if(coord.eq.0) then
        wkstr = 'meter'
      elseif((coord.eq.1).or.(coord.eq.2)) then
        wkstr = 'degrees'
      endif
      call length (wkstr,slen,sbgn,send)
      call ncaptc (ncoutid,varid,'units',ncchar,slen,wkstr(sbgn:send),
     &             rcode)
c
      varid = ncvdef (ncoutid,'thetad',vartyp,0,0,rcode)
      wkstr = 'domain rotation angle'
      call length (wkstr,slen,sbgn,send)
      call ncaptc (ncoutid,varid,'long_name',ncchar,slen,
     *             wkstr(sbgn:send),rcode)
      wkstr = 'degrees'
      call length (wkstr,slen,sbgn,send)
      call ncaptc (ncoutid,varid,'units',ncchar,slen,
     *             wkstr(sbgn:send),rcode)
c
c  Influential observations parameters.
c
      varid = ncvdef (ncoutid,'nnce',nclong,0,0,rcode)
      wkstr = 'number of influential observations'
      call length (wkstr,slen,sbgn,send)
      call ncaptc (ncoutid,varid,'long_name',ncchar,slen,
     *             wkstr(sbgn:send),rcode)
c
      varid = ncvdef (ncoutid,'rnce',vartyp,0,0,rcode)
      wkstr = 'radius of influence'
      call length (wkstr,slen,sbgn,send)
      call ncaptc (ncoutid,varid,'long_name',ncchar,slen,
     *             wkstr(sbgn:send),rcode)
      wkstr = 'meter'
      call length (wkstr,slen,sbgn,send)
      call ncaptc (ncoutid,varid,'units',ncchar,slen,
     *             wkstr(sbgn:send),rcode)
c
      varid = ncvdef (ncoutid,'tnce',vartyp,0,0,rcode)
      wkstr = 'influence time window'
      call length (wkstr,slen,sbgn,send)
      call ncaptc (ncoutid,varid,'long_name',ncchar,slen,
     *             wkstr(sbgn:send),rcode)
      wkstr = 'day'
      call length (wkstr,slen,sbgn,send)
      call ncaptc (ncoutid,varid,'units',ncchar,slen,
     *             wkstr(sbgn:send),rcode)
c
c  Averaging radius and time window.
c
      varid = ncvdef (ncoutid,'ravg',vartyp,0,0,rcode)
      wkstr = 'averaging radius'
      call length (wkstr,slen,sbgn,send)
      call ncaptc (ncoutid,varid,'long_name',ncchar,slen,
     *             wkstr(sbgn:send),rcode)
      wkstr = 'meter'
      call length (wkstr,slen,sbgn,send)
      call ncaptc (ncoutid,varid,'units',ncchar,slen,
     *             wkstr(sbgn:send),rcode)
c
      varid = ncvdef (ncoutid,'tavg',vartyp,0,0,rcode)
      wkstr = 'averaging time window'
      call length (wkstr,slen,sbgn,send)
      call ncaptc (ncoutid,varid,'long_name',ncchar,slen,
     *             wkstr(sbgn:send),rcode)
      wkstr = 'day'
      call length (wkstr,slen,sbgn,send)
      call ncaptc (ncoutid,varid,'units',ncchar,slen,
     *             wkstr(sbgn:send),rcode)
c
c  Outlier radius.
c
      varid = ncvdef (ncoutid,'rout',vartyp,0,0,rcode)
      wkstr = 'radius for outlier observations'
      call length (wkstr,slen,sbgn,send)
      call ncaptc (ncoutid,varid,'long_name',ncchar,slen,
     *             wkstr(sbgn:send),rcode)
      wkstr = 'meter'
      call length (wkstr,slen,sbgn,send)
      call ncaptc (ncoutid,varid,'units',ncchar,slen,
     *             wkstr(sbgn:send),rcode)
c
c  Analytical correlation type.
c
      varid = ncvdef (ncoutid,'icorr',nclong,0,0,rcode)
      wkstr = 'analytical correlation type'
      call length (wkstr,slen,sbgn,send)
      call ncaptc (ncoutid,varid,'long_name',ncchar,slen,
     *             wkstr(sbgn:send),rcode)
      wkstr = 'Gaussian in space and time'
      call length (wkstr,slen,sbgn,send)
      call ncaptc (ncoutid,varid,'option_1',ncchar,slen,
     *             wkstr(sbgn:send),rcode)
c
c  Zero-crossing correlation scales for estimate and mean fields.
c
      varid = ncvdef (ncoutid,'xzero',vartyp,0,0,rcode)
      wkstr = 'estimate, zonal zero-crossing for correlation'
      call length (wkstr,slen,sbgn,send)
      call ncaptc (ncoutid,varid,'long_name',ncchar,slen,
     *             wkstr(sbgn:send),rcode)
      wkstr = 'meter'
      call length (wkstr,slen,sbgn,send)
      call ncaptc (ncoutid,varid,'units',ncchar,slen,
     *             wkstr(sbgn:send),rcode)
c
      varid = ncvdef (ncoutid,'yzero',vartyp,0,0,rcode)
      wkstr = 'estimate, meridional zero-crossing for correlation'
      call length (wkstr,slen,sbgn,send)
      call ncaptc (ncoutid,varid,'long_name',ncchar,slen,
     *             wkstr(sbgn:send),rcode)
      wkstr = 'meter'
      call length (wkstr,slen,sbgn,send)
      call ncaptc (ncoutid,varid,'units',ncchar,slen,
     *             wkstr(sbgn:send),rcode)
c
      varid = ncvdef (ncoutid,'xzerom',vartyp,0,0,rcode)
      wkstr = 'mean, zonal zero-crossing for correlation'
      call length (wkstr,slen,sbgn,send)
      call ncaptc (ncoutid,varid,'long_name',ncchar,slen,
     *             wkstr(sbgn:send),rcode)
      wkstr = 'meter'
      call length (wkstr,slen,sbgn,send)
      call ncaptc (ncoutid,varid,'units',ncchar,slen,
     *             wkstr(sbgn:send),rcode)
c
      varid = ncvdef (ncoutid,'yzerom',vartyp,0,0,rcode)
      wkstr = 'mean, meridional zero-crossing for correlation'
      call length (wkstr,slen,sbgn,send)
      call ncaptc (ncoutid,varid,'long_name',ncchar,slen,
     *             wkstr(sbgn:send),rcode)
      wkstr = 'meter'
      call length (wkstr,slen,sbgn,send)
      call ncaptc (ncoutid,varid,'units',ncchar,slen,
     *             wkstr(sbgn:send),rcode)
c
c  Spatial decorrelation scales for estimate and mean fields.
c
      varid = ncvdef (ncoutid,'xdcay',vartyp,0,0,rcode)
      wkstr = 'estimate, zonal decorrelation scale'
      call length (wkstr,slen,sbgn,send)
      call ncaptc (ncoutid,varid,'long_name',ncchar,slen,
     *             wkstr(sbgn:send),rcode)
      wkstr = 'meter'
      call length (wkstr,slen,sbgn,send)
      call ncaptc (ncoutid,varid,'units',ncchar,slen,
     *             wkstr(sbgn:send),rcode)
c
      varid = ncvdef (ncoutid,'ydcay',vartyp,0,0,rcode)
      wkstr = 'estimate, meridional decorrelation scale'
      call length (wkstr,slen,sbgn,send)
      call ncaptc (ncoutid,varid,'long_name',ncchar,slen,
     *             wkstr(sbgn:send),rcode)
      wkstr = 'meter'
      call length (wkstr,slen,sbgn,send)
      call ncaptc (ncoutid,varid,'units',ncchar,slen,
     *             wkstr(sbgn:send),rcode)
c
      varid = ncvdef (ncoutid,'xdcaym',vartyp,0,0,rcode)
      wkstr = 'mean, zonal decorrelation scale'
      call length (wkstr,slen,sbgn,send)
      call ncaptc (ncoutid,varid,'long_name',ncchar,slen,
     *             wkstr(sbgn:send),rcode)
      wkstr = 'meter'
      call length (wkstr,slen,sbgn,send)
      call ncaptc (ncoutid,varid,'units',ncchar,slen,
     *             wkstr(sbgn:send),rcode)
c
      varid = ncvdef (ncoutid,'ydcaym',vartyp,0,0,rcode)
      wkstr = 'mean, meridional decorrelation scale'
      call length (wkstr,slen,sbgn,send)
      call ncaptc (ncoutid,varid,'long_name',ncchar,slen,
     *             wkstr(sbgn:send),rcode)
      wkstr = 'meter'
      call length (wkstr,slen,sbgn,send)
      call ncaptc (ncoutid,varid,'units',ncchar,slen,
     *             wkstr(sbgn:send),rcode)
c
c  Temporal decorrelation scale for estimate and mean fields.
c
      varid = ncvdef (ncoutid,'tdcay',vartyp,0,0,rcode)
      wkstr = 'temporal decorrelation scale'
      call length (wkstr,slen,sbgn,send)
      call ncaptc (ncoutid,varid,'long_name',ncchar,slen,
     *             wkstr(sbgn:send),rcode)
      wkstr = 'day'
      call length (wkstr,slen,sbgn,send)
      call ncaptc (ncoutid,varid,'units',ncchar,slen,
     *             wkstr(sbgn:send),rcode)
c
      varid = ncvdef (ncoutid,'tdcaym',vartyp,0,0,rcode)
      wkstr = 'mean, temporal decorrelation scale'
      call length (wkstr,slen,sbgn,send)
      call ncaptc (ncoutid,varid,'long_name',ncchar,slen,
     *             wkstr(sbgn:send),rcode)
      wkstr = 'day'
      call length (wkstr,slen,sbgn,send)
      call ncaptc (ncoutid,varid,'units',ncchar,slen,
     *             wkstr(sbgn:send),rcode)
c
c  Correlation phase speed and rotation angle for estimate and mean fields.
c
      varid = ncvdef (ncoutid,'uphse',vartyp,0,0,rcode)
      wkstr = 'correlation, zonal phase speed'
      call length (wkstr,slen,sbgn,send)
      call ncaptc (ncoutid,varid,'long_name',ncchar,slen,
     *             wkstr(sbgn:send),rcode)
      wkstr = 'meter day-1'
      call length (wkstr,slen,sbgn,send)
      call ncaptc (ncoutid,varid,'units',ncchar,slen,
     *             wkstr(sbgn:send),rcode)
c
      varid = ncvdef (ncoutid,'vphse',vartyp,0,0,rcode)
      wkstr = 'correlation, meridional phase speed'
      call length (wkstr,slen,sbgn,send)
      call ncaptc (ncoutid,varid,'long_name',ncchar,slen,
     *             wkstr(sbgn:send),rcode)
      wkstr = 'meter day-1'
      call length (wkstr,slen,sbgn,send)
      call ncaptc (ncoutid,varid,'units',ncchar,slen,
     *             wkstr(sbgn:send),rcode)
c
      varid = ncvdef (ncoutid,'corang',vartyp,0,0,rcode)
      wkstr = 'correlation, rotation angle'
      call length (wkstr,slen,sbgn,send)
      call ncaptc (ncoutid,varid,'long_name',ncchar,slen,
     *             wkstr(sbgn:send),rcode)
      wkstr = 'degrees, counterclockwise from EAST'
      call length (wkstr,slen,sbgn,send)
      call ncaptc (ncoutid,varid,'units',ncchar,slen,
     *             wkstr(sbgn:send),rcode)
c
      varid = ncvdef (ncoutid,'uphsem',vartyp,0,0,rcode)
      wkstr = 'mean, correlation, zonal phase speed'
      call length (wkstr,slen,sbgn,send)
      call ncaptc (ncoutid,varid,'long_name',ncchar,slen,
     *             wkstr(sbgn:send),rcode)
      wkstr = 'meter day-1'
      call length (wkstr,slen,sbgn,send)
      call ncaptc (ncoutid,varid,'units',ncchar,slen,
     *             wkstr(sbgn:send),rcode)
c
      varid = ncvdef (ncoutid,'vphsem',vartyp,0,0,rcode)
      wkstr = 'mean, correlation, meridional phase speed'
      call length (wkstr,slen,sbgn,send)
      call ncaptc (ncoutid,varid,'long_name',ncchar,slen,
     *             wkstr(sbgn:send),rcode)
      wkstr = 'meter day-1'
      call length (wkstr,slen,sbgn,send)
      call ncaptc (ncoutid,varid,'units',ncchar,slen,
     *             wkstr(sbgn:send),rcode)
c
      varid = ncvdef (ncoutid,'corangm',vartyp,0,0,rcode)
      wkstr = 'mean, correlation, rotation angle'
      call length (wkstr,slen,sbgn,send)
      call ncaptc (ncoutid,varid,'long_name',ncchar,slen,
     *             wkstr(sbgn:send),rcode)
      wkstr = 'degrees, counterclockwise from EAST'
      call length (wkstr,slen,sbgn,send)
      call ncaptc (ncoutid,varid,'units',ncchar,slen,
     *             wkstr(sbgn:send),rcode)
c
c  Observations and climatology noise variance.
c
      varid = ncvdef (ncoutid,'obserr',vartyp,0,0,rcode)
      wkstr = 'observation noise variance'
      call length (wkstr,slen,sbgn,send)
      call ncaptc (ncoutid,varid,'long_name',ncchar,slen,
     *             wkstr(sbgn:send),rcode)
c
      varid = ncvdef (ncoutid,'clmerr',vartyp,0,0,rcode)
      wkstr = 'climatology noise variance'
      call length (wkstr,slen,sbgn,send)
      call ncaptc (ncoutid,varid,'long_name',ncchar,slen,
     *             wkstr(sbgn:send),rcode)
c
c  Detrend option.
c
      varid = ncvdef (ncoutid,'itrt',nclong,0,0,rcode)
      wkstr = 'degree of polynomial surface to remove'
      call length (wkstr,slen,sbgn,send)
      call ncaptc (ncoutid,varid,'long_name',ncchar,slen,
     *             wkstr(sbgn:send),rcode)
      wkstr = 'mean'
      call length (wkstr,slen,sbgn,send)
      call ncaptc (ncoutid,varid,'option_0',ncchar,slen,
     *             wkstr(sbgn:send),rcode)
      wkstr = 'linear'
      call length (wkstr,slen,sbgn,send)
      call ncaptc (ncoutid,varid,'option_1',ncchar,slen,
     *             wkstr(sbgn:send),rcode)
      wkstr = 'quadratic'
      call length (wkstr,slen,sbgn,send)
      call ncaptc (ncoutid,varid,'option_2',ncchar,slen,
     *             wkstr(sbgn:send),rcode)
      wkstr = 'cubic'
      call length (wkstr,slen,sbgn,send)
      call ncaptc (ncoutid,varid,'option_3',ncchar,slen,
     *             wkstr(sbgn:send),rcode)
c
c  Shapiro filter order and number of applications.
c
      varid = ncvdef (ncoutid,'nord',nclong,0,0,rcode)
      wkstr = 'order of Shapiro filter'
      call length (wkstr,slen,sbgn,send)
      call ncaptc (ncoutid,varid,'long_name',ncchar,slen,
     *             wkstr(sbgn:send),rcode)
c
      varid = ncvdef (ncoutid,'nfrq',nclong,0,0,rcode)
      wkstr = 'number of Shapiro filter applications'
      call length (wkstr,slen,sbgn,send)
      call ncaptc (ncoutid,varid,'long_name',ncchar,slen,
     *             wkstr(sbgn:send),rcode)
c
c  Parameters used in computation of dynamic height.
c
      if(ldynht) then
        varid = ncvdef (ncoutid,'zref',vartyp,0,0,rcode)
        wkstr = 'level of no motion'
        call length (wkstr,slen,sbgn,send)
        call ncaptc (ncoutid,varid,'long_name',ncchar,slen,
     *               wkstr(sbgn:send),rcode)
        wkstr = 'meter'
        call length (wkstr,slen,sbgn,send)
        call ncaptc (ncoutid,varid,'units',ncchar,slen,
     *               wkstr(sbgn:send),rcode)
c
        varid = ncvdef (ncoutid,'idhopt',nclong,0,0,rcode)
        wkstr = 'specific volume integration option'
        call length (wkstr,slen,sbgn,send)
        call ncaptc (ncoutid,varid,'long_name',ncchar,slen,
     *               wkstr(sbgn:send),rcode)
        wkstr = 'ZREF to surface'
        call length (wkstr,slen,sbgn,send)
        call ncaptc (ncoutid,varid,'option_1',ncchar,slen,
     *               wkstr(sbgn:send),rcode)
        wkstr = 'ZREF to bottom'
        call length (wkstr,slen,sbgn,send)
        call ncaptc (ncoutid,varid,'option_2',ncchar,slen,
     *               wkstr(sbgn:send),rcode)
        wkstr = 'ZREF to surface and ZREF to bottom'
        call length (wkstr,slen,sbgn,send)
        call ncaptc (ncoutid,varid,'option_3',ncchar,slen,
     *               wkstr(sbgn:send),rcode)
        wkstr = 'surface to local bottom'
        call length (wkstr,slen,sbgn,send)
        call ncaptc (ncoutid,varid,'option_4',ncchar,slen,
     *               wkstr(sbgn:send),rcode)
      endif
c
c-----------------------------------------------------------------------
c  Define geometry variables and their attributes.
c-----------------------------------------------------------------------
c
c  Define depths at the middle of the vertical boxes.
c
      fdim(1)=ax3dim
      fdim(2)=levdim
      varid = ncvdef (ncoutid,'zout',vartyp,2,fdim,rcode)
      wkstr = 'depths at center of the grid vertical boxes'
      call length (wkstr,slen,sbgn,send)
      call ncaptc (ncoutid,varid,'long_name',ncchar,slen,
     *             wkstr(sbgn:send),rcode)
      wkstr = 'meter'
      call length (wkstr,slen,sbgn,send)
      call ncaptc (ncoutid,varid,'units',ncchar,slen,
     *             wkstr(sbgn:send),rcode)
      call ncapt (ncoutid,varid,'_FillValue',vartyp,1,spv,rcode)
c
c  Define 2D grid positions.  These fields are used in the vizualization
c  modules.
c
      if(lmsk) then
        fdim(1)=ax2dim
        fdim(2)=londim
        fdim(3)=latdim
        g2did = ncvdef (ncoutid,'grid2',vartyp,3,fdim,rcode)
        wkstr = '2D grid positions'
        call length (wkstr,slen,sbgn,send)
        call ncaptc (ncoutid,g2did,'long_name',ncchar,slen,
     *               wkstr(sbgn:send),rcode)
        wkstr = '1: longitude, 2: latitude'
        call length (wkstr,slen,sbgn,send)
        call ncaptc (ncoutid,g2did,'axis',ncchar,slen,
     *               wkstr(sbgn:send),rcode)
        wkstr = 'degrees_east, degrees_north'
        call length (wkstr,slen,sbgn,send)
        call ncaptc (ncoutid,g2did,'units',ncchar,slen,
     *               wkstr(sbgn:send),rcode)
        call ncapt (ncoutid,g2did,'_FillValue',vartyp,1,spv,rcode)
      endif
c
c  Define 3D grid positions.  These fields are used in the vizualization
c  modules.
c
      fdim(1)=ax3dim
      fdim(2)=londim
      fdim(3)=latdim
      g3did = ncvdef (ncoutid,'grid3',vartyp,3,fdim,rcode)
      wkstr = '3D grid positions'
      call length (wkstr,slen,sbgn,send)
      call ncaptc (ncoutid,g3did,'long_name',ncchar,slen,
     *             wkstr(sbgn:send),rcode)
      wkstr = '1: longitude, 2: latitude, 3: depth'
      call length (wkstr,slen,sbgn,send)
      call ncaptc (ncoutid,g3did,'axis',ncchar,slen,
     *             wkstr(sbgn:send),rcode)
      wkstr = 'degrees_east, degrees_north, meter'
      call length (wkstr,slen,sbgn,send)
      call ncaptc (ncoutid,g3did,'units',ncchar,slen,
     *             wkstr(sbgn:send),rcode)
      call ncapt (ncoutid,g3did,'_FillValue',vartyp,1,spv,rcode)
c
c  Define Land/Sea mask data.
c
      if(lmsk) then
        fdim(1)=londim
        fdim(2)=latdim
        mskid = ncvdef (ncoutid,'mask',nclong,2,fdim,rcode)
        wkstr = 'land/sea mask'
        call length (wkstr,slen,sbgn,send)
        call ncaptc (ncoutid,mskid,'long_name',ncchar,slen,
     *               wkstr(sbgn:send),rcode)
        wkstr = 'land'
        call length (wkstr,slen,sbgn,send)
        call ncaptc (ncoutid,mskid,'option_0',ncchar,slen,
     *               wkstr(sbgn:send),rcode)
        wkstr = 'sea'
        call length (wkstr,slen,sbgn,send)
        call ncaptc (ncoutid,mskid,'option_1',ncchar,slen,
     *               wkstr(sbgn:send),rcode)
        wkstr = 'mask, scalar'
        call length (wkstr,slen,sbgn,send)
        call ncaptc (ncoutid,mskid,'field',ncchar,slen,
     *               wkstr(sbgn:send),rcode)
        wkstr = 'grid2'
        call length (wkstr,slen,sbgn,send)
        call ncaptc (ncoutid,mskid,'positions',ncchar,slen,
     *               wkstr(sbgn:send),rcode)
        call ncapt (ncoutid,mskid,'_FillValue',nclong,1,-1,rcode)
      endif
c
c-----------------------------------------------------------------------
c  Define output variables and their attributes in the netCDF file.
c-----------------------------------------------------------------------
c
      fdim(1)=levdim
      fdim(2)=londim
      fdim(3)=latdim
      fdim(4)=timdim
c
      fdim2(1)=levdim
      fdim2(2)=timdim
c
c  Time variable.
c
      timeid = ncvdef (ncoutid,'time',vartyp,1,timdim,rcode)
      wkstr = 'estimate time'
      call length (wkstr,slen,sbgn,send)
      call ncaptc (ncoutid,timeid,'long_name',ncchar,slen,
     *             wkstr(sbgn:send),rcode)
      wkstr = 'modified Julian day'
      call length (wkstr,slen,sbgn,send)
      call ncaptc (ncoutid,timeid,'units',ncchar,slen,
     *             wkstr(sbgn:send),rcode)
      call ncapt (ncoutid,timeid,'add_offset',vartyp,1,jul_off,rcode)
c
c  Output variables.
c
      do 10 n=1,nfld
        m=idfld(n)
c
c  Field estimate.
c
        call length (fldnam(1,m),slen,sbgn,send)
        ncfldid(n) = ncvdef (ncoutid,fldnam(1,m)(sbgn:send),vartyp,4,
     *                       fdim,rcode)
        call length (fldnam(2,m),slen,sbgn,send)
        call ncaptc (ncoutid,ncfldid(n),'long_name',ncchar,slen,
     *               fldnam(2,m)(sbgn:send),rcode)
        call length (fldnam(3,m),slen,sbgn,send)
        call ncaptc (ncoutid,ncfldid(n),'units',ncchar,slen,
     *               fldnam(3,m)(sbgn:send),rcode)
        call length (fldnam(4,m),slen,sbgn,send)
        wkstr = fldnam(4,m)(sbgn:send)//', series'
        call length (wkstr,slen,sbgn,send)
        call ncaptc (ncoutid,ncfldid(n),'field',ncchar,slen,
     *               wkstr(sbgn:send),rcode)
        wkstr = 'grid3, product; zout, product'
        call length (wkstr,slen,sbgn,send)
        call ncaptc (ncoutid,ncfldid(n),'positions',ncchar,slen,
     *               wkstr(sbgn:send),rcode)
        if(lmsk) then
          wkstr = 'mask'
          call length (wkstr,slen,sbgn,send)
          call ncaptc (ncoutid,ncfldid(n),'mask',ncchar,slen,
     *                 wkstr(sbgn:send),rcode)
        endif
        call ncapt (ncoutid,ncfldid(n),'missing_value',vartyp,1,spv,
     *              rcode)
        call ncapt (ncoutid,ncfldid(n),'_FillValue',vartyp,1,spv,rcode)
c
c  Error field.
c
        call length (fldnam(1,m),slen,sbgn,send)
        wkstr = fldnam(1,m)(sbgn:send)//'err'
        call length (wkstr,slen,sbgn,send)
        ncerrid(n) = ncvdef (ncoutid,wkstr(sbgn:send),vartyp,4,
     *                       fdim,rcode)
        call length (fldnam(2,m),slen,sbgn,send)
        wkstr = 'observation error, '//fldnam(2,m)(sbgn:send)
        call length (wkstr,slen,sbgn,send)
        call ncaptc (ncoutid,ncerrid(n),'long_name',ncchar,slen,
     *               wkstr(sbgn:send),rcode)
        call length (fldnam(3,m),slen,sbgn,send)
        call ncaptc(ncoutid,ncerrid(n),'units',ncchar,slen,
     *              fldnam(3,m)(sbgn:send),rcode)
        call length (fldnam(4,m),slen,sbgn,send)
        wkstr = 'error '//fldnam(4,m)(sbgn:send)//', series'
        call length (wkstr,slen,sbgn,send)
        call ncaptc (ncoutid,ncerrid(n),'field',ncchar,slen,
     *               wkstr(sbgn:send),rcode)
        wkstr = 'grid3, product; zout, product'
        call length (wkstr,slen,sbgn,send)
        call ncaptc (ncoutid,ncerrid(n),'positions',ncchar,slen,
     *               wkstr(sbgn:send),rcode)
        if(lmsk) then
          wkstr = 'mask'
          call length (wkstr,slen,sbgn,send)
          call ncaptc (ncoutid,ncerrid(n),'mask',ncchar,slen,
     *                 wkstr(sbgn:send),rcode)
        endif
        call ncapt (ncoutid,ncerrid(n),'missing_value',vartyp,1,spv,
     *              rcode)
        call ncapt (ncoutid,ncerrid(n),'_FillValue',vartyp,1,spv,rcode)
c
c  RMS deviation field.
c
        call length (fldnam(1,m),slen,sbgn,send)
        wkstr = fldnam(1,m)(sbgn:send)//'rmsdev'
        call length (wkstr,slen,sbgn,send)
        ncrmsid(n) = ncvdef (ncoutid,wkstr(sbgn:send),vartyp,2,
     *                       fdim2,rcode)
        call length (fldnam(2,m),slen,sbgn,send)
        wkstr = 'RMS deviation from mean, '//fldnam(2,m)(sbgn:send)
        call length (wkstr,slen,sbgn,send)
        call ncaptc (ncoutid,ncrmsid(n),'long_name',ncchar,slen,
     *               wkstr(sbgn:send),rcode)
        call length (fldnam(3,m),slen,sbgn,send)
        call ncaptc(ncoutid,ncrmsid(n),'units',ncchar,slen,
     *              fldnam(3,m)(sbgn:send),rcode)
        call length (fldnam(4,m),slen,sbgn,send)
        wkstr = 'RMS '//fldnam(4,m)(sbgn:send)//', series'
        call length (wkstr,slen,sbgn,send)
        call ncaptc (ncoutid,ncrmsid(n),'field',ncchar,slen,
     *               wkstr(sbgn:send),rcode)
        wkstr = 'zout'
        call length (wkstr,slen,sbgn,send)
        call ncaptc (ncoutid,ncrmsid(n),'positions',ncchar,slen,
     *               wkstr(sbgn:send),rcode)
        call ncapt (ncoutid,ncrmsid(n),'missing_value',vartyp,1,spv,
     *              rcode)
        call ncapt (ncoutid,ncrmsid(n),'_FillValue',vartyp,1,spv,rcode)
c
c  Mean field.
c
        call length (fldnam(1,m),slen,sbgn,send)
        wkstr = fldnam(1,m)(sbgn:send)//'mean'
        call length (wkstr,slen,sbgn,send)
        ncavgid(n) = ncvdef (ncoutid,wkstr(sbgn:send),vartyp,4,fdim,
     *                       rcode)
        call length (fldnam(2,m),slen,sbgn,send)
        wkstr = 'mean, '//fldnam(2,m)(sbgn:send)
        call length (wkstr,slen,sbgn,send)
        call ncaptc (ncoutid,ncavgid(n),'long_name',ncchar,slen,
     *               wkstr(sbgn:send),rcode)
        call length (fldnam(3,m),slen,sbgn,send)
        call ncaptc (ncoutid,ncavgid(n),'units',ncchar,slen,
     *               fldnam(3,m)(sbgn:send),rcode)
        call length (fldnam(4,m),slen,sbgn,send)
        wkstr = 'mean '//fldnam(4,m)(sbgn:send)//', series'
        call length (wkstr,slen,sbgn,send)
        call ncaptc (ncoutid,ncavgid(n),'field',ncchar,slen,
     *               wkstr(sbgn:send),rcode)
        wkstr = 'grid3, product; zout, product'
        call length (wkstr,slen,sbgn,send)
        call ncaptc (ncoutid,ncavgid(n),'positions',ncchar,slen,
     *               wkstr(sbgn:send),rcode)
        if(lmsk) then
          wkstr = 'mask'
          call length (wkstr,slen,sbgn,send)
          call ncaptc (ncoutid,ncavgid(n),'mask',ncchar,slen,
     *                 wkstr(sbgn:send),rcode)
        endif
        call ncapt (ncoutid,ncavgid(n),'missing_value',vartyp,1,spv,
     *              rcode)
        call ncapt (ncoutid,ncavgid(n),'_FillValue',vartyp,1,spv,rcode)
  10  continue
c
c=======================================================================
c  Leave definition mode.
c=======================================================================
c
      call ncendf(ncoutid,rcode)
c
c=======================================================================
c  Write out parameters into netCDF file.
c=======================================================================
c
c  Observations and climatology input format type.
c
      varid=ncvid(ncoutid,'ihfrmt',rcode)
      call ncvpt1(ncoutid,varid,1,ihfrmt,rcode)
      if((iclima.eq.1).or.(iclima.eq.2)) then
        varid=ncvid(ncoutid,'icfrmt',rcode)
        call ncvpt1(ncoutid,varid,1,icfrmt,rcode)
      endif
c
c  Mean field computation switch.
c
      varid=ncvid(ncoutid,'iclima',rcode)
      call ncvpt1(ncoutid,varid,1,iclima,rcode)
c
c  OA coordinates type.
c
      varid=ncvid(ncoutid,'coord',rcode)
      call ncvpt1(ncoutid,varid,1,coord,rcode)
c
      if(coord.eq.0) then
        scl=km2m
       else
        scl=c1
      endif
c
c  Geometry parameters.
c
      varid=ncvid(ncoutid,'dx',rcode)
      call ncvpt1(ncoutid,varid,1,dx*scl,rcode)
      varid=ncvid(ncoutid,'dy',rcode)
      call ncvpt1(ncoutid,varid,1,dy*scl,rcode)
      varid=ncvid(ncoutid,'rlngd',rcode)
      call ncvpt1(ncoutid,varid,1,clngd,rcode)
      varid=ncvid(ncoutid,'rlatd',rcode)
      call ncvpt1(ncoutid,varid,1,clatd,rcode)
      varid=ncvid(ncoutid,'delx',rcode)
      call ncvpt1(ncoutid,varid,1,delx*scl,rcode)
      varid=ncvid(ncoutid,'dely',rcode)
      call ncvpt1(ncoutid,varid,1,dely*scl,rcode)
      varid=ncvid(ncoutid,'thetad',rcode)
      call ncvpt1(ncoutid,varid,1,thetad,rcode)
c
c  Influential observations parameters.
c
      varid=ncvid(ncoutid,'nnce',rcode)
      call ncvpt1(ncoutid,varid,1,nnce,rcode)
      varid=ncvid(ncoutid,'rnce',rcode)
      call ncvpt1(ncoutid,varid,1,rnce*km2m,rcode)
      varid=ncvid(ncoutid,'tnce',rcode)
      call ncvpt1(ncoutid,varid,1,tnce,rcode)
c
c  Averaging radius and time window.
c
      varid=ncvid(ncoutid,'ravg',rcode)
      call ncvpt1(ncoutid,varid,1,ravg*km2m,rcode)
      varid=ncvid(ncoutid,'tavg',rcode)
      call ncvpt1(ncoutid,varid,1,tavg,rcode)
c
c  Outlier radius.
c
      varid=ncvid(ncoutid,'rout',rcode)
      call ncvpt1(ncoutid,varid,1,rout*km2m,rcode)
c
c  Analytical correlation type.
c
      varid=ncvid(ncoutid,'icorr',rcode)
      call ncvpt1(ncoutid,varid,1,icorr,rcode)
c
c  Zero-crossing correlation scales for estimate and mean fields.
c
      varid=ncvid(ncoutid,'xzero',rcode)
      call ncvpt1(ncoutid,varid,1,xzero*km2m,rcode)
      varid=ncvid(ncoutid,'yzero',rcode)
      call ncvpt1(ncoutid,varid,1,yzero*km2m,rcode)
      varid=ncvid(ncoutid,'xzerom',rcode)
      call ncvpt1(ncoutid,varid,1,xzerom*km2m,rcode)
      varid=ncvid(ncoutid,'yzerom',rcode)
      call ncvpt1(ncoutid,varid,1,yzerom*km2m,rcode)
c
c  Spatial decorrelation scales for estimate and mean fields.
c
      varid=ncvid(ncoutid,'xdcay',rcode)
      call ncvpt1(ncoutid,varid,1,xdcay*km2m,rcode)
      varid=ncvid(ncoutid,'ydcay',rcode)
      call ncvpt1(ncoutid,varid,1,ydcay*km2m,rcode)
      varid=ncvid(ncoutid,'xdcaym',rcode)
      call ncvpt1(ncoutid,varid,1,xdcaym*km2m,rcode)
      varid=ncvid(ncoutid,'ydcaym',rcode)
      call ncvpt1(ncoutid,varid,1,ydcaym*km2m,rcode)
c
c  Temporal decorrelation scales for estimate and mean fields.
c
      varid=ncvid(ncoutid,'tdcay',rcode)
      call ncvpt1(ncoutid,varid,1,tdcay,rcode)
      varid=ncvid(ncoutid,'tdcaym',rcode)
      call ncvpt1(ncoutid,varid,1,tdcaym,rcode)
c
c  Correlation phase speeds and rotation angles for estimate and mean fields.
c
      varid=ncvid(ncoutid,'uphse',rcode)
      call ncvpt1(ncoutid,varid,1,uphse*km2m,rcode)
      varid=ncvid(ncoutid,'vphse',rcode)
      call ncvpt1(ncoutid,varid,1,vphse*km2m,rcode)
      varid=ncvid(ncoutid,'corang',rcode)
      call ncvpt1(ncoutid,varid,1,corang,rcode)
      varid=ncvid(ncoutid,'uphsem',rcode)
      call ncvpt1(ncoutid,varid,1,uphsem*km2m,rcode)
      varid=ncvid(ncoutid,'vphsem',rcode)
      call ncvpt1(ncoutid,varid,1,vphsem*km2m,rcode)
      varid=ncvid(ncoutid,'corangm',rcode)
      call ncvpt1(ncoutid,varid,1,corangm,rcode)
c
c  Observations and climatology noise vairance.
c
      varid=ncvid(ncoutid,'obserr',rcode)
      call ncvpt1(ncoutid,varid,1,obserr,rcode)
      varid=ncvid(ncoutid,'clmerr',rcode)
      call ncvpt1(ncoutid,varid,1,clmerr,rcode)
c
c  Detrend option.
c
      varid=ncvid(ncoutid,'itrt',rcode)
      call ncvpt1(ncoutid,varid,1,itrt,rcode)
c
c  Shapiro filter order and number of applications.
c
      varid=ncvid(ncoutid,'nord',rcode)
      call ncvpt1(ncoutid,varid,1,nord,rcode)
      varid=ncvid(ncoutid,'nfrq',rcode)
      call ncvpt1(ncoutid,varid,1,nfrq,rcode)
c
c  Parameters used in computation of dynamic height.
c
      if(ldynht) then
        varid=ncvid(ncoutid,'zref',rcode)
        call ncvpt1(ncoutid,varid,1,zref,rcode)
        varid=ncvid(ncoutid,'idhopt',rcode)
        call ncvpt1(ncoutid,varid,1,idhopt,rcode)
      endif
c
c  Write out depths at the middle of the grid vertical boxes.
c
      start(1)=zindx
      count(1)=1
      start(2)=1
      count(2)=nlev
      do 30 n=1,nlev
        wrk(n)=-abs(z(n))
  30  continue
      varid=ncvid(ncoutid,'zout',rcode)
      call ncvpt(ncoutid,varid,start,count,wrk,rcode)
      if(rcode.ne.0) then
        write(iprt,901) 'zout'
        call exitus('DEFCDF')
      endif
c
c  Write (x,y) positions for 2D fields.
c
      if(lmsk) then
        start(1)=xindx
        count(1)=1
        start(2)=1
        count(2)=im
        start(3)=1
        count(3)=jm
        call ncvpt(ncoutid,g2did,start,count,lon,rcode)
        if(rcode.ne.0) then
          write(iprt,901) 'grid2 x-axis'
          call exitus('DEFCDF')
        endif
        start(1)=yindx
        count(1)=1
        call ncvpt(ncoutid,g2did,start,count,lat,rcode)
        if(rcode.ne.0) then
          write(iprt,901) 'grid2 y-axis'
          call exitus('DEFCDF')
        endif
      endif
c
c  Write (x,y) positions for 3D fields.
c
      start(1)=xindx
      count(1)=1
      start(2)=1
      count(2)=im
      start(3)=1
      count(3)=jm
      call ncvpt(ncoutid,g3did,start,count,lon,rcode)
      if(rcode.ne.0) then
        write(iprt,901) 'grid3 x-axis'
        call exitus('DEFCDF')
      endif
      start(1)=yindx
      count(1)=1
      call ncvpt(ncoutid,g3did,start,count,lat,rcode)
      if(rcode.ne.0) then
        write(iprt,901) 'grid3 y-axis'
        call exitus('DEFCDF')
      endif
c
c  Write out Land/Sea mask data.
c
      if(lmsk) then
        start(1)=1
        count(1)=im
        start(2)=1
        count(2)=jm
        call ncvpt(ncoutid,mskid,start,count,landt,rcode)
        if(rcode.ne.0) then
          write(iprt,901) 'mask'
          call exitus('DEFCDF')
        endif
      endif
c
 900  format(/' DEFCDF - unable to create output NetCDF file: ',a)
 901  format(/' DEFCDF - error while writing variable: ',a,2x,
     *        ' into output NetCDF file.')
      return
      end
