       subroutine diagn (f,np,depth,day,fldid,iunit)
c
c=======================================================================
c                                                                    ===
c  Given a field F of length NP,  this routine searches for its      ===
c  minimum  FMIN and maximum  FMAX values and computes the mean      ===
c  FAVG, the root mean square FRMS, the average deviation FADV,      ===
c  the standard deviation FSDV, the variance FVAR, the skewness      ===
c  FSKW, and the kurtosis FKUR.  All these values are stored in      ===
c  common block FDIAGN.                                              ===
c                                                                    ===
c  On Input:                                                         ===
c                                                                    ===
c     F        field to analize (real array)                         ===
c     NP       number of points (integer)                            ===
c     DEPTH    depth of field (real)                                 ===
c     DAY      day (Julian day or year day of field (real)           ===
c     FLDID    field identification (character)                      ===
c     IUNIT    output logical unit (integer)                         ===
c                                                                    ===
c  Required common blocks:                                           ===
c                                                                    ===
c     CALDATE, DATE, FDIAGN                                          ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <date.h>
#include <fdiagn.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
       integer ip,iunit,np,npts
       real c0,day,denom,depth,f(np),p,s,small,spval1,spval2
       character*(*) fldid
       parameter (c0=0.0,spval1=0.99e+35,spval2=1.0e+35,
     &            small=1.1754944e-38)
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c-----------------------------------------------------------------------
c  Compute the mean and get minimum and maximum values.
c-----------------------------------------------------------------------
c
       npts=0
       favg=c0
       fmin=spval1
       fmax=-spval1
       do 10 ip=1,np
         if (f(ip).lt.spval1) then
           fmin=min(fmin,f(ip))
           fmax=max(fmax,f(ip))
           npts=npts+1
           favg=favg+f(ip)
         endif
 10    continue
       if (npts.ne.0) favg=favg/float(npts)
c
c-----------------------------------------------------------------------
c  Compute the root mean square (FRMS), average deviation (FADEV),
c  standard deviation (FSDV), variance (FVAR), skewness (FSKEW), and
c  kurtosis (FKUR).
c-----------------------------------------------------------------------
c
       frms=c0
       fadv=c0
       fvar=c0
       fskw=c0
       fkur=c0
       npts=c0
       do 20 ip=1,np
         if (f(ip).lt.spval1) then
           npts=npts+1
           frms=frms+f(ip)*f(ip)
           s=f(ip)-favg
           fadv=fadv+abs(s)
           p=s*s
           fvar=fvar+p
           p=p*s
           fskw=fskw+p
           p=p*s
           fkur=fkur+p
         endif
 20    continue
       if (npts.gt.1) then
         frms=sqrt(frms/float(npts))
         fadv=fadv/float(npts)
         fvar=fvar/float(npts-1)
         fsdv=sqrt(fvar)
c
         denom=float(npts)*fsdv**3
         if (abs(small*fskw).lt.abs(denom)) then
           fskw=fskw/denom
         else
           fskw=spval2
         endif
c
         denom=float(npts)*fvar**2
         if (abs(small*fkur).lt.abs(denom)) then
           fkur=fkur/denom-3.
         else
           fkur=spval2
         endif
c
       else
         favg=spval2
         frms=spval2
         fadv=spval2
         fvar=spval2
         fsdv=spval2
         fskw=spval2
         fkur=spval2
       endif
c
c-----------------------------------------------------------------------
c  If Julian day is given, report complete date.
c-----------------------------------------------------------------------
c
       if (day.gt.366.) then
         djulian=day
         call caldate (day,dchar,tchar,iday,month,iyear,iyday)
         write(iunit,30) day,iyday,dchar,tchar
 30      format(/,'  Field Diagnostics:',//,26x,'Day = ',f10.3,
     &          5x,'(',i3,', ',a,', ',a,')')
       else
         write(iunit,40) day
 40      format(/,'  Field Diagnostics:',//,26x,'Day = ',f10.3)
       endif
       write(iunit,50) fldid,depth,npts,fmin,fmax,favg,frms,fadv,fvar,
     &                 fsdv,fskw,fkur
 50    format(10x,'         Field type = ',a,/,
     &        10x,'             Depth  = ',f10.3,/,
     &        10x,'   Number of points = ',i8,/,
     &        10x,'            Minimum = ',1pe15.8,/,
     &        10x,'            Maximum = ',1pe15.8,/,
     &        10x,'               Mean = ',1pe15.8,/,
     &        10x,'                RMS = ',1pe15.8,/,
     &        10x,'  Average Deviation = ',1pe15.8,/,
     &        10x,'           Variance = ',1pe15.8,/,
     &        10x,' Standard Deviation = ',1pe15.8,/,
     &        10x,'           Skewness = ',1pe15.8,/,
     &        10x,'           Kurtosis = ',1pe15.8,/)
       return
       end
