      subroutine errscl (nobs,stdobs,nclm,stdclm,imjm,emap,fmaprms)
c
c=======================================================================
c                                                                    ===
c  This routine determines the scaling factor for the nondimensional ===
c  error field.                                                      ===
c                                                                    ===
c  ------                                                            ===
c  Input:                                                            ===
c  ------                                                            ===
c                                                                    ===
c  NOBS......Number of synoptic observations.          (integer)     ===
c  STDOBS....Standard Deviation for synoptic data.     (real)        ===
c  NCLM......Number of climatology observations.       (integer)     ===
c  STDCLM....Standard Deviation for climatology data.  (real)        ===
c  IMJM......Number of model grid points.              (integer)     ===
c  EMAP......Nondimensional error field.               (real array)  ===
c                                                                    ===
c  -------                                                           ===
c  Output:                                                           ===
c  -------                                                           ===
c                                                                    ===
c  FMAPRMS...Error scaling value.                      (real)        ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer imjm,n,nclm,nobs
      real    c1,fmaprms,small,stdclm,stdobs,wt
      real    emap(imjm)
c
      parameter (c1=1.0, small=2.2204461e-16)
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
      if (nclm.lt.1) then
c
c  No climatology, scaling based on observations.
c
         fmaprms = stdobs
c
        else if (nobs.lt.1) then
c
c  No observations, scaling based on climatology.
c
         fmaprms = stdclm
c
        else
c
c  Average observation and climatology based on error field.
c
         wt = emap(1)
         do 10 n = 2, imjm
            wt = wt + emap(n)
  10     continue
         wt = wt/float(imjm)
         fmaprms = (c1-wt)*stdobs + wt*stdclm
c
      end if
c
c-----------------------------------------------------------------------
c  Protect against zero scaling.
c-----------------------------------------------------------------------
c
      fmaprms = max( fmaprms, small )
c
      return
      end
