       subroutine indepen(fobs,xobs,yobs,tobs,nobs,ravg,tavg,oaday,iprt)
c
c=======================================================================
c                                                                    ===
c  This routine checks to see if the  observations are  independent  ===
c  from each other.  Any  observation  that is  within a  radius of  ===
c  RAVG or a time window of TAVG with other observation is averaged  ===
c  together, since the amount of new information in that data point  ===
c  is small. If RAVG and TAVG are zero, then close observations are  ===
c  not averaged. The routines  REMOVE  and  DOWN_SHIFT do the array  ===
c  rearranging that is necessary.                                    ===
c                                                                    ===
c  Arguments:                                                        ===
c                                                                    ===
c     FOBS     observation field (real array; input/output)          ===
c     XOBS     X position of observation (real array; input/output)  ===
c     YOBS     Y position of observation (real array; input/output)  ===
c     TOBS     time of observation (real array; input/output)        ===
c     NOBS     number of observations (integer; input/output)        ===
c     RAVG     averaging radius for nearby observations (real;       ===
c              input)                                                ===
c     TAVG     averaging time window for nearby observations (real;  ===
c              input)                                                ===
c     OADAY    time of interpolation (real; user input)              ===
c     IPRT     output logical unit                                   ===
c                                                                    ===
c  Calls:  DOWN_SHIFT, GCIRCLE, REMOVE                               ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <param.h>
#include <corscl.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
       integer i,ic(mobs),iprt,j,nobs
       real c0,dang,delt,dist,oaday,phi,ravg,tavg
       real fobs(nobs),xobs(nobs),yobs(nobs),tobs(nobs)
       real gcircle
       parameter (c0=0.0)
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c  If no data, return to calling program.
c
       if (nobs.eq.0) return
c
c  Initialize counter.
c
       do 10 i=1,nobs
         ic(i)=1
 10    continue
c
c  Average nearby observations.
c
       do 30 i=1,nobs-1
         if (ic(i).ne.0) then
           do 20 j=i+1,nobs
             if (ic(j).ne.0) then
               delt=abs(tobs(i)-tobs(j))
               if (delt.le.tavg) then
                 if (ccoor.eq.0) then
                    dist=sqrt((xobs(i)-xobs(j))**2+(yobs(i)-yobs(j))**2)
                 elseif ((ccoor.eq.1).or.(ccoor.eq.2)) then
                    dang=gcircle(xobs(i),yobs(i),xobs(j),yobs(j),dist,
     &                           phi)
                 endif
                 if (dist.le.ravg) then
                   ic(i)=ic(i)+1
                   ic(j)=0
                   fobs(i)=fobs(i)+(fobs(j)-fobs(i))/ic(i)
                   xobs(i)=xobs(i)+(xobs(j)-xobs(i))/ic(i)
                   yobs(i)=yobs(i)+(yobs(j)-yobs(i))/ic(i)
                   tobs(i)=tobs(i)+(tobs(j)-tobs(i))/ic(i)
                 endif
               endif
             endif
 20        continue
         endif
 30    continue
c
c-----------------------------------------------------------------------
c  Remove unnecessary points.
c-----------------------------------------------------------------------
c
       call remove (fobs,xobs,yobs,tobs,ic,nobs,iprt)
c
C
       return
       end
