       subroutine invmtx (a,na,v,nv,n,d,ip,ier)
c
c=======================================================================
c                                                                    ===
c  This routine calculates the inverse of the matrix A, of order N,  ===
c  using Gaussian elimination with full pivoting.                    ===
c                                                                    ===
c  On Input:                                                         ===
c                                                                    ===
c     A        N x N matrix to be inverted (real array)              ===
c     N        order of the matrix to be inverted (integer)          ===
c     NA       row (first) dimension of A (integer)                  ===
c     NV       row (first) dimension of V (integer)                  ===
c     IP       working storage (integer; dimensioned at least 2*N)   ===
c                                                                    ===
c  On Output:                                                        ===
c                                                                    ===
c     V        the inverse of A (real array)                         ===
c     D        the determinant of A (real)                           ===
c     IER      error flag (integer)                                  ===
c              IER=0   success                                       ===
c              IER=1   determinant too large                         ===
c              IER=33  matrix is numerically singular                ===
c              IER=34  N  < 1                                        ===
c              IER=34  NA < N                                        ===
c              IER=34  NV < N                                        ===
c                                                                    ===
c  Calls:  IERINV                                                    ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
       integer i,ier,ierinv,iex,iexmax,j,k,l,m,n,na,npm,nv
       integer ip(*)
       real a(na,n),d,hold,pvt,pvtmx,v(nv,n),vh,vmax
       data iexmax /75/
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
       ier=ierinv(n,na,nv)
       if (ier.ne.0) return
       do 102 j=1,n
         ip(j)=0
         do 101 i=1,n
           v(i,j)=a(i,j)
 101     continue
 102   continue
       d=1.
       iex=0
       do 110 m=1,n
         vmax=0.
         do 104 j=1,n
           if (ip(j).ne.0) goto 104
           do 103 i=1,n
             if (ip(i).ne.0) goto 103
             vh=abs(v(i,j))
             if (vmax.gt.vh) goto 103
             vmax=vh
             k=i
             l=j
 103       continue
 104     continue
         ip(l)=k
         npm=n+m
         ip(npm)=l
         d=d*v(k,l)
 105     if (abs(d).le.1.0) goto 106
         d=d*0.1
         iex=iex+1
         goto 105
 106     continue
         pvt=v(k,l)
         if (m.eq.1) pvtmx=abs(pvt)
         if (abs(pvt/float(m))+pvtmx.eq.pvtmx) goto 113
         v(k,l)=1.
         do 107 j=1,n
           hold=v(k,j)
           v(k,j)=v(l,j)
           v(l,j)=hold/pvt
 107     continue
         do 109 i=1,n
           if (i.eq.l) goto 109
           hold=v(i,l)
           v(i,l)=0.
           do 108 j=1,n
             v(i,j)=v(i,j)-v(l,j)*hold
 108       continue
 109     continue
 110   continue
       m=n+n+1
       do 112 j=1,n
         m=m-1
         l=ip(m)
         k=ip(l)
         if (k.eq.l) goto 112
         d=-d
         do 111 i=1,n
           hold=v(i,l)
           v(i,l)=v(i,k)
           v(i,k)=hold
 111     continue
 112   continue
       if (iex.gt.iexmax) goto 115
       d=d*10.**iex
       return
 113   ier=33
       print 114
 114   format(' INVMTX: matrix singular')
       return
 115   ier=1
       d=float(iex)
       print 116
 116   format(' INVMTX: determinant too large')
       return
       end
