       subroutine ludcmp (a,n,np,indx,d,vv,ier)
c
c=======================================================================
c                                                                    ===
c  Given an N x N matrix A, with physical dimension NP, this routine ===
c  replaces it by the  LU  decomposition of a rowwise permutation of ===
c  itself.   A and N are input.   A is output, arranged according to ===
c  Crout algorithm;   INDX is an output vector which records the row ===
c  permutation effected by the partial pivoting;  D is output as  +1 ===
c  or  -1  depending on  whether the  number of row interchanges was ===
c  even or odd,  respectively.  VV  is an  input  scratch  vector of ===
c  length  N  which stores the implicit scaling of each row.  IER is ===
c  output as 1 or 0 depending on whether the matrix A is singular or ===
c  not,  respectively.  This subroutine is used in  combination with ===
c  LUBKSB to solve linear equations or invert a matrix.              ===
c                                                                    ===
c  Reference:   Press, W.H, et al., 1989: Numerical Recipes, The Art ===
c               of Scientific Computing, pp 31-37.                   ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
       integer i,ier,imax,j,k,n,np
       integer indx(n)
       real a(np,np),aamax,d,dum,sum,tiny,vv(n)
       parameter (tiny=1.0e-20)
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
       ier=0
       d=1.
       do 12 i=1,n
         aamax=0.
         do 11 j=1,n
           if (abs(a(i,j)).gt.aamax) aamax=abs(a(i,j))
 11      continue
         if (aamax.eq.0.) then
           ier=1
         else
           vv(i)=1./aamax
         endif
 12    continue
       if (ier.eq.1) return
       do 19 j=1,n
         if (j.gt.1) then
           do 14 i=1,j-1
             sum=a(i,j)
             if (i.gt.1) then
               do 13 k=1,i-1
                 sum=sum-a(i,k)*a(k,j)
 13            continue
               a(i,j)=sum
             endif
 14        continue
         endif
         aamax=0.
         do 16 i=j,n
           sum=a(i,j)
           if (j.gt.1) then
             do 15 k=1,j-1
               sum=sum-a(i,k)*a(k,j)
 15          continue
             a(i,j)=sum
           endif
           dum=vv(i)*abs(sum)
           if (dum.ge.aamax) then
             imax=i
             aamax=dum
           endif
 16      continue
         if (j.ne.imax) then
           do 17 k=1,n
             dum=a(imax,k)
             a(imax,k)=a(j,k)
             a(j,k)=dum
 17        continue
           d=-d
           vv(imax)=vv(j)
         endif
         indx(j)=imax
         if (j.ne.n) then
           if (a(j,j).eq.0.) a(j,j)=tiny
           dum=1./a(j,j)
           do 18 i=j+1,n
             a(i,j)=a(i,j)*dum
 18        continue
         endif
 19    continue
       if (a(n,n).eq.0.) a(n,n)=tiny
       return
       end
