       program oamain
c
c=======================================================================
c                                                                    ===
c  Generalized space-time objective analysis/statistical forecast    ===
c  package, 1993 version. This package is based on Everett Carter    ===
c  1981 original version.  The  OBJAN  routine is based on a code    ===
c  written by Carlos J. Lozano.                                      ===
c                                                                    ===
c  Hernan G. Arango (December 1994)                                  ===
c  Harvard University                                                ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <param.h>
#include <clima.h>
#include <fdiagn.h>
#include <hydobs.h>
#include <inppar.h>
#include <oagrid.h>
#include <oa_netcdf.h>
#include <obscor.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
       integer i,ifield,j,job,k,l,lenfld,lenstr,nclm,nobs,nsel
       integer count(4),index(mobs),start(4),start2(2)
       integer lnblk
#ifdef sunfpe
       integer ieeer,my_handler,ieee_handler
#endif
       logical fnd_mean
       real c1,fmaprms,small,stdclm,stdobs,tmap,trnd
       real fclm(mobs),tclm(mobs),xclm(mobs),yclm(mobs),
     &      fobs(mobs),tobs(mobs),xobs(mobs),yobs(mobs),
     &      emap(mgrd),fcor(mobs),fmap(mgrd),fmean(mgrd),obsmean(mobs)
       character*60 text
c
       parameter (c1=1.0, small=2.2204461e-16)
c
#ifdef sunfpe
      external my_handler
c
#endif
       data nclm,nobs /2*0/
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
#ifdef sunfpe
c-----------------------------------------------------------------------
c     Enable floating point error flags.                               |
c-----------------------------------------------------------------------
c
      ieeer = ieee_handler ('set','common',my_handler)
      if (ieeer .ne. 0) write (6,900)
c
#endif
c-----------------------------------------------------------------------
c  Read in input parameters from input script file.
c-----------------------------------------------------------------------
c
       call oapar
c
c-----------------------------------------------------------------------
c  Read in hydrographic data an interpolate to the desired OA depth
c  levels.
c-----------------------------------------------------------------------
c
       call getobs (iinp,iprt)
c
c-----------------------------------------------------------------------
c  Read in climatological data and interpolate to the desired OA
c  depth levels.
c-----------------------------------------------------------------------
c
       if ((iclima.eq.1).or.(iclima.eq.2)) then
         call getclima (iclm,iprt)
       endif
c
c=======================================================================
c  Begin Objective Analysis: loop over number of days, levels and
c                            fields.
c=======================================================================
c
       count(1)=1
       count(2)=im
       count(3)=jm
       count(4)=1
c
       start(2)=1
       start(3)=1
c
       do 80 l=1,nday
         start(4)=l
         start2(2)=l
         do 70 k=1,nlev
           start(1)=k
           start2(1)=k
           do 60 j=1,nfld
c
c-----------------------------------------------------------------------
c  Extract hydrographic field to OA from HDATA and store it in scratch
c  vectors FOBS, TOBS, XOBS, and YOBS.  Initialize "time flags" to
c  recognize temporal dependence.
c-----------------------------------------------------------------------
c
             tmap=oaday(l)
             ifield=idfld(j)
             call xhydro (fobs,xobs,yobs,tobs,nobs,k,ifield,iprt)
c
c-----------------------------------------------------------------------
c  Throw away the observations that are far from the OA grid.
c  Any observation,  whose  distance from  domain centroid is
c  greater than ROUT is removed. The arrays FOBS, XOBS, YOBS,
c  and  TOBS  are rewritten and  NOBS  becomes the new number
c  observations.
c-----------------------------------------------------------------------
c
             call outlier (fobs,xobs,yobs,tobs,nobs,rout,iprt)
c
c-----------------------------------------------------------------------
c  If applicable,  extract climatology field  from  CDAT  and
c  store it in scratch vectors FCLM, TCLM, XCLM, and YCLM.
c-----------------------------------------------------------------------
c
             if ((iclima.eq.1).or.(iclima.eq.2)) then
               call xclima (fclm,xclm,yclm,tclm,nclm,k,ifield,iprt)
               call outlier (fclm,xclm,yclm,tclm,nclm,rout,iprt)
             endif
c
c-----------------------------------------------------------------------
c  If there are very close observations average them together
c  within an spatial radius of  RAVG (in km) and within  TAVG
c  days of each other.  Arrays XOBS, YOBS, TOBS, and FOBS are
c  rewritten and NOBS becomes the new number of observations.
c  Determine the central time TMAP of the interpolation.
c-----------------------------------------------------------------------
c
             call indepen (fobs,xobs,yobs,tobs,nobs,ravg,tavg,tmap,iprt)
c
c-----------------------------------------------------------------------
c  Compute the diagnostics of the data.
c-----------------------------------------------------------------------
c
             stdobs = obserr
             lenfld=lnblk(fldnam(2,ifield),len(fldnam(2,ifield)))
             if (nobs.gt.0) then
               text=' Observed '//fldnam(2,ifield)(1:lenfld)
               lenstr=lnblk(text,len(text))
               call diagn (fobs,nobs,z(k),tmap,text(1:lenstr),iprt)
             end if
             if (nobs.gt.1) stdobs = stdobs + fsdv
c
             if (((iclima.eq.1).or.(iclima.eq.2)).and.(nclm.gt.0)) then
                stdclm = clmerr
                text=' Climatology '//fldnam(2,ifield)(1:lenfld)
                lenstr=lnblk(text,len(text))
                call diagn (fclm,nclm,z(k),tmap,text(1:lenstr),iprt)
                if (nclm.gt.1) stdclm = stdclm + fsdv
             endif
c
#ifdef sunflush
             call flush(iprt)
c
#endif
c-----------------------------------------------------------------------
c  Compute OAed mean FMEAN at each interpolation point.
c-----------------------------------------------------------------------
c
             call large_scales
             call oamean (fmean,obsmean,fobs,xobs,yobs,tobs,nobs,fclm,
     &                    xclm,yclm,tclm,nclm,iclima,tmap,nnce,rnce,
     &                    tnce,iprt,fnd_mean)
             call synop_scales
c
c-----------------------------------------------------------------------
c  Continue calculation on field only if a mean field was found.
c-----------------------------------------------------------------------
c
             if (fnd_mean) then
c
c-----------------------------------------------------------------------
c  If observations exist, objectively analysize the field.  Otherwise,
c  use the mean field.
c-----------------------------------------------------------------------
c
               if (nobs.gt.0) then
c
c-----------------------------------------------------------------------
c  If requested, first compute trend coefficients and then detrend
c  the observations.
c-----------------------------------------------------------------------
c
                 if (itrt.ne.0) then
                   job=1
                   call trend (fobs,xobs,yobs,nobs,itrt,trnd,job,iprt)
                   job=2
                   do 10 i=1,nobs
                     call trend (fobs(i),xobs(i),yobs(i),1,itrt,trnd,
     &                           job,iprt)
                     fobs(i)=fobs(i)-trnd
 10                continue
                 endif
c
c-----------------------------------------------------------------------
c  Perform the OA on one grid point at a time. All the observations are
c  not used in each grid point (too much computation for very little
c  gain!).
c-----------------------------------------------------------------------
c
                 do 20 i=1,imjm
c
c-----------------------------------------------------------------------
c  Pick up the most influential data points for each grid point.  The
c  NSEL selected influential observations indices are stored in INDEX
c  and its sorted correlations in FCOR.
c-----------------------------------------------------------------------
c
                   call select (fcor,index,nsel,fobs,xobs,yobs,tobs,nobs
     &                          ,xmap(i),ymap(i),tmap,rnce,tnce,iprt)
c
c-----------------------------------------------------------------------
c  Performs the OA.  The mapped field and its associated error is
c  stored in FMAP and EMAP, respectively, one point at a time. FMEAN
c  is the local mean used in the estimation of each FMAP.
c-----------------------------------------------------------------------
c
                   call objan (fcor,index,nsel,nnce,fobs,xobs,yobs,tobs,
     &                         obsmean,nobs,0,nobs,xmap(i),ymap(i),tmap,
     &                         fmean(i),fmap(i),emap(i),iprt)
c
c  If a trend was taken out, put it back in.
c
                   if (itrt.ne.0) then
                     job=2
                     call trend (fmap(i),xmap(i),ymap(i),1,itrt,trnd,
     &                           job,iprt)
                     fmap(i)=fmap(i)+trnd
                   endif
 20              continue
c
               else
c
c-----------------------------------------------------------------------
c  No observations, field reverts to the mean.
c-----------------------------------------------------------------------
c
                 do 30 i=1,imjm
                   fmap(i)=fmean(i)
                   emap(i)=c1
 30              continue
                 write(iprt,910) fldnam(2,ifield)(1:lenfld),z(k),tmap
c
               endif
c
c-----------------------------------------------------------------------
c  If requested, Shapiro filter the interpolated field.
c-----------------------------------------------------------------------
c
               if (nfrq.gt.0) then
                 do 40 i=1,nfrq
                   call filter (fmap,im,im,jm,nord)
 40              continue
               endif
c
c-----------------------------------------------------------------------
c  Dimensionalize the error fields.  The OA errors are originally
c  nondimensionalized by the field variance.
c-----------------------------------------------------------------------
c
               call errscl (nobs,stdobs,nclm,stdclm,imjm,emap,fmaprms)
               do 50 i=1,imjm
                 emap(i)=sqrt(emap(i))*fmaprms
 50            continue
c
c-----------------------------------------------------------------------
c  Calculate and print the diagnostics of the interpolation: field,
c  mean, and error.
c-----------------------------------------------------------------------
c
               text=' Interpolated '//fldnam(2,ifield)(1:lenfld)
               lenstr=lnblk(text,len(text))
               call diagn (fmap,imjm,z(k),tmap,text(1:lenstr),iprt)
c
               text=' Mean '//fldnam(2,ifield)(1:lenfld)
               lenstr=lnblk(text,len(text))
               call diagn (fmean,imjm,z(k),tmap,text(1:lenstr),iprt)
c
               text=fldnam(2,ifield)(1:lenfld)//' OA Error'
               lenstr=lnblk(text,len(text))
               call diagn (emap,imjm,z(k),tmap,text(1:lenstr),iprt)
c
               text=fldnam(2,ifield)(1:lenfld)//' RMS deviation'
               lenstr=lnblk(text,len(text))
               write (iprt,920) text(1:lenstr),fmaprms
c
#ifdef sunflush
               call flush(iprt)
c
#endif
c-----------------------------------------------------------------------
c  Write out fields into NetCDF file.  Synchronize output NetCDF file to
c  disk to allow other processes to access data immediatelly after it is
c  written.
c-----------------------------------------------------------------------
c
               call ncvpt(ncoutid,timeid,start(4),count(4),tmap,rcode)
               if(rcode.ne.0) then
                 write(iprt,930) 'time',k,l
                 call exitus ('OAMAIN')
               endif
               call ncvpt(ncoutid,ncfldid(j),start,count,fmap,rcode)
               if(rcode.ne.0) then
                 write(iprt,930) fldnam(2,ifield)(1:lenfld),k,l
                 call exitus ('OAMAIN')
               endif
               call ncvpt(ncoutid,ncerrid(j),start,count,emap,rcode)
               if(rcode.ne.0) then
                 write(iprt,930)fldnam(2,ifield)(1:lenfld)//' error',k,l
                 call exitus ('OAMAIN')
               endif
               call ncvpt1(ncoutid,ncrmsid(j),start2,fmaprms,rcode)
               if(rcode.ne.0) then
                 write(iprt,930) fldnam(2,ifield)(1:lenfld)//
     *                         ' RMS deviation',k,l
                 call exitus ('OAMAIN')
               endif
               call ncvpt(ncoutid,ncavgid(j),start,count,fmean,rcode)
               if(rcode.ne.0) then
                 write(iprt,930) 'mean '//fldnam(2,ifield)(1:lenfld),k,l
                 call exitus ('OAMAIN')
               endif
               call ncsnc(ncoutid,rcode)
               if(rcode.ne.0) then
                 write(iprt,940) k,l
                 call exitus ('OAMAIN')
               endif
c
             else
c
c-----------------------------------------------------------------------
c  No mean field:  no OA possible.
c-----------------------------------------------------------------------
c
               write(iprt,950) fldnam(2,ifield)(1:lenfld),z(k),tmap
c
             endif
 60        continue
 70      continue
 80    continue
c
c-----------------------------------------------------------------------
c  Close all data files.
c-----------------------------------------------------------------------
c
       call exitus ('OA DONE')
c
#ifdef sunfpe
 900   format(/'OAMAIN - Warning:  ieee_handler cannot set my_handler'/)
#endif
 910   format(/'OAMAIN - Warning:  no observations - using mean field'/
     &        15x,'field:  ',a/11x,'depth (m):  ',1pg16.8/
     &        9x,'time (jday):  ',1pg16.8)
 920   format (2x,a,' = ',1pg16.8//)
 930   format(/,' OAMAIN - error while writing field: ',a,2x,
     &          ' at level INDEX = ',i3,' and time INDEX = ',i3)
 940   format(/,' OAMAIN - unable to synchronize output NetCDF to disk',
     &          ' at level INDEX = ',i3,' and time INDEX = ',i3)
 950   format(/'OAMAIN - Warning:  unable to compute mean field - ',
     &         'no mapping will be done.'/15x,'field:  ',a/
     &        11x,'depth (m):  ',1pg16.8/9x,'time (jday):  ',1pg16.8)
c
       end
