       subroutine objan (fcor,index,nsel,nnce,fobs,xobs,yobs,tobs,
     &                   obsmean,ntot,iclima,nobs,xmap,ymap,tmap,fmean,
     &                   fmap,emap,iprt)
c
c=======================================================================
c                                                                    ===
c  Space-time objective analysis routine.                            ===
c                                                                    ===
c  On Input:                                                         ===
c                                                                    ===
c     FCOR     observation correlation sorted by their influence     ===
c              (real array)                                          ===
c     INDEX    influential indices that indicate which values of     ===
c              FOBS, XOBS, YOBS, and TOBS to use (integer array)     ===
c     NSEL     number of influential points selected (integer)       ===
c     FOBS     observation field (real array)                        ===
c     XOBS     X position of observation (real array)                ===
c     YOBS     Y position of observation (real array)                ===
c     TOBS     time of observation (real array)                      ===
c     OBSMEAN  mean at each observation point (real array)           ===
c     NTOT     total number of observations plus climatology         ===
c              (integer)                                             ===
c     ICLIMA   mean field computation option:                        ===
c              [0] use observations only                             ===
c              [1] use climatology only                              ===
c              [2] use both observations and climatology             ===
c     NOBS     number of observations (integer)                      ===
c     XMAP     X position to interpolate (real)                      ===
c     YMAP     Y position to interpolate (real)                      ===
c     TMAP     time of interpolation (real)                          ===
c     FMEAN    mean at interpolated point (XMAP,YMAP,TMAP) (real)    ===
c     IPRT     output logical unit (integer)                         ===
c                                                                    ===
c  On Output:                                                        ===
c                                                                    ===
c     FMAP     optimal estimate (real)                               ===
c     EMAP     normalized error variance (real)                      ===
c                                                                    ===
c  Required common blocks:                                           ===
c                                                                    ===
c     DEBUG, OBSCOR                                                  ===
c                                                                    ===
c  Calls:  ACOR, LUBKSB, LUDCMP                                      ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <param.h>
#include <debug.h>
#include <obscor.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
       integer i,iclima,ier,ii,iprt,j,jj,nnce,nobs,nsel,ntot
       integer index(mobs),iwk(mnce)
       real acor,bnorm,d,derrclm,derrobs,fmap,fmean,emap,err,errclm,
     &      errobs,errsq,percent,sum,tmap,xmap,ymap
       real a(mnce,mnce),asav(mnce,mnce),adgn(mnce),b(mnce),fcor(mobs),
     &      fobs(ntot),obsmean(ntot),tobs(ntot),wk(mnce),xobs(ntot),
     &      yobs(ntot)
       data percent /0.08/
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c  if applicable, overwrite number of selected influential observations.
c
       if (nsel.gt.nnce) then
         nsel=nnce
       endif
       if (nsel.lt.1) then
         fmap=fmean
         emap=1.0
         if (iwrt.ne.0) write(iprt,10) nsel,emap,fmap
 10      format(' OBJAN: insufficient influential observations,',
     &          ' NSEL=',i4,/,8x,'assigned EMAP,FMAP=',f7.4,1pe15.5/)
#ifdef sunflush
         if (iwrt.ne.0) call flush(iprt)
#endif
         return
       endif
c
c-----------------------------------------------------------------------
c  Construct correlation matrix A and duplicate it.
c-----------------------------------------------------------------------
c
       do 30 j=1,nsel
         jj=index(j)
         do 20 i=j,nsel
           ii=index(i)
           if ((ii.le.nobs).and.(jj.le.nobs)) then
             a(i,j)=acor(xobs(jj),yobs(jj),tobs(jj),xobs(ii),yobs(ii),
     &                   tobs(ii))
            else
             a(i,j)=acor(xobs(jj),yobs(jj),tobs(jj),xobs(ii),yobs(ii),
     &                   tobs(jj))
           end if
           asav(i,j)=a(i,j)
           a(j,i)=a(i,j)
           asav(j,i)=a(i,j)
 20      continue
 30    continue
c
       emap=asav(1,1)
c
c-----------------------------------------------------------------------
c  Store the diagonal of A and set right hand side of matrix equation.
c-----------------------------------------------------------------------
c
       do 40 i=1,nsel
         adgn(i)=a(i,i)
         b(i)=fcor(i)
 40    continue
c
c-----------------------------------------------------------------------
c  Solve linear set of equations, A X=B, using LU decomposition.  If
c  Matrix A is singular, condition it by adding ERR to its diagonal.
c-----------------------------------------------------------------------
c
       ier=1
       if ((iclima.eq.0).or.(iclima.eq.3)) then
         errclm=0.0
         errobs=obserr
       elseif (iclima.eq.1) then
         errclm=clmerr
         errobs=0.0
       elseif (iclima.eq.2) then
         errclm=clmerr
         errobs=obserr
       endif
       err=max(errclm,errobs)
       derrobs=(errmax-obserr)/5.
       derrclm=(errmax-clmerr)/5.
c
       do 90 while ((ier.ne.0).and.(err.lt.errmax))
c
c  Update diagonal terms with the error variances
c
         do 45 j=1,nsel
           if (iclima.eq.1) then
             a(j,j)=adgn(j)+errclm
           else
             if (index(j).gt.nobs) then
               a(j,j)=adgn(j)+errclm
             else
               a(j,j)=adgn(j)+errobs
             endif
           endif
 45      continue
c
c
c  Perform LU decomposition, or direct solution.
c
         if (nsel.gt.1) then
           call ludcmp (a,nsel,mnce,iwk,d,wk,ier)
           call lubksb (a,nsel,mnce,iwk,b)
          else
           b(1)=b(1)/a(1,1)
         endif
c
c  Renew matix A.
c
         do 60 j=1,nsel
           do 50 i=1,nsel
             a(i,j)=asav(i,j)
 50        continue
           if (iclima.eq.1) then
             a(j,j)=adgn(j)+errclm
           else
             if (index(j).gt.nobs) then
               a(j,j)=adgn(j)+errclm
             else
               a(j,j)=adgn(j)+errobs
             endif
           endif
 60      continue
c
c  Verify inversion.
c
         errsq=0.
         bnorm=0.
         do 80 j=1,nsel
           sum=0.
           do 70 i=1,nsel
             sum=sum+a(i,j)*b(i)
 70        continue
           errsq=errsq+(sum-fcor(j))**2
           bnorm=bnorm+fcor(j)*fcor(j)
 80      continue
c
c  Check if matrix conditioning is required.
c
         if (errsq.lt.percent*bnorm) then
           ier=0
         else
           ier=1
           if ((iclima.eq.0).or.(iclima.eq.3)) then
             errobs=errobs+derrobs
           elseif (iclima.eq.1) then
             errclm=errclm+derrclm
           elseif (iclima.eq.2) then
             errclm=errclm+derrclm
             errobs=errobs+derrobs
           endif
           err=max(errclm,errobs)
         endif
 90    continue
c
c-----------------------------------------------------------------------
c  Calculate the RMS interpolation error EMAP and calculate the
c  interpolated value FMAP.
c-----------------------------------------------------------------------
c
       if (ier.eq.0) then
c
c  Compute error variance.
c
         do 130 j=1,nsel
           do 120 i=1,nsel
             emap=emap-b(i)*a(i,j)*b(j)
 120       continue
 130     continue
c
c  Compute optimal estimate.
c
         fmap=fmean
         do 140 i=1,nsel
           fmap=fmap+(fobs(index(i))-obsmean(index(i)))*b(i)
 140     continue
       else
         fmap=fmean
         emap=1.0
         if (iwrt.ne.0) then
           write(iprt,150) xmap,ymap,tmap,err,bnorm,errsq
 150       format(' OBJAN: unsuccessful estimation at (X,Y,T) = ',
     &            3f12.3,/,8x,'(ERR,BNORM,ERRSQ) =',f7.4,1pe15.5,
     &            1pe15.5)
           write(iprt,160) emap,fmap
 160       format(8x,'assigned EMAP,FMAP=',f7.4,1pe15.5,/)
#ifdef sunflush
           call flush(iprt)
#endif
         endif
       endif
       return
       end
