      subroutine readgrids
c
c=======================================================================
c                                                                    ===
c  This routines read some varaibles from GRIDS NetCDF file.         ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <param.h>
#include <domdat.h>
#include <inppar.h>
#include <netcdf.inc>
#include <oagrid.h>
#include <oa_netcdf.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer dbgn,dend,dimid,dimsiz,dlen,fbgn,fend,flen,icoor,imax,
     *        jmax,n,ndims,ngatts,nvars,recdim,sbn,snd,sln,xindx,yindx
      integer count(3),start(3)
      logical old
      real      c0,c1,gdelx,gdely,gridx,gridy,m2km,rlatd,rlngd,scl,theta
      character*5   ustr
      character*256 dimnam
      parameter (c0=0.0,c1=1.0,m2km=0.001,xindx=1,yindx=2)
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c  Open GRIDS NetCDF file.
c
      call ncpopt(ncverbos)
      call length (fname(5),flen,fbgn,fend)
      ncgrdid=ncopn(fname(5)(fbgn:fend),ncnowrit,rcode)
      if(rcode.ne.0) then
        write(iprt,900) fname(5)(fbgn:fend)
        call exitus('READGRIDS')
      endif
c
c-----------------------------------------------------------------------
c  Inquire about the contents of open NetCDF file:  Inquire about the
c  dimensions and variables.
c-----------------------------------------------------------------------
c
      call ncinq(ncgrdid,ndims,nvars,ngatts,recdim,rcode)
      if(rcode.eq.0) then
c
c  Inquire about dimensions.
c
        do 10 n=1,ndims
          dimid=n
          call ncdinq(ncgrdid,dimid,dimnam,dimsiz,rcode)
          if(rcode.ne.0) then
            write(iprt,910) n,fname(5)(fbgn:fend)
            call exitus('READGRIDS')
          endif
          call length (dimnam,dlen,dbgn,dend)
          if((dimnam(dbgn:dend).eq.'lon').or.
     *       (dimnam(dbgn:dend).eq.'tlon')) then
            imax=dimsiz
          elseif((dimnam(dbgn:dend).eq.'lat').or.
     *           (dimnam(dbgn:dend).eq.'tlat')) then
            jmax=dimsiz
          endif
  10    continue
c
c  Check main dimensions.
c
        if(imax.ne.im) then
          write(iprt,950) 'IM = ',im,imax
          im=imax
          imjm=im*jm
        endif
        if(jmax.ne.jm) then
          write(iprt,950) 'JM = ',jm,jmax
          jm=jmax
          imjm=im*jm
        endif
        if (imjm.gt.mgrd) then
          write(iprt,920) mgrd,imjm
          call exitus ('READGRIDS')
        endif
c
      else
        write(iprt,930) fname(5)(fbgn:fend)
        call exitus('READGRIDS')
      endif
c
c-----------------------------------------------------------------------
c  Read in and check some geometry parameters.
c-----------------------------------------------------------------------
c
c  Coordinate type.
c
      varid = ncvid (ncgrdid,'coord',rcode)
      if (rcode.ne.0) then
        write(iprt,960) 'coord',fname(5)(fbgn:fend)
        call exitus ('READGRIDS')
      end if
      call ncvgt1 (ncgrdid,varid,1,icoor,rcode)
      if (rcode.ne.0) then
        write(iprt,970) 'coord',fname(5)(fbgn:fend)
        call exitus ('READGRIDS')
      end if
      if (coord.ne.icoor) then
        write(iprt,950) 'COORD = ',coord,icoor
        coord=icoor
      end if
c
      if (coord.eq.0) then
         scl  = m2km
         ustr = '(km)'
       else
         scl  = c1
         ustr = '(deg)'
      end if
      call length (ustr,sln,sbn,snd)
c
c  Grid spacing.
c
      varid = ncvid (ncgrdid,'meandx',rcode)
      if (rcode.ne.0) then
        write(iprt,960) 'meandx',fname(5)(fbgn:fend)
        call exitus ('READGRIDS')
      end if
      call ncvgt1 (ncgrdid,varid,1,gridx,rcode)
      if (rcode.ne.0) then
        write(iprt,970) 'meandx',fname(5)(fbgn:fend)
        call exitus ('READGRIDS')
      end if
      gridx = gridx*scl
      if (gridx.ne.dx) then
        write(iprt,940) 'DX = ',dx,ustr(sbn:snd),gridx,ustr(sbn:snd)
        dx=gridx
      end if
c
      varid = ncvid (ncgrdid,'meandy',rcode)
      if (rcode.ne.0) then
        write(iprt,960) 'meandy',fname(5)(fbgn:fend)
        call exitus ('READGRIDS')
      end if
      call ncvgt1 (ncgrdid,varid,1,gridy,rcode)
      if (rcode.ne.0) then
        write(iprt,970) 'meandy',fname(5)(fbgn:fend)
        call exitus ('READGRIDS')
      end if
      gridy = gridy*scl
      if (gridy.ne.dy) then
        write(iprt,940) 'DY = ',dy,ustr(sbn:snd),gridy,ustr(sbn:snd)
        dy=gridy
      end if
c
c  Transformation centroid.
c
      varid = ncvid (ncgrdid,'rlngd',rcode)
      if (rcode.ne.0) then
        write(iprt,960) 'rlngd',fname(5)(fbgn:fend)
        call exitus ('READGRIDS')
      end if
      call ncvgt1 (ncgrdid,varid,1,rlngd,rcode)
      if (rcode.ne.0) then
        write(iprt,970) 'rlngd',fname(5)(fbgn:fend)
        call exitus ('READGRIDS')
      end if
c
      varid = ncvid (ncgrdid,'rlatd',rcode)
      if (rcode.ne.0) then
        write(iprt,960) 'rlatd',fname(5)(fbgn:fend)
        call exitus ('READGRIDS')
      end if
      call ncvgt1 (ncgrdid,varid,1,rlatd,rcode)
      if (rcode.ne.0) then
        write(iprt,970) 'rlatd',fname(5)(fbgn:fend)
        call exitus ('READGRIDS')
      end if
c
c  Grid rotation.
c
      varid = ncvid (ncgrdid,'thetad',rcode)
      if (rcode.ne.0) then
        write(iprt,960) 'thetad',fname(5)(fbgn:fend)
        call exitus ('READGRIDS')
      end if
      call ncvgt1 (ncgrdid,varid,1,theta,rcode)
      if (rcode.ne.0) then
        write(iprt,970) 'thetad',fname(5)(fbgn:fend)
        call exitus ('READGRIDS')
      end if
      if (theta.ne.thetad) then
        write(iprt,940) 'THETAD = ',thetad,'(deg)',theta,'(deg)'
        thetad=theta
      end if
c
c  Grid offset.
c
      old = .false.
c
      varid = ncvid (ncgrdid,'delx',rcode)
      if (rcode.eq.0) then
        call ncvgt1 (ncgrdid,varid,1,gdelx,rcode)
        if (rcode.ne.0) then
          write(iprt,970) 'delx',fname(5)(fbgn:fend)
          call exitus ('READGRIDS')
        end if
       else
        old = .true.
      end if
c
      varid = ncvid (ncgrdid,'dely',rcode)
      if (rcode.eq.0) then
        call ncvgt1 (ncgrdid,varid,1,gdely,rcode)
        if (rcode.ne.0) then
          write(iprt,970) 'dely',fname(5)(fbgn:fend)
          call exitus ('READGRIDS')
        end if
       else
        old = .true.
      end if
c
c  Preserve backward compatibility.
c
      if (old) then
        if (coord.ne.1) then
          gdelx=c0
          gdely=c0
          write(iprt,980)
         else
          gdelx=rlngd
          gdely=rlatd
          rlngd=c0
          rlatd=c0
          write(iprt,990) rlngd,rlatd
        end if
      end if
c
c  Check backwardly compatibility CLATD, CLNGD, DELX and DELY.
c
      if (rlatd.ne.clatd) then
        write(iprt,940) 'CLATD = ',clatd,'(deg)',rlatd,'(deg)'
        clatd=rlatd
      end if
c
      if (rlngd.ne.clngd) then
        write(iprt,940) 'CLNGD = ',clngd,'(deg)',rlngd,'(deg)'
        clngd=rlngd
      endif
c
      gdelx = gdelx*scl
      if (gdelx.ne.delx) then
        write(iprt,940) 'DELX = ',delx,ustr(sbn:snd),gdelx,ustr(sbn:snd)
        delx=gdelx
      end if
c
      gdely = gdely*scl
      if (gdely.ne.dely) then
        write(iprt,940) 'DELY = ',dely,ustr(sbn:snd),gdely,ustr(sbn:snd)
        dely=gdely
      end if
c
c  Land Mask.
c
      varid = ncvid (ncgrdid,'landt',rcode)
      lmsk  = rcode .eq. 0
c
c-----------------------------------------------------------------------
c  Read in Land/Sea mask data.
c-----------------------------------------------------------------------
c
      if(lmsk) then
        start(1)=1
        count(1)=imax
        start(2)=1
        count(2)=jmax
        varid=ncvid(ncgrdid,'landt',rcode)
        if(rcode.ne.0) then
          write(iprt,960) 'landt',fname(5)(fbgn:fend)
          call exitus('READGRIDS')
        endif
        call ncvgt(ncgrdid,varid,start,count,landt,rcode)
        if(rcode.ne.0) then
          write(iprt,970) 'landt',fname(5)(fbgn:fend)
          call exitus('READGRIDS')
        endif
      endif
c
c-----------------------------------------------------------------------
c  Read in longitude and latitude data for each grid point.
c-----------------------------------------------------------------------
c
      start(1)= xindx
      count(1)=1
      start(2)=1
      count(2)=imax
      start(3)=1
      count(3)=jmax
      varid=ncvid(ncgrdid,'tgrid2',rcode)
      if(rcode.ne.0) then
        write(iprt,960) 'tgrid2',fname(5)(fbgn:fend)
        call exitus('READGRIDS')
      endif
      call ncvgt(ncgrdid,varid,start,count,lon,rcode)
      if(rcode.ne.0) then
        write(iprt,970) 'tgrid2 x-index',fname(5)(fbgn:fend)
        call exitus('READGRIDS')
      endif
      start(1)= yindx
      count(1)=1
      call ncvgt(ncgrdid,varid,start,count,lat,rcode)
      if(rcode.ne.0) then
        write(iprt,970) 'tgrid2 y-index',fname(5)(fbgn:fend)
        call exitus('READGRIDS')
      endif
c
 900  format(/'READGRIDS - unable to open GRIDS NetCDF file: ',a)
 910  format(/' READGRIDS - error while reading dimension: ',1h",a,1h"/
     *        13x,'in GRIDS NetCDF file: ',1h",a,1h")
 920  format(' READGRIDS: underdimensioned arrays, MGRD, IMJM = ',i5,1x
     &       ,i5/12x,'change file ',1h",'param.h',1h",' and recompile'/)
 930  format(/' READGRIDS - unable to inquire about contents of'/13x,
     *        'GRIDS NetCDF file: ',1h",a,1h")
 940  format(/' READGRIDS - WARNING: inconsistent parameter value, ',
     *       1h",a,1h",g15.8,1x,a/32x,'replaced with GRIDS value = ',
     *       g15.8,1x,a)
 950  format(/' READGRIDS - WARNING: inconsistent parameter value, ',
     *       1h",a,1h",i10/32x,'replaced with GRIDS value = ',i10)
 960  format(/' READGRIDS - cannot find variable: ',1h",a,1h"/13x,
     *        'in GRIDS NetCDF file: ',1h",a,1h")
 970  format(/' READGRIDS - error while reading variable: ',1h",a,1h"/
     *        13x,'in GRIDS NetCDF file: ',1h",a,1h")
 980  format(/' READGRIDS - WARNING: old GRIDS file.'/13x,
     *       'Replacing GRIDS values (DELX,DELY) by (0,0)')
 990  format(/' READGRIDS - WARNING: old GRIDS file.'/13x,'Replacing ',
     *       'GRIDS values (DELX,DELY) by (',f8.3,', ',f8.3,')'/13x,
     *       'and GRIDS values (CLNGD,CLATD) by (0,0)')
      return
      end
