      subroutine readhydro
c
c=======================================================================
c                                                                    ===
c  This routine reads hydrographic data in HOPS ascii format.        ===
c                                                                    ===
c  Entries:                                                          ===
c                                                                    ===
c  READ_HEADER   reads and decode file header information.           ===
c  READ_HYDRO    reads hydrographic data, one hydrographic station   ===
c                per each call.                                      ===
c                                                                    ===
c  Calls:  LENGTH, NXT_BLNK, SET_TYPE                                ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <param.h>
#include <hydro.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer iend,ios,istr,iunit,m,n,sbgn,send,slen
      integer     nxt_blnk
      character*7  fmt
      character*80 text
c
c=======================================================================
c  Read in header information. =========================================
c=======================================================================
c
      entry read_header(iunit)
c
      nhdr=1
      eof=.false.
      read (iunit,'(a)',iostat=ios) header(nhdr)
c
      do 40 while ((header(nhdr)(1:3).ne.'END') .and. (ios.eq.0))
c
        istr=index(header(nhdr),'=') + 1
        iend=len(header(nhdr))
        call length (header(nhdr)(istr:iend),slen,sbgn,send)
        sbgn = sbgn + istr - 1
        send = send + istr - 1
        text=header(nhdr)(sbgn:send)
c
        if(header(nhdr)(2:6).eq.'title') then
          read(text,'(a)') htitle
        elseif(header(nhdr)(2:9).eq.'stations') then
          write (fmt,10) slen
  10      format ('(i',i2,')')
          read (text,fmt) nhobs
        elseif(header(nhdr)(2:9).eq.'str_time') then
          iend = index(header(nhdr),',')
          if (iend.ne.0) send=iend
          write (fmt,20) send-sbgn+1
  20      format ('(f',i2,'.0)')
          read (text,fmt) hstrday
        elseif(header(nhdr)(2:9).eq.'end_time') then
          iend = index(header(nhdr),',')
          if (iend.ne.0) send=iend
          write (fmt,20) send-sbgn+1
          read (text,fmt) hendday
        elseif(header(nhdr)(2:12).eq.'Jday_offset') then
          write (fmt,10) slen
          read (text,fmt) jdayoff
        elseif(header(nhdr)(2:8).eq.'lng_min') then
          write (fmt,20) slen
          read (text,fmt) hlng_min
        elseif(header(nhdr)(2:8).eq.'lng_max') then
          write (fmt,20) slen
          read (text,fmt) hlng_max
        elseif(header(nhdr)(2:8).eq.'lat_min') then
          write (fmt,20) slen
          read (text,fmt) hlat_min
        elseif(header(nhdr)(2:8).eq.'lat_max') then
          write (fmt,20) slen
          read (text,fmt) hlat_max
        elseif(header(nhdr)(2:5).eq.'type') then
          istr = 1
          iend = index (text(istr:slen),',')
          do 30 while (iend.gt.0)
            iend = iend + istr - 2
            call set_type (text(istr:iend))
            istr = nxt_blnk (text(istr:slen)) + istr
            iend = index (text(istr:slen),',')
  30      continue
          call set_type (text(istr:slen))
        endif
c
        nhdr=nhdr+1
        read (iunit,'(a)',iostat=ios) header(nhdr)
c
  40  continue
      return
c
c=======================================================================
c  Read in hydrography cast. ===========================================
c=======================================================================
c
      entry read_hydro(iunit)
c
c  Read cast block header.
c
      read(iunit,*,iostat=ios) nhvar,nhpts,castid,hlng,hlat,hdpth,htime,
     *                         (hscle(m),m=1,nhvar)
      if (ios.eq.0) read(iunit,*,iostat=ios) hflag,htype
c
c  Decode cast type.
c
      if (ios.eq.0) then
c
        call length (htype,slen,sbgn,send)
        iend = index (htype,':') - 1
        htool = htype(sbgn:iend)
c
        axbt=.false.
        ctd=.false.
        xbt=.false.
        xbts=.false.
        xctd=.false.
c
        call set_type (htool(sbgn:iend))
c
        iend = iend + 1
c
        do 50 m = 1, nhvar
          istr = min( iend+1, send )
          call length (htype(istr:send),slen,sbgn,iend)
          istr = istr + sbgn - 1
          iend = nxt_blnk (htype(istr:send)) + istr - 2
          if (iend.lt.istr) iend = send
          hflds(m) = htype(istr:iend)
  50    continue
c
      endif
c
c  Read in cast block records.
c
      m = 0
      do 70 while ((m.lt.nhvar).and.(ios.eq.0))
        read(iunit,*,iostat=ios) (ihdat(n),n=1,nhpts)
        if (ios.eq.0) then
          m = m + 1
          do 60 n=1,nhpts
            hdat(n,m)=float(ihdat(n))*hscle(m)
  60      continue
        end if
  70  continue
c
      eof = ios .ne. 0
c
      return
      end
