       subroutine remove (fobs,xobs,yobs,tobs,mask,nobs,iprt)
c
c=======================================================================
c                                                                    ===
c  This routine removes elements from the given arrays according     ===
c  to the supplied mask.                                             ===
c                                                                    ===
c  Arguments:                                                        ===
c                                                                    ===
c     FOBS     observation field (real array; input/output)          ===
c     XOBS     X position of observation (real array; input/output)  ===
c     YOBS     Y position of observation (real array; input/output)  ===
c     TOBS     time of observation (real array; input/output)        ===
c     MASK     Indicates whether or not to remove an element from    ===
c              each of the arrays (integer array; input/output):     ===
c              MASK =  0 =>  remove the corresponding elements       ===
c                            from each array.                        ===
c              MASK <> 0 =>  do NOT remove.                          ===
c     NOBS     number of observations (integer; input/output)        ===
c     IPRT     output logical unit (integer; input)                  ===
c                                                                    ===
c  Calls:  DOWN_SHIFT                                                ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
       logical extra
       integer c0,iprt,j,m,mask(*),nobs
       real fobs(nobs),tobs(nobs),xobs(nobs),yobs(nobs)
       parameter (c0=0)
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c  Initialize pointer and working number of elements.
c
       j=1
       m=nobs
c
c  If both of the last two elements need to be removed, an extra
c  call to down_shift will have to be made at the end.
c
       extra=(mask(m).eq.c0).and.(mask(m-1).eq.c0)
c
c  Loop through the working number of elements.
c
       do 20 while (j.lt.m)
c
c  Increment pointer until next element to be removed or end.
c
         do 10 while ((mask(j).ne.c0).and.(j.lt.m))
           j=j+1
 10      continue
c
c  If indicated, remove Jth element from each array and update
c  working number of elements.
c
         if (mask(j).eq.c0)
     &     call down_shift (fobs,xobs,yobs,tobs,mask,j,m)
 20    continue
c
c  Make sure last element really should be kept.
c
       if (extra) call down_shift (fobs,xobs,yobs,tobs,mask,j,m)
c
c  Update number of elements.
c
       if (m.ne.nobs) write(iprt,30) nobs-m,nobs
 30    format(' REMOVE : ',i5,' observations removed from initial',
     &        ' file of ',i5,' observations',/)
       nobs=m
       return
       end
