      subroutine rout_chk (rout,unit)
c
c=======================================================================
c                                                                    ===
c  This routine checks the outlier radius to see if it is big enough ===
c  to contain the grid.                                              ===
c                                                                    ===
c  ------                                                            ===
c  Input:                                                            ===
c  ------                                                            ===
c                                                                    ===
c  ROUT   outlier radius.                (real; km)                  ===
c  UNIT   unit number of the echo file.  (integer)                   ===
c                                                                    ===
c  Common Blocks:                                                    ===
c                                                                    ===
c  /DOMDAT/                                                          ===
c                                                                    ===
c     CLATD    domain centroid latitude.            (real; degrees)  ===
c     CLNGD    domain centroid longitude.           (real; degrees)  ===
c     DX       domain grid spacing in x-direction.  (real; km | deg) ===
c     DY       domain grid spacing in y-direction.  (real; km | deg) ===
c     THETAD   domain rotation angle.               (real; degrees)  ===
c                                                                    ===
c  /OAGRID/                                                          ===
c                                                                    ===
c     COORD  objective analysis coordinates option. (integer)        ===
c            [0] Cartesian                                           ===
c            [1] unrotated spherical                                 ===
c            [2] rotated spherical                                   ===
c     DELX,                                                          ===
c     DELY   Offset grid-trans. centers.            (real; km | deg) ===
c     IM     number of points in the x-direction.   (integer)        ===
c     IMJM   total number of points.                (integer)        ===
c     JM     number of points in the y-direction.   (integer)        ===
c     LAT    latitude coordinates of the OA grid.   (real; degrees)  ===
c     LON    longitude coordinates of the OA grid.  (real; degrees)  ===
c                                                                    ===
c  Calls:  GCIRCLE                                                   ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <param.h>
#include <domdat.h>
#include <oagrid.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer i,imm1,ip,j,jmm1,unit
      real    bearing,c0,dang,dist,latcen,loncen,p5,radgrid,rout,xc,yc
      real    gcircle
c
      parameter (c0=0.0, p5=0.5)
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c-----------------------------------------------------------------------
c  Compute the "radius" of the grid.
c-----------------------------------------------------------------------
c
      if (coord.eq.0) then
        radgrid=sqrt((dx*p5*float(im-1))**2+(dy*p5*float(jm-1))**2)
       elseif((coord.eq.1).or.(coord.eq.2)) then
        radgrid=c0
        imm1=im-1
        jmm1=jm-1
        xc = p5*float(im+1)
        yc = p5*float(jm+1)
        call xy2ll (xc,yc,coord,im,jm,dx,dy,clngd,clatd,
     *                 delx,dely,thetad,loncen,latcen)
        do 10 i = 1, im
          ip = i
          dang = gcircle (loncen,latcen,lon(ip),lat(ip),dist,bearing)
          radgrid = max(radgrid, dist)
          ip = i+jmm1*im
          dang = gcircle (loncen,latcen,lon(ip),lat(ip),dist,bearing)
          radgrid = max(radgrid, dist)
  10    continue
        do 20 j = 2, jmm1
          ip = 1 + (j-1)*im
          dang = gcircle (loncen,latcen,lon(ip),lat(ip),dist,bearing)
          radgrid = max(radgrid, dist)
          ip = im + (j-1)*im
          dang = gcircle (loncen,latcen,lon(ip),lat(ip),dist,bearing)
          radgrid = max(radgrid, dist)
  20    continue
      end if
c
c-----------------------------------------------------------------------
c  Write a warning message if ROUT does NOT contain the grid.
c-----------------------------------------------------------------------
c
      if (rout.lt.radgrid) write (unit,30) rout,radgrid
c
      return
c
  30  format (/50('*')/'*',48x,'*'/'* Warning:  ROUT does NOT contain ',
     &        'the grid.',5x,' *'/'*',20x,'ROUT (km):  ',1pg15.8,' *'/
     &        '*',4x,1h",'radius',1h",' of the grid (km):  ',1pg15.8,
     &        ' *'/'*',48x,'*'/50('*')/)
c
      end
