       subroutine select (fcor,index,nsel,fobs,xobs,yobs,tobs,nobs,xmap,
     &                    ymap,tmap,rnce,tnce,iprt)
c
c=======================================================================
c                                                                    ===
c  This routine selects at most nearby influential points to         ===
c  an interpolation point (XMAP,YMAP,TMAP).                          ===
c                                                                    ===
c  On Input:                                                         ===
c                                                                    ===
c     FOBS     observation field (real array)                        ===
c     XOBS     X position of observation (real array)                ===
c     YOBS     Y position of observation (real array)                ===
c     TOBS     time of observation (real array)                      ===
c     NOBS     number of observations (integer)                      ===
c     XMAP     X position to interpolate (real)                      ===
c     YMAP     Y position to interpolate (real)                      ===
c     TMAP     time of interpolation (real)                          ===
c     RNCE     spatial radius of influence (real)                    ===
c     TNCE     temporal window of influence (real)                   ===
c     IPRT     output logical unit                                   ===
c                                                                    ===
c  On Output:                                                        ===
c                                                                    ===
c     INDEX    sorted influential observations indices (integer      ===
c              array)                                                ===
c     NSEL     number of influential observations (integer)          ===
c                                                                    ===
c  Required common blocks:                                           ===
c                                                                    ===
c     CORSCL, DEBUG, OBSCOR                                          ===
c                                                                    ===
c  Calls:  GCIRCLE, SORT                                             ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <param.h>
#include <corscl.h>
#include <debug.h>
#include <obscor.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
       integer i,index(mobs),iprt,nobs,nsel
       real acor,dang,delt,delx,dely,dist,gcircle,phi,rnce,tmap,tnce,
     &      xmap,ymap
       real fcor(mobs),fobs(nobs),tobs(nobs),xobs(nobs),yobs(nobs)
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c  Select the most influential observations and compute their
c  associated autocorrelation.
c
       nsel=0
       do 10 i=1,nobs
         delx=xmap-xobs(i)
         dely=ymap-yobs(i)
         delt=tmap-tobs(i)
         if (ccoor.eq.0) then
           dist=sqrt(delx*delx+dely*dely)
         elseif ((ccoor.eq.1).or.(ccoor.eq.2)) then
           dang=gcircle(xobs(i),yobs(i),xmap,ymap,dist,phi)
         endif
         if (abs(delt).le.tnce) then
           if (dist.le.rnce) then
             nsel=nsel+1
             index(nsel)=i
             fcor(nsel)=acor(xmap,ymap,tmap,xobs(i),yobs(i),tobs(i))
           endif
         endif
 10    continue
c
       if (nsel.eq.0) then
         if (iwrt.ne.0) write(iprt,20) xmap,ymap,tmap
 20      format(' SELECT: no influential observations found for',/,
     &          '         (XMAP,YMAP,TMAP)=',3f12.3,/,
     &          '         check RNCE and TNCE values'/)
#ifdef sunflush
         if (iwrt.ne.0) call flush(iprt)
#endif
         return
       endif
c
c-----------------------------------------------------------------------
c  Determine the influential observations indices by sorting their
c  correlations in ascending order.
c-----------------------------------------------------------------------
c
       call sort (fcor,index,nsel)
       return
       end
