       function svafunc (depth)
c
c=======================================================================
c                                                                    ===
c  This routine evaluates the  specific volume anomaly stored in     ===
c  common block  TRAPZ, at the current depth  DEPTH,  via linear     ===
c  interpolation.  This routine is successively called by  QTRAP     ===
c  to carry out the integration of  the specific volume  anomaly     ===
c  using trapezoidal rule.                                           ===
c                                                                    ===
c  On Input:                                                         ===
c                                                                    ===
c     DEPTH    depth to evaluate (real; meters)                      ===
c                                                                    ===
c  On Output:                                                        ===
c                                                                    ===
c     SVAFUNC  interpolated specific volume anomaly (real)           ===
c                                                                    ===
c  Required common blocks:                                           ===
c                                                                    ===
c     TRAPZ                                                          ===
c                                                                    ===
c  Calls:  EXITUS, LINTRP                                            ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <param.h>
#include <trapz.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
       real depth,spval,svafunc,val
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c  Check out of bounds arrays.
c
       if (np.gt.nstp) then
         print 10, nstp,np
 10      format (' SVAFUNC: underdimensioned arrays, NSTP, NP = ',
     &           2i5,/'        change NSTP and recompile',/)
         call exitus ('SVAFUNC')
       endif
c
c-----------------------------------------------------------------------
c  Evaluate SVA(z) at z=DEPTH by linear interpolation.
c-----------------------------------------------------------------------
c
       spval=1.0e30
       call lintrp (np,h,sva,1,depth,val,spval)
       if(val.eq.spval) then
         print 100, depth,h(1),h(np)
100      format(' SVAFUNC:  depth ',f10.4,/,
     $  10x,' not in the range [ ',f10.4,',',f10.4,']')
         call exitus ('SVAFUNC')
       endif
       svafunc=val
       return
       end
