       subroutine trend (f,x,y,n,itrt,trnd,job,iprt)
c
c=======================================================================
c                                                                    ===
c  This routine computes  trend coefficients and linear, quadratic,  ===
c  or cubic trend of the field F of lenght N at the position (X,Y).  ===
c  The trend is a Taylor polymomial surface of order ITRT.           ===
c                                                                    ===
c  On Input:                                                         ===
c                                                                    ===
c     F        field (real array)                                    ===
c     X        field X position (real array)                         ===
c     Y        field Y position (real array)                         ===
c     N        number of field points (integer)                      ===
c     ITRT     degree of polynomial surface to detrend (integer)     ===
c              [0] no trend to remove or add, only mean              ===
c              [1] 1st order polynomial trend                        ===
c              [2] quadratic trend, 2nc order polynomial             ===
c              [3] cubic trend, 3rd order polynomial                 ===
c     JOB      internal flag (integer)                               ===
c              [1] compute trend coefficients and remove trend       ===
c              [2] add trend back in                                 ===
c     IPRT     output logical unit                                   ===
c                                                                    ===
c  On Output:                                                        ===
c                                                                    ===
c     TRND     trend value to remove or add (real)                   ===
c                                                                    ===
c  Calls:  EXITUS, TRENDCOEF                                         ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <trdcff.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
       integer iprt,itrt,job,n
       real c0,c6,dx,dx2,dx3,dy,dy2,dy3,p5,trnd,xmean,ymean
       real f(n),x(n),y(n)
       parameter (c0=0.0,c6=6.0,p5=0.5)
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c  If no data, return to calling program.
c
       if((n.eq.0).and.(job.eq.1)) return
c
c  Check switches.
c
       if (job.eq.1) then
         if (itrt.eq.1) then
           write(iprt,10)
 10        format(' TREND: removing/adding linear trend',/)
         elseif (itrt.eq.2) then
           write(iprt,20)
 20        format(' TREND: removing/adding quadratic trend',/)
         elseif (itrt.eq.3) then
           write(iprt,30)
 30        format(' TREND: removing/adding cubic trend',/)
         else
           write(iprt,40) itrt
 40        format(' TREND: illegal polynomial order, ITRT=',i4,/)
           call exitus ('TREND')
         endif
       endif
       if (job.lt.1.or.job.gt.2) then
         write(iprt,50) job
 50      format(' TRENT: illegal job option, JOB=',i4,/)
         call exitus ('TREND')
       endif
c
c-----------------------------------------------------------------------
c  Get trend cofficient or value to detrend.
c-----------------------------------------------------------------------
c
       trnd=c0
c
c  Compute trend coefficients.
c
       if (job.eq.1) then
         call trendcoef (f,x,y,n,itrt,tcoef)
c
c  Compute trend to remove or add.
c
       elseif (job.eq.2) then
         xmean=tcoef(11)
         ymean=tcoef(12)
         dx=x(n)-xmean
         dx2=dx*dx
         dx3=dx2*dx
         dy=y(n)-ymean
         dy2=dy*dy
         dy3=dy2*dy
         trnd=tcoef(1)+tcoef(2)*dx+tcoef(3)*dy+
     &                 tcoef(4)*dx2*p5+tcoef(5)*dy2*p5+
     &                 tcoef(6)*dx*dy+tcoef(7)*dx3/c6+
     &                 tcoef(8)*dy3/c6+tcoef(9)*dx2*dy*p5+
     &                 tcoef(10)*dx*dy2*p5
       endif
       return
       end
