       subroutine trendcoef (at,xt,yt,np,nds,parm)
c
c=======================================================================
c                                                                    ===
c  This routine caculates from  NP observations of a variable AT,    ===
c  which is located at a  east-west distance  XT  and north-south    ===
c  distance YT a two-dimensional Taylor polynomial of degree NDS.    ===
c  It  does  this  by  a  linear  least-square  fit.   The  trend    ===
c  coefficients-PARM  consist  of the  weighted  mean,  stored in    ===
c  PARM(1), the partial derivatives of the variable  AT, starting    ===
c  with the first partial of X in PARM(2), then the first partial    ===
c  of Y in PARM(3),  then the second partial of AT with X in (4),    ===
c  then with Y in (5),  then the mixed partial of X and Y in (6),    ===
c  then the third partial of X in (7), then with Y in (8) ,  then    ===
c  the mixed third order partial consisting of two in  X  and one    ===
c  in Y in (9) and finally the mixed second of Y and one of  X in    ===
c  PARM(10).  PARM(11)  holds  XO,  the  arithmetic  mean  of the    ===
c  east-west distances and PARM(12) holds YO, the arithmetic mean    ===
c  of the north-south distances. ND is the number of coefficients    ===
c  to  caculate.   R  holds  the  independent  variables  of  the    ===
c  regression, RT is its  transpose,  RTR is R  multiplied by its    ===
c  transpose and RTRI is the inverse of RTR. ESD is the estimated    ===
c  error in each regression coefficient AR,  IAREA are  work area    ===
c  matrices and AE are the estimated AT at each observation.         ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <param.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
       integer i,ier,j,k,na,nd,nds,ndte,np
       integer iarea(200)
       parameter (na=10)
       real aemax,as,av,c0,c1,c6,det,fit,p5,sdf,xmax,xmax2,xmax3,xo,xsd,
     &      ymax,ymax2,ymax3,yo,ysd
       real ae(mobs),ar(na,mobs),at(np),esd(na),parm(*),r(mobs,na),
     &      rt(na,mobs),rtr(na,na),rtri(na,na),xt(np),yt(np)
       parameter (c0=0.0,c1=1.0,c6=6.0,p5=0.5)
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
       if (nds.eq.1) nd=3
       if (nds.eq.2) nd=6
       if (nds.eq.3) nd=10
c
c  Zero out the PARM array, so that if less than a cubic surface is
c  fitted, the higher order coefficients are zero.
c
       do 10 i=1,na
         parm(i)=c0
 10    continue
c
c  Calculate the mean of XT, denote it XO and the mean of YT, denote
c  it YO from NP observations.  The standard deviations are also
c  calculated, but are not needed here.  Find the maximum value of
c  XT and YT to scale the matrix R.  This makes the matrix that is
c  is inverted better behaved, especially for the cubic fit.
c
       if (np.eq.0) goto 85
       call asm (xt,np,xmax,xo,xsd)
       call asm (yt,np,ymax,yo,ysd)
c
c  Fill the independent variable array R(I,J) with their values.  "I"
c  counts the observations, while "J" is the independent variable type.
c  The regression is of the form; AT=R*PARM and we are estimating PARM
c  given AT and R. 
c
       do 20 i=1,np
         r(i,1)=1.0
         r(i,2)=(xt(i)-xo)/xmax
         r(i,3)=(yt(i)-yo)/ymax
         if (nd.eq.1) goto 20
         r(i,4)=(r(i,2)**2)*p5
         r(i,5)=(r(i,3)**2)*p5
         r(i,6)=r(i,2)*r(i,3)
         if (nd.eq.2) goto 20
         r(i,7)=(r(i,2)**3)/c6
         r(i,8)=(r(i,3)**3)/c6
         r(i,9)=r(i,4)*r(i,3)
         r(i,10)=r(i,5)*r(i,2)  
 20    continue
c
c  Transpose R.
c
       do 30 i=1,np
       do 30 j=1,nd
         rt(j,i)=r(i,j)
 30    continue
c
c  Multiply R by R transpose.
c  
       do 40 i=1,nd
       do 40 j=1,nd
         rtr(i,j)=c0
       do 40 k=1,np
         rtr(i,j)=rtr(i,j)+(rt(i,k)*r(k,j))
 40    continue 
c 
c  Invert RTR and store in RTRI, NA is the row dimension of RTR and
c  RTRI, DET is the determinant, ND is the number of coefficients
c  to be estimated, i.e. the number of independent variables in
c  RTR, IAREA is a work area and IER is an error code.
c
       call invmtx (rtr, na,rtri,na,nd,det,iarea,ier)      
       if (ier.gt.0) print 45,ier
 45    format(' TRENDCOFF: inversion error',1x,i5)
c  
c  Calculate RTRTI*RT and store in AR.
c 
       do 50 i=1,nd
       do 50 j=1,np
         ar(i,j)=c0
       do 50 k=1,nd
         ar(i,j)=ar(i,j)+rtri(i,k)*rt(k,j)
 50    continue
c
c  Calculate the regression coefficients and store in PARM.
c
       do 60 i=1,nd
       do 60 j=1,np
         parm(i)=parm(i)+ar(i,j)*at(j)  
 60    continue
c
c  Calculate the FIT, a normalized residual sum of squares;
c  0 is the worst, 1 is the best, .8 is marginal and >.9 you
c  should be happy with your fit.  The standard deviation of
c  each regression coeff is also calculated and stored in ESD.
c
       fit=c0
       as=c0
       do 70 i=1,np
         ae(i)=c0
         do 71 j=1,nd
           ae(i)=ae(i)+r(i,j)*parm(j)
 71      continue
         as=as+at(i)**2
         fit=fit+(ae(i)-at(i))**2
 70    continue
       do 80 i=1,nd
         ndte=nd
         if (nd.ge.np) ndte=np-1
         esd(i)=rtri(i,i)*(fit/float(np-ndte))
 80    continue
c
c  Find the mean and the standard deviation of the detrended field.
c
       call asm (ae,np,aemax,av,sdf)
       fit=c1-(fit/as)
c
c  The regression coefficients and their standard deviations are 
c  unscaled so that they become the wanted derivative estimates.
c
       if (ier.gt.0) goto 85
       xmax2=xmax*xmax
       ymax2=ymax*ymax
       xmax3=xmax2*xmax
       ymax3=ymax2*ymax
       parm(2)=parm(2)/xmax
       parm(3)=parm(3)/ymax
       parm(4)=parm(4)/xmax2
       parm(5)=parm(5)/ymax2
       parm(6)=parm(6)/(xmax*ymax)
       parm(7)=parm(7)/xmax3
       parm(8)=parm(8)/ymax3
       parm(9)=parm(9)/(xmax2*ymax)
       parm(10)=parm(10)/(xmax*ymax2)
       esd(1)=sqrt(esd(1))
       esd(2)=sqrt(esd(2))/xmax
       esd(3)=sqrt(esd(3))/ymax
       esd(4)=sqrt(esd(4))/xmax2      
       esd(5)=sqrt(esd(5))/ymax2
       esd(6)=sqrt(esd(6))/(xmax*ymax)
       esd(7)=sqrt(esd(7))/xmax3
       esd(8)=sqrt(esd(8))/ymax3
       esd(9)=sqrt(esd(9))/(xmax2*ymax)
       esd(10)=sqrt(esd(10))/(xmax*ymax2)
 85    continue
       parm(11)=xo
       parm(12)=yo
       return
       end
