       subroutine dhlev ( dhl, kref, zlev, m, zref, idhopt )
c
c=======================================================================
c                                                                    ===
c  This routine sets the dephts DHL that are used by DYNHT to carry  ===
c  out the integration of the specific volume anomaly.               ===
c                                                                    ===
c  On Input:                                                         ===
c                                                                    ===
c     ZLEV     desired dynamic height levels (real array; meters)    ===
c     M        number of desired depth levels (integer)              ===
c     ZREF     depth level of no motion (real; meters)               ===
c     IDHOPT   integration direction (integer)                       ===
c              IDHOPT = 1  from ZREF to the surface                  ===
c              IDHOPT = 2  from ZREF to the bottom                   ===
c              IDHOPT = 3  both above directions from ZREF           ===
c                                                                    ===
c  On Output:                                                        ===
c                                                                    ===
c     DHL      integration depths for the specified integration      ===
c              direction (real array; negative; meters)              ===
c     KREF     array element in DHL containing reference depth       ===
c              (integer)                                             ===
c                                                                    ===
c=======================================================================
c     
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
       integer idhopt,k,kref,m
       real dhl(m+1),zlev(m),zref
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c  Initilaize dynamic height levels array.
c
       do 10 k=1,m+1
           dhl(k)=0.
 10    continue
c
c-----------------------------------------------------------------------
c  Select specific volume integration depths.
c-----------------------------------------------------------------------
c
c  Depths for integrating from ZREF to the surface.
c
       if (idhopt.eq.1) then
         kref = 0
         do 20 k=1,m
           if (abs(zlev(k)).lt.abs(zref)) kref=k
 20      continue
         dhl(kref+1)=-abs(zref)
         do 30 k=kref,1,-1
           dhl(k)=-abs(zlev(k))
 30      continue
c
c  Depths for integrating from ZREF to the bottom.
c
       elseif (idhopt.eq.2) then       
         kref=m+1
         do 40 k=m,1,-1
           if (abs(zlev(k)).gt.abs(zref)) kref=k
 40      continue
         dhl(kref-1)=-abs(zref)
         do 50 k=kref,m
           dhl(k)=-abs(zlev(k))
 50      continue
c
c  Depths for integrating from ZREF to the surface and from
c  ZREF to bottom.
c
       elseif (idhopt.eq.3) then
         kref=0
         do 60 k=1,m
           if (abs(zlev(k)).lt.abs(zref)) kref = k
 60      continue
         dhl(kref+1)=-abs(zref)
         do 70 k=kref,1,-1
           dhl(k)=-abs(zlev(k))
 70      continue
         if (abs(zlev(kref+1)).ne.abs(zref)) then
           do 80 k=kref+1,m
             dhl(k+1)=-abs(zlev(k))
 80        continue
         else
           do 90 k=kref+1, m
             dhl(k)=-abs(zlev(k))
 90        continue
         end if
       end if
       return
       end
