       subroutine getdynht (dh,dlev,nlev,zref,idhopt,hvar,npts,spval)
c
c=======================================================================
c                                                                    ===
c  This routine computes dynamic height referenced to ZREF from      ===
c  the pressure,  temperature,  and salinity profiles stored in      ===
c  HVAR by routine GETOBS.                                           ===
c                                                                    ===
c  On Input:                                                         ===
c                                                                    ===
c     DLEV     depth level(s) in meters to OA (real 1-D array)       ===
c     NLEV     number of depth levels to OA (integer)                ===
c     ZREF     level of no motion in meters (real)                   ===
c     IDHOPT   specific volume anomaly integration option            ===
c              [1] integrate from ZREF to dlev(1)                    ===
c              [2] integrate fmom ZREF to dlev(nlev)[bottom of cast] ===
c              [3] integrate in both [1] and [2] directions          ===
c              [4] integrate from dlev(1) to the bottom of the       ===
c                  profile.                                          ===
c              For options 1,3,4 a cast must have data               ===
c                  at or above dlev(1).                              ===
c              For options 1  a cast must have data at depths        ===
c                  below dref                                        ===
c              For option 2 a cast must have data above or at dref.  ===
c                                                                    ===
c     HVAR     input hydrographic profiles (real 2-D array)          ===
c              HVAR(*,1):  pressure or depth                         ===
c              HVAR(*,2):  temperature                               ===
c              HVAR(*,3):  salinity                                  ===
c     NPTS     number of profile points (integer)                    ===
c     SPVAL    special value to flag no data (real)                  ===
c                                                                    ===
c  On Output:                                                        ===
c                                                                    ===
c     DH       dynamic height in dynamic meters (real 1-D array)     ===
c                                                                    ===
c  Calls:  DYNHT                                                     ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <param.h>
#include <inppar.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
       logical compute
       integer i,idhopt,intopt,nlev,npts
       real dbot,dh(nlev),dlev(nlev),dref,hvar(mpts,mvar),spval,zbot,
     &      zref,dtop,ztop
   
      
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
       if ((idhopt.lt.1).or.(idhopt.gt.4)) then
         write (iprt,100) idhopt
100      format(/' DYNHT: illegal flag, IDHOPT = ',i5,/)
         call exitus ('DYNHT')
       endif
c
c -- set options and reference levels  for dynht
c
       if (idhopt.eq.4) then           
           intopt=2
           dref=dlev(1)
       else
           intopt=idhopt
           dref=zref
       endif
c
c  Reject casts with insufficient data.
c

       compute=.false.

       dtop=dlev(1)
       dbot=dlev(nlev)


       ztop=hvar(1   ,1)
       zbot=hvar(npts,1)

       if(intopt.eq.1.or.intopt.eq.3) then
           if(zbot.ge.dref.and.ztop.le.dref.and.ztop.le.dtop) then
              compute=.true.
           endif
       endif
  
       if(intopt.eq.2) then
          if ((zbot.ge.dref).and.(ztop.le.dref)) then
              compute=.true.
          endif
       endif
c
c  Compute dynamic height if sufficient data in the vertical profiles.
c
       if (compute) then
         call dynht (dh,dlev,nlev,dref,hvar(1,3),hvar(1,2),hvar(1,1),
     &               npts,intopt,spval)
 
       else
         do 30 i=1,nlev
           dh(i)=spval
 30      continue
       endif
       return
       end
