      subroutine linmin(amat,p,bmat,xi,n,fret,wk)
c
c=======================================================================
c                                                                    ===
c  Given an N dimensional point P  and  an N dimensional direction   ===
c  XI,  this subroutine moves and resets  P  to where the function   ===
c  FUNC(P)  takes on a minimum along the XI direction from P,  and   ===
c  replaces XI by the actual vector displacement that P was moved.   ===
c  Also returns as FRET the value of FUNC at the returned location   ===
c  P. This is actually all accomplished by calling routines MNBRAK   ===
c  and BRENT.                                                        ===
c                                                                    ===
c  On Input:                                                         ===
c                                                                    ===
c     AMAT   symmetric, positive-definite, NxN matrix to invert      ===
c            using conjugate gradient method (real array).           ===
c            first guess solution vecto (real array).                ===
c     BMAT   right-hand side vector (real array).                    ===
c     XI     first guess sequence of directions (real array).        ===
c     N      length of vector (integer).                             ===
c     WK     working vector (real vector)                            ===
c                                                                    ===
c  On Output:                                                        ===
c                                                                    ===
c     P      solution vector for the linear system via minimization  ===
c            (real array).                                           ===
c     XI     sequence of directions (real array).                    ===
c     FRET   value of the function at minimum (real).                ===
c                                                                    ===
c  Calls:    BRENT, F1DIM (external), MNBRAK                         ===
c                                                                    ===
c  Reference:  Press, W.H. et al., 1989: Numerical Recipes, The Art  ===
c              of Scientific Computing,  pp 300-301.                 ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer j,n
      real ax,bx,c0,c1,c2,fa,fb,fx,fret,tol,xmin,xx
      real amat(n,n),bmat(n),p(n),xi(n),wk(n)
      real brent
      parameter (c0=0.0,c1=1.0,c2=2.0,tol=1.e-4)
      external f1dim
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c  Initial guess for brackets.
c
      ax=c0
      xx=c1
      call mnbrak(ax,xx,bx,fa,fx,fb,f1dim,amat,bmat,p,xi,wk,n)
      fret=brent(ax,xx,bx,f1dim,amat,bmat,p,xi,wk,n,tol,xmin)
c
c  Construct the vector results to return.
c
      do 20 j=1,n
        xi(j)=xmin*xi(j)
        p(j)=p(j)+xi(j)
  20  continue
      return
      end
