       subroutine lubksb (a,n,np,indx,b)
c
c=======================================================================
c                                                                    ===
c  Solves the set of N linear equations  A X = B. Here  A is input,  ===
c  not as the matrix A  but rather as its LU decomposition,  set by  ===
c  routine LUDCMP. INDX is input as the permutation vector returned  ===
c  by  LUDCMP.  B is input as  the  right-hand  side vector B,  and  ===
c  returns with the solution vector X. A,N,NP,INDX are not modified  ===
c  by this  routine and  can be left in place for  successive calls  ===
c  with  different  right-hand sides  B.  This  routine  takes into  ===
c  account  the  possiblility  that  B  will  begin with  many zero  ===
c  elements, so is efficient for use in matrix inversion.            ===
c                                                                    ===
c  Reference:  Press, W.H, et al., 1989: Numerical Recipes, The Art  ===
c              of Scientific Computing, pp 31-37.                    ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
       integer i,ii,j,ll,n,np
       integer indx(n)
       real a(np,np),b(n),sum
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
       ii=0
       do 12 i=1,n
         ll=indx(i)
         sum=b(ll)
         b(ll)=b(i)
         if (ii.ne.0) then
           do 11 j=ii,i-1
             sum=sum-a(i,j)*b(j)
 11        continue
         elseif (sum.ne.0.) then
           ii=i
         endif
         b(i)=sum
 12    continue
       do 14 i=n,1,-1
         sum=b(i)
         if (i.lt.n) then
           do 13 j=i+1,n
             sum=sum-a(i,j)*b(j)
 13        continue
         endif
         b(i)=sum/a(i,i)
 14    continue
       return
       end
