      subroutine mapcor (nobs,xobs,yobs,tobs,iclima,nclm,xclm,yclm,tclm,
     &                                                             iprt)
c
c=======================================================================
c                                                                    ===
c  This routine sets the mapping correlation matrices.               ===
c                                                                    ===
c  On Input:                                                         ===
c     XOBS     X position of observation (real array)                ===
c     YOBS     Y position of observation (real array)                ===
c     TOBS     time of observation (real array)                      ===
c     NOBS     number of observations (integer)                      ===
c     XCLM     X position of climatology (real array)                ===
c     YCLM     Y position of climatology (real array)                ===
c     TCLM     time of climatology (real array)                      ===
c     NCLM     number of observations (integer)                      ===
c     ICLIMA   weighted mean computation option (integer):           ===
c              [0] use observations only                             ===
c              [1] use climatology only                              ===
c              [2] use both observations and climatology             ===
c              [3] global observation mean                           ===
c     IPRT     output logical unit (integer)                         ===
c                                                                    ===
c  Required common blocks:                                           ===
c                                                                    ===
c    CORSCL, OBSCOR                                                  ===
c                                                                    ===
c  Calls:  ACOR, EXITUS, LUDCMP                                      ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <param.h>
#include <corscl.h>
#include <obscor.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
       integer nobs,nclm,iclima
       integer i,ier,ij,iprt,j,ji,jj
       real  xobs(nobs),yobs(nobs),tobs(nobs)
       real  xclm(nclm),yclm(nclm),tclm(nclm)
       real coss,sins,tdcays,uphs,vphs,xdcays,xzeros,ydcays,yzeros
       real d(mobs),wk(mobs)
       real acor
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
       if(method.eq.2) return
c
c  Construct observations correlation matrix.
c
       do 20 j=1,nobs
         do 10 i=j,nobs
           ij=i+(j-1)*nobs
           aobs(ij)=acor(xobs(j),yobs(j),tobs(j),xobs(i),yobs(i),
     &                                                          tobs(i))
           cobs(ij)=aobs(ij)
           ji=j+(i-1)*nobs
           aobs(ji)=aobs(ij)
           cobs(ji)=aobs(ij)
 10      continue
         jj=j+(j-1)*nobs
         aobs(jj)=aobs(jj)+obserr
         cobs(jj)=aobs(jj)
 20    continue
c
c-----------------------------------------------------------------------
c  Construct climatology correlation matrix.
c-----------------------------------------------------------------------
c
       if ((0.le.iclima).and.(iclima.le.2)) then
c
c  Save synoptic correlation scales and load climatological
c  correlation scales.
c
         xzeros=xzero
         yzeros=yzero
         xdcays=xdcay
         ydcays=ydcay
         tdcays=tdcay
         uphs=uphse
         vphs=vphse
         coss=cosang
         sins=sinang
c
         xzero=xzerom
         yzero=yzerom
         xdcay=xdcaym
         ydcay=ydcaym
         tdcay=tdcaym
         uphse=uphsem
         vphse=vphsem
         cosang=cosangm
         sinang=sinangm
c
c  Build correlation matrix for the mean at observation positions.
c
         if ((iclima.eq.0).or.(iclima.eq.2)) then
           do 40 j=1,nobs
             do 30 i=j,nobs
               ij=i+(j-1)*nobs
               acobs(ij)=acor(xobs(j),yobs(j),tobs(j),xobs(i),yobs(i),
     &                                                          tobs(i))
               ccobs(ij)=acobs(ij)
               ji=j+(i-1)*nobs
               acobs(ji)=acobs(ij)
               ccobs(ji)=acobs(ij)
 30          continue
             jj=j+(j-1)*nobs
#ifdef obserrpfjl
             acobs(jj)=acobs(jj)+obserr
#else
             acobs(jj)=acobs(jj)+clmerr
#endif
             ccobs(jj)=acobs(jj)
 40        continue
         endif
c
c  Build correlation matrix for the mean at climatology positions.
c  (Climatology is rendered time independent.)
c
         if ((iclima.eq.1).or.(iclima.eq.2)) then
           do 60 j=1,nclm
             do 50 i=j,nclm
               ij=i+(j-1)*nclm
               aclm(ij)=acor(xclm(j),yclm(j),tclm(j),xclm(i),yclm(i),
     &                                                          tclm(j))
               cclm(ij)=aclm(ij)
               ji=j+(i-1)*nclm
               aclm(ji)=aclm(ij)
               cclm(ji)=aclm(ij)
 50          continue
             jj=j+(j-1)*nclm
             aclm(jj)=aclm(jj)+clmerr
             cclm(jj)=aclm(jj)
 60        continue
         endif
c
c  Restore synoptic correlation scales.
c
         xzero=xzeros
         yzero=yzeros
         xdcay=xdcays
         ydcay=ydcays
         tdcay=tdcays
         uphse=uphs
         vphse=vphs
         cosang=coss
         sinang=sins
c
       endif
c
c-----------------------------------------------------------------------
c  Perform first step of the LU decomposition for each of the
c  correlation matrices.
c-----------------------------------------------------------------------
c
       if (method.eq.0) then
         if (nobs.gt.0) call ludcmp (aobs,nobs,nobs,wobs,d,wk,ier)
         if (ier.eq.1) then
           write(iprt,900) 'AOBS'
           call exitus ('MAPCOR')
         endif
         if ((0.le.iclima).and.(iclima.le.2)) then
           if ((iclima.eq.0).or.(iclima.eq.2)) then
             if (nobs.gt.0) call ludcmp (acobs,nobs,nobs,wcobs,d,wk,ier)
             if (ier.eq.1) then
               write(iprt,900) 'ACOBS'
               call exitus ('MAPCOR')
             endif
           endif
           if ((iclima.eq.1).or.(iclima.eq.2)) then
             if (nclm.gt.0) call ludcmp (aclm,nclm,nclm,wclm,d,wk,ier)
             if (ier.eq.1) then
               write(iprt,900) 'ACLM'
               call exitus ('MAPCOR')
             endif
           endif
         endif
       endif
c
 900   format(/' MAPCOR: matrix ',a,' is singular.')
       return
       end
