       program oagmain
c
c=======================================================================
c                                                                    ===
c  Generalized space-time objective analysis/statistical forecast    ===
c  package, 1994 version.  Global OA statistics.                     ===
c                                                                    ===
c  Hernan G. Arango and Carlos J. Lozano (December 1994)             ===
c  Harvard University                                                ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <param.h>
#include <clima.h>
#include <fdiagn.h>
#include <hydobs.h>
#include <inppar.h>
#include <oagrid.h>
#include <oa_netcdf.h>
#include <obscor.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
       integer corsiz,i,ifield,j,k,l,lenfld,lenstr,n,nclm,nobs
       integer count(4),start(4),start2(2)
       integer lnblk
#ifdef sunfpe
       integer ieeer,my_handler,ieee_handler
#endif
       logical fnd_field,fnd_mean
       real c1,fmaprms,stdclm,stdobs,tmap
       real fclm(mobs),tclm(mobs),xclm(mobs),yclm(mobs),
     &      fobs(mobs),tobs(mobs),xobs(mobs),yobs(mobs),
     &      emap(mgrd),fmap(mgrd),fmean(mgrd),fper(mobs),
     &      obsmean(mobs),work(mobs)
#ifdef pfjlerr
     &      ,emean(mgrd)
#endif
       character*60 text
c
       parameter (c1=1.0)
c
#ifdef sunfpe
       external   my_handler
c
#endif
       data nclm,nobs /2*0/
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
#ifdef sunfpe
c-----------------------------------------------------------------------
c     Enable floating point error flags.                               |
c-----------------------------------------------------------------------
c
      ieeer = ieee_handler ('set','common',my_handler)
      if (ieeer .ne. 0) write (6,900)
c
#endif
c-----------------------------------------------------------------------
c  Read in input parameters from input script file.
c-----------------------------------------------------------------------
c
       call oapar
c
c-----------------------------------------------------------------------
c  Read in hydrographic data an interpolate to the desired OA depth
c  levels.
c-----------------------------------------------------------------------
c
       call getobs (iinp,iprt,rout)
c
c-----------------------------------------------------------------------
c  Read in climatological data and interpolate to the desired OA
c  depth levels.
c-----------------------------------------------------------------------
c
       if ((iclima.eq.1).or.(iclima.eq.2)) then
         call getclima (iclm,iprt,rout)
       endif
c
c=======================================================================
c  Begin Objective Analysis: loop over number of days, levels and
c                            fields.
c=======================================================================
c
       count(1)=1
       count(2)=im
       count(4)=1
       count(3)=jm
c
       start(2)=1
       start(3)=1
c
       do 80 l=1,nday
         start(4)=l
         start2(2)=l
         do 70 k=1,nlev
           start(1)=k
           start2(1)=k
           do 60 j=1,nfld
c
c
c-----------------------------------------------------------------------
c  Extract hydrographic field to OA from HDATA and store it in scratch
c  vectors FOBS, TOBS, XOBS, and YOBS.
c-----------------------------------------------------------------------
c
             tmap=oaday(l)
             ifield=idfld(j)
             call xhydro (fobs,xobs,yobs,tobs,nobs,k,ifield,iprt)
c
c
c-----------------------------------------------------------------------
c  If applicable,  extract climatology field  from  CDAT  and
c  store it in scratch vectors FCLM, TCLM, XCLM, and YCLM.
c-----------------------------------------------------------------------
c
             if ((iclima.eq.1).or.(iclima.eq.2)) then
                call xclima (fclm,xclm,yclm,tclm,nclm,k,ifield,iprt)
             endif
c
c-----------------------------------------------------------------------
c  Build correlation matrices.
c-----------------------------------------------------------------------
c
             call mapcor (nobs,xobs,yobs,tobs,iclima,nclm,xclm,yclm,
     &                                                        tclm,iprt)
c
c-----------------------------------------------------------------------
c  Compute the diagnostics of the observation field.
c-----------------------------------------------------------------------
c
             stdobs = obserr
             lenfld=lnblk(fldnam(2,ifield),len(fldnam(2,ifield)))
             if (nobs.gt.0) then
               text=' Observed '//fldnam(2,ifield)(1:lenfld)
               lenstr=lnblk(text,len(text))
               call diagn (fobs,nobs,z(k),tmap,text(1:lenstr),iprt)
             endif
             if (nobs.gt.1) stdobs = stdobs + fsdv
c
             if (((iclima.eq.1).or.(iclima.eq.2)).and.(nclm.gt.0)) then
                stdclm = clmerr
                text=' Climatology '//fldnam(2,ifield)(1:lenfld)
                lenstr=lnblk(text,len(text))
                call diagn (fclm,nclm,z(k),tmap,text(1:lenstr),iprt)
                if (nclm.gt.1) stdclm = stdclm + fsdv
             endif
c
#ifdef sunflush
             call flush(iprt)
c
#endif
c-----------------------------------------------------------------------
c  Compute OAed mean FMEAN at each interpolation point.
c-----------------------------------------------------------------------
c
             call large_scales
             call oamean (fmean,obsmean,fobs,xobs,yobs,tobs,nobs,fclm,
     &                    xclm,yclm,tclm,nclm,iclima,tmap,spval,iprt,
#ifndef pfjlerr
     &                                                         fnd_mean)
#else
     &                                                   fnd_mean,emean)
#endif
             call synop_scales
c
c-----------------------------------------------------------------------
c  Performs the OA.  The mapped field and its associated error is
c  stored in FMAP and EMAP, respectively. Accumulate the variance of
c  the interpolated field that is used to dimensionalize the error
c  field.
c-----------------------------------------------------------------------
c
             if ((nobs.gt.0).and.fnd_mean) then
               do 10 n=1,nobs
                  fper(n)=fobs(n)-obsmean(n)
 10            continue
               corsiz=nobs*nobs
               call oamap (cobs,aobs,corsiz,wobs,nobs,xobs,yobs,tobs,
     &                     fper,work,imjm,xmap,ymap,tmap,method,fmap,
     &                     emap,cclm)
               do 20 i=1,imjm
                  fmap(i)=fmap(i)+fmean(i)
#ifdef pfjlerr
                  emap(i)=emap(i)*emean(i)
#endif
 20            continue
               fnd_field=.true.
             elseif (fnd_mean) then
               do 30 i=1,imjm
                  fmap(i)=fmean(i)
                  emap(i)=c1
 30            continue
               fnd_field=.true.
               write(iprt,910) fldnam(2,ifield)(1:lenfld),z(k),tmap
             else
               fnd_field=.false.
               write(iprt,920) fldnam(2,ifield)(1:lenfld),z(k),tmap
             endif
c
c-----------------------------------------------------------------------
c  If a field was constructed, proceed.  Otherwise skip to next field.
c-----------------------------------------------------------------------
c
             if (fnd_field) then
c
c-----------------------------------------------------------------------
c  If requested, Shapiro filter the interpolated field.
c-----------------------------------------------------------------------
c
               if (nfrq.gt.0) then
                  do 40 i=1,nfrq
                     call filter (fmap,im,im,jm,nord)
 40               continue
               endif
c
c-----------------------------------------------------------------------
c  Dimensionalize the error fields.  The OA errors are originally
c  nondimensionalized by the field variance.
c-----------------------------------------------------------------------
c
               call errscl (nobs,stdobs,nclm,stdclm,imjm,emap,fmaprms)
               do 50 i=1,imjm
                  emap(i)=sqrt(emap(i))*fmaprms
 50            continue
c
c-----------------------------------------------------------------------
c  Calculate and print the diagnostics of the interpolation: field,
c  mean, and error.
c-----------------------------------------------------------------------
c
               text=' Interpolated '//fldnam(2,ifield)(1:lenfld)
               lenstr=lnblk(text,len(text))
               call diagn (fmap,imjm,z(k),tmap,text(1:lenstr),iprt)
c
               text=' Mean '//fldnam(2,ifield)(1:lenfld)
               lenstr=lnblk(text,len(text))
               call diagn (fmean,imjm,z(k),tmap,text(1:lenstr),iprt)
c
               text=fldnam(2,ifield)(1:lenfld)//' OA Error'
               lenstr=lnblk(text,len(text))
               call diagn (emap,imjm,z(k),tmap,text(1:lenstr),iprt)
c
               text=fldnam(2,ifield)(1:lenfld)//' RMS deviation'
               lenstr=lnblk(text,len(text))
               write (iprt,930) text(1:lenstr),fmaprms
c
#ifdef sunflush
c-----------------------------------------------------------------------
c  Flush output buffers.
c-----------------------------------------------------------------------
c
               call flush(iprt)
c
#endif
c-----------------------------------------------------------------------
c  Write out fields into NetCDF file.  Synchronize output NetCDF file to
c  disk to allow other processes to access data immediatelly after it is
c  written.
c-----------------------------------------------------------------------
c
               call ncvpt (ncoutid,timeid,start(4),count(4),tmap,rcode)
               if(rcode.ne.0) then
                  write(iprt,940) 'time',k,l
                  call exitus ('OAGMAIN')
               endif
               call ncvpt(ncoutid,ncfldid(j),start,count,fmap,rcode)
               if(rcode.ne.0) then
                  write(iprt,940) fldnam(2,ifield)(1:lenfld),k,l
                  call exitus ('OAGMAIN')
               endif
               call ncvpt(ncoutid,ncerrid(j),start,count,emap,rcode)
               if(rcode.ne.0) then
                  write(iprt,940) fldnam(2,ifield)(1:lenfld)//' error',
     &                                                               k,l
                  call exitus ('OAGMAIN')
               endif
               call ncvpt1(ncoutid,ncrmsid(j),start2,fmaprms,rcode)
               if(rcode.ne.0) then
                 write(iprt,940) fldnam(2,ifield)(1:lenfld)//
     &                           ' RMS deviation',k,l
                 call exitus ('OAMAIN')
               endif
               call ncvpt(ncoutid,ncavgid(j),start,count,fmean,rcode)
               if(rcode.ne.0) then
                  write(iprt,940)'mean '//fldnam(2,ifield)(1:lenfld),k,l
                  call exitus ('OAGMAIN')
               endif
               call ncsnc(ncoutid,rcode)
               if(rcode.ne.0) then
                  write(iprt,950) k,l
                  call exitus ('OAGMAIN')
               endif
c
             endif
c
  60       continue
  70     continue
  80   continue
c
c-----------------------------------------------------------------------
c  Close all data files.
c-----------------------------------------------------------------------
c
       call exitus ('OAG DONE')
c
#ifdef sunfpe
 900   format(/'OAGMAIN - Warning:  ieee_handler cannot set my_handler'/
     &        )
#endif
 910   format(/'OAGMAIN - Warning:  no observations - using mean field'/
     &        16x,'field:  ',a/12x,'depth (m):  ',1pg16.8/
     &        10x,'time (jday):  ',1pg16.8)
 920   format(/'OAGMAIN - Warning:  unable to compute mean field - ',
     &         'no mapping will be done.'/16x,'field:  ',a/
     &        12x,'depth (m):  ',1pg16.8/10x,'time (jday):  ',1pg16.8)
 930   format (2x,a,' = ',1pg16.8//)
 940   format(/' OAGMAIN - error while writing field: ',a,2x,
     &          ' at level INDEX = ',i3,' and time INDEX = ',i3)
 950   format(/' OAGMAIN - unable to synchronize output NetCDF to disk',
     &          ' at level INDEX = ',i3,' and time INDEX = ',i3)
c
       end
