       subroutine oamean (mapmean,obsmean,fobs,xobs,yobs,tobs,nobs,fclm,
     &                       xclm,yclm,tclm,nclm,iclima,tmap,spval,iprt,
#ifndef pfjlerr
     &                                                            found)
#else
     &                                                   found,maperror)
#endif
c
c=======================================================================
c                                                                    ===
c  This routine computes the mean FMEAN at each OA grid point and    ===
c  the mean  OBSMEAN  at each influential observation point.  The    ===
c  climatology  data is  used in the  computation of  these means    ===
c  when the switch ICLIMA is activated.                              ===
c                                                                    ===
c  On Input:                                                         ===
c                                                                    ===
c     FOBS     observation field (real array)                        ===
c     XOBS     X position of observation (real array)                ===
c     YOBS     Y position of observation (real array)                ===
c     TOBS     time of observation (real array)                      ===
c     NOBS     number of observations (integer)                      ===
c     FCLM     climatological field (real array)                     ===
c     XCLM     X position of climatology (real array)                ===
c     YCLM     Y position of climatology (real array)                ===
c     TCLM     time of climatology (real array)                      ===
c     NCLM     number of observations (integer)                      ===
c     ICLIMA   weighted mean computation option (integer):           ===
c              [0] use observations only                             ===
c              [1] use climatology only                              ===
c              [2] use both observations and climatology             ===
c              [3] global observation mean                           ===
c     TMAP     time of interpolation (real)                          ===
c     SPVAL    special value for flagged out data (real)             ===
c     IPRT     output logical unit (integer)                         ===
c                                                                    ===
c  On Output:                                                        ===
c                                                                    ===
c     MAPMEAN  mean at each OA grid point (real array)               ===
c     OBSMEAN  mean at each observation point (real array)           ===
c     FOUND    flag to indicate success at finding mean (logical)    ===
c              [true]  mean was successfully found                   ===
c              [false] mean was not found                            ===
c                                                                    ===
c  Required common blocks:                                           ===
c                                                                    ===
c     CORSCL, OAGRID, OBSCOR                                         ===
c                                                                    ===
c  Calls:  OAMAP                                                     ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <param.h>
#include <corscl.h>
#include <oagrid.h>
#include <obscor.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer corsiz,i,icclm,iclima,icobs,iprt,n,nclm,nobs
      logical found,opt0,opt1,opt2,opt3
      real c0,c1,c2,clmavg,coss,favg,obsavg,sins,spval,sum,tdcays,tmap,
     &     uphs,vphs,xdcays,xzeros,ydcays,yzeros
      real fclm(nclm),fobs(nobs),fper(mobs),maperror(mgrd),
     &     mapmean(mgrd),obserror(mobs),obsmean(nobs),tclm(nclm),
     &     tobs(nobs),wkerror(mgrd),wkmean(mgrd),work(mobs),xclm(nclm),
     &     xobs(nobs),yclm(nclm),yobs(nobs)
      parameter (c0=0.0,c1=1.0,c2=2.0)
      save xzeros,yzeros,xdcays,ydcays,tdcays,uphs,vphs,coss,sins
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c-----------------------------------------------------------------------
c  Compute data (observations plus climatology) average, FAVG.
c-----------------------------------------------------------------------
c
c  Observations average.
c
       obsavg=c0
       sum=c0
       icobs=0
       do 10 n=1,nobs
         if (fobs(n).ne.spval) then
           sum=sum+fobs(n)
           icobs=icobs+1
         endif
  10   continue
       if (icobs.gt.0) obsavg=sum/float(icobs)
c
c  Climatology average.
c
       if ((iclima.eq.1).or.(iclima.eq.2)) then
         clmavg=c0
         sum=c0
         icclm=0
         do 20 n=1,nclm
           if (fclm(n).ne.spval) then
             sum=sum+fclm(n)
             icclm=icclm+1
           endif
  20     continue
         if (icclm.gt.0) clmavg=sum/float(icclm)
       endif
c
c-----------------------------------------------------------------------
c  Determine ability & method to compute mean field.
c-----------------------------------------------------------------------
c
      opt0=((iclima.eq.0).and.(icobs.gt.0)) .or.
     &     ((iclima.eq.2).and.(icobs.gt.0).and.(icclm.le.0))
c
      opt1=((iclima.eq.1).and.(icclm.gt.0)) .or.
     &     ((iclima.eq.2).and.(icobs.le.0).and.(icclm.gt.0))
c
      opt2=(iclima.eq.2).and.(icobs.gt.0).and.(icclm.gt.0)
c
      opt3=(iclima.eq.3).and.(icobs.gt.0)
c
      found=opt0 .or. opt1 .or. opt2 .or. opt3
c
c=======================================================================
c  Objectively analize observations and/or climatology to compute
c  mean field FMEAN.
c=======================================================================
c
c  Mean field computed from synoptic observations only.
c
       if (opt0) then
         favg=obsavg
         do 30 n=1,nobs
           if (fobs(n).eq.spval) then
             fper(n)=c0
           else
             fper(n)=fobs(n)-favg
           endif
  30     continue
         corsiz=nobs*nobs
         call oamap (ccobs,acobs,corsiz,wcobs,nobs,xobs,yobs,tobs,fper,
     &         work,nobs,xobs,yobs,tmap,method,obsmean,obserror,aclm)
         call oamap (ccobs,acobs,corsiz,wcobs,nobs,xobs,yobs,tobs,fper,
     &         work,imjm,xmap,ymap,tmap,method,mapmean,maperror,aclm)
c
c  Mean field computed from climatology data only.
c
       elseif (opt1) then
         favg=clmavg
         do 40 n=1,nclm
           if (fclm(n).eq.spval) then
             fper(n)=c0
           else
             fper(n)=fclm(n)-favg
           endif
           tclm(n)=tmap
  40     continue
         corsiz=nclm*nclm
         call oamap (cclm,aclm,corsiz,wclm,nclm,xclm,yclm,tclm,fper,
     &      work,nobs,xobs,yobs,tmap,method,obsmean,obserror,acobs)
         call oamap (cclm,aclm,corsiz,wclm,nclm,xclm,yclm,tclm,fper,
     &      work,imjm,xmap,ymap,tmap,method,mapmean,maperror,acobs)
c
c  Mean field computed from both observations and climatology.
c
       elseif (opt2) then
         favg=(obsavg*float(icobs)+clmavg*float(icclm))/
     &        float(icobs+icclm)
         do 50 n=1,nclm
           if (fclm(n).eq.spval) then
             fper(n)=c0
           else
             fper(n)=fclm(n)-favg
           endif
           tclm(n)=tmap
  50     continue
         corsiz=nclm*nclm
         call oamap (cclm,aclm,corsiz,wclm,nclm,xclm,yclm,tclm,fper,
     &        work,nobs,xobs,yobs,tmap,method,wkmean,wkerror,acobs)
         do 60 n=1,nobs
           if (fobs(n).eq.spval) then
             fper(n)=c0
           else
             fper(n)=fobs(n)-favg
           endif
  60     continue
         corsiz=nobs*nobs
         call oamap (ccobs,acobs,corsiz,wcobs,nobs,xobs,yobs,tobs,fper,
     &        work,nobs,xobs,yobs,tmap,method,obsmean,obserror,aclm)
         do 70 n=1,nobs
           obsmean(n)=(wkerror(n)*obsmean(n)+obserror(n)*wkmean(n))/
     &                (wkerror(n)+obserror(n))
  70     continue
c
         do 80 n=1,nclm
           if (fclm(n).eq.spval) then
             fper(n)=c0
           else
             fper(n)=fclm(n)-favg
           endif
  80     continue
         corsiz=nclm*nclm
         call oamap (cclm,aclm,corsiz,wclm,nclm,xclm,yclm,tclm,fper,
     &        work,imjm,xmap,ymap,tmap,method,wkmean,wkerror,acobs)
         do 90 n=1,nobs
           if (fobs(n).eq.spval) then
             fper(n)=c0
           else
             fper(n)=fobs(n)-favg
           endif
  90     continue
         corsiz=nobs*nobs
         call oamap (ccobs,acobs,corsiz,wcobs,nobs,xobs,yobs,tobs,fper,
     &         work,imjm,xmap,ymap,tmap,method,mapmean,maperror,aclm)
         do 100 i=1,imjm
           mapmean(i)=(wkerror(i)*mapmean(i)+maperror(i)*wkmean(i))/
     &                (wkerror(i)+maperror(i))
           maperror(i)=c2*wkerror(i)*maperror(i)/
     &                 (wkerror(i)+maperror(i))
 100     continue
c
c  Mean field computed from the global observation average.
c
       elseif (opt3) then
         favg=obsavg
         do 110 n=1,nobs
           obsmean(n)=c0
 110     continue
         do 120 i=1,imjm
           mapmean(i)=c0
 120     continue
c
c  Unable to compute mean field.
c
       else
         write(iprt,130)
 130     format(/' OAMEAN : no data available.'/)
       endif
c
c-----------------------------------------------------------------------
c  Construct observation and OA grid mean fields.
c-----------------------------------------------------------------------
c
      if (found) then
         do 140 n=1,nobs
           obsmean(n)=obsmean(n)+favg
 140      continue
         do 150 i=1,imjm
           mapmean(i)=mapmean(i)+favg
#ifdef pfjlerr
           maperror(i)=clmerr + (c1-clmerr)*maperror(i)
#endif
 150     continue
       endif
c
       return
c
c-----------------------------------------------------------------------
c  Activate correlation scales for computing weighted mean.  Store
c  OA mapping correlation scales.
c-----------------------------------------------------------------------
c
      entry large_scales
c
      xzeros=xzero
      yzeros=yzero
      xdcays=xdcay
      ydcays=ydcay
      tdcays=tdcay
      uphs=uphse
      vphs=vphse
      coss=cosang
      sins=sinang
c
      xzero=xzerom
      yzero=yzerom
      xdcay=xdcaym
      ydcay=ydcaym
      tdcay=tdcaym
      uphse=uphsem
      vphse=vphsem
      cosang=cosangm
      sinang=sinangm
      synoptic = 0
c
      return
c
c-----------------------------------------------------------------------
c  Restore saved correlation scales.
c-----------------------------------------------------------------------
c
      entry synop_scales
c
      xzero=xzeros
      yzero=yzeros
      xdcay=xdcays
      ydcay=ydcays
      tdcay=tdcays
      uphse=uphs
      vphse=vphs
      cosang=coss
      sinang=sins
      synoptic = 1
c
      return
      end
