       subroutine oapar
c
c=======================================================================
c                                                                    ===
c  This routine reads from standard input all the OA parameters,     ===
c  flags and options which are stored in the appropriate common      ===
c  blocks.                                                           ===
c                                                                    ===
c  Required common blocks:                                           ===
c                                                                    ===
c    CDESCENT, CLIMA, CORSCL, DEBUG, DOMDAT, HYDOBD, INPPAR,         ===
c    OAGRID, OBSCOR                                                  ===
c                                                                    ===
c  Calls:   DEFCDF, EXITUS, HEADLN, LNBLK, READGRIDS, ROUT_CHK, XY2LL===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <param.h>
#include <cdescent.h>
#include <clima.h>
#include <corscl.h>
#include <debug.h>
#include <domdat.h>
#include <hydobs.h>
#include <inppar.h>
#include <oagrid.h>
#include <obscor.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
       integer i,ip,j,k,lenfn1,lenfn2,lenfn3,lenfn4,lenfn5,lentit
       integer lnblk
       real c0,c1,c2,c9,c360,gdelx,gdely,gridx,gridy,km2cm,km2m,m2km,p5
       double precision pi
       parameter (c1=1.0,c0=0.0,c2=2.0,c9=9.0,c360=360.0,km2cm=100000.0,
     &            km2m=1000.0,m2km=0.001,p5=0.5)
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c  Set angle conversion factors.
c
       pi=4.d0*datan(1.d0)
       deg2rad=pi/180.d0
c
c  Read in title.
c
       read(5,'(a)') title
c
c  Read in input format type for hydrogaphic data:
c
c      [0] unformatted: depth, T, S, dynamic height
c      [1] unformatted: depth, T, S  (CTD, XCTD file)
c      [2] unformatted: depth, T     (XBT, AXBT file)
c      [3] unformatted: depth, dynamic height
c      [4] unformatted: depth, any oceanic field
c      [5] unformatted: any field (a single value)
c      [6] formatted: HOPS hydrographic data format
c
       read(5,*) ihfrmt
       if ((ihfrmt.lt.0).or.(ihfrmt.gt.6)) then
         write(6,10) ihfrmt
  10     format(' OAPAR: illegal input format flag, IHFRMT = ',i4,/)
         call exitus ('OAPAR')
       endif
c
c  Read in option to computed weighted mean:
c
c      [0] use hydrographic observations only
c      [1] use climatologic observations only
c      [2] use both hydrographic and climatologic observations
c      [3] use global observation mean (a single value)
c
       read(5,*) iclima
       if ((iclima.lt.0).or.(iclima.gt.3)) then
         write(6,20) iclima
  20     format(' OAPAR: illegal flag, ICLIMA = ',i4,/)
         call exitus ('OAPAR')
       endif
c
c  Read in input format type for climatological data
c  (same classification as for hydrographic data)
c
       read(5,*) icfrmt
       if ((icfrmt.lt.0).or.(icfrmt.gt.6)) then
         write(6,30) icfrmt
  30     format(' OAPAR: illegal input format flag, ICFRMT = ',i4,/)
         call exitus ('OAPAR')
       endif
c
c  Read in OA grid coordinates flag:  [0] Cartesian (tangential plane)
c                                     [1] unrotated spherical
c                                     [2] rotated spherical
c
       read(5,*) coord
       if ((coord.lt.0).or.(coord.gt.2)) then
         write(6,40) coord
  40     format(' OAPAR: illegal input format flag, COORD = ',i4,/)
         call exitus ('OAPAR')
       endif
c
c  Read in number of points to map in the zonal meridional
c  directions.
c
       read(5,*) im
       read(5,*) jm
       imjm=im*jm
       if (imjm.gt.mgrd) then
         write(6,50) mgrd,imjm
  50     format(' OAPAR: underdimensioned arrays, MGRD, IMJM = ',
     &          2i4,/,'         change file  param.h  and recompile',/)
         call exitus ('OAPAR')
       endif
c
c  Read in zonal and meridional grid spacing (km or degrees).
c
       read(5,*) dx
       read(5,*) dy
c
c  Read in domain centroid longitude and latitude (degrees, west and
c  south values are negative).
c
       read(5,*) clngd
       read(5,*) clatd
c
c  Read in zonal and meridional offset (km or degrees).
c
       read(5,*) delx
       read(5,*) dely
c
c  Read in domain rotation angle (degrees, positive counterclockwise
c  from true EAST).
c
       read(5,*) thetad
       thetad=mod(thetad+c360,c360)
c
c  Read in outlier radius (km).  Observations outside this radius
c  from the center of the domain are thrown away by routine OUTLIER.
c
       read(5,*) rout
c
c  Read in OA solution method switch: [0] direct: LU decomposition
c                                     [1] minimization: CG
c                                     [2] 1D inversion. (Tarantola)
c
       read(5,*) method
       if (method.lt.0.or.method.gt.2) then
         write(6,55) method
 55      format(' OAPAR: illegal method, METHOD = ',i4,/)
         call exitus ('OAPAR')
       endif
c
c  Read in flag for analytical correlation function to use.
c
       read(5,*) icorr
       if (icorr.ne.1) then
         write(6,60) icorr
  60     format(' OAPAR: illegal correlation type, ICORR = ',i4,/)
         call exitus ('OAPAR')
       endif
c
c  Read in zonal and meridional zero-crossing for the analytical
c  correlation between hydrographic observations (km).
c
       read(5,*) xzero
       read(5,*) yzero
c
c  Read in zonal and meridional spatial (km) and temporal (days)
c  decorrelation (or decay) scales for the analytical correlation.
c
       read(5,*) xdcay
       read(5,*) ydcay
       read(5,*) tdcay
c
c  Read in zonal and meridional phase speed (km/day) for the
c  analytical correlation.
c
       read(5,*) uphse
       read(5,*) vphse
c
c  Read in rotation angle (degrees, counterclockwise from EAST) for
c  the analytical correlation.
c
       read(5,*) corang
       corang=mod(corang+c360,c360)
c
c  Read in zonal and meridional zero-crossing scales of the analytical
c  correlation to be used in mean computation (km).
c
       read(5,*) xzerom
       read(5,*) yzerom
c
c  Read in zonal and meridional spatial (km) and temporal (days) decorrelation
c  (decay) scales of the analytical correlation to be used in mean computation.
c
       read(5,*) xdcaym
       read(5,*) ydcaym
       read(5,*) tdcaym
c
c  Read in zonal and meridional phase speed (km/day) for the
c  analytical correlation to be used in mean computation.
c
       read(5,*) uphsem
       read(5,*) vphsem
c
c  Read in rotation angle (degrees, counterclockwise from EAST) for
c  the analytical correlation to be used in mean computation.
c
       read(5,*) corangm
       corangm=mod(corangm+c360,c360)
c
c  Read in observation and climatology error.
c
       read(5,*) obserr
       read(5,*) clmerr
c
c  Read in the order and number of times of the Shapiro filter
c  to be applied to each OA field.  If NFRQ=0, no filtering.
c
       read(5,*) nord
       read(5,*) nfrq
c
c  Read in number and field types to objectively analyze.  The
c  field type classification is:   [0] generic oceanic field
c                                  [1] pressure (depth)
c                                  [2] temperature
c                                  [3] salinity
c                                  [4] dynamic height
c                                  [5] density
c                                  [6] sigma-t
c                                  [7] sound speed
c
       read(5,*) nfld
       if (nfld.gt.mvar) then
         write(6,70) mvar,nfld
  70     format(' OAPAR: underdimensioned arrays, MVAR, NFLD = ',
     &          2i4,/,'        change file  param.h  and recompile',/)
         call exitus ('OAPAR')
       endif
       read(5,*) (idfld(i),i=1,nfld)
       if (ihfrmt.eq.5) then
         nfld=1
         idfld(1)=0
       endif
       ldynht=.false.
       do 80 i=1,nfld
         if (idfld(i).eq.dynhid) ldynht=.true.
  80   continue
c
c  Read in dynamic height computation option (IDHOPT) and level of
c  no motion in meters (ZREF).  This computation is only possible
c  when pressure (or depth), temperature, and salinity are available
c  at input (IHFRMT=0,1) and when requested with IDFLD=4.  The options
c  for IDHOPT are:
c
c      [0]  DO NOT compute
c      [1]  integrate specific volume anomaly from ZREF to the surface
c      [2]  integrate specific volume anomaly from ZREF to the bottom
c      [3]  integrate in both [1] and [2] directions
c      [4]  integrate from the surface to the bottom of the profile
c
       read(5,*) idhopt
       read(5,*) zref
       if ((idhopt.lt.0).or.(idhopt.gt.4)) then
         write(6,90) idhopt
  90     format(' OAPAR: illegal dynamic height option, IDHOPT = ',i4,/)
         call exitus ('OAPAR')
       endif
       if (ihfrmt.ne.6) then
         if ((idhopt.ne.0).and.(ihfrmt.gt.1)) then
           write(6,100)
 100       format(' OAPAR: (S,T,P) are not available for dynamic',
     &            ' height computation',/,'         check flags IHFRMT',
     &            ' and IDHOPT',/)
           call exitus ('OAPAR')
         endif
       endif
       if (icfrmt.ne.6) then
         if ((idhopt.ne.0).and.(icfrmt.gt.1).and.(iclima.ne.0)) then
           write(6,110)
 110       format(' OAPAR: (S,T,P) are not available for dynamic',
     &            ' height computation',/,'         check flags ICFRMT',
     &            ' and IDHOPT',/)
           call exitus ('OAPAR')
         endif
       endif
c
c  Read in number day(s) and day(s) to objective analize.  If OADAY=0,
c  the objective analysis will be centered at the mean observations
c  time.
c
       read(5,*) nday
       if (nday.gt.mday) then
         write(6,120) mday,nday
 120     format(' OAPAR: underdimensioned arrays, MDAY, NDAY = ',
     &          2i4,/,'         change file  param.h  and recompile',/)
         call exitus ('OAPAR')
       endif
       read(5,*) (oaday(k),k=1,nday)
c
c  Read in number levels and level depth(s) to objectively analyze.
c
       read(5,*) nlev
       if (nlev.gt.mlev) then
         write(6,130) mlev, nlev
 130     format(' OAPAR: underdimensioned arrays, MLEV, NLEV=',
     &          2i4,/,'         change file  param.h  and recompile',/)
         call exitus ('OAPAR')
       endif
       read(5,*) (z(k),k=1,nlev)
       if (ihfrmt.eq.5) then
         nlev=1
         z(k)=-c9
       endif
c
c  Read in flag to read in GRIDS NetCDF file, [0] no, [1] yes.
c
       read(5,*) igrids
c
c  Read in flag to write out verbose output in routine OBJAN: [0] no,
c  [1] yes.  If this flag is turn on then OBJAN writes into the echo
c  file a message everytime when there are insufficient influential
c  observations or when the interpolation is unsuccessful because a
c  poor condionted correlation matrix.
c
       read(5,*) iwrt
c
c  Read in output NetCDF filename.
c
       read(5,'(a)') fname(1)
c
c  Read in output (ascii) echo filename.
c
       read(5,'(a)') fname(2)
       open (iprt,file=fname(2),form='formatted',status='unknown')
       call headln (iprt)
c
c  Read in input hydrography data filename.
c
       read(5,'(a)') fname(3)
       if ((0.le.ihfrmt).and.(ihfrmt.le.5)) then
         open (iinp,file=fname(3),form='unformatted',status='old',
     &         err=140)
         goto 160
       elseif (ihfrmt.eq.6) then
         open (iinp,file=fname(3),form='formatted',status='old',
     &         err=140)
         goto 160
       endif
 140   write(6,150) fname(3)
 150   format(' OAPAR: error while opening hydrography file: ',a)
       call exitus ('OAPAR')
 160   continue
c
c  Read in input climatological data filename.
c
       read(5,'(a)') fname(4)
       if ((iclima.eq.1).or.(iclima.eq.2)) then
         if ((0.le.icfrmt).and.(icfrmt.le.5)) then
           open (iclm,file=fname(4),form='unformatted',status='old',
     &           err=170)
           goto 190
         elseif (icfrmt.eq.6) then
           open (iclm,file=fname(4),form='formatted',status='old',
     &           err=170)
           goto 190
         endif
 170     write(6,180) fname(4)
 180     format(' OAPAR: error while opening climatology file: ',a)
         call exitus ('OAPAR')
       endif
 190   continue
c
c  Read in GRIDS NetCDF filename.
c
       read(5,'(a)') fname(5)
c
c-----------------------------------------------------------------------
c  Read in GRIDS NetCDF file.
c-----------------------------------------------------------------------
c
c  The parameters COORD, IM, JM, CLNGD, CLATD, THETAD, DX, DY, DELX,
c  DELY and the (LON,LAT) grid are those read from the GRIDS NetCDF file
c  (if different).
c
       if (igrids.ne.0) call readgrids
c
c-----------------------------------------------------------------------
c  Set coordinate type flag for correlation calculation.
c-----------------------------------------------------------------------
c
       ccoor=coord
c
c-----------------------------------------------------------------------
c  Set OA grid.
c-----------------------------------------------------------------------
c
c  Set the longitude and latitude grid.
c
       if (coord.eq.0) then
         gridx=dx*km2cm
         gridy=dy*km2cm
         gdelx=delx*km2cm
         gdely=dely*km2cm
       elseif ((coord.eq.1).or.(coord.eq.2)) then
         gridx=dx
         gridy=dy
         gdelx=delx
         gdely=dely
       endif
       do 210 j=1,jm
         do 200 i=1,im
           ip=i+(j-1)*im
           call xy2ll (float(i),float(j),coord,im,jm,gridx,gridy,clngd,
     &                 clatd,gdelx,gdely,thetad,lon(ip),lat(ip))
 200     continue
 210   continue
c
c  Set the internal coordinates (Cartesian or spherical) of the mapping
c  which will be used to compute the correlations.
c
c
       do 230 j=1,jm
         do 220 i=1,im
           ip=i+(j-1)*im
           if (coord.eq.0) then
             xmap(ip)=float(i)*dx
             ymap(ip)=float(j)*dy
           elseif ((coord.eq.1).or.(coord.eq.2)) then
             xmap(ip)=lon(ip)
             ymap(ip)=lat(ip)
           endif
 220     continue
 230   continue
c
c  Set correlation rotation sine and cosine terms.
c  (Spherical systems are assumed to be decomposed in the correlation
c   function along geographic latitude/longitude lines)
c
       if (coord.eq.0) then
         sinang=sin((corang-thetad)*deg2rad)
         cosang=cos((corang-thetad)*deg2rad)
         sinangm=sin((corangm-thetad)*deg2rad)
         cosangm=cos((corangm-thetad)*deg2rad)
       elseif ((coord.eq.1).or.(coord.eq.2)) then
         sinang=sin(corang*deg2rad)
         cosang=cos(corang*deg2rad)
         sinangm=sin(corangm*deg2rad)
         cosangm=cos(corangm*deg2rad)
       endif
c
c-----------------------------------------------------------------------
c  Define NetCDF dimensions, variables, and attributes.
c-----------------------------------------------------------------------
c
       call defcdf
c
c-----------------------------------------------------------------------
c  Write out information to echo file.
c-----------------------------------------------------------------------
c
       lentit=lnblk(title,len(title))
       lenfn1=lnblk(fname(1),len(fname(1)))
       lenfn2=lnblk(fname(2),len(fname(2)))
       lenfn3=lnblk(fname(3),len(fname(3)))
       write(iprt,240) title(1:lentit),fname(1)(1:lenfn1),
     &                 fname(2)(1:lenfn2),fname(3)(1:lenfn3)
       if ((iclima.eq.1).or.(iclima.eq.2)) then
         lenfn4=lnblk(fname(4),len(fname(4)))
         write(iprt,250) fname(4)(1:lenfn4)
       endif
       if (igrids.ne.0) then
         lenfn5=lnblk(fname(5),len(fname(5)))
         write(iprt,260) fname(5)(1:lenfn5)
       endif
       if (coord.eq.0) then
         write(iprt,270) coord,im,jm,dx,dy,thetad,clngd,clatd,delx,dely
       elseif (coord.eq.1) then
         write(iprt,280) coord,im,jm,dx,dy,delx,dely
       else
         write(iprt,290) coord,im,jm,dx,dy,thetad,clngd,clatd,delx,dely
       endif
       write(iprt,300) icorr,xzero,yzero,xdcay,ydcay,tdcay,uphse,
     &                 vphse,corang,rout,obserr
       if ((nfrq.gt.0).and.(nord.gt.0)) write(iprt,310) nord,nfrq
c
       if(idhopt.eq.1) then
         write(iprt,320)
       elseif(idhopt.eq.2) then
         write(iprt,330)
       elseif(idhopt.eq.3) then
         write(iprt,340)
       elseif(idhopt.eq.4) then
         write(iprt,350)
       endif
c
       call rout_chk (rout,iprt)
c
 240   format(/2x,'Objective Analysis Parameters:'/
     &  /2x,'      title: ',a
     &  /2x,'Output file: ',a
     &  /2x,'Echo   file: ',a
     &  /2x,'Input  file: ',a)
 250   format(2x,'Climatology: ',a)
 260   format(2x,'GRIDS  file: ',a)
 270   format(
     &  /5x,'                          coordinate type, COORD: ',i1
     &  /5x,'                               (Cartesian)'
     &  /5x,'     number of grid points to interpolate, IM,JM: ',2i5
     &  /5x,'                        grid spacing (km), DX,DY: ',2f10.4
     &  /5x,'             domain rotation angle (deg), THETAD: ', f10.4
     &  /5x,'              transformation centroid, CLNG,CLAT: ',2f10.4
     &  /5x,'          domain centroid offset (km), DELX,DELY: ',2f10.4)
 280   format(
     &  /5x,'                          coordinate type, COORD: ',i1
     &  /5x,'                           (unrotated spherical)'
     &  /5x,'     number of grid points to interpolate, IM,JM: ',2i5
     &  /5x,'                       grid spacing (deg), DX,DY: ',2f10.4
     &  /5x,'         domain centroid offset (deg), DELX,DELY: ',2f10.4)
 290   format(
     &  /5x,'                          coordinate type, COORD: ',i1
     &  /5x,'                            (rotated spherical)'
     &  /5x,'     number of grid points to interpolate, IM,JM: ',2i5
     &  /5x,'                       grid spacing (deg), DX,DY: ',2f10.4
     &  /5x,'             domain rotation angle (deg), THETAD: ', f10.4
     &  /5x,'              transformation centroid, CLNG,CLAT: ',2f10.4
     &  /5x,'         domain centroid offset (deg), DELX,DELY: ',2f10.4)
 300   format(
     &  /5x,'              analytical correlation type, ICORR: ', i5
     &  /5x,'        X and Y zero crossings (km), XZERO,YZERO: ',2f10.4
     &  /5x,'  spatial decorrelation scales (km), XDCAY,YDCAY: ',2f10.4
     &  /5x,'      temporal decorrelation scale (days), TDCAY: ', f10.4
     &  /5x,'  correlation phase speeds (km/day), UPHSE,VPHSE: ',2f10.4
     &  /5x,'       correlation direction angle (deg), CORANG: ', f10.4
     & //5x,'                domain outlier radius (km), ROUT: ', f10.4
     & //5x,'                       observation error, OBSERR: ', f10.4)
 310   format(
     &  /5x,'order and frequency of Shapiro filter, NORD,NFRQ: ',2i5)
 320   format(/40x,'IDHOPT = 1',/,10x,
     & ' integrate specific volume anomaly from ZREF to the surface.')
 330   format(/40x,'IDHOPT = 2',/,10x,
     & ' integrate specific volume anomaly from ZREF to the bottom.')
 340   format(/40x,'IDHOPT = 3',/,10x,
     & ' integrate above and below ZREF.')
 350   format(/40x,'IDHOPT = 4',/,10x,
     & ' integrate from the first level to the bottom of the profile.')
c
c  Write out information about weighted mean.
c
       write(iprt,360)
       if (iclima.eq.0) then
         write(iprt,370) iclima
        elseif (iclima.eq.1) then
         write(iprt,380) iclima
        elseif (iclima.eq.2) then
         write(iprt,390) iclima
        else
         write(iprt,400) iclima
       endif
       write(iprt,410) xzerom,yzerom,xdcaym,ydcaym
       if (iclima.ne.1) write (iprt,420) tdcaym,uphsem,vphsem
       write (iprt,430) corangm
       if ((iclima.eq.1).or.(iclima.eq.2)) write(iprt,440) clmerr
 360   format(//,2x,'Weighted Mean Parameters:',/)
 370   format(
     &   5x,'        weighted mean computation option, ICLIMA: ', i5
     &  /5x,'             (mean from observations only)')
 380   format(
     &   5x,'        weighted mean computation option, ICLIMA: ', i5
     &  /5x,'              (mean from climatology only)')
 390   format(
     &   5x,'        weighted mean computation option, ICLIMA: ', i5
     &  /5x,'        (mean from observations and climatology)')
 400   format(
     &   5x,'        weighted mean computation option, ICLIMA: ', i5
     &  /5x,'        (global observations mean, single value)')
 410   format(
     &   5x,'        X and Y zero crossings (km), XZERO,YZERO: ',2f10.4
     &  /5x,'  spatial decorrelation scales (km), XDCAY,YDCAY: ',2f10.4)
 420   format(
     &   5x,'      temporal decorrelation scale (days), TDCAY: ', f10.4
     &  /5x,'  correlation phase speeds (km/day), UPHSE,VPHSE: ',2f10.4)
 430   format(
     &   5x,'       correlation direction angle (deg), CORANG: ', f10.4)
 440   format(
     &  /5x,'                       climatology error, CLMERR: ', f10.4)
c
#ifdef sunflush
c-----------------------------------------------------------------------
c  Flush output buffers.
c-----------------------------------------------------------------------
c
       call flush(iprt)
c
#endif
       return
       end
