       subroutine xclima (fclm,xclm,yclm,tclm,nclm,lev,ifield,iprt)
c
c=======================================================================
c                                                                    ===
c  This extracts specified field from the climatology data stored    ===
c  in CDAT.                                                          ===
c                                                                    ===
c  On Input:                                                         ===
c                                                                    ===
c     LEV      depth level to extract (integer index for array CDAT) ===
c     IFIELD   field type to extract (integer):                      ===
c              [0] generic oceanic field                             ===
c              [1] pressure (depth)                                  ===
c              [2] temperature                                       ===
c              [3] salinity                                          ===
c              [4] dynamic height                                    ===
c              [5] density                                           ===
c              [6] sigma-t                                           ===
c              [7] sound speed                                       ===
c     IPRT     output logical unit (integer)                         ===
c                                                                    ===
c  On Output:                                                        ===
c                                                                    ===
c     FCLM     climatology field (real array)                        ===
c     XCLM     X position of climatology (real array)                ===
c     YCLM     Y position of climatology (real array)                ===
c     TCLM     time of climatology (real array)                      ===
c     NCLM     number of climatology stations (integer)              ===
c                                                                    ===
c                                                                    ===
c  Required common blocks:                                           ===
c                                                                    ===
c     CLIMA, HYDOBS, OA_NETCDF                                       ===
c                                                                    ===
c  Calls:    EXITUS                                                  ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <param.h>
#include <clima.h>
#include <hydobs.h>
#include <oa_netcdf.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
       logical flagged,tssecfld
       integer i,ifield,iprt,lenstr,lev,n,nclm
       integer lnblk
       real c0,fld,fld1,fld2,fld3
       real fclm(*),tclm(*),xclm(*),yclm(*)
       real svan,svel
       character*14 text
       parameter (c0=0.0)
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
       lenstr=lnblk(fldnam(2,ifield),len(fldnam(2,ifield)))
       text=fldnam(2,ifield)(1:lenstr)
       if (icfrmt.ne.5) then
         write(iprt,10) text(1:lenstr),z(lev)
  10     format(' XCLIMA : Extracting ',a,' at Depth Z = ',f10.2)
       else
         write(iprt,20) text(1:lenstr)
  20     format(' XCLIMA : Extracting ',a)
       endif
c
c  Set switch to compute secundary fields (density anomaly, sigma-t and
c  sound speed) from temperature and salinity.
c
       tssecfld=.false.
       if ((ifield.eq.densid).or.(ifield.eq.sigtid).or.
     &     (ifield.eq.sndsid)) tssecfld=.true.
c
c-----------------------------------------------------------------------
c  Extract or compute the requested field from storage array HDATA.
c-----------------------------------------------------------------------
c
       nclm=0
c
       do 40 i=1,nclmobs
         flagged=.false.
         fld1=spval
         fld2=spval
c
c  Scan over the number of variables for the desired field(s).
c
         nhydvar=cvars(i,0)
         do 30 n=1,nhydvar
           if (tssecfld) then
             if (cvars(i,n).eq.tempid) then
               fld1=cdata(i,lev,n)
             elseif (cvars(i,n).eq.saltid) then
               fld2=cdata(i,lev,n)
             endif
           elseif (cvars(i,n).eq.ifield) then
             fld1=cdata(i,lev,n)
           endif
  30     continue
c
c  Check if the extracted fields are flagged as special value.
c
         if (tssecfld) then
           if ((fld1.eq.spval).or.(fld2.eq.spval)) flagged=.true.
         elseif (fld1.eq.spval) then
           flagged=.true.
         endif
c
c  Load extracted field into working arrays.  If applicable, compute
c  secundary field.
c
         if (.not.flagged) then
           if (ifield.eq.densid) then
             fld3=svan(fld2,fld1,z(lev),fld)
           elseif (ifield.eq.sigtid) then
             fld3=svan(fld2,fld1,c0,fld)
           elseif (ifield.eq.sndsid) then
             fld=svel(fld2,fld1,z(lev))
           else
             fld=fld1
           endif
           nclm=nclm+1
           fclm(nclm)=fld
           xclm(nclm)=xc(i)
           yclm(nclm)=yc(i)
           tclm(nclm)=tc(i)
         endif
  40   continue
c
       if (nclm.eq.0) then
         if (nclmobs.eq.0) then
           write(iprt,50) nclmobs
  50       format(/,' XCLIMA - no observations available, NCLMOBS = ',
     &            i2)
         else
           write(iprt,60) nclmobs
  60       format(/,' XCLIMA - all obsevations are flagged out,',
     &              ' NCLMOBS = ',2i5)
         endif
       else
         write(iprt,70) nclmobs,nclm,nclmobs-nclm
  70     format(10x,'number of input   hydrographic stations = ',i5,/,
     &          10x,'number of usable  hydrographic stations = ',i5,/,
     &          10x,'number of flagged hydrographic stations = ',i5,/)
       endif
c
#ifdef sunflush
c-----------------------------------------------------------------------
c  Flush output buffers.
c-----------------------------------------------------------------------
c
       call flush(iprt)
c
#endif
       return
       end
