       subroutine xhydro (fobs,xobs,yobs,tobs,nobs,lev,ifield,iprt)
c
c=======================================================================
c                                                                    ===
c  This extracts the field to objectively analyze from the           ===
c  observations stored in HDATA.                                     ===
c                                                                    ===
c  On Input:                                                         ===
c                                                                    ===
c     LEV      depth level to extract (integer index for array HDATA)===
c     IFIELD   field type to extract (integer):                      ===
c              [0] generic oceanic field                             ===
c              [1] pressure (depth)                                  ===
c              [2] temperature                                       ===
c              [3] salinity                                          ===
c              [4] dynamic height                                    ===
c              [5] density                                           ===
c              [6] sigma-t                                           ===
c              [7] sound speed                                       ===
c     IPRT     output logical unit (integer)                         ===
c                                                                    ===
c  On Output:                                                        ===
c                                                                    ===
c     FOBS     climatology field (real array)                        ===
c     XOBS     X position of climatology (real array)                ===
c     YOBS     Y position of climatology (real array)                ===
c     TOBS     time of climatology (real array)                      ===
c     NOBS     number of climatology stations (integer)              ===
c                                                                    ===
c                                                                    ===
c  Required common blocks:                                           ===
c                                                                    ===
c     HYDOBS, OA_NETCDF                                              ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <param.h>
#include <hydobs.h>
#include <oa_netcdf.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
       logical flagged,tssecfld
       integer i,ifield,iprt,lenstr,lev,n,nobs
       integer lnblk
       real c0,fld,fld1,fld2,fld3
       real fobs(*),tobs(*),xobs(*),yobs(*)
       real svan,svel
       character*14 text
       parameter (c0=0.0)
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
       lenstr=lnblk(fldnam(2,ifield),len(fldnam(2,ifield)))
       text=fldnam(2,ifield)(1:lenstr)
       if (ihfrmt.ne.5) then
         write(iprt,10) text(1:lenstr),z(lev)
  10     format(' XHYDRO : Extracting ',a,' at depth Z = ',f10.2)
       else
         write(iprt,20) text(1:lenstr)
  20     format(' XHYDRO : Extracting ',a)
       endif
c
c  Set switch to compute secundary fields (density anomaly, sigma-t and
c  sound speed) from temperature and salinity.
c
       tssecfld=.false.
       if ((ifield.eq.densid).or.(ifield.eq.sigtid).or.
     &     (ifield.eq.sndsid)) tssecfld=.true.
c
c-----------------------------------------------------------------------
c  Extract or compute the requested field from storage array HDATA.
c-----------------------------------------------------------------------
c
       nobs=0
c
       do 40 i=1,nhydobs
         flagged=.false.
         fld1=spval
         fld2=spval
c
c  Scan over the number of variables for the desired field(s).
c
         nhydvar=hvars(i,0)
         do 30 n=1,nhydvar
           if (tssecfld) then
             if (hvars(i,n).eq.tempid) then
               fld1=hdata(i,lev,n)
             elseif (hvars(i,n).eq.saltid) then
               fld2=hdata(i,lev,n)
             endif
           elseif (hvars(i,n).eq.ifield) then
             fld1=hdata(i,lev,n)
           endif
  30     continue
c
c  Check if the extracted fields are flagged as special value.
c
         if (tssecfld) then
           if ((fld1.eq.spval).or.(fld2.eq.spval)) flagged=.true.
         elseif (fld1.eq.spval) then
           flagged=.true.
         endif
c
c  Load extracted field into working arrays.  If applicable, compute
c  secundary field.
c
         if (.not.flagged) then
           if (ifield.eq.densid) then
             fld3=svan(fld2,fld1,z(lev),fld)
           elseif (ifield.eq.sigtid) then
             fld3=svan(fld2,fld1,c0,fld)
           elseif (ifield.eq.sndsid) then
             fld=svel(fld2,fld1,z(lev))
           else
             fld=fld1
           endif
           nobs=nobs+1
           fobs(nobs)=fld
           xobs(nobs)=x(i)
           yobs(nobs)=y(i)
           tobs(nobs)=t(i)
         endif
c
  40   continue
c
       if (nobs.eq.0) then
         if (nhydobs.eq.0) then
           write(iprt,50) nhydobs
  50       format(/,' XHYDRO - no observations available, NHYDOBS = ',
     &            i2)
         else
           write(iprt,60) nhydobs
  60       format(/,' XHYDRO - all observations are flagged out,',
     &              ' NHYDOBS = ',2i5)
         endif
       else
         write(iprt,70) nhydobs,nobs,nhydobs-nobs
  70     format(10x,'number of input   hydrographic stations = ',i5,/,
     &          10x,'number of usable  hydrographic stations = ',i5,/,
     &          10x,'number of flagged hydrographic stations = ',i5,/)
       endif
c
#ifdef sunflush
c-----------------------------------------------------------------------
c  Flush output buffers.
c-----------------------------------------------------------------------
c
       call flush(iprt)
c
#endif
       return
       end
