      subroutine getpbn
c
c=======================================================================
c                                                                    ===
c  This routine extracts the indices of the outer boundary, including===
#ifndef surfpress
c  exterior coastlines, for the transport streamfunction boundary.   ===
#else
c  exterior coastlines, for the surface pressure boundary segments.  ===
#endif
c                                                                    ===
#ifdef coast
c  ------                                                            ===
c  Input:                                                            ===
c  ------                                                            ===
c                                                                    ===
c  Common Blocks:                                                    ===
c                                                                    ===
c  /FULLWD/                                                          ===
c                                                                    ===
c     ICOAST     coast x-coordinate.                 (integer array) ===
c     JCOAST     coast y-coordinate.                 (integer array) ===
c     LENCOAST   number of points per coast.         (integer vector)===
c     NCSEG      number of coastal segments.         (integer)       ===
# ifdef islands
c     NISLE      number of islands.                  (integer)       ===
# endif
c                                                                    ===
#endif
c  -------                                                           ===
c  Output:                                                           ===
c  -------                                                           ===
c                                                                    ===
c  Common Blocks:                                                    ===
c                                                                    ===
c  /FULLWD/                                                          ===
c                                                                    ===
#ifndef surfpress
c     IEXT    Extraction I-coords, external bndy.   (integer vector) ===
c     JEXT    Extraction J-coords, external bndy.   (integer vector) ===
c     NOEXT   Length of external boundary.          (integer)        ===
#else
c     IEXT    Extraction I-coords, external bndy.   (integer array)  ===
c     JEXT    Extraction J-coords, external bndy.   (integer array)  ===
c     LENEXT  Length of external bndy segments.     (integer vector) ===
c     NOEXT   Number of external bndy segments.     (integer)        ===
#endif
c                                                                    ===
c  ------                                                            ===
c  Calls:                                                            ===
c  ------                                                            ===
c                                                                    ===
#ifdef coast
c     GET_OPN                                                        ===
#else
c     none                                                           ===
#endif
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <cdefs.h>
#include <param.h>
#include <fullwd.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer n
#ifdef coast
     &        ,nnxt,nxcst
# ifndef surfpress
     &        ,m,nopn
      integer iopn(maxext),jopn(maxext)
# endif
#endif
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
#ifdef coast
c-----------------------------------------------------------------------
c  Compute the number of exterior coasts.
c-----------------------------------------------------------------------
c
# ifndef islands
      nxcst = ncseg
# else
      nxcst = ncseg - nisle
# endif
c
c-----------------------------------------------------------------------
c  Extract exterior boundary points.
c-----------------------------------------------------------------------
c
      if (nxcst.gt.0) then
c
# ifndef surfpress
         noext = 0
# else
         noext = nxcst
# endif
c
         do 20 n = 1, nxcst
c
c  Extract open segment.
c
            if (n.lt.nxcst) then
               nnxt = n + 1
             else
               nnxt = 1
            end if
c
# ifndef surfpress
            call get_opn (icoast(lencoast(n),n),jcoast(lencoast(n),n),
     &                    icoast(1,nnxt),jcoast(1,nnxt),maxext,imt,jmt,
     &                    nopn,iopn,jopn)
c
c    First point actually belongs to preceeding coast,
c    last point actually belongs to following coast.
c
            noext       = noext + 1
            iext(noext) = icoast(1,n)
            jext(noext) = jcoast(1,n)
c
            do 10 m = 2, (nopn-1)
               noext       = noext + 1
               iext(noext) = iopn(m)
               jext(noext) = jopn(m)
  10        continue
# else
            call get_opn (icoast(lencoast(n),n),jcoast(lencoast(n),n),
     &                    icoast(1,nnxt),jcoast(1,nnxt),maxext,imt,jmt,
     &                    lenext(n),iext(1,n),jext(1,n))
# endif
c
  20     continue
c
      else
c
#else
c-----------------------------------------------------------------------
c  Extract exterior boundary points.
c-----------------------------------------------------------------------
c
#endif
#ifndef surfpress
         noext = 0
c
         do 30 n = 1, imt
            noext       = noext + 1
            iext(noext) = n
            jext(noext) = 1
  30     continue
c
         do 40 n = 2, jmt
            noext       = noext + 1
            iext(noext) = imt
            jext(noext) = n
  40     continue
c
         do 50 n = imtm1, 1, -1
            noext       = noext + 1
            iext(noext) = n
            jext(noext) = jmt
  50     continue
c
         do 60 n = jmtm1, 2, -1
            noext       = noext + 1
            iext(noext) = 1
            jext(noext) = n
  60     continue
#else
         noext     = 0
         lenext(1) = 0
c
         do 30 n = 1, imt
            lenext(1)         = lenext(1) + 1
            iext(lenext(1),1) = n
            jext(lenext(1),1) = 1
  30     continue
c
         do 40 n = 2, jmt
            lenext(1)         = lenext(1) + 1
            iext(lenext(1),1) = imt
            jext(lenext(1),1) = n
  40     continue
c
         do 50 n = imtm1, 1, -1
            lenext(1)         = lenext(1) + 1
            iext(lenext(1),1) = n
            jext(lenext(1),1) = jmt
  50     continue
c
         do 60 n = jmtm1, 2, -1
            lenext(1)         = lenext(1) + 1
            iext(lenext(1),1) = 1
            jext(lenext(1),1) = n
  60     continue
#endif
c
#ifdef coast
      endif
c
#endif
      return
      end
