      subroutine psbym1
c
c=======================================================================
c                                                                    ===
c  This routine makes a simplified guess of the surface elevation    ===
c  one point inside the boundary.                                    ===
c                                                                    ===
c  ------                                                            ===
c  Input:                                                            ===
c  ------                                                            ===
c                                                                    ===
c  Common Blocks:                                                    ===
c                                                                    ===
c  /BNDATA/                                                          ===
c                                                                    ===
c     DETATBY  perturbation in boundary surface elevation.           ===
c     PO       surface pressure boundary conditions.                 ===
c     PBC0     surface pressure boundary & near boundary values.     ===
c                                                                    ===
c  /OPTIONS/                                                         ===
c                                                                    ===
c     IOPT    various switches from standard input:                  ===
c             IOPT(3)  type of BCs on surface pressure.              ===
c                                                                    ===
c  /SCALAR/                                                          ===
c                                                                    ===
c     GRAV     acceleration due to gravity.   (cm/s^2)               ===
c                                                                    ===
c  /TIDESP/                                                          ===
c                                                                    ===
c     SRFTD    tidal elevation.   (cm)                               ===
c                                                                    ===
c  -------                                                           ===
c  Output:                                                           ===
c  -------                                                           ===
c                                                                    ===
c  Common Blocks:                                                    ===
c                                                                    ===
c  /BNDATA/                                                          ===
c                                                                    ===
c     DETATBY  perturbation in bndy & near bndy surface elevation.   ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <cdefs.h>
#include <param.h>
#include <pconst.h>
#include <bndata.h>
#include <options.h>
#include <scalar.h>
#if defined freesurf & defined ext_tide & !defined mixtideonly 
# include <tidesp.h>
#endif
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer i,j
c
c=======================================================================
c  Begin executable code
c=======================================================================
c
c-----------------------------------------------------------------------
c  If not already computed, determine difference between provided
c  values at boundary and chosen BCs for surface pressure.
c-----------------------------------------------------------------------
c
      if (iopt(3).ne.7) then
         do 10 j = 1, jmt
            detatby(j,1,itbp,west) = (po(j,1,west)-pbc0(j,1,itbp,west))
     &                               /grav
            detatby(j,1,itbp,east) = (po(j,1,east)-pbc0(j,1,itbp,east))
     &                               /grav
#if defined freesurf & defined ext_tide & !defined mixtideonly 
            detatby(j,1,itbp,west) = detatby(j,1,itbp,west) -
     &                               srftd(1,j,itda)
            detatby(j,1,itbp,east) = detatby(j,1,itbp,east) -
     &                               srftd(imt,j,itda)
#endif
  10     continue
c
         do 20 i = 1, imt
            detatby(i,1,itbp,south)=(po(i,1,south)-pbc0(i,1,itbp,south))
     &                              /grav
            detatby(i,1,itbp,north)=(po(i,1,north)-pbc0(i,1,itbp,north))
     &                              /grav
#if defined freesurf & defined ext_tide & !defined mixtideonly 
            detatby(i,1,itbp,south) = detatby(i,1,itbp,south) -
     &                                srftd(i,1,itda)
            detatby(i,1,itbp,north) = detatby(i,1,itbp,north) -
     &                                srftd(i,jmt,itda)
#endif
  20     continue
      endif
c
c-----------------------------------------------------------------------
c  Away from corners, use no-normal extension.
c-----------------------------------------------------------------------
c
      do 30 j = 3, jmtm2
         detatby(j,2,itbp,west) = detatby(j,1,itbp,west)
         detatby(j,2,itbp,east) = detatby(j,1,itbp,east)
  30  continue
c
      do 40 i = 3, imtm2
         detatby(i,2,itbp,south) = detatby(i,1,itbp,south)
         detatby(i,2,itbp,north) = detatby(i,1,itbp,north)
  40  continue
c
c-----------------------------------------------------------------------
c  Fill corners w/ identities & compromises.
c-----------------------------------------------------------------------
c
c SW corner
c
      detatby(1,2,itbp,west)  = detatby(2,1,itbp,south)
      detatby(1,2,itbp,south) = detatby(2,1,itbp,west)
      detatby(2,2,itbp,west)  = p5*(detatby(2,1,itbp,west) +
     &                              detatby(2,1,itbp,south))
      detatby(2,2,itbp,south) = detatby(2,2,itbp,west)
c
c SE corner
c
      detatby(1,2,itbp,east)      = detatby(imtm1,1,itbp,south)
      detatby(imt,2,itbp,south)   = detatby(2,1,itbp,east)
      detatby(2,2,itbp,east)      = p5*(detatby(2,1,itbp,east) +
     &                                  detatby(imtm1,1,itbp,south))
      detatby(imtm1,2,itbp,south) = detatby(2,2,itbp,east)
c
c NW corner
c
      detatby(jmt,2,itbp,west)   = detatby(2,1,itbp,north)
      detatby(1,2,itbp,north)    = detatby(jmtm1,1,itbp,west)
      detatby(jmtm1,2,itbp,west) = p5*(detatby(jmtm1,1,itbp,west) +
     &                                 detatby(2,1,itbp,north))
      detatby(2,2,itbp,north)    = detatby(jmtm1,2,itbp,west)
c
c NE corner
c
      detatby(jmt,2,itbp,east)    = detatby(imtm1,1,itbp,north)
      detatby(imt,2,itbp,north)   = detatby(jmtm1,1,itbp,east)
      detatby(jmtm1,2,itbp,east)  = p5*(detatby(jmtm1,1,itbp,east) +
     &                                  detatby(imtm1,1,itbp,north))
      detatby(imtm1,2,itbp,north) = detatby(jmtm1,2,itbp,east)
c
      return
      end
