      subroutine baro_velocity
c
c=======================================================================
c                                                                    ===
c  This routine computes  the surface pressure                       ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <cdefs.h>
#include <param.h>
#include <curflds.h>
#include <grddat.h>
#include <iounits.h>
#include <moddat.h>
#include <ndimen.h>
#include <switches.h>
#include <hybrid.h>
#include <zdat.h>
#include <cstseg.h>
#include <convinfo.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer i,ip,ip1,ipi,ipij,ipj,j,jp1,k,kzmax,kzmin
      logical extpsbdy,first
c
#ifdef coast
      integer isz(isesize),iez(isesize)
      real    fkmz(np),fkmp(np),fkmq(np)
#endif
c
      real pv1(np,0:nz),pv2(np,0:nz),corpbar(np)
      real weigh(np),ztd(np),a(np*9),pwork(np),hvex(np)
      real fcori(np),utop(np),vtop(np)

      real sumpv1,sumpv2,zvalav1,zvalav2,zlayth,deltaz,deltaz1,deltaz2,
     *     psiH1,psiH2
      real pbaroS(ijmx),pbaroN(ijmx),pbaroW(ijmx),pbaroE(ijmx),
     &     dxt(ijmx),dxt2r(ijmx),dxu2r(ijmx),dyt(ijmx),dyt2r(ijmx),
     &     dyu2r(ijmx),vmtxoy(np),vmtyox(np)
#ifndef solvercg
      integer ir(np),ia(np+1),ja(9*np)
      real
     *        am(9*np),rp(np),pspar(np)
#else
      double precision
     *        wk(np,4)
#endif
#if defined testinversion | defined localfilter
      real 
     *     xtest(np)
#endif
      real c0,c1,fac,grav,p25,p5,cenlon,dxx,dyy,rdxx,rdyy
      real scle,yoff,cenlat,deg2cm,fx,deg2rad,pi,rearth
      parameter (c0=0.0, c1=1.0, grav=980.6, p25=0.25, p5=0.5,
     &           rearth=6371.315e5,
     *           pi=3.14159 26535 89793 23846, deg2rad=pi/180.0,
     *           deg2cm=deg2rad*rearth)
c
      save first,dxt,dxt2r,dxu2r,dyt,dyt2r,dyu2r,vmtxoy,vmtyox
c
      data first /.true./
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c-----------------------------------------------------------------------
c  On first call, set unchanging spacings etc.
c-----------------------------------------------------------------------
c
      if (first) then
         first = .false.
         if(coord.eq.0)then
            dxx=dx
            dyy=dy
         else
            dxx=dx*deg2cm
            dyy=dy*deg2cm
         endif
         rdxx = p5/dxx
         rdyy = p5/dyy
         do 10 i = 1, im
            dxt(i)   = dxx
            dxt2r(i) = rdxx
            dxu2r(i) = rdxx
  10     continue
         do 20 j = 1, jm
            dyt(j)   = dyy
            dyt2r(j) = rdyy
            dyu2r(j) = rdyy
  20     continue
         do 30 ip = 1, im*jm
            vmtxoy(ip) = vmetx(ip)/vmety(ip)
            vmtyox(ip) = vmety(ip)/vmetx(ip)
  30     continue
      endif
c
c-----------------------------------------------------------------------
c  Start typical work.
c-----------------------------------------------------------------------
c
      if (isesize.lt.jm*lseg) then
         write (stdout,*) 'Set ISESIZE in param.h to at least ',jm*lseg
         call exitus ('BARO_VELOCITY')
      endif
c
      write(stdout,60) dcur
  60  format(/,' Computing external velocity at day = ',
     *     f12.4)
c
c     Pass depth at u points to hvex
c     ------------------------------
c
      do 70 i=1,im
         do 70 j=1,jm
            ip=i+(j-1)*im
            hvex(ip)=hv(ip)
  70     continue
#ifdef coast
c
c     Get the masking indices
c     -----------------------
c
      call mskind(im,jm,km,lseg,landt,isz,iez,isq,ieq,isp,iep,hvex,
     *            fkmz,fkmp,fkmq)
#endif
c
c  If using horizontally uniform T,S; set internal mode velocities to zero
c  and surface pressure constant (zero external mode velocities).
c
      if(job.eq.3) then
        do 80 j=1,jm
        do 80 i=1,im
           ip=i+(j-1)*im
           ubar(ip)=c0
           vbar(ip)=c0
           pbar(ip)=c0
  80    continue
      else
c
c-----------------------------------------------------------------------
c     Set working array
c-----------------------------------------------------------------------
c
c     Compute barotropic velocity:
c     ---------------------------
         do 100 j=1,jm
         do 100 i=1,im
            ip=i+(j-1)*im
            pwork(ip)=c0
            weigh(ip)=c1/hv(ip)
            do 90 k=0,kfld 
               pv1(ip,k)=c0
               pv2(ip,k)=c0
  90        continue
 100     continue
         call grad_ts(im,jm,np,dx,dy,pbar,vmetx,vmety,weigh,vbar,ubar)
c
         do 110 j=1,jm
         do 110 i=1,im
            ip=i+(j-1)*im
            ubar(ip)=-ubar(ip)
 110     continue           
c
c  Prepare parameters to compute Coriolis parameter f
c
         scle=f0
         call xy2ll (p5*float(im+1),p5*float(jm+1),
     *        coord,im,jm,dx,dy,rlng0,
     *        rlat0,delx,dely,thetad,cenlon,cenlat)
c
         if (iflag(6).eq.3) fx=sin(cenlat*deg2rad)
         do 130 j=1,jm
            do 120 i=1,im
               ip=i+(j-1)*im
               if (iflag(6).eq.2) then
                  yoff=(geolat(ip)-cenlat)*deg2cm
                  scle=f0+beta*yoff
               elseif (iflag(6).eq.3) then
                  scle=f0*sin(geolat(ip)*deg2rad)/fx
               endif
               fcori(ip)=scle
 120        continue
 130     continue
         if (psurf.eq.2) then
c
c  Preparing first guess: (1) f/h  pbar 
c
            do 140 ip=1,im*jm
               corpbar(ip)=fcori(ip)*pbar(ip)/h(ip)
 140        continue
c
c Preparing first guess: (2) poteng/h
c
            call ts2poteng
c
c Set initial surface pressure guess
c
            do 150 ip=1,im*jm
               pbar(ip)=corpbar(ip)-poteng(ip)
 150        continue
         else
            fac=v0*dhor*f0
            do 160 ip=1,im*jm
               pbar(ip)=fac*psi(ip,1)
 160        continue
            if(psurf.eq.1) then
               do 170 ip=1,im*jm
                  utop(ip)=ubar(ip)+ui(ip,1)
                  vtop(ip)=vbar(ip)+vi(ip,1)
 170           continue
            endif
         endif
c
c-----------------------------------------------------------------------
c  Preparing RHS: (1) Set internal pressure contribution:
c                     - Integral from -HV to z=0 of GRAD PI.
c
c                     PI= Pressure/rho (kinematic pressure)
c-----------------------------------------------------------------------
c
c  Compute (scaled) internal pressure (PSI) at z-levels
c  Note: original values of streamfunction PSI will be overwritten.
c
         call ts2psi
c
c  Form GRAD PI at all z-levels
c
         fac=v0*dhor*f0
         do 180 ip=1,im*jm
            weigh(ip)=fac
 180     continue
         do 190 k=1,kfld
            call grad_ts(im,jm,np,dx,dy,psi(1,k),vmetx,vmety,
     *           weigh,pv1(1,k),pv2(1,k))
 190     continue
c
c  Integrate Grad PI from surface to depth of (velocity-point) topography 
c
         do 240 j=1,jm
            do 230 i=1,im
c
               sumpv1=c0
               sumpv2=c0
               ip=i+(j-1)*im
c
               kzmin=1
               do 200 k=1,kfld
                  if(-zfld(k).gt.c0) then
                     kzmin=kzmin+1
                  endif
 200           continue
c
               kzmax=kfld
               do 210 k=kfld,1,-1
                  if(abs(zfld(k)).ge.abs(hv(ip))) then
                     kzmax=kzmax-1
                  endif
 210           continue
c
c            Interior points:
c
               do 220 k=kzmin,kzmax-1
                  zlayth=abs(zfld(k+1)-zfld(k))
                  zvalav1=p5*(pv1(ip,k  )+pv1(ip,k+1))
                  sumpv1=sumpv1+zvalav1*zlayth
                  zvalav2=p5*(pv2(ip,k  )+ pv2(ip,k+1))
                  sumpv2=sumpv2+zvalav2*zlayth
 220           continue
c
c     If top grid pt. above H=0 and/or bottom pt. below
c     H=H_max:
c
               if(abs(zfld(kzmin)).gt.c0) then
                  deltaz=abs(zfld(kzmin))
                  sumpv1=sumpv1+deltaz*pv1(ip,kzmin)
                  sumpv2=sumpv2+deltaz*pv2(ip,kzmin)
               endif
c
               if(abs(zfld(kzmax)).lt.abs(hv(ip))) then
                  if(kzmax.lt.kfld)then
                     deltaz1=abs(hv(ip))-abs(zfld(kzmax))
                     deltaz2=abs(zfld(kzmax+1))-abs(hv(ip))

                     psiH1=pv1(ip,kzmax+1)*deltaz1+
     *                    pv1(ip,kzmax  )*deltaz2
                     psiH1=psiH1/(deltaz1+deltaz2)
                     zvalav1=p5*(psiH1+pv1(ip,kzmax))
                     sumpv1=sumpv1+zvalav1*deltaz1

                     psiH2=pv2(ip,kzmax+1)*deltaz1+
     *                    pv2(ip,kzmax  )*deltaz2
                     psiH2=psiH2/(deltaz1+deltaz2)
                     zvalav2=p5*(psiH2+pv2(ip,kzmax))
                     sumpv2=sumpv2+zvalav2*deltaz1
                  else
                     deltaz1=abs(hv(ip))-abs(zfld(kzmax))
                     sumpv1=sumpv1+pv1(ip,kzmax)*deltaz1
                     sumpv2=sumpv2+pv2(ip,kzmax)*deltaz1
                  endif
               endif
               pv1(ip,0)=-sumpv1
               pv2(ip,0)=-sumpv2
 230        continue
 240     continue
c
c-----------------------------------------------------------------------
c  Preparing RHS: (2) Set Coriolis terms contribution:
c                     -f[-V,U]
c-----------------------------------------------------------------------
c
         do 250 ip=1,im*jm
            pv1(ip,0)= fcori(ip)*vbar(ip)*hv(ip)+pv1(ip,0)
            pv2(ip,0)=-fcori(ip)*ubar(ip)*hv(ip)+pv2(ip,0)
            weigh(ip)=c1
 250     continue
c
c-----------------------------------------------------------------------
c  Construct Dirichlet BCs from RHS
c-----------------------------------------------------------------------
c
         if (psurf.eq.1) call psrfbdy (pv2,pv1)
c
c-----------------------------------------------------------------------
c Compute  RHS: ZTD= cos(lat_u) div(PV1,pv2)
c     PV=-Int_Hv^0 GRAD PI DZ -f[-V,U]
c-----------------------------------------------------------------------
c
c  [DXX,DYY]= [grid-east,grid-north] spacing (cm) and WEIGH=cos(lat_u)
c
         if(coord.eq.0)then
            dxx=dx
            dyy=dy
         else
            dxx=dx*deg2cm
            dyy=dy*deg2cm
         endif
c
         do 260 ip=1,jm*im
            weigh(ip)=vmetx(ip)/vmety(ip)
 260     continue
c
#ifdef coast
         call div(im,jm,lseg,dxx,dyy,weigh,isp,iep,pv1,pv2,ztd)
#else
         call div(im,jm,dxx,dyy,weigh,pv1,pv2,ztd)
#endif
c           
c-----------------------------------------------------------------------
c  Reset open segments, if requested.
c-----------------------------------------------------------------------
c
      extpsbdy = .false.
c
      if ((openps.eq.2).and.(nisle.lt.nseg))  then
         write (stdout,910)
         call setpsopn (pbar,im,jm,np)
         extpsbdy = .true.
       elseif (((openps.eq.2).and.(nisle.eq.nseg)).or.usepsby)  then
         write (stdout,910)
         call spresobdy (pbar,im,jm,np)
         extpsbdy = .true.
      end if
c           
c-----------------------------------------------------------------------
c  Get the Dirichlet (if any) boundary conditions.
c-----------------------------------------------------------------------
c
         do 280 j=1,jm
            do 270 i=1,im
               ip=i+(j-1)*im
               if(i.eq.1) pbaroW(j)=pbar(ip)
               if(i.eq.im) pbaroE(j)=pbar(ip)
               if(j.eq.1) pbaroS(i)=pbar(ip)
               if(j.eq.jm) pbaroN(i)=pbar(ip)
 270        continue
 280     continue
c
c Fill interior wet points of PWORK with first guess (PBAR)
c
         call init_pbar(pwork,pbar,im,jm
#ifdef coast
     *                  ,lseg,isp,iep
#endif
     *                  )
c
c-----------------------------------------------------------------------
c  Get boundary conditions and fill-in the working array.
c-----------------------------------------------------------------------
c
c  Update the time change  at the southern and  northern boundaries.
c
         do 290 i=1,im
            pwork(i)=pbaroS(i)
            ip=i+(jm-1)*im
            pwork(ip)=pbaroN(i)
 290     continue
c
#ifdef cyclic
c
c  Set Cyclic boundary conditions.
c
         do 300 j=1,jm
            ip=(j-1)*im+1
            ip1=(j-1)*im+im-1
            pwork(ip)=pwork(ip1)
            ip=(j-1)*im+im
            ip1=(j-1)*im+2
            pwork(ip)=pwork(ip1)
 300     continue
#else
c
c  Update the time change of stream function at the western and
c  eastern boundaries.
c
         do 300 j=1,jm
            ip=1+(j-1)*im
            pwork(ip)=pbaroW(j)
            ip1=im+(j-1)*im
            pwork(ip1)=pbaroE(j)
 300     continue
#endif
#ifdef testsolver
         write(tst2out) im,jm,km,lseg,dx,dy,coord,deg2cm
         do 320 j=1,jm
            do 310 i=1,im
               ip=i+(j-1)*im
               write(tst5out) vmetx(ip),vmety(ip)
               write(tst4out) hv(ip)
               if(i.eq.1)
     $              write(tst6out) pbaroW(j),pbaroE(j)
               if(j.eq.1)
     $              write(tst7out) pbaroN(i),pbaroS(i)
 310        continue
 320     continue   
#endif
c
c-----------------------------------------------------------------------
c  Call Elliptic solver.
c-----------------------------------------------------------------------
c
         write(stdout,*)
         write(stdout,*)
     $        '==============================================='
         write(stdout,*)
     $        ' Convergence Information for Surface Pressure  '
         write(stdout,*)
     $        '==============================================='
         write(stdout,*)
         write(stdout,*) 
#ifndef solvercg
     $        'Solving the equations with PCG '
#else
     $        'Solving the equations with CG '
#endif
         write(stdout,*)
         write(stdout,*) 'Relative tolerance=',tolrel
         write(stdout,*) 'Absolute tolerance=',tolabs
         write(stdout,*)
c
c
         call Press_solve (im,jm,dxt2r,dxu2r,dyt2r,dyu2r,hvex,vmtxoy,
     &                     vmtyox,a,pwork,ztd,
#ifdef coast
     &                     lseg,isq,ieq,isp,iep,
#endif
#ifndef solvercg
     &                     ir,ia,ja,am,rp,pspar
#else
     &                     wk,np
#endif
#if defined testinversion | defined localfilter
     &                     ,xtest
#endif
     &                      )
c
         do 330 ip=1,jm*im
            pbar(ip)=pwork(ip)
 330     continue
c
         write(stdout,900)resini,residu,restarget,mican,maxits
c
      endif
c
c-----------------------------------------------------------------------
c  Remove a mean value from surface pressure.
c-----------------------------------------------------------------------
c
      if (.not.extpsbdy) then
         write (stdout,920)
# ifdef coast
         call rmmean_pbar (im,jm,lseg,pbar,isp,iep,dxt,tmetx,dyt,tmety)
# else
         call rmmean_pbar (im,jm,pbar,dxt,tmetx,dyt,tmety)
# endif
      end if
c
c-----------------------------------------------------------------------
c  If requested, add externally computed component.
c-----------------------------------------------------------------------
c
      if(ptype.eq.2.and.in_ageo.eq.2) then
         do 350 j=1,jm
            do 340 i=1,im
               ip=i+(j-1)*im
               pbar(ip)=pbar(ip)+grav*elev(ip)
 340        continue
 350     continue
      endif
c
c-----------------------------------------------------------------------
c  Reset barotropic velocities to preserve original transport under
c  new free surface.  Only required for free-surface initializations.
c-----------------------------------------------------------------------
c
      if ((ptype.eq.2) .and. (job.eq.0)) then
         do 360 j = 1, jm
            jp1 = min((j+1), jm)
            do 360 i = 1, im
               ip1 = min((i+1), im)
               ip   = i   + (j  -1)*im
               ipi  = ip1 + (j  -1)*im
               ipj  = i   + (jp1-1)*im
               ipij = ip1 + (jp1-1)*im
               hvex(ip) = hv(ip) + p25*(pbar(ip) + pbar(ipi) +
     &                                  pbar(ipj) + pbar(ipij))/grav
               fx = hv(ip)/hvex(ip)
               ubar(ip) = ubar(ip)*fx
               vbar(ip) = vbar(ip)*fx
 360     continue
      end if
c
 900  format (
#ifndef solvercg
     &        'PCG SOLVER'/
#else
     &        ' CG SOLVER'/
#endif
     &        '         Initial residual  ',1pe16.7/
     &        '         Final   residual  ',1pe16.7/
     &        '         Targeted residual ',1pe16.7/
     &        '         Number of iterations ', i10/
     &        '          Max. No. of Iters.  ', i10 )
 910  format (/'Imposing provided Dirichlet surface pressure boundary ',
     &         'values.')
 920  format (/'Removing mean from surface pressure field.')
c
      return
      end
