      subroutine fixpland (im,jm,p)
c
c=======================================================================
c                                                                    ===
c  This routine ensures that the transport streamfunction is         ===
c  constant under land.                                              ===
c                                                                    ===
c  ------                                                            ===
c  Input:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     IM      number of points in the x-direction.    (integer)      ===
c     JM      number of points in the y-direction.    (integer)      ===
c     P       Transport streamfunction.               (real array)   ===
c                                                                    ===
c  Common Blocks:                                                    ===
c                                                                    ===
c  /CSTSEG/                                                          ===
c                                                                    ===
c     CSTSEGX   coast x-coordinate.                  (integer array) ===
c     CSTSEGY   coast y-coordinate.                  (integer array) ===
c     LANDP     transport streamfn land/sea mask.    (integer array) ===
c                                                                    ===
c  -------                                                           ===
c  Output:                                                           ===
c  -------                                                           ===
c                                                                    ===
c     P   Transport streamfunction, constant under land. (real array)===
c                                                                    ===
c  ------                                                            ===
c  Calls:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     none                                                           ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <param.h>
#include <cstseg.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer i,im,ip,j,jm
      real    p(im,jm)
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c-----------------------------------------------------------------------
c  Reset the transport streamfunction under the mask to be the same as
c  the first point on the corresponding coastline.
c-----------------------------------------------------------------------
c
      do 10 j = 1, jm
      do 10 i = 1, im
         ip = i + (j-1)*im
         if (landp(ip).gt.0) then
            p(i,j) = p(cstsegx(1,landp(ip)),cstsegy(1,landp(ip)))
         endif
  10  continue
c
      return
      end
