      subroutine put_bry (nrmbdy)
c
c=======================================================================
c                                                                    ===
c  This routine writes PE output boundary conditions.  The type of   ===
c  boundary condition on PBAR (transport streamfunction) is either   ===
c  specify PBAR at the boundary and next interior points  (IBRY=1)   ===
c  or specify PBAR and d(vorticity)/dt (IBRY=2).                     ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <param.h>
#include <cstseg.h>
#include <curflds.h>
#include <grddat.h>
#include <iounits.h>
#include <moddat.h>
#include <ndimen.h>
#include <pefldid.h>
#include <pi_netcdf.h>
#include <switches.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer mxnz
      parameter (mxnz=mx*nz)
c
      integer i,ip,ip2,j,k,m,n,nrmbdy
      integer ibdy(4),count(6),start(6)
      logical actue,actun,actus,actuw,actve,actvn,actvs,actvw
      real    denom,c0,c2,grav,p25,t1,t2
#ifdef surfpress
     &        ,denx,deny,t3,t4
#endif
      real f(mxnz),pbry(mx,4),qbry(mx,4),tbry(mx,nz,4,mt),ubry(mx,nz,4),
     &     vbry(mx,nz,4)
#ifdef surfpress
     &     ,etavbry(mx,4),pxbry(mx,4),pybry(mx,4),ubby(mx,4),vbby(mx,4)
#endif
      parameter (c0=0.0, c2=2.0, grav=980.6, p25=0.25)
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
      ibdy(west)  = jm
      ibdy(south) = im
      ibdy(east)  = jm
      ibdy(north) = im
      write(stdout,900) dcur
c
c-----------------------------------------------------------------------
c  Set western and eastern boundaries.
c-----------------------------------------------------------------------
c
      do 10 j=1,jm-1
c
c  Compute barotropic vorticity.
c
#ifndef surfpress
        if(iflag(4).eq.2) then
#else
        if((iflag(4).eq.2).and.(ptype.eq.0)) then
#endif
          ip=nrmbdy+(j-1)*im
          t1=(vbar(ip+1   )*vmety(ip+1   )-
     *        vbar(ip     )*vmety(ip     ))+
     *       (vbar(ip+im+1)*vmety(ip+im+1)-
     *        vbar(ip+im  )*vmety(ip+im  ))
          t2=(ubar(ip+im+1)*vmetx(ip+im+1)-
     *        ubar(ip+1   )*vmetx(ip+1   ))+
     *       (ubar(ip+im  )*vmetx(ip+im  )-
     *        ubar(ip     )*vmetx(ip     ))
          pbry(j+1,west)=pbar(ip+im)
          denom=c2*dx*tmetx(ip+im+1)*tmety(ip+im+1)
          qbry(j+1,west)=(t1-t2)/denom
c
          ip=(im-nrmbdy)+(j-1)*im
          t1=(vbar(ip     )*vmety(ip     )-
     *        vbar(ip-1   )*vmety(ip-1   ))+
     *       (vbar(ip+im  )*vmety(ip+im  )-
     *        vbar(ip+im-1)*vmety(ip+im+1))
          t2=(ubar(ip+im  )*vmetx(ip+im  )-
     *        ubar(ip     )*vmetx(ip     ))+
     *       (ubar(ip+im-1)*vmetx(ip+im-1)-
     *        ubar(ip-1   )*vmetx(ip-1   ))
          pbry(j+1,east)=pbar(ip+im+1)
          denom=c2*dx*tmetx(ip+im)*tmety(ip+im)
          qbry(j+1,east)=(t1-t2)/denom
c
c  Set boundary value to transport streamfunction instead.
c
#ifndef surfpress
        else
#else
        elseif(ptype.eq.0) then
#endif
          ip=nrmbdy+j*im
          pbry(j+1,west)=pbar(ip  )
          qbry(j+1,west)=pbar(ip+1)
          ip=im-nrmbdy+1+j*im
          pbry(j+1,east)=pbar(ip  )
          qbry(j+1,east)=pbar(ip-1)
c
#ifdef surfpress
c  Compute surface pressure gradient.
c
        else
          ip = nrmbdy+(j-1)*im
          t1 = pbar(ip+1   )-pbar(ip)
          t2 = pbar(ip+im+1)-pbar(ip+im)
          t3 = pbar(ip+im  )-pbar(ip)
          t4 = pbar(ip+im+1)-pbar(ip+1)
          pbry(j+1,west) = pbar(ip+im)
          denx = c2*dx*vmetx(ip)
          deny = c2*dy*vmety(ip)
          pxbry(j,west) = (t1+t2)/denx
          pybry(j,west) = (t3+t4)/deny
          etavbry(j,west) = p25*(pbar(ip+1   ) + pbar(ip) +
     &                           pbar(ip+im+1) + pbar(ip+im))/grav
c
          ip = (im-nrmbdy)+(j-1)*im
          t1 = pbar(ip+1   )-pbar(ip)
          t2 = pbar(ip+im+1)-pbar(ip+im)
          t3 = pbar(ip+im  )-pbar(ip)
          t4 = pbar(ip+im+1)-pbar(ip+1)
          pbry(j+1,east) = pbar(ip+im+1)
          denx = c2*dx*vmetx(ip)
          deny = c2*dy*vmety(ip)
          pxbry(j,east) = (t1+t2)/denx
          pybry(j,east) = (t3+t4)/deny
          etavbry(j,east) = p25*(pbar(ip+1   ) + pbar(ip) +
     &                           pbar(ip+im+1) + pbar(ip+im))/grav
#endif
        end if
        if(icoast.ne.0) then
          if(landt(nrmbdy+j*im).eq.0) then
            if((landt(nrmbdy+(min(j+2,jm)-1)*im)+
     *          landt(nrmbdy+(j-1)*im)).eq.0) then
              qbry(j+1,west)=c0
            endif
          endif
          if(landt(im-nrmbdy+1+j*im).eq.0) then
            if((landt(im-nrmbdy+1+(min(j+2,jm)-1)*im)+
     *          landt(im-nrmbdy+1+(j-1)*im)).eq.0) then
              qbry(j+1,east)=c0
            endif
          endif
        endif
  10  continue
      pbry(1,west)=pbar(nrmbdy)
      pbry(1,east)=pbar(im-nrmbdy+1)
      qbry(1,west)=qbry(2,west)
      qbry(1,east)=qbry(2,east)
c
c  Set boundary condition for internal velocity and tracers.
c  (Velocity masking mimics that in fsaveu,fsavev.)
c
      do 40 j=1,jm
        ip=nrmbdy+(j-1)*im
        ip2=j*im-nrmbdy
        actuw = (icoast.eq.0) .or. (landv(ip).eq.2) .or.
     &          ( (landv(ip).eq.1).and.
     &            (landv(min(nrmbdy+1,im)+(j-1)*im).eq.1).and.
     &            (landv(max(nrmbdy-1,1 )+(j-1)*im).eq.1) )
        actue = (icoast.eq.0) .or. (landv(ip2).eq.2) .or.
     &          ( (landv(ip2).eq.1).and.
     &            (landv(min(im-nrmbdy+1,im)+(j-1)*im).eq.1).and.
     &            (landv(max(im-nrmbdy-1,1 )+(j-1)*im).eq.1) )
        actvw = (icoast.eq.0) .or. (landv(ip).eq.2) .or.
     &          ( (landv(ip).eq.1).and.
     &            (landv(nrmbdy+(max(j-1,1 )-1)*im).eq.1).and.
     &            (landv(nrmbdy+(min(j+1,jm)-1)*im).eq.1) )
        actve = (icoast.eq.0) .or. (landv(ip2).eq.2) .or.
     &          ( (landv(ip2).eq.1).and.
     &            (landv(max(j-1,1 )*im-nrmbdy).eq.1).and.
     &            (landv(min(j+1,jm)*im-nrmbdy).eq.1) )
        do 30 k=1,km
          if (actuw) then
            ubry(j,k,west)=ui(ip,k)
           else
            ubry(j,k,west)=c0
          endif
          if (actue) then
            ubry(j,k,east)=ui(ip2,k)
           else
            ubry(j,k,east)=c0
          endif
          if (actvw) then
            vbry(j,k,west)=vi(ip,k)
           else
            vbry(j,k,west)=c0
          endif
          if (actve) then
            vbry(j,k,east)=vi(ip2,k)
           else
            vbry(j,k,east)=c0
          endif
          do 20 m=1,nt
            tbry(j,k,west,m)=t(ip,k,m)
            tbry(j,k,east,m)=t(ip2+1,k,m)
  20      continue
  30    continue
#ifdef surfpress
        if (ptype.gt.0) then
          if (actuw) then
            ubby(j,west) = ubar(ip)
           else
            ubby(j,west)  = c0
            pxbry(j,west) = c0
          endif
          if (actue) then
            ubby(j,east) = ubar(ip2)
           else
            ubby(j,east)  = c0
            pxbry(j,east) = c0
          endif
          if (actvw) then
            vbby(j,west) = vbar(ip)
           else
            vbby(j,west)  = c0
            pybry(j,west) = c0
          endif
          if (actve) then
            vbby(j,east) = vbar(ip2)
           else
            vbby(j,east)  = c0
            pybry(j,east) = c0
          endif
        endif
#endif
  40  continue
c
c-----------------------------------------------------------------------
c  Set southern and northern boundaries.
c-----------------------------------------------------------------------
c
      do 50 i=1,im-1
c
c  Compute barotropic vorticity.
c
#ifndef surfpress
        if(iflag(4).eq.2) then
#else
        if((iflag(4).eq.2).and.(ptype.eq.0)) then
#endif
          ip=i+(nrmbdy-1)*im
          t1=(vbar(ip+1   )*vmety(ip+1   )-
     &        vbar(ip     )*vmety(ip     ))+
     &       (vbar(ip+im+1)*vmety(ip+im+1)-
     &        vbar(ip+im  )*vmety(ip+im  ))
          t2=(ubar(ip+im+1)*vmetx(ip+im+1)-
     &        ubar(ip+1   )*vmetx(ip+1   ))+
     &       (ubar(ip+im  )*vmetx(ip+im  )-
     &        ubar(ip     )*vmetx(ip     ))
          pbry(i+1,south) = pbar(ip+1)
          denom = c2*dx*tmetx(ip+im+1)*tmety(ip+im+1)
          qbry(i+1,south) = (t1-t2)/denom
c
          ip=i+((jm-nrmbdy)-1)*im
          t1=(vbar(ip-im+1)*vmety(ip-im+1)-
     &        vbar(ip-im  )*vmety(ip-im  ))+
     &       (vbar(ip+1   )*vmety(ip+1   )-
     &        vbar(ip     )*vmety(ip     ))
          t2=(ubar(ip+1   )*vmetx(ip+1   )-
     &        ubar(ip-im+1)*vmetx(ip-im+1))+
     &       (ubar(ip     )*vmetx(ip     )-
     &        ubar(ip-im  )*vmetx(ip-im  ))
          pbry(i+1,north) = pbar(ip+im+1)
          denom = c2*dx*tmetx(ip+1)*tmety(ip+1)
          qbry(i+1,north) = (t1-t2)/denom
c
c  Set boundary value to transport streamfunction instead.
c
#ifndef surfpress
        else
#else
        elseif(ptype.eq.0) then
#endif
          ip = i+1+(nrmbdy-1)*im
          pbry(i+1,south) = pbar(ip   )
          qbry(i+1,south) = pbar(ip+im)
          ip = (i+1)+(jm-nrmbdy)*im
          pbry(i+1,north) = pbar(ip   )
          qbry(i+1,north) = pbar(ip-im)
c
#ifdef surfpress
c  Compute surface pressure gradient.
c
        else
          ip = i+(nrmbdy-1)*im
          t1 = pbar(ip+1   )-pbar(ip)
          t2 = pbar(ip+im+1)-pbar(ip+im)
          t3 = pbar(ip+im  )-pbar(ip)
          t4 = pbar(ip+im+1)-pbar(ip+1)
          pbry(i+1,south) = pbar(ip+1)
          denx = c2*dx*vmetx(ip)
          deny = c2*dy*vmety(ip)
          pxbry(i,south) = (t1+t2)/denx
          pybry(i,south) = (t3+t4)/deny
          etavbry(i,south) = p25*(pbar(ip+1   ) + pbar(ip) +
     &                            pbar(ip+im+1) + pbar(ip+im))/grav
c
          ip = i+((jm-nrmbdy)-1)*im
          t1 = pbar(ip+1   )-pbar(ip)
          t2 = pbar(ip+im+1)-pbar(ip+im)
          t3 = pbar(ip+im  )-pbar(ip)
          t4 = pbar(ip+im+1)-pbar(ip+1)
          pbry(i+1,north) = pbar(ip+im+1)
          denx = c2*dx*vmetx(ip)
          deny = c2*dy*vmety(ip)
          pxbry(i,north) = (t1+t2)/denx
          pybry(i,north) = (t3+t4)/deny
          etavbry(i,north) = p25*(pbar(ip+1   ) + pbar(ip) +
     &                            pbar(ip+im+1) + pbar(ip+im))/grav
#endif
        endif
        if(icoast.ne.0) then
          if(landt(i+1+(nrmbdy-1)*im).eq.0) then
            if((landt(min(i+2,im)+(nrmbdy-1)*im)+
     *          landt(i+(nrmbdy-1)*im)).eq.0) then
              qbry(i+1,south)=c0
            endif
          endif
          if(landt(i+1+(jm-nrmbdy)*im).eq.0) then
            if((landt(min(i+2,im)+(jm-nrmbdy)*im)+
     *          landt(i+(jm-nrmbdy)*im)).eq.0) then
              qbry(i+1,north)=c0
            endif
          endif
        endif
  50  continue
      pbry(1,south) = pbar(1+(nrmbdy-1)*im)
      pbry(1,north) = pbar(1+(jm-nrmbdy)*im)
      qbry(1,south) = qbry(2,south)
      qbry(1,north) = qbry(2,north)
c
c  Set boundary codition for internal velocity and tracers.
c  (Velocity masking mimics that in fsaveu,fsavev.)
c
      do 80 i=1,im
        ip=i+(nrmbdy-1)*im
        ip2=(jm-nrmbdy-1)*im+i
        actus = (icoast.eq.0) .or. (landv(ip).eq.2) .or.
     &          ( (landv(ip).eq.1).and.
     &            (landv(min(i+1,im)+(nrmbdy-1)*im).eq.1).and.
     &            (landv(max(i-1,1 )+(nrmbdy-1)*im).eq.1) )
        actun = (icoast.eq.0) .or. (landv(ip2).eq.2) .or.
     &          ( (landv(ip2).eq.1).and.
     &            (landv(min(i+1,im)+(jm-nrmbdy-1)*im).eq.1).and.
     &            (landv(max(i-1,1 )+(jm-nrmbdy-1)*im).eq.1) )
        actvs = (icoast.eq.0) .or. (landv(ip).eq.2) .or.
     &          ( (landv(ip).eq.1).and.
     &            (landv(i+(max(nrmbdy-1,1 )-1)*im).eq.1).and.
     &            (landv(i+(min(nrmbdy+1,jm)-1)*im).eq.1) )
        actvn = (icoast.eq.0) .or. (landv(ip2).eq.2) .or.
     &          ( (landv(ip2).eq.1).and.
     &            (landv(i+(max(jm-nrmbdy-1,1 )-1)*im).eq.1).and.
     &            (landv(i+(min(jm-nrmbdy+1,jm)-1)*im).eq.1) )
        do 70 k=1,km
          if (actus) then
            ubry(i,k,south) = ui(ip,k)
           else
            ubry(i,k,south) = c0
          endif
          if (actun) then
            ubry(i,k,north) = ui(ip2,k)
           else
            ubry(i,k,north) = c0
          endif
          if (actvs) then
            vbry(i,k,south) = vi(ip,k)
           else
            vbry(i,k,south) = c0
          endif
          if (actvn) then
            vbry(i,k,north) = vi(ip2,k)
           else
            vbry(i,k,north) = c0
          endif
          do 60 m=1,nt
            tbry(i,k,south,m) = t(ip,k,m)
            tbry(i,k,north,m) = t(ip2,k,m)
  60      continue
  70    continue
#ifdef surfpress
        if (ptype.gt.0) then
          if (actus) then
            ubby(i,south) = ubar(ip)
           else
            ubby(i,south)  = c0
            pxbry(i,south) = c0
          endif
          if (actun) then
            ubby(i,north) = ubar(ip2)
           else
            ubby(i,north)  = c0
            pxbry(i,north) = c0
          endif
          if (actvs) then
            vbby(i,south) = vbar(ip)
           else
            vbby(i,south)  = c0
            pybry(i,south) = c0
          endif
          if (actvn) then
            vbby(i,north) = vbar(ip2)
           else
            vbby(i,north)  = c0
            pybry(i,north) = c0
          endif
        endif
#endif
  80  continue
c
c-----------------------------------------------------------------------
c  Write out boundary information.
c-----------------------------------------------------------------------
c
c  Advance time counter and write out time.
c
      if ((job.ne.1).and.(nrmbdy.eq.1)) then
        tindx=tindx+1
        start(1)=tindx
        count(1)=1
        call ncvpt(ncoutid,timeid,start,count,dcur,rcode)
        if(rcode.ne.0) then
          write(stdout,901) 'time'
          call exitus('PUT_INIT')
        endif
      endif
c
c  Write boundary conditions for each boundary edge.
c
      do 100 n=1,4
        start(2)=1
        count(2)=km
        start(3)=1
        count(3)=ibdy(n)
        start(4)=nrmbdy
        count(4)=1
        start(5)=n
        count(5)=1
        start(6)=tindx
        count(6)=1
c
c  Internal mode velocity.
c
        call fsave(f,mxnz,ubry(1,1,n),mx,nz,ibdy(n),1,km)
        start(1)=xindx
        count(1)=1
        call ncvpt(ncoutid,vbryid,start,count,f,rcode)
        if(rcode.ne.0) then
          write(stdout,902) 'vbry x-component',n
          call exitus('PUT_BRY')
        endif
        call fsave(f,mxnz,vbry(1,1,n),mx,nz,ibdy(n),1,km)
        start(1)=yindx
        count(1)=1
        call ncvpt(ncoutid,vbryid,start,count,f,rcode)
        if(rcode.ne.0) then
          write(stdout,902) 'vbry y-component',n
          call exitus('PUT_BRY')
        endif
c
#ifdef surfpress
c  External mode velocity.
c
        if (ptype.gt.0) then
          count(2)=1
          start(2)=xindx
          call ncvpt(ncoutid,vbbyid,start(2),count(2),ubby(1,n),rcode)
          if(rcode.ne.0) then
            write(stdout,902) 'vbbry x-component',n
            call exitus('PUT_BRY')
          endif
          start(2)=yindx
          call ncvpt(ncoutid,vbbyid,start(2),count(2),vbby(1,n),rcode)
          if(rcode.ne.0) then
            write(stdout,902) 'vbbry y-component',n
            call exitus('PUT_BRY')
          endif
c
          start(2)=xindx
          call ncvpt(ncoutid,qbryid,start(2),count(2),pxbry(1,n),rcode)
          if(rcode.ne.0) then
            write(stdout,902) 'qbry x-component',n
            call exitus('PUT_BRY')
          endif
          start(2)=yindx
          call ncvpt(ncoutid,qbryid,start(2),count(2),pybry(1,n),rcode)
          if(rcode.ne.0) then
            write(stdout,902) 'qbry y-component',n
            call exitus('PUT_BRY')
          endif
          start(2)=1
          count(2)=km
c
          call ncvpt (ncoutid,etvbyid,start(3),count(3),etavbry(1,n),
     &                rcode)
          if(rcode.ne.0) then
            write(stdout,902) 'etav-bry',n
            call exitus('PUT_BRY')
          endif
        endif
c
#endif
c  Tracers.
c
        do 90 m=1,nt
          start(1)=m
          count(1)=1
          call fsave(f,mxnz,tbry(1,1,n,m),mx,nz,ibdy(n),1,km)
          call ncvpt(ncoutid,tbryid,start,count,f,rcode)
          if(rcode.ne.0) then
            write(stdout,903) 'tbry',n,m
            call exitus('PUT_BRY')
          endif
  90    continue
c
#ifndef surfpress
c  Transport streamfunction and time rate of change of vorticity.
#else
c  Transport streamfunction and time rate of change of vorticity
c  or surface pressure and time rate of divergence
#endif
c
        start(1)=1
        count(1)=ibdy(n)
        start(2)=nrmbdy
        count(2)=1
        start(3)=n
        count(3)=1
        start(4)=tindx
        count(4)=1
        call fsave(f,mxnz,pbry(1,n),mx,1,ibdy(n),1,1)
        call ncvpt(ncoutid,pbryid,start,count,f,rcode)
        if(rcode.ne.0) then
          write(stdout,902) 'pbry',n
          call exitus('PUT_BRY')
        endif
        if (ptype.eq.0) then
           call fsave(f,mxnz,qbry(1,n),mx,1,ibdy(n),1,1)
           call ncvpt(ncoutid,qbryid,start,count,f,rcode)
           if(rcode.ne.0) then
             write(stdout,902) 'qbry',n
             call exitus('PUT_BRY')
           endif
        endif
 100  continue
c
c  Synchronize NetCDF data to disk.
c
      call ncsnc(ncoutid,rcode)
      if(rcode.ne.0) then
        write(stdout,904)
        call exitus('PUT_BRY')
      endif
c
 900  format(/' Writing boundary conditions for day = ',f12.4/)
 901  format(/' PUT_BRY - error while writing variable: ',a)
 902  format(/' PUT_BRY - error while writing variable: ',a,
     *        ' at BOUNDARY = ',i1)
 903  format(/' PUT_BRY - error while writing variable: ',a,
     *        ' at BOUNDARY = ',i1,2x,' and TRACER = ',i2)
 904  format(/' PUT_BRY - unable to synchronize data to disk.')
      return
      end
