      subroutine put_qbry (qbry,tind,ibdy,icomp)
c
c=======================================================================
c                                                                    ===
c  This routine writes the time rate of change of either the         ===
c  barotropic vorticity or a component of surface pressure gradient. ===
c                                                                    ===
c  ------                                                            ===
c  Input:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     QBRY    Boundary data.                       (real array)      ===
c     TIND    Time index.                          (integer)         ===
c     IBDY    Length of boundaries.                (integer vector)  ===
c     ICOMP   Component index (zero for scalar).   (integer)         ===
c                                                                    ===
c  Common Blocks:                                                    ===
c                                                                    ===
c  /IOUNITS/                                                         ===
c                                                                    ===
c     STDOUT    Standard output unit.                 (integer)      ===
c                                                                    ===
c  /PI_NETCDF/                                                       ===
c                                                                    ===
c     NCOUTID   NetCDF ID for output file.            (integer)      ===
c     QBRYID    Boundary, time rate of change of                     ===
c               barotropic vorticity or grad(Ps).     (integer)      ===
c                                                                    ===
c  ------                                                            ===
c  Calls:                                                            ===
c  ------                                                            ===
c                                                                    ===
c  HOPS:    EXITUS                                                   ===
c  NetCDF:  NCVPT                                                    ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <param.h>
#include <iounits.h>
#include <pi_netcdf.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer icomp,n,nrm,vecshft,tind
      integer ibdy(4),count(5),start(5)
      real    qbry(mx,4,3)
c
      data count,start /5*1,5*1/
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c-----------------------------------------------------------------------
c  Set dimensionality.
c-----------------------------------------------------------------------
c
      if (icomp.gt.0) then
         vecshft  = 1
         start(1) = icomp
         count(1) = 1
       else
         vecshft = 0
      endif
      start(vecshft+1)=1
      start(vecshft+4) = tind
c
c-----------------------------------------------------------------------
c  Write out boundary information.
c-----------------------------------------------------------------------
c
      do 20 n=1,4
         count(vecshft+1) = ibdy(n)
         start(vecshft+3) = n
         do 10 nrm=1,3
            start(vecshft+2) = nrm
            call ncvpt (ncoutid,qbryid,start,count,qbry(1,n,nrm),rcode)
            if (rcode.ne.0) then
               write(stdout,900) 'qbry',n,(nrm-1)
               call exitus('PUT_QBRY')
            endif
  10     continue
  20  continue
c
      return
c
 900  format (/'***Error:  PUT_QBRY - unable to write variable: ',a,
     &         ' at BOUNDARY = ',i1,', Dnormal = ',i1)
c
      end
