      subroutine reset_vgrid (etat,etav,nlen)
c
c=======================================================================
c                                                                    ===
c  This subroutine resets the depths of each tracer and velocity grid===
c  point in the hybrid (single or double transformation) coordinate  ===
c  system:                                                           ===
c                                                                    ===
c     Common Blocks:                                                 ===
c                                                                    ===
c     /HYBRID/                                                       ===
c                                                                    ===
c     DEPTHMT   the depths (cm) at the middle of the tracer boxes    ===
c               (output; real array)                                 ===
c     DEPTHMV   the depths (cm) at the middle of the velocity boxes  ===
c               (output; real array)                                 ===
c     KP        coordinate interface level (input; integer)          ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <param.h>
#include <hybrid.h>
#include <ndimen.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer imjm,ip,k,km1,nlen
      real    c1,fact,facv,p5
      real etat(nlen),etav(nlen)
c
      parameter (c1=1.0, p5=0.5)
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c-----------------------------------------------------------------------
c  Deform all thicknesses
c-----------------------------------------------------------------------
c
      imjm = im*jm
c
      do 20 ip = 1, imjm
         fact = c1 + etat(ip)/htz(ip)
         facv = c1 + etav(ip)/hvz(ip)
         do 10 k = 1, km
            dztf(ip,k) = fact*dzt(ip,k)
            dzvf(ip,k) = fact*dzv(ip,k)
  10     continue
  20  continue
c
c-----------------------------------------------------------------------
c  Compute total thickness of the deformed water column.
c-----------------------------------------------------------------------
c
      do 30 ip = 1, imjm
         hvzf(ip) = dzvf(ip,1)
  30  continue
c
      do 40 k = 2, km
      do 40 ip = 1, imjm
         hvzf(ip) = hvzf(ip) + dzvf(ip,k)
  40  continue
c
c-----------------------------------------------------------------------
c  Compute depths at the middles of deformed tracer and velocity boxes.
c-----------------------------------------------------------------------
c
      do 50 ip = 1, imjm
         depthmt(ip,1) = p5*dztf(ip,1) - etat(ip)
         depthmv(ip,1) = p5*dzvf(ip,1) - etav(ip)
  50  continue
c
      do 60 k = 2, km
      do 60 ip = 1, imjm
         km1           = k - 1
         depthmt(ip,k) = depthmt(ip,km1) + p5*(dztf(ip,km1)+dztf(ip,k))
         depthmv(ip,k) = depthmv(ip,km1) + p5*(dzvf(ip,km1)+dzvf(ip,k))
  60  continue
c
      return
      end

