      subroutine rsettide
c
c=======================================================================
c                                                                    ===
c  This routine resets the initial barotropic tidal velocity so that ===
c  the total, nonlinear transport divergence balances the tidal rate ===
c  of change of surface elevation.                                   ===
c                                                                    ===
c  ------                                                            ===
c  Input:                                                            ===
c  ------                                                            ===
c                                                                    ===
c  Common Blocks:                                                    ===
c                                                                    ===
c  /CURFLDS/                                                         ===
c                                                                    ===
c     ELEV     sub-tidal surface elevation.                          ===
c     ELVTID   linear tidal surface elevation.  (real array; cm)     ===
c     UBAR     vertically integrated, total u-velocity component.    ===
c     UBTID    barotropic, linear tidal velocity, u-component.       ===
c     VBAR     vertically integrated, total v-velocity component.    ===
c     VBTID    barotropic, linear tidal velocity, v-component.       ===
c                                                                    ===
c  /HYBRID/                                                          ===
c                                                                    ===
c     HV   bathymetry at the velocity points.   (real array; cm)     ===
c                                                                    ===
c  /NDIMEN/                                                          ===
c                                                                    ===
c     IM   number of points in the x-direction.                      ===
c     JM   number of points in the y-direction.                      ===
c                                                                    ===
c  -------                                                           ===
c  Output:                                                           ===
c  -------                                                           ===
c                                                                    ===
c  Common Blocks:                                                    ===
c                                                                    ===
c  /CURFLDS/                                                         ===
c                                                                    ===
c     UBTID    barotropic, linear tidal velocity, u-component.       ===
c     VBTID    barotropic, linear tidal velocity, v-component.       ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <cdefs.h>
#include <param.h>
#include <curflds.h>
#include <hybrid.h>
#include <ndimen.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer i,ip,ip1,ipi,ipj,ipij,j,jp1
      real    grav,p25
      real hv1(np),hv2(np),hvex(np)
c
      parameter (grav=980.6, p25=0.25)
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c-----------------------------------------------------------------------
c  Pass depth at u points to hvex
c-----------------------------------------------------------------------
c
      do 10 j = 1, jm
         jp1 = min((j+1), jm)
         do 10 i = 1, im
            ip1 = min((i+1), im)
            ip   = i   + (j  -1)*im
            ipi  = ip1 + (j  -1)*im
            ipj  = i   + (jp1-1)*im
            ipij = ip1 + (jp1-1)*im
            hv1(ip) = hv(ip) + p25*(pbar(ip) + pbar(ipi) +
     &                               pbar(ipj) + pbar(ipij))/grav
            hv2(ip) = hv1(ip)
     &                 + p25*(elvtid(ip) + elvtid(ipi) + elvtid(ipj)
     &                                                   + elvtid(ipij))
            hvex(ip) = hv2(ip)
  10  continue
c
c-----------------------------------------------------------------------
c  Construct barotropic velocities.
c-----------------------------------------------------------------------
c
c  Add velocity corrections to barotropic tidal velocities.
c
      do 20 ip = 1, im*jm
         ubtid(ip) = ubtid(ip)*hv(ip)/hv2(ip) + ubar(ip)*hv1(ip)/hv2(ip)
     &               - ubar(ip)
         vbtid(ip) = vbtid(ip)*hv(ip)/hv2(ip) + vbar(ip)*hv1(ip)/hv2(ip)
     &               - vbar(ip)
  20  continue
c
      return
      end
