%                         HOPS Land/Sea mask utility.
%                         ===========================
%
% This utility is a graphical user interface enabling the user to easily
% create and modify a land mask for HOPS.  This utility call the mexcdf
% utilities for reading and writing to netCDF files. 
%
% Driver:
%
%   pe_mask     - Processes PE Land/Sea mask data.
%
% Input/Output:
%
%   read_mask   - Reads in Land/Sea mask data from GRIDS NetCDF file.
%   write_mask  - Writes Land/Sea mask data into GRIDS NetCDF file.
%   rcoastline  - Reads coastline data files.
%
% Land/Sea mask:
%
%   set_mask    - Sets Land/Sea mask data.
%   v_mask      - Computes the Land/Sea mask data at the velocity points.
%   xtr_seg     - Extracts non-island coastal segments.
%   xtr_box     - Extracts island coastal segments and bounding boxes.
%   coastline   - Extracts one coastal segment at the time.
%   init_mask   - Constructs an initial guess for the Land/Sea mask.
%   clean_mask  - Cleans the Land/Sea mask.
%   clmsk_itr   - One iteration of basic mask cleaning.
%   med_filt2D  - 2D median filter, used in heavy-duty cleaning
%   get_point   - Get single point of graphical user input.
%
% Graphic Interface:
%
%   pemask_uifn - Initializes and controls graphic buttons.
%   get_hand    - Gets handles to buttons from figure's UserData matrix.
%   get_states  - Gets state flags from figure's UserData matrix.
%   put_states  - Puts new state flag values into figure's UserData matrix.
%   radchk      - Maintains mutual exclusivity of grouped radio buttons.
%   pemsk_hnd   - Function for indexing the handles from UserData matrix.
%   pemsk_ind   - Function for indexing the state flags from UserData matrix.
%
% Coordinate transformation:
%
%   ll2xy       - Spherical to Cartesian.
%   xy2ll       - Cartesian to spherical.
%   get_ewpt    - Determines new Equator in the spherical rotation.
%   rotparm     - Computes parameters associated with the spherical rotation.
%
% Plotting:
%
%   draw_cstp   - Draws coastlines in grid-unit coordinates. 
%   add_cst_xy  - Draws coastlines in grid-units from GSHHS data-set. 
%   plot_cst_xy - Draws a single type of coastline from GSHHS data-set. 
%
% Misc:
%
%   date_stamp  - Current date/time stamp.
%   day_code    - Determines numerical value for day of week from date.
%   pe_seaseg   - Determines the maximum number of sea segments (per
%                 row and per column) defined by the Land/Sea mask.
