function status = add_cst_xy (cstfile,landclr,seaclr,domdat);
%
% function status = add_cst_xy (cstfile,landclr,seaclr,domdat);
%
% This function adds coastlines to a figure, using the new
% netCDF version of GSHHS.  This version adds the coasts
% in the HOPS transformed XY space.
%
% ------
% Input:
% ------
%
%    CSTFILE   Name of netCDF GSHHS coastline data file.
%    LANDCLR   Color to use when drawing land.
%    SEACLR    Color to use when drawing water.
%    DOMDAT    Vector containing domain definition parameters.
%                 DOMDAT( 1) = COORD - grid type
%                 DOMDAT( 2) = LONC  - longitude trans. center
%                 DOMDAT( 3) = LATC  - latitude trans. center
%                 DOMDAT( 4) = THETA - grid rotation angle
%                 DOMDAT( 5) = IM    - number of x-grid points
%                 DOMDAT( 6) = JM    - number of y-grid points
%                 DOMDAT( 7) = DX    - x-grid spacing
%                 DOMDAT( 8) = DY    - y-grid spacing
%                 DOMDAT( 9) = DELX  - x-offset grid-trans. centers
%                 DOMDAT(10) = DELY  - y-offset grid-trans. centers
%
% -------
% Output:
% -------
%
%    STATUS    Exit status.

%-------------------------------------------------------------------------------
% Open coastline netCDF file.
%-------------------------------------------------------------------------------

status = mexcdf ('setopts',0);
status = 0;

ncid = netcdf (cstfile);

if isempty(ncid)
   status = -1
   return;
end;

%-------------------------------------------------------------------------------
% Draw land.
%-------------------------------------------------------------------------------

plot_cst_xy (ncid,'Land',landclr,domdat);

%-------------------------------------------------------------------------------
% Add lakes.
%-------------------------------------------------------------------------------

plot_cst_xy (ncid,'Lake',seaclr,domdat);

%-------------------------------------------------------------------------------
% Add islands in lakes.
%-------------------------------------------------------------------------------

plot_cst_xy (ncid,'Island',landclr,domdat);

%-------------------------------------------------------------------------------
% Add ponds in islands in lakes.
%-------------------------------------------------------------------------------

plot_cst_xy (ncid,'Pond',seaclr,domdat);

%-------------------------------------------------------------------------------
% Close coastline netCDF file.
%-------------------------------------------------------------------------------

dum = close (ncid);
