function masknew = clean_mask (maskold,fullness);
%
% function masknew = clean_mask (maskold,fullness);
%
% This function cleans the land mask:
%
%    (1)  Open Sea points which touch land
%         are changed to land points.
%
%    (2)  Boundary Sea points which don't
%         touch Open Sea are changed to land
%         points.
%
% ------
% Input:
% ------
%
%    MASKOLD....Land mask at tracer points.
%    FULLNESS...Degree of cleaning.  (string)
%               ['Full']      Start with median filter.  Follow up with
%                             direct replacements.  Finish by replacing
%                             LANDT by land portions of ISMASK
%               ['Partial']   Only use direct replacements.  [Default]
%
% -------
% Output:
% -------
%
%    MASKNEW....Corrected land mask at tracer points.

%-------------------------------------------------------------------------------
%  Set default values.
%-------------------------------------------------------------------------------

if (nargin<2),
   fullness = 'Partial';
end;

%-------------------------------------------------------------------------------
%  Fall out if no land.
%-------------------------------------------------------------------------------

if isempty(find(maskold==0)),
   masknew=maskold;
   return
end;

%-------------------------------------------------------------------------------
% If requested, median filter the mask.
%-------------------------------------------------------------------------------

if strcmp (lower(fullness),'full'),
  maskraw        = maskold;
  [maskold,iter] = med_filt2D (maskraw,500,1);
  clear iter maskraw;
end;

%-------------------------------------------------------------------------------
% Use direct replacement on bad points.
%-------------------------------------------------------------------------------

%-------------------------
%--- Initial cleaning. ---
%-------------------------

masknew = clmsk_itr (maskold);

%-------------------------------------------
%--- Loop until steady state is reached. ---
%-------------------------------------------

while (max(max(abs(maskold-masknew)))~=0),
   maskold = masknew;
   masknew = clmsk_itr (maskold);
end;

%-------------------------------------------------------------------------------
% If requested, replace with land portion of ismask.
%-------------------------------------------------------------------------------

if strcmp (lower(fullness),'full'),
   maskwk = ones(size(masknew));
   [vmask,ismask] = v_mask (masknew);
   ind = find(ismask==2);
   if ~isempty(ind),
      maskwk(ind) = zeros(size(ind));
   end;
   masknew = maskwk;
end;
