 function h = draw_cstp (lon,lat,domdat);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                         %
% function h = draw_cstp (lon,lat,domdat);                                %
%                                                                         %
% This function  draws the coastlines within the box defined by           %
% the plotting object. It assumes that the User opened and read           %
% the  appropriate  coastline file  and  that lines outside the           %
% plotting box are clipped.  The coastlines are plotted in grid           %
% index coordinates; it uses routine LL2XY for the conversion.            %
%                                                                         %
% ------                                                                  %
% Input:                                                                  %
% ------                                                                  %
%                                                                         %
%    LON          longitude of the points (degrees).                      %
%    LAT          latitude of the points (real vector; degrees).          %
%    DOMDAT       Vector containing domain definition parameters.         %
%                    DOMDAT( 1) = COORD - grid type                       %
%                    DOMDAT( 2) = LONC  - longitude trans. center         %
%                    DOMDAT( 3) = LATC  - latitude trans. center          %
%                    DOMDAT( 4) = THETA - grid rotation angle             %
%                    DOMDAT( 5) = IM    - number of x-grid points         %
%                    DOMDAT( 6) = JM    - number of y-grid points         %
%                    DOMDAT( 7) = DX    - x-grid spacing                  %
%                    DOMDAT( 8) = DY    - y-grid spacing                  %
%                    DOMDAT( 9) = DELX  - x-offset grid-trans. centers    %
%                    DOMDAT(10) = DELY  - y-offset grid-trans. centers    %
%                                                                         %
% Calls:   ll2xy                                                          %
%                                                                         %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%-----------------------------------------------------------------------
% Find break points for coastal segments.
%-----------------------------------------------------------------------

spval = 999.0;
icst = find(lon==spval);

%-----------------------------------------------------------------------
% Extract domain data.
%-----------------------------------------------------------------------

coord = domdat( 1);
lonc  = domdat( 2);
latc  = domdat( 3);
theta = domdat( 4);
im    = domdat( 5);
jm    = domdat( 6);
dx    = domdat( 7);
dy    = domdat( 8);
delx  = domdat( 9);
dely  = domdat(10);

%-----------------------------------------------------------------------
% Plot coastal segments;
%-----------------------------------------------------------------------

[x,y]   = ll2xy (lon,lat,coord,im,jm,dx,dy,lonc,latc,delx,dely,theta);
x(icst) = NaN.*ones(size(icst));
y(icst) = x(icst);

plot(x,y);

return
