function [x,y,butt,States] = get_point (cancelstr);
%
% function [x,y,butt,States] = get_point (cancelstr);
%
% This function is a front-end to ginput.  It is designed to get
% a single point which is NOT a User Interface selection.
%
% ------
% Input:
% ------
%
%    cancelstr...String indicating whether this operation can be cancelled.
%                ['Cancelable']     This operation can be cancelled.
%                ['UnCancelable']   This operation can NOT be cancelled.
%
% -------
% Output:
% -------
%
%    x, y........The coordinates of the point selected.
%    butt........The button pressed to select.
%    States......Current state vector.

%-------------------------------------------------------------------------------
% Set test string.  Get Matlab version number
%-------------------------------------------------------------------------------

tststr = lower (cancelstr);

matver = version;
matvnum = str2num(matver(1));

%-------------------------------------------------------------------------------
% Get point.
%-------------------------------------------------------------------------------

%------------------
%--- First try. ---
%------------------

[x,y,butt] = ginput(1);
if (matvnum>=5),
   uiwait;
 else
   figure(gcf);
end;
States     = get_states;

%------------------------------------------
%--- Keep trying until valid selection. ---
%------------------------------------------

if strcmp(tststr,'uncancelable'),

   while ( ( States(pemsk_ind('Change')) | ...
             States(pemsk_ind('Cancel')) ) & ...
                                            ~States(pemsk_ind('Stop')) ),
      States(pemsk_ind('Change')) = 0;
      States(pemsk_ind('Cancel')) = 0;
      put_states (States);
      [x,y,butt] = ginput(1);
      if (matvnum>=5),
         uiwait;
       else
         figure(gcf);
      end;
      States     = get_states;
   end

 else

   while ( States(pemsk_ind('Change')) & ~States(pemsk_ind('Stop')) ),
      States(pemsk_ind('Change')) = 0;
      put_states (States);
      [x,y,butt] = ginput(1);
      if (matvnum>=5),
         uiwait;
       else
         figure(gcf);
      end;
      States     = get_states;
   end,

end
