function mask = init_mask (bath,zmsk_def);
%
% function mask = init_mask (bath,zmsk_def);
%
% This function creates an initial guess for the land mask.
%
% ------
% Input:
% ------
%
%    BATH       Domain topography.
%    ZMSK_DEF   Default transition isobath between land and sea points.
%
% -------
% Output:
% -------
%
%    MASK       Land/Sea mask.

%-------------------------------------------------------------------------------
% Initialize the mask.
%-------------------------------------------------------------------------------


zmsk = input (['Enter transition isobath (+/- meters) between land ',...
                  'and sea points [',num2str(zmsk_def),'] : ']);
if (isempty(zmsk)),
      zmsk = zmsk_def;
end

mask = ones(size(bath));
ind = find(bath > zmsk);
mask(ind) = zeros(size(ind));

%-------------------------------------------------------------------------------
% Try to make initial guess conform to limitations.
%-------------------------------------------------------------------------------

disp ('   Cleaning initial guess mask ...');

maskraw = mask;
mask = clean_mask (maskraw,'Full');

clear maskraw;
