function nseg = pe_seaseg (landt);
%
% function nseg = pe_seaseg (landt);
%
% This function computes the maximum number of ocean
% segments per row or per column for the supplied mask.
%
% Input:
%
%    landt...Array.  The land mask at tracer points.
%            This mask is assumed to be binary with
%            ocean points given by 1's and land points
%            given by 0's.
%
% Output:
%
%    nseg....Scalar.  The maximum number of ocean segments
%            in the mask per row and per column.
%

%-------------------------------------------------------------------------------
% Get the size of the mask.  Create pointers for manipulating.
%-------------------------------------------------------------------------------

[jmt imt] = size (landt);

imtm1 = imt - 1;
jmtm1 = jmt - 1;

north = [2:jmt jmtm1];
south = [2 1:jmtm1];

east = [2:imt imtm1];
west = [2 1:imtm1];

%-------------------------------------------------------------------------------
% Construct mask matrix for velocity points.
%-------------------------------------------------------------------------------

landv = landt.*landt(:,east).*landt(north,:).*landt(north,east);

%-------------------------------------------------------------------------------
% Construct mask matrix for "interior" tracer points.
%-------------------------------------------------------------------------------

landti = landv(south,west).*landv(south,:).*landv(:,west).*landv;

%-------------------------------------------------------------------------------
% Construct pointers for differencing.
%-------------------------------------------------------------------------------

north = 2:jmt;
south = north - 1;

east = 2:imt;
west = east - 1;

%-------------------------------------------------------------------------------
% Get the maximum number of segments per tracer row.
%-------------------------------------------------------------------------------

test = (landti(:,east) - landti(:,west))';
ind = find(test<0);
test(ind) = zeros(size(ind));

row_seg_t = max( (sum( test ) + (landti(:,1).*landti(:,2))') );

%-------------------------------------------------------------------------------
% Get the maximum number of segments per tracer column.
%-------------------------------------------------------------------------------

test = (landti(north,:) - landti(south,:));
ind = find(test<0);
test(ind) = zeros(size(ind));

col_seg_t = max( ( sum( test ) + (landti(1,:).*landti(2,:)) ) );

%-------------------------------------------------------------------------------
% Get the maximum number of segments per velocity row.
%-------------------------------------------------------------------------------

test = (landv(:,east) - landv(:,west))';
ind = find(test<0);
test(ind) = zeros(size(ind));

row_seg_v = max( (sum( test ) + (landv(:,1).*landv(:,2))') );

%-------------------------------------------------------------------------------
% Get the maximum number of segments per velocity column.
%-------------------------------------------------------------------------------

test = (landv(north,:) - landv(south,:));
ind = find(test<0);
test(ind) = zeros(size(ind));

col_seg_v = max( ( sum( test ) + (landv(1,:).*landv(2,:)) ) );

%-------------------------------------------------------------------------------
% Get the maximum number of ocean segments.
%-------------------------------------------------------------------------------

nseg = max( [row_seg_t col_seg_t row_seg_v col_seg_v 1] );
