function States = pemask_uifn (task);
%
% function pemask_uifn (task);;
%
% This function manages the graphical User Interface controls
% for the script pe_mask.
%
% ------
% Input:
% ------
%
%    task.....Character string defining the task for this function.

%-------------------------------------------------------------------------------
% Initialize User Interface buttons.
%-------------------------------------------------------------------------------

if strcmp(lower(task),'initialize'),

%   ---------------------------------------------
%   --- Initialize space for all state flags. ---
%   ---------------------------------------------

   States(pemsk_ind('All')) = zeros(size(pemsk_ind('All')));

%   -------------------------------------------------
%   --- Set flip/land/sea selector radio buttons. ---
%   -------------------------------------------------

   fls(1) = uicontrol ('Style',           'RadioButton',           ...
                       'Units',           'Normalized',            ...
                       'Position',        [0.0 0.925 0.075 0.075], ...
                       'BackGroundColor', 'c',                     ...
                       'String',          'Flip',                  ...
                       'Value',           0,                       ...
                       'CallBack',        'pemask_uifn (''Flip'');');

   fls(2) = uicontrol ('Style',           'RadioButton',          ...
                       'Units',           'Normalized',           ...
                       'Position',        [0.0 0.85 0.075 0.075], ...
                       'BackGroundColor', 'c',                    ...
                       'String',          'Land',                 ...
                       'Value',           1,                      ...
                       'CallBack',        'pemask_uifn (''Land'');');

   fls(3) = uicontrol ('Style',           'RadioButton',           ...
                       'Units',           'Normalized',            ...
                       'Position',        [0.0 0.775 0.075 0.075], ...
                       'BackGroundColor', 'c',                     ...
                       'String',          'Sea',                   ...
                       'Value',           0,                       ...
                       'CallBack',        'pemask_uifn (''Sea'');');

   for i = 1:3,
      set (fls(i),'UserData',fls(:,[1:(i-1) (i+1):3]));
   end;

   AllHand(pemsk_hnd('TState')) = fls;
   States(pemsk_ind('Flip'))    = get (AllHand(pemsk_hnd('Flip')),'Value');
   States(pemsk_ind('Land'))    = get (AllHand(pemsk_hnd('Land')),'Value');
   States(pemsk_ind('Sea'))     = get (AllHand(pemsk_hnd('Sea')),'Value');

%   ----------------------------------------------
%   --- Set point/area selector radio buttons. ---
%   ----------------------------------------------

   pa(1) = uicontrol ('Style',           'RadioButton',           ...
                      'Units',           'Normalized',            ...
                      'Position',        [0.0 0.567 0.075 0.075], ...
                      'BackGroundColor', 'y',                     ...
                      'String',          'Point',                 ...
                      'Value',           0,                       ...
                      'CallBack',        'pemask_uifn (''Point'');');

   pa(2) = uicontrol ('Style',           'RadioButton',           ...
                      'Units',           'Normalized',            ...
                      'Position',        [0.0 0.492 0.075 0.075], ...
                      'BackGroundColor', 'y',                     ...
                      'String',          'Area',                  ...
                      'Value',           1,                       ...
                      'CallBack',        'pemask_uifn (''Area'');');

   for i = 1:2,
      set (pa(i),'UserData',pa(:,[1:(i-1) (i+1):2]));
   end;

   AllHand(pemsk_hnd('MState')) = pa;
   States(pemsk_ind('Point'))   = get (AllHand(pemsk_hnd('Point')),'Value');
   States(pemsk_ind('Area'))    = get (AllHand(pemsk_hnd('Area')),'Value');

%   ------------------------------------------------
%   --- Set cancel, stop and abort push buttons. ---
%   ------------------------------------------------

   cnl = uicontrol ('Style',           'PushButton',            ...
                    'Units',           'Normalized',            ...
                    'Position',        [0.0 0.284 0.075 0.075], ...
                    'BackGroundColor', [0.75 0.75 1.0],         ...
                    'String',          'Cancel',                ...
                    'CallBack',        'pemask_uifn (''Cancel'');');

   AllHand(pemsk_hnd('Cancel')) = cnl;
   States(pemsk_ind('Cancel'))  = 0;

   stp = uicontrol ('Style',           'PushButton',            ...
                    'Units',           'Normalized',            ...
                    'Position',        [0.0 0.075 0.075 0.075], ...
                    'BackGroundColor', 'g',                     ...
                    'String',          'Done',                  ...
                    'CallBack',        'pemask_uifn (''Stop'');');

   AllHand(pemsk_hnd('Stop')) = stp;
   States(pemsk_ind('Stop'))  = 0;

   abt = uicontrol ('Style',           'PushButton',          ...
                    'Units',           'Normalized',          ...
                    'Position',        [0.0 0.0 0.075 0.075], ...
                    'BackGroundColor', [1.0 0.25 0.25],       ...
                    'String',          'Abort',               ...
                    'CallBack',        'pemask_uifn (''Abort'');');

   AllHand(pemsk_hnd('Abort')) = abt;
   States(pemsk_ind('Abort'))  = 0;

%   --------------------------------------
%   --- Load figure's UserData matrix. ---
%   --------------------------------------

   set (gcf,'UserData',[length(AllHand) AllHand States]);

%   --------------------------------------------------------
%   --- For higher versions of Matlab, Set button Fonts. ---
%   --------------------------------------------------------

   vstr = version;
   vnum = str2num(vstr(1));

   if (vnum>4),
      set (AllHand,'FontName','Times','FontSize',14);
   end;

%-------------------------------------------------------------------------------
% Update type state & buttons.
%-------------------------------------------------------------------------------

elseif ( strcmp(lower(task),'flip') | strcmp(lower(task),'land') | ...
                                      strcmp(lower(task),'sea') ),

   CurrObj   = radchk;
   AllHand   = get_hand;
   States    = get_states;
   States(pemsk_ind('Flip'))    = get (AllHand(pemsk_hnd('Flip')),'Value');
   States(pemsk_ind('Land'))    = get (AllHand(pemsk_hnd('Land')),'Value');
   States(pemsk_ind('Sea'))     = get (AllHand(pemsk_hnd('Sea')),'Value');
   States(pemsk_ind('Change'))  = 1;
   put_states (States);

%-------------------------------------------------------------------------------
% Update area of attack state & buttons.
%-------------------------------------------------------------------------------

elseif ( strcmp(lower(task),'point') | strcmp(lower(task),'area') ),

   CurrObj   = radchk;
   AllHand   = get_hand;
   States    = get_states;
   States(pemsk_ind('Point'))   = get (AllHand(pemsk_hnd('Point')),'Value');
   States(pemsk_ind('Area'))    = get (AllHand(pemsk_hnd('Area')),'Value');
   States(pemsk_ind('Change'))  = 1;
   put_states (States);

%-------------------------------------------------------------------------------
% Set flag to cancel a 2-point action.
%-------------------------------------------------------------------------------

elseif strcmp(lower(task),'cancel'),

   States    = get_states;
   States(pemsk_ind('Cancel')) = 1;
   put_states (States);

%-------------------------------------------------------------------------------
% Set flag to stop changing land mask.
%-------------------------------------------------------------------------------

elseif strcmp(lower(task),'stop'),

   States    = get_states;
   States(pemsk_ind('Stop')) = 1;
   put_states (States);

%-------------------------------------------------------------------------------
% Set flag to abort procedure.
%-------------------------------------------------------------------------------

elseif strcmp(lower(task),'abort'),

   States    = get_states;
   States(pemsk_ind('Stop'))  = 1;
   States(pemsk_ind('Abort')) = 1;
   put_states (States);

%-------------------------------------------------------------------------------
% Dummy call to try to get timings good.
%-------------------------------------------------------------------------------

elseif strcmp(lower(task),'dummy'),

   States = get_states;
   put_states (States);

end;

%-------------------------------------------------------------------------------
% For Matlab 5 & beyond, resume suspended execution.
%-------------------------------------------------------------------------------

vstr = version;

if (str2num(vstr(1))>=5),
   uiresume;
end;
