function indx = samp_hnd (type);
%
% function indx = samp_hnd (type);
%
% This function returns the index for the location of the
% requested handle data in the User InterFace AllHand vector.
%
% ------
% Input:
% ------
%
%    type...Character string specifying desired handle.
%              'TState'     "Type of change" state handles.
%              'Flip'       "Interchange Land/Sea point" state handle
%              'Land'       "Convert to Land point" state handle
%              'Sea'        "Convert to Sea point" state handle
%              'MState'     "Method of alteration" handles.
%              'Point'      "Change single point" state handle.
%              'Area'       "Change a rectangular area" state handle.
%              'Cancel'     "Cancel a 2-point operation" handle.
%              'Stop'       "Stopping" handle (done).
%              'Abort'      "Abort procedure" handle.
%
% -------
% Output:
% -------
%
%    indx...Index of desired handle in AllHand vector.

teststr = lower(type);

if strcmp(teststr,'tstate'),
   indx = 1:3;
  elseif (strcmp(teststr,'flip')),
   indx = 1;
  elseif (strcmp(teststr,'land')),
   indx = 2;
  elseif (strcmp(teststr,'sea')),
   indx = 3;
  elseif strcmp(teststr,'mstate'),
   indx = 4:5;
  elseif (strcmp(teststr,'point')),
   indx = 4;
  elseif (strcmp(teststr,'area')),
   indx = 5;
  elseif strcmp(teststr,'cancel'),
   indx = 6;
  elseif strcmp(teststr,'stop'),
   indx = 7;
  elseif strcmp(teststr,'abort'),
   indx = 8;
end;
