function indx = pemsk_ind (type);
%
% function indx = pemsk_ind (type);
%
% This function returns the index for the location of the
% requested state data in the User InterFace State vector.
%
% ------
% Input:
% ------
%
%    type...Character string specifying desired field.
%              'TState'     "Type of change" state flags.
%              'Flip'       "Interchange Land/Sea point" state flag
%              'Land'       "Convert to Land point" state flag
%              'Sea'        "Convert to Sea point" state flag
%              'MState'     "Method of alteration" state flags.
%              'Point'      "Change single point" state flag.
%              'Area'       "Change a rectangular area" state flag.
%              'Cancel'     "Cancel a 2-point operation" flag.
%              'Change'     "Change of state" flag.
%              'Stop'       "Stopping" flag (done).
%              'Abort'      "Abort procedure" flag.
%              'All'        Indices for all flags.  (Useful for initializing)
%
% -------
% Output:
% -------
%
%    indx...Index of desired field in State vector.

teststr = lower(type);

if (strcmp(teststr,'tstate')),
   indx = 1:3;
  elseif (strcmp(teststr,'flip')),
   indx = 1;
  elseif (strcmp(teststr,'land')),
   indx = 2;
  elseif (strcmp(teststr,'sea')),
   indx = 3;
  elseif (strcmp(teststr,'mstate')),
   indx = 4:5;
  elseif (strcmp(teststr,'point')),
   indx = 4;
  elseif (strcmp(teststr,'area')),
   indx = 5;
  elseif (strcmp(teststr,'cancel')),
   indx = 6;
  elseif (strcmp(teststr,'change')),
   indx = 7;
  elseif (strcmp(teststr,'stop')),
   indx = 8;
  elseif (strcmp(teststr,'abort')),
   indx = 9;
  elseif (strcmp(teststr,'all')),
   indx = 1:9;
end;
