 function h = pltmask (mask,clon,clat,domdat);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                      %
% function h = pltmask (mask,clon,clat,domdat);                        %
%                                                                      %
% This function plots the land/sea mask. It also ovelays the given     %
% coastlines.                                                          %
%                                                                      %
% ------                                                               %
% Input:                                                               %
% ------                                                               %
%                                                                      %
%    MASK       Land/Sea mask (integer matrix):                        %
%               MASK=0 land, Mask=1 Sea.                               %
%    CLON       longitudes of coastline (real vector; degrees).        %
%    CLAT       latitudes of coastline (real vector; degrees).         %
%    DOMDAT     Vector containing domain definition parameters.        %
%                  DOMDAT( 1) = COORD - grid type                      %
%                  DOMDAT( 2) = LONC  - longitude trans. center        %
%                  DOMDAT( 3) = LATC  - latitude trans. center         %
%                  DOMDAT( 4) = THETA - grid rotation angle            %
%                  DOMDAT( 5) = IM    - number of x-grid points        %
%                  DOMDAT( 6) = JM    - number of y-grid points        %
%                  DOMDAT( 7) = DX    - x-grid spacing                 %
%                  DOMDAT( 8) = DY    - y-grid spacing                 %
%                  DOMDAT( 9) = DELX  - x-offset grid-trans. centers   %
%                  DOMDAT(10) = DELY  - y-offset grid-trans. centers   %
%                                                                      %
% Calls:    draw_cstp                                                  %
%                                                                      %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%-----------------------------------------------------------------------
% Extract domain data.
%-----------------------------------------------------------------------

im = domdat( 5);
jm = domdat( 6);

%-----------------------------------------------------------------------
% Set indices for land and water points.
%-----------------------------------------------------------------------

  [jl,il]=find(mask==0);
  [jw,iw]=find(mask>0);

%-----------------------------------------------------------------------
% Plot mask.
%-----------------------------------------------------------------------

  clf
  plot(il,jl,'w*');
  hold on;
  plot(iw,jw,'c.');
  axis([1 im 1 jm]);
  grid;

%-----------------------------------------------------------------------
% Draw coastline in grid-units.
%-----------------------------------------------------------------------

  draw_cstp (clon,clat,domdat);

  return

