      subroutine cst_seg
c
c==========================================================================
c                                                                       ===
c   This routine extracts the coastal segments from the mask field at   ===
c   the velocity points (ISMASK) and sets the corners of the island     ===
c   boxes.                                                              ===
c                                                                       ===
c   Calls:  CLEAN_BNDY,  FIND_ST,  INIT_ILIST,  LOAD_BNDY,  LOAD_COAST, ===
c           XTR_CST                                                     ===
c                                                                       ===
c==========================================================================
c
c--------------------------------------------------------------------------
c  Define global data.
c--------------------------------------------------------------------------
c
#include <param.h>
#include <cstmsk.h>
c
c--------------------------------------------------------------------------
c  Define local data.
c--------------------------------------------------------------------------
c
      integer ndatfld,nfld,npp1
      parameter (ndatfld=2, nfld=ndatfld+1, npp1=np+1)
c
      integer bndptr,cstptr,isptr,m,n,wkbptr,wkcptr
      integer bndnodes(npp1,nfld),cstnodes(np,nfld)
c
c==========================================================================
c  Begin executable code.
c==========================================================================
c
c-----------------------------------------------------------------------
c  Inform user of coastal extraction.
c-----------------------------------------------------------------------
c
      write (stdout,60)
c
c-----------------------------------------------------------------------
c  Set-up linked-list of coastal nodes.
c-----------------------------------------------------------------------
c
c  Initialize data structures.
c
      call init_ilist (np,nfld,cstptr,wkcptr,cstnodes)
c
c  Load coastal nodes.
c
      call load_coast (im,im,jm,ismask,cstptr,wkcptr,np,nfld,cstnodes)
c
c-----------------------------------------------------------------------
c  Set-up linked-list of outer boundary nodes.
c-----------------------------------------------------------------------
c
c  Initialize data structures.
c
      call init_ilist (npp1,nfld,bndptr,wkbptr,bndnodes)
c
c  Load boundary nodes.
c
      call load_bndy (im,jm,bndptr,wkbptr,npp1,nfld,bndnodes)
c
c-----------------------------------------------------------------------
c  Extract exterior coastal segments.
c-----------------------------------------------------------------------
c
c  Find start of first coast.
c
      call find_st (im,im,jm,ismask,bndptr,wkbptr,npp1,nfld,bndnodes)
c
      lsegmx = 0
      nseg   = 0
c
c----------------------------------------------------
c--- Loop while unexamined boundary points exist. ---
c----------------------------------------------------
c
      do 10 while (bndptr.ne.0)
c
c  Extract indicated coastal segment.
c
         nseg = nseg + 1
         call xtr_cst (bndnodes(bndptr,1),bndnodes(bndptr,2),cstptr,
     &                 wkcptr,np,nfld,cstnodes,mpseg,lenseg(nseg),
     &                 cstsegx(1,nseg),cstsegy(1,nseg))
c
c  Remove boundary points under land.
c
         call clean_bndy (cstsegx(1,nseg),cstsegy(1,nseg),
     &                    cstsegx(lenseg(nseg),nseg),
     &                    cstsegy(lenseg(nseg),nseg),
     &                    im,jm,bndptr,wkbptr,npp1,nfld,bndnodes)
c
c  Exterior coasts end one point shy of the boundary.
c
         lenseg(nseg) = lenseg(nseg) - 1
         lsegmx       = max (lsegmx, lenseg(nseg))
c
c  Find start of next coast.
c
         call find_st (im,im,jm,ismask,bndptr,wkbptr,npp1,nfld,bndnodes)
c
 10   continue
c
c-----------------------------------------------------------------------
c  Extract island coastal segments.
c-----------------------------------------------------------------------
c
      nisle = 0
c
c-----------------------------------------------
c--- Loop while unused coastal points exist. ---
c-----------------------------------------------
c
      do 20 while (cstptr.ne.0)
c
c  Extract indicated coastal segment.
c
         nseg  = nseg + 1
         nisle = nisle + 1
c
         call xtr_cst (cstnodes(cstptr,1),cstnodes(cstptr,2),cstptr,
     &                 wkcptr,np,nfld,cstnodes,mpseg,lenseg(nseg),
     &                 cstsegx(1,nseg),cstsegy(1,nseg))
c
         lsegmx = max (lsegmx, lenseg(nseg))
c
 20   continue
c
c-----------------------------------------------------------------------
c  Find island boxes.
c-----------------------------------------------------------------------
c
      do 40 n = (nseg-nisle+1), nseg
c
         isptr       = n - nseg + nisle
         isis(isptr) = cstsegx(1,n)
         jsis(isptr) = cstsegy(1,n)
         ieis(isptr) = cstsegx(1,n)
         jeis(isptr) = cstsegy(1,n)
c
         do 30 m = 2, lenseg(n)
            isis(isptr) = min(isis(isptr), cstsegx(m,n))
            jsis(isptr) = min(jsis(isptr), cstsegy(m,n))
            ieis(isptr) = max(ieis(isptr), cstsegx(m,n))
            jeis(isptr) = max(jeis(isptr), cstsegy(m,n))
  30     continue
c
  40  continue
c
c-----------------------------------------------------------------------
c  Report results.
c-----------------------------------------------------------------------
c
      write (stdout,70) nseg,(nseg-nisle),nisle
c
      do 50 n = 1, nseg
         if (n.le.(nseg-nisle)) then
            write (stdout,80) n,cstsegx(1,n),cstsegy(1,n),'exterior'
          else
            write (stdout,80) n,cstsegx(1,n),cstsegy(1,n),'island'
         end if
  50  continue
c
      return
c
  60  format (//'  Coastal Segment(s) Extraction:'/
     &          '  -----------------------------'/)
  70  format (3x,'Found ',i5,' coastlines:'/6x,i5,' exterior coasts'/6x,
     &        i5,' islands'//3x,'Starting locations:'//6x,'coast',5x,
     &        'starting point',8x,'type'/)
  80  format (6x,i5,5x,'(',i5,', ',i5,')',5x,'(',a,')')
c
      end
