      subroutine edt_mask (landt,mask,nx,im,jm,nrow,ncol)
c
c=======================================================================
c                                                                    ===
c  This routine is used to modify the Land/Sea mask at the tracer    ===
c  points interactively.                                             ===
c                                                                    ===
c  ------                                                            ===
c  Input:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     MASK    initial Land/Sea mask at the tracer points (integer    ===
c             array):  MASK=0 Land, MASK=1 Sea.                      ===
c     NX      length of first dimension for MASK and LANDT in the    ===
c             calling program (integer).                             ===
c     IM      number of points in the x-direction (integer).         ===
c     JM      number of points in the y-direction (integer).         ===
c     NROW    number of rows per page for printing.                  ===
c     NCOL    number of columns per page for printing.               ===
c                                                                    ===
c  -------                                                           ===
c  Output:                                                           ===
c  -------                                                           ===
c                                                                    ===
c     MASK    edited Land/Sea mask at tracer points (integer array). ===
c     LANDT   accepted Land/Sea mask at tracer points (integer       ===
c             array):  LANDT=0 Land, LANDT=1 Sea.                    ===
c                                                                    ===
c  Calls:     EXITUS, PRT_MASK                                       ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <param.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer i,im,iunit,j,jm,ncol,newval,n,nfrst,nlast,npts,nrow,nx,
     *        oldval
      integer iflip(nfpts),jflip(nfpts),landt(nx,jm),mask(nx,jm)
      character*1  accept,idxjob,mskjob
      character*60 filenam
      parameter (iunit=1)
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
      write(stdout,10)
  10  format(/
     *  /'   Interactive Editing of the Mask field at the T-points:'/,
     *   '   ----------------------------------------------------- '/,
     *  /'     The mask field has a zero value  at the land points',
     *  /'     and a value of one at the sea points.  The User can',
     *  /'     modify this mask field by specifing the (I,J) index',
     *  /'     location(s) of the value(s) to flip.')
c
      nfrst=1
      nlast=0
      do 150 while (.true.)
        write(stdout,20)
  20    format(/'  Would you like to modify the mask field, [y/n]:')
        read(stdinp,30) mskjob
  30    format(a)
        if ((mskjob.eq.'N').or.(mskjob.eq.'n')) goto 160
        write(stdout,40)
  40    format('  Are the (I,J) locations entered from the terminal [t]'
     *   /'                          or read from a data file  [f]:')
        read(stdinp,30) idxjob
        if ((idxjob.eq.'T').or.(idxjob.eq.'t')) then
          write(stdout,50)
  50      format('  Enter the (I,J) location pairs to flip:',/,
     *           '   (enter negative values to end entry)',/)
          n=nfrst
          do 70 while (.true.)
            write(stdout,60) n
  60        format(10x,'(I,J) pair ',i2.2,' :')
            read(stdinp,*) iflip(n),jflip(n)
            if ((iflip(n).le.0).or.(jflip(n).le.0)) goto 80
            n=n+1
  70      continue
  80      npts=n-nfrst
          if(npts.gt.nfpts) then
            write(stdout,85) nfpts,npts
  85        format(/,' EDT_MASK - underestimated dimension parameter, ',
     *               ' NFPTS = ',2i6)
            stop
          endif
        else
          write(stdout,90)
  90      format('  Enter filename for (I,J) pairs:')
          read(stdinp,30) filenam
          open(iunit,file=filenam,form='formatted',status='old')
          n=nfrst
          do 100 while (.true.)
            read(iunit,*,end=110) iflip(n),jflip(n)
            n=n+1
 100      continue
 110      close(iunit)
          npts=n-nfrst
          if(npts.gt.nfpts) then
            write(stdout,85) nfpts,npts
            stop
          endif
        endif
c
c  Flip mask field at the specified locations.
c
        do 120 n=nfrst,nfrst+npts-1
          oldval=mask(iflip(n),jflip(n))
          if (oldval.eq.0) then
            newval=1
          else
            newval=0
          endif
          mask(iflip(n),jflip(n))=newval
 120    continue
c
c  Write out mask field for examination.
c
        call prt_mask(mask,nx,im,jm,nrow,ncol,'T_mask.wrk')
        write(stdout,130)
 130    format(/'>>> File ','''T_mask.wrk''',' was written for your',
     *          ' examination.'/)
c
c  Accept or reject the modifications entered in this pass.
c
        write(stdout,140)
 140    format('  Are the modification(s) accepted? [y/n]:')
        read(stdinp,30) accept
        if ((accept.eq.'Y').or.(accept.eq.'y')) then
          nlast=nfrst+npts-1
          nfrst=nlast+1
        else
          nfrst=nlast
        endif
 150  continue
c
c  Restore unmodified field.
c
 160  continue
      do 180 j=1,jm
        do 170 i=1,im
          mask(i,j)=landt(i,j)
 170    continue
 180  continue
c
c  Apply all modification, if any.
c
      if (nlast.ne.0) then
        do 190 n=1,nlast
          oldval=landt(iflip(n),jflip(n))
          if (oldval.eq.0) then
            newval=1
          else
            newval=0
          endif
          landt(iflip(n),jflip(n))=newval
 190    continue
      endif
      call prt_mask(landt,nx,im,jm,nrow,ncol,'T_mask.dat')
      write(stdout,200)
 200  format(/'>>> Final File ','''T_mask.dat''',' was written for',
     *        ' your examination.')
      return
      end
