      subroutine load_bndy (im,jm,bndptr,wkptr,mxlst,nfld,bndnodes)
c
c=======================================================================
c                                                                    ===
c  This routine loads the domain boundary nodes into a linked-list.  ===
c                                                                    ===
c  ------                                                            ===
c  Input:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     IM         Number of x-points in mask.      (integer)          ===
c     JM         Number of y-points in mask.      (integer)          ===
c     BNDPTR     Pointer to boundary nodes.       (integer)          ===
c     WKPTR      Pointer to work space.           (integer)          ===
c     MXLST      Maximum length of BNDNODES.      (integer)          ===
c     NFLD       Number of fields in BNDNODES.    (integer)          ===
c                                                                    ===
c  -------                                                           ===
c  Output:                                                           ===
c  -------                                                           ===
c                                                                    ===
c     BNDPTR     Updated boundary pointer.        (integer)          ===
c     WKPTR      Updated work space pointer.      (integer)          ===
c     BNDNODES   List of boundary nodes.          (integer array)    ===
c                                                                    ===
c  ------                                                            ===
c  Calls:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     HOPS:  EXITUS,  INS_ILIST                                      ===
c                                                                    ===
c=======================================================================
c
c--------------------------------------------------------------------------
c  Define global data.
c--------------------------------------------------------------------------
c
#include <param.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer bndptr,i,im,j,jm,mxlst,nfld,wkptr
      integer bndnodes(mxlst,nfld),vals(2)
      logical error
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c-----------------------------------------------------------------------
c  Load boundary points in reverse order, the linked-list is LIFO.
c-----------------------------------------------------------------------
c
c-----------------------------------------------------------------------
c  Load Western boundary.  Add (1,1) point, for a second time, to be
c  used as pointer to last "next" point.
c-----------------------------------------------------------------------
c
      vals(1) = 1
c
      do 10 j = 1, (jm-1)
         vals(2) = j
         call ins_ilist (mxlst,nfld,bndptr,wkptr,bndnodes,vals,error)
         if (error) then
            write (stdout,900)
            call exitus ('LOAD_BNDY')
         end if
  10  continue
c
c-----------------------------------------------------------------------
c  Load Northern boundary.
c-----------------------------------------------------------------------
c
      vals(2) = jm
c
      do 20 i = 1, (im-1)
         vals(1) = i
         call ins_ilist (mxlst,nfld,bndptr,wkptr,bndnodes,vals,error)
         if (error) then
            write (stdout,900)
            call exitus ('LOAD_BNDY')
         end if
  20  continue
c
c-----------------------------------------------------------------------
c  Load Eastern boundary.
c-----------------------------------------------------------------------
c
      vals(1) = im
c
      do 30 j = jm, 2, -1
         vals(2) = j
         call ins_ilist (mxlst,nfld,bndptr,wkptr,bndnodes,vals,error)
         if (error) then
            write (stdout,900)
            call exitus ('LOAD_BNDY')
         end if
  30  continue
c
c-----------------------------------------------------------------------
c  Load Southern boundary.
c-----------------------------------------------------------------------
c
      vals(2) = 1
c
      do 40 i = im, 1, -1
         vals(1) = i
         call ins_ilist (mxlst,nfld,bndptr,wkptr,bndnodes,vals,error)
         if (error) then
            write (stdout,900)
            call exitus ('LOAD_BNDY')
         end if
  40  continue
c
      return
c
 900  format (/'***Error:  LOAD_BNDY - insufficient space in ',
     &         'linked-list to load domain boundary data.')
c
      end
