      subroutine load_coast (nx,im,jm,ismask,cstptr,wkptr,mxlst,nfld,
     &                       cstnodes)
c
c=======================================================================
c                                                                    ===
c  This routine loads the coastline nodes into the linked-list.      ===
c                                                                    ===
c  ------                                                            ===
c  Input:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     NX         Leading dimension of ISMASK.     (integer)          ===
c     IM         Number of x-points in mask.      (integer)          ===
c     JM         Number of y-points in mask.      (integer)          ===
c     ISMASK     Land/Sea/Coast mask.             (integer array)    ===
c     CSTPTR     Pointer to coastal nodes.        (integer)          ===
c     WKPTR      Pointer to work space.           (integer)          ===
c     MXLST      Maximum length of BNDNODES.      (integer)          ===
c     NFLD       Number of fields in BNDNODES.    (integer)          ===
c                                                                    ===
c  -------                                                           ===
c  Output:                                                           ===
c  -------                                                           ===
c                                                                    ===
c     CSTPTR     Updated coast pointer.           (integer)          ===
c     WKPTR      Updated work space pointer.      (integer)          ===
c     CSTNODES   List of coast nodes.             (integer array)    ===
c                                                                    ===
c  ------                                                            ===
c  Calls:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     HOPS:  EXITUS,  INS_ILIST                                      ===
c                                                                    ===
c=======================================================================
c
c--------------------------------------------------------------------------
c  Define global data.
c--------------------------------------------------------------------------
c
#include <param.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer cstptr,cstval,i,im,j,jm,mxlst,nfld,nx,wkptr
      integer cstnodes(mxlst,nfld),ismask(nx,jm),vals(2)
      logical error
c
      parameter (cstval=1)
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
      do 10 i = im, 1, -1
      do 10 j = jm, 1, -1
c
         if (ismask(i,j).eq.cstval) then
c
            vals(1) = i
            vals(2) = j
            call ins_ilist (mxlst,nfld,cstptr,wkptr,cstnodes,vals,error)
c
            if (error) then
               write (stdout,900)
               call exitus ('LOAD_COAST')
            end if
c
         end if
c
  10  continue
c
      return
c
 900  format (/'***Error:  LOAD_COAST - insufficient space in ',
     &         'linked-list to load coastline data.')
c
      end
