      program pe_mask
c
c=======================================================================
c                                                                    ===
c  Given the bottom topography, this program setup the land/sea      ===
c  mask at the tracer points,  coastal segments,  and the start      ===
c  indices of the island(s) box(es), if any.                         ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <param.h>
#include <cstmsk.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer i,ip,j,ncol,nrow,slen,sbgn,send
#ifdef sunfpe
      integer ieeer,my_handler,ieee_handler
#endif
      integer mask(np)
      real zmask
      character*10 fmt
      character*80 grdname,text
c
#ifdef sunfpe
      external   my_handler
c
#endif
c=======================================================================
c  Begin executable code.
c=======================================================================
c
#ifdef sunfpe
c-----------------------------------------------------------------------
c  Enable floating point error flags.
c-----------------------------------------------------------------------
c
      ieeer = ieee_handler ('set','common',my_handler)
      if (ieeer .ne. 0) write (6,900)
c
#endif
c-----------------------------------------------------------------------
c  Read in parameters from standard input.
c-----------------------------------------------------------------------
c
c  Read in GRIDS NetCDF file name.
c
      write(stdout,10)
  10  format(/'   Land/Sea Mask Processing:',/,
     *       /' Enter GRIDS NetCDF file name :')
      read(stdinp,20) grdname
  20  format(a)
c
c  Read in number of rows and columns per page on output.
c
      write(stdout,30)
  30  format(' Enter number of colums per page for printing [80] :')
      read(stdinp,20) text
      call length (text,slen,sbgn,send)
      if (slen.gt.0) then
        write (fmt,35) slen
  35    format ('(i',i2.2,')')
        read (text(sbgn:send),fmt) ncol
       else
        ncol=80
      endif
c
      write(stdout,40)
  40  format(' Enter number of rows   per page for printing [60] :')
      read(stdinp,20) text
      call length (text,slen,sbgn,send)
      if (slen.gt.0) then
        write (fmt,35) slen
        read (text(sbgn:send),fmt) nrow
       else
        nrow=60
      endif
c
c-----------------------------------------------------------------------
c  Read in input bottom topography and Land/Sea masking if any.
c-----------------------------------------------------------------------
c
      call read_grids(grdname)
c
c-----------------------------------------------------------------------
c  If Land/Sea mask data is available in the GRIDS NetCDF, inquire the
c  value of the transition isobath and set mask data.
c-----------------------------------------------------------------------
c
      if(.not.llandt) then
        write(stdout,50)
  50    format(' Enter isobath (+/- meters) for transition between',
     *         ' land and sea points :')
        read(stdinp,*) zmask
c
c  Set Land/Sea mask at the tracer points.
c
        do 70 j=1,jm
          do 60 i=1,im
            ip=i+(j-1)*im
            if(topo(ip).gt.zmask) then
              landt(ip)=0
              mask(ip)=0
            else
              landt(ip)=1
              mask(ip)=1
            endif
  60      continue
  70    continue    
      else
        do 90 j=1,jm
          do 80 i=1,im
            ip=i+(j-1)*im
            mask(ip)=landt(ip)
  80      continue
  90    continue
      endif
c
c-----------------------------------------------------------------------
c  Print out Land/Sea mask ASCII file for preliminary checking.
c-----------------------------------------------------------------------
c
      call prt_mask(landt,im,im,jm,nrow,ncol,'T_mask.wrk')
      write(stdout,100)
 100  format(/'>>> File ','''T_mask.wrk''',' was written for your',
     *        ' examination.')
c
c-----------------------------------------------------------------------
c  Modify mask file, interactively.
c-----------------------------------------------------------------------
c
      call edt_mask(landt,mask,im,im,jm,nrow,ncol)
c
c-----------------------------------------------------------------------
c  Set land/sea mask at the velocity points from that of the tracer
c  points.
c-----------------------------------------------------------------------
c
      call set_mask
      call prt_mask(ismask,im,im,jm,nrow,ncol,'ismask.dat')
      call prt_mask(landv,im,im,jm,nrow,ncol,'V_mask.dat')
      write(stdout,110)
 110  format(/'>>> File ','''ismask.dat''',' was written for your',
     *        ' examination.')
      write(stdout,120)
 120  format(/'>>> File ','''V_mask.dat''',' was written for your',
     *        ' examination.')
c
c-----------------------------------------------------------------------
c  Extract coastal segments from the mask field at the velocity points.
c-----------------------------------------------------------------------
c
      call cst_seg
c
c-----------------------------------------------------------------------
c  Write out mask data into GRIDS NetCDF file
c-----------------------------------------------------------------------
c
      call write_mask(grdname)
      call exitus('PE_MASK DONE')
      stop
#ifdef sunfpe
 900   format(/'PE_MASK - Warning:  ieee_handler cannot set my_handler'/
     &        )
#endif
      end
