      function pe_seaseg (landt,im,jm,work)
c
c-----------------------------------------------------------------------
c     This function computes the maximum number of ocean segments per  |
c     row or per column from the given land/sea mask.                  |
c                                                                      |
c     Calls:  none                                                     |
c                                                                      |
c     Input:                                                           |
c                                                                      |
c     landt.....Integer array.  Land/Sea mask.  Assumed binary with    |
c                  land=0 and sea=1.                                   |
c     im........Integer.  Number of points in x-direction.             |
c     jm........Integer.  Number of points in y-direction.             |
c     work......Integer array.  Work array of size (im,jm)             |
c                                                                      |
c     Output:                                                          |
c                                                                      |
c     pe_seaseg...Integer.  Maximum number of ocean segments per row or|
c                  per column.                                         |
c-----------------------------------------------------------------------
c
      integer col_seg,i,im,imm1,j,jm,jmm1,landt(im,jm),pe_seaseg,
     &        row_seg,sum,work(im,jm),vseg
c
c=======================================================================
c     Begin executable code.                                           #
c=======================================================================
c
c-----------------------------------------------------------------------
c     Create penultimate pointers.                                     |
c-----------------------------------------------------------------------
c
      imm1 = im - 1
      jmm1 = jm - 1
c
c-----------------------------------------------------------------------
c     Compute "mask" at velocity points.                               |
c-----------------------------------------------------------------------
c
      do 20 j = 1, jmm1
         do 10 i = 1, imm1
            work(i,j) = min( landt(i,j), landt(i+1,j), landt(i,j+1),
     &                                                  landt(i+1,j+1) )
 10      continue
         work(im,j) = work(imm1,j)
 20   continue
c
      do 30 i = 1, im
         work(i,jm) = work(i,jmm1)
 30   continue
c
c-----------------------------------------------------------------------
c     Compute maximum number of segments per row of velocity mask.     |
c-----------------------------------------------------------------------
c
      row_seg = 0
c
      do 50 j = 1, jm
c
         sum = landt(1,j)
         do 40 i = 1, im-1
            sum = sum + max( (work(i+1,j)-work(i,j)), 0 )
 40      continue
c
         row_seg = max ( row_seg, sum )
c
 50   continue
c
c-----------------------------------------------------------------------
c     Compute maximum number of segments per column of velocity mask.  |
c-----------------------------------------------------------------------
c
      col_seg = 0
c
      do 70 i = 1, im
c
         sum = landt(i,1)
         do 60 j = 1, jm-1
            sum = sum + max( (work(i,j+1)-work(i,j)), 0 )
 60      continue
c
         col_seg = max ( col_seg, sum )
c
 70   continue
c
c-----------------------------------------------------------------------
c     Get the maximum number of ocean segments over velocity points.   |
c-----------------------------------------------------------------------
c
      vseg = max( row_seg, col_seg, 1 )
c
c-----------------------------------------------------------------------
c     Compute "mask" at interior tracer points.                        |
c-----------------------------------------------------------------------
c
      do 90 j = jm, 2, -1
         do 80 i = im, 2, -1
            work(i,j) = min( work(i,j), work(i-1,j), work(i,j-1),
     &                                                  work(i-1,j-1) )
 80      continue
         work(1,j) = work(2,j)
 90   continue
c
      do 100 i = 1, im
         work(i,1) = work(i,2)
100   continue
c
c-----------------------------------------------------------------------
c     Compute maximum number of segments per row of interior tracer    |
c     mask.                                                            |
c-----------------------------------------------------------------------
c
      row_seg = 0
c
      do 120 j = 1, jm
c
         sum = work(1,j)
         do 110 i = 1, im-1
            sum = sum + max( (work(i+1,j)-work(i,j)), 0 )
110      continue
c
         row_seg = max ( row_seg, sum )
c
120   continue
c
c-----------------------------------------------------------------------
c     Compute maximum number of segments per column of interior tracer |
c     mask.                                                            |
c-----------------------------------------------------------------------
c
      col_seg = 0
c
      do 140 i = 1, im
c
         sum = work(i,1)
         do 130 j = 1, jm-1
            sum = sum + max( (work(i,j+1)-work(i,j)), 0 )
130      continue
c
         col_seg = max ( col_seg, sum )
c
140   continue
c
c-----------------------------------------------------------------------
c     Get the maximum number of ocean segments.                        |
c-----------------------------------------------------------------------
c
      pe_seaseg = max( row_seg, col_seg, vseg )
c
      return
      end
