      subroutine read_grids(grdname)
c
c=======================================================================
c                                                                    ===
c  This routine reads bottom topography and Land/Sea mask data, if   ===
c  any, from GRIDS NetCDF file.                                      ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <param.h>
#include <cstmsk.h>
#include <netcdf.inc>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer dimid,dimsiz,n,ndims,ngatts,nvars,nvatts,rcode,recdim,sbn2
     *        ,sbgn,send,slen,sln2,snd2,vartyp,varid
      integer       nvdims(maxvar),vdims(6,maxvar)
      character*(*) grdname
      character*128 dimnam,varnam(maxvar)
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c-----------------------------------------------------------------------
c  Open GRIDS NetCDF file.
c-----------------------------------------------------------------------
c
      call length (grdname,slen,sbgn,send)
      if (slen.lt.1) then
        write(stdout,900)
        call exitus('READ_GRIDS')
      endif
c
      rcode = nf_open (grdname(sbgn:send),NF_WRITE,ncid)
c
      if (rcode.eq.NF_NOERR) then
        ncstat = 2
       else
        write(stdout,910) grdname(sbgn:send),nf_strerror(rcode)
        call exitus('READ_GRIDS')
      endif
c
c-----------------------------------------------------------------------
c  Inquire about the contents of open NetCDF file:  Inquire about the
c  dimensions and variables.
c-----------------------------------------------------------------------
c
      rcode = nf_inq (ncid,ndims,nvars,ngatts,recdim)
c
      if (rcode.eq.NF_NOERR) then
c
c  Inquire about dimensions.
c
        do 10 n=1,ndims
          dimid=n
          rcode = nf_inq_dim (ncid,dimid,dimnam,dimsiz)
          if (rcode.ne.NF_NOERR) then
            write(stdout,920) n,grdname(sbgn:send),nf_strerror(rcode)
            call exitus('READ_GRIDS')
          endif
          call length (dimnam,sln2,sbn2,snd2)
          if((dimnam(sbn2:snd2).eq.'lon').or.
     *       (dimnam(sbn2:snd2).eq.'tlon')) then
            im=dimsiz
            tlondim=dimid
          elseif(dimnam(sbn2:snd2).eq.'vlon') then
            im=dimsiz
            vlondim=dimid
          elseif((dimnam(sbn2:snd2).eq.'lat').or.
     *           (dimnam(sbn2:snd2).eq.'tlat')) then
            jm=dimsiz
            tlatdim=dimid
          elseif(dimnam(sbn2:snd2).eq.'vlat') then
            jm=dimsiz
            vlatdim=dimid
          elseif(dimnam(sbn2:snd2).eq.'ncseg') then
            nseg=dimsiz
            ncsegdim=dimid
          elseif(dimnam(sbn2:snd2).eq.'lcseg') then
            lsegmx=dimsiz
            lcsegdim=dimid
          elseif(dimnam(sbn2:snd2).eq.'island') then
            nisle=dimsiz
            isledim=dimid
          endif
  10    continue
c
c  Inquire about variables.  Check if Land/Sea variables exist.
c
        llandt=.false.
        llandv=.false.
        lcstseg=.false.
        llenseg=.false.
        lisbox=.false.
        do 20 n=1,nvars
          varid=n
          rcode = nf_inq_var (ncid,varid,varnam(n),vartyp,nvdims(n),
     *                        vdims(1,n),nvatts)
          if (rcode.ne.NF_NOERR) then
            write(stdout,930) n,grdname(sbgn:send),nf_strerror(rcode)
            call exitus('READ_GRIDS')
          endif
          call length (varnam(n),sln2,sbn2,snd2)
          if(varnam(n)(sbn2:snd2).eq.'raw_bath') then
            bathid=varid
          elseif(varnam(n)(sbn2:snd2).eq.'landt') then
            landtid=varid
            llandt=.true.
          elseif(varnam(n)(sbn2:snd2).eq.'landv') then
            landvid=varid
            llandv=.true.
          elseif(varnam(n)(sbn2:snd2).eq.'icoast') then
            csegxid=varid
            lcstseg=.true.
          elseif(varnam(n)(sbn2:snd2).eq.'jcoast') then
            csegyid=varid
            lcstseg=.true.
          elseif(varnam(n)(sbn2:snd2).eq.'lencoast') then
            llenseg=.true.
          elseif(varnam(n)(sbn2:snd2).eq.'isis') then
            isisid=varid
            lisbox=.true.
          elseif(varnam(n)(sbn2:snd2).eq.'ieis') then
            ieisid=varid
            lisbox=.true.
          elseif(varnam(n)(sbn2:snd2).eq.'jsis') then
            jsisid=varid
            lisbox=.true.
          elseif(varnam(n)(sbn2:snd2).eq.'jeis') then
            jeisid=varid
            lisbox=.true.
          endif
  20    continue
      else
        write(stdout,940) grdname(sbgn:send),nf_strerror(rcode)
        call exitus('READ_GRIDS')
      endif
c
c-----------------------------------------------------------------------
c  Read in raw bathymetry.
c-----------------------------------------------------------------------
c
      rcode = nf_get_var_real (ncid,bathid,topo)
      if (rcode.ne.NF_NOERR) then
        write(stdout,950) 'raw_bath',grdname(sbgn:send),
     &                    nf_strerror(rcode)
        call exitus('READ_GRIDS')
      endif
c
c-----------------------------------------------------------------------
c  Read in Land/Sea mask at the tracer points.
c-----------------------------------------------------------------------
c
      if (llandt) then
        rcode = nf_get_var_int (ncid,landtid,landt)
        if (rcode.ne.NF_NOERR) then
          write(stdout,950) 'landt',grdname(sbgn:send),
     &                      nf_strerror(rcode)
          call exitus('READ_GRIDS')
        endif
      endif
c
 900  format(/,'READ_GRIDS - invalid (zero length) NetCDF filename')
 910  format(/,'READ_GRIDS - unable to open NetCDF file: ',a/13x,a)
 920  format(/' READ_GRIDS - error while inquiring about dimension: ',
     *       i3,2x,' in open NetCDF file: ',a/13x,a)
 930  format(/' READ_GRIDS - error while inquiring about variable: ',
     *       i3,2x,' in open NetCDF file: ',a/13x,a)
 940  format(/' READ_GRIDS - unable to inquire about contents of',
     *        ' open NetCDF file: ',a/13x,a)
 950  format(/' READ_GRIDS - error while reading variable: ',
     *       a,2x,' in open NetCDF file: ',a/13x,a)
      return
      end
