      function valid_st (nx,im,jm,ismask,bndptr,mxlst,nfld,bndnodes)
c
c=======================================================================
c                                                                    ===
c  This routine determines if the first node in the boundary list is ===
c  a valid starting point for a coastline.                           ===
c                                                                    ===
c  ------                                                            ===
c  Input:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     NX         Leading dimension of ISMASK.     (integer)          ===
c     IM         Number of x-points in mask.      (integer)          ===
c     JM         Number of y-points in mask.      (integer)          ===
c     ISMASK     Land/Sea/Coast mask.             (integer array)    ===
c     BNDPTR     Pointer to boundary nodes.       (integer)          ===
c     MXLST      Maximum length of BNDNODES.      (integer)          ===
c     NFLD       Number of fields in BNDNODES.    (integer)          ===
c     BNDNODES   List of boundary nodes.          (integer array)    ===
c                                                                    ===
c  -------                                                           ===
c  Output:                                                           ===
c  -------                                                           ===
c                                                                    ===
c     VALID_ST   Indicates if first node is a                        ===
c                valid starting point for coast.  (logical)          ===
c                                                                    ===
c  ------                                                            ===
c  Calls:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     none                                                           ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer bndptr,cstval,i0,i1,im,j0,j1,jm,landval,mxlst,nfld,nx,
     &        nxtptr
      integer bndnodes(mxlst,nfld),ismask(nx,jm)
      logical valid_st
c
      parameter (cstval=1, landval=2)
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c-----------------------------------------------------------------------
c  Find next boundary point.
c-----------------------------------------------------------------------
c
      if (bndptr.ne.0) then
         nxtptr = bndnodes(bndptr,nfld)
      end if
c
c-----------------------------------------------------------------------
c  Test current boundary point for validity.
c-----------------------------------------------------------------------
c
      if ( (bndptr.ne.0) .and. (nxtptr.ne.0) ) then
c
         i0       = bndnodes(bndptr,1)
         j0       = bndnodes(bndptr,2)
         i1       = bndnodes(nxtptr,1)
         j1       = bndnodes(nxtptr,2)
         valid_st = (ismask(i0,j0).eq.cstval) .and.
     &              (ismask(i1,j1).eq.landval)
c
       else
c
         valid_st = .false.
c
      end if
c
      return
      end
