      subroutine write_mask (grdname)
c
c=======================================================================
c                                                                    ===
c  This routine writes out Land/Sea mask data into GRIDS NetCDF      ===
c  file.                                                             ===
c                                                                    ===
c  On Input:                                                         ===
c                                                                    ===
c     GRDNAME   GRIDS NetCDF file name (character).                  ===
c                                                                    ===
c  Calls:  EXITUS, LENGTH                                            ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <param.h>
#include <cstmsk.h>
#include <netcdf.inc>
#include <version.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer lcseg_def,n,ncseg_def,nisle_def,rcode,sbgn,sbn2,sbn3,send,
     *        slen,sln2,sln3,snd2,snd3,varid
      integer count(2),fdim(2),start(2),work(np)
      integer pe_seaseg
      character*(*) grdname
      character*10  text
      character*44  date_str
      character*120 history
      character*256 wkstr
      data ncseg_def /mcseg/
      data lcseg_def /mpseg/
      data nisle_def /misle/
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c  Create hystory attribute label.
c
      call get_date(date_str)
      call length (date_str,slen,sbgn,send)
      call length (model,sln2,sbn2,snd2)
      call length (vnum,sln3,sbn3,snd3)
      if (slen.gt.0) then
        history=model(sbn2:snd2)//', Version '//vnum(sbn3:snd3)//', '//
     *          date_str(sbgn:send)
      else
        history=model(sbn2:snd2)//', Version '//vnum(sbn3:snd3)
      endif
c
c-----------------------------------------------------------------------
c  Put GRIDS NetCDF file into define mode and define mask varables.
c-----------------------------------------------------------------------
c
c  Put file into define mode.
c
      call length (grdname,slen,sbgn,send)
c
      rcode = nf_redef (ncid)
c
      if (rcode.eq.NF_NOERR) then
        ncstat = 1
       else
        write(stdout,900) grdname(sbgn:send),nf_strerror(rcode)
        call exitus('WRITE_MASK')
      endif
c
c  Define new dimensions.
c
      if((.not.lcstseg).or.(.not.llenseg)) then
        write(text,'(i10)') mcseg
        call length (text,sln2,sbn2,snd2)
        write(stdout,10) text(sbn2:snd2)
  10    format(/,' Defining Land/Sea Mask data for GRIDS NetCDF:',/,
     *           ' --------------------------------------------',/,
     *           '   (maximum and default values in brackets)',/,
     *         /,' Enter maximum number of coastal segments to define',
     *           ' [',a,'] :')
        read(stdinp,20) text
  20    format(a)
        call length (text,sln2,sbn2,snd2)
        if(sln2.gt.0) then
          read(text,'(i10)') ncseg_def
        else
          ncseg_def=mcseg
        endif
        if (ncseg_def.gt.mcseg) then
          write(stdout,910) 'MCSEG = ',mcseg,ncseg_def
          call exitus ('WRITE_MASK')
        endif
        rcode = nf_def_dim (ncid,'ncseg',ncseg_def,ncsegdim)
        if (rcode.ne.NF_NOERR) then
          write(stdout,920) 'ncseg',grdname(sbgn:send),
     &                      nf_strerror(rcode)
          call exitus('WRITE_MASK')
        endif
c
        write(text,'(i10)') mpseg
        call length (text,sln2,sbn2,snd2)
        write(stdout,30) text(sbn2:snd2)
  30    format(' Enter maximum number of points per coastal segments',
     *         ' to define [',a,'] :')
        read(stdinp,20) text
        call length (text,sln2,sbn2,snd2)
        if(sln2.gt.0) then
          read(text,'(i10)') lcseg_def
        else
          lcseg_def=mpseg
        endif
        if(lcseg_def.gt.mpseg) then
          write(stdout,910) 'MPSEG = ',mpseg,lcseg_def
          call exitus('WRITE_MASK')
        endif
        rcode = nf_def_dim (ncid,'lcseg',lcseg_def,lcsegdim)
        if (rcode.ne.NF_NOERR) then
          write(stdout,920) 'ncseg',grdname(sbgn:send),
     &                      nf_strerror(rcode)
          call exitus('WRITE_MASK')
        endif
c
       else
c
c    Extract maximum sizes.
c
        rcode = nf_inq_dimid (ncid,'ncseg',ncsegdim)
        if (rcode.ne.NF_NOERR) then
          write(stdout,955) 'ncseg',grdname(sbgn:send),
     &                      nf_strerror(rcode)
          call exitus('WRITE_MASK')
        endif
        rcode = nf_inq_dimlen (ncid,ncsegdim,ncseg_def)
        if (rcode.ne.NF_NOERR) then
          write(stdout,965) 'ncseg',grdname(sbgn:send),
     &                      nf_strerror(rcode)
          call exitus('WRITE_MASK')
        endif
        ncseg_def = min (ncseg_def,mcseg)
c
        rcode = nf_inq_dimid (ncid,'lcseg',lcsegdim)
        if (rcode.ne.NF_NOERR) then
          write(stdout,955) 'lcseg',grdname(sbgn:send),
     &                      nf_strerror(rcode)
          call exitus('WRITE_MASK')
        endif
        rcode = nf_inq_dimlen (ncid,lcsegdim,lcseg_def)
        if (rcode.ne.NF_NOERR) then
          write(stdout,965) 'lcseg',grdname(sbgn:send),
     &                      nf_strerror(rcode)
          call exitus('WRITE_MASK')
        endif
        lcseg_def = min (lcseg_def,mpseg)
      endif
c
      if((.not.lisbox).and.(nisle.gt.0)) then
        write(text,'(i10)') misle
        call length (text,sln2,sbn2,snd2)
        write(stdout,40) text(sbn2:snd2)
  40    format(' Enter maximum number of islands to'
     *         ,' define [',a,'] :')
        read(stdinp,20) text
        call length (text,sln2,sbn2,snd2)
        if(sln2.gt.0) then
          read(text,'(i10)') nisle_def
        else
          nisle_def=misle
        endif
        if (nisle_def.gt.misle) then
          write(stdout,910) 'MISLE = ',misle,nisle_def
          call exitus('WRITE_MASK')
        endif
        rcode = nf_def_dim (ncid,'island',nisle_def,isledim)
        if (rcode.ne.NF_NOERR) then
          write(stdout,920) 'island',grdname(sbgn:send),
     &                      nf_strerror(rcode)
          call exitus('WRITE_MASK')
        endif
c
       elseif(lisbox.and.(nisle.gt.0)) then
c
c    Extract maximum sizes.
c
        rcode = nf_inq_dimid (ncid,'island',isledim)
        if (rcode.ne.NF_NOERR) then
          write(stdout,955) 'island',grdname(sbgn:send),
     &                      nf_strerror(rcode)
          call exitus('WRITE_MASK')
        endif
        rcode = nf_inq_dimlen (ncid,isledim,nisle_def)
        if (rcode.ne.NF_NOERR) then
          write(stdout,965) 'island',grdname(sbgn:send),
     &                      nf_strerror(rcode)
          call exitus('WRITE_MASK')
        endif
        nisle_def = min (nisle_def,misle)
      endif
c
c  Define number of coastal segments and its maximum length.
c
      if((.not.lcstseg).or.(.not.llenseg)) then
        rcode = nf_def_var (ncid,'ncseg',NF_INT,0,0,varid)
        if (rcode.ne.NF_NOERR) then
          write(stdout,930) 'ncseg',grdname(sbgn:send),
     &                      nf_strerror(rcode)
          call exitus('WRITE_MASK')
        endif
        wkstr = 'number of coastal segments'
        call length (wkstr,sln2,sbn2,snd2)
        rcode = nf_put_att_text (ncid,varid,'long_name',sln2,
     *                           wkstr(sbn2:snd2))
        if (rcode.ne.NF_NOERR) then
          write(stdout,940) 'ncseg:long_name',grdname(sbgn:send),
     &                      nf_strerror(rcode)
          call exitus('WRITE_MASK')
        endif
c
        rcode = nf_def_var (ncid,'lcseg',NF_INT,0,0,varid)
        if (rcode.ne.NF_NOERR) then
          write(stdout,930) 'lcseg',grdname(sbgn:send),
     &                      nf_strerror(rcode)
          call exitus('WRITE_MASK')
        endif
        wkstr = 'maximum length of coastal segments'
        call length (wkstr,sln2,sbn2,snd2)
        rcode = nf_put_att_text (ncid,varid,'long_name',sln2,
     *                           wkstr(sbn2:snd2))
        if (rcode.ne.NF_NOERR) then
          write(stdout,940) 'lcseg:long_name',grdname(sbgn:send),
     &                      nf_strerror(rcode)
          call exitus('WRITE_MASK')
        endif
      endif
c
c  Define number of islands in the basin.
c
      if((.not.lisbox).and.(nisle.gt.0)) then
        rcode = nf_def_var (ncid,'nisle',NF_INT,0,0,varid)
        if (rcode.ne.NF_NOERR) then
          write(stdout,930) 'nisle',grdname(sbgn:send),
     &                      nf_strerror(rcode)
          call exitus('WRITE_MASK')
        endif
        wkstr = 'number of islands'
        call length (wkstr,sln2,sbn2,snd2)
        rcode = nf_put_att_text (ncid,varid,'long_name',sln2,
     *                           wkstr(sbn2:snd2))
        if (rcode.ne.NF_NOERR) then
          write(stdout,940) 'nisle:long_name',grdname(sbgn:send),
     &                      nf_strerror(rcode)
          call exitus('WRITE_MASK')
        endif
      endif
c
c  Define the coastal segments and their length.
c
      if((.not.lcstseg).or.(.not.llenseg)) then
        rcode = nf_def_var (ncid,'lencoast',NF_INT,1,ncsegdim,varid)
        if (rcode.ne.NF_NOERR) then
          write(stdout,930) 'lencoast',grdname(sbgn:send),
     &                      nf_strerror(rcode)
          call exitus('WRITE_MASK')
        endif
        wkstr = 'length of coastal segments'
        call length (wkstr,sln2,sbn2,snd2)
        rcode = nf_put_att_text (ncid,varid,'long_name',sln2,
     *                           wkstr(sbn2:snd2))
        if (rcode.ne.NF_NOERR) then
          write(stdout,940) 'lencoast:long_name',grdname(sbgn:send),
     &                      nf_strerror(rcode)
          call exitus('WRITE_MASK')
        endif
        rcode = nf_put_att_int (ncid,varid,'_FillValue',NF_INT,1,0)
        if (rcode.ne.NF_NOERR) then
          write(stdout,940) 'lencoast:_FillValue',grdname(sbgn:send),
     &                      nf_strerror(rcode)
          call exitus('WRITE_MASK')
        endif
c
        fdim(1)=lcsegdim
        fdim(2)=ncsegdim
        rcode = nf_def_var (ncid,'icoast',NF_INT,2,fdim,csegxid)
        if (rcode.ne.NF_NOERR) then
          write(stdout,930) 'icoast',grdname(sbgn:send),
     &                      nf_strerror(rcode)
          call exitus('WRITE_MASK')
        endif
        wkstr = 'coastal segment x-index coordinate'
        call length (wkstr,sln2,sbn2,snd2)
        rcode = nf_put_att_text (ncid,csegxid,'long_name',sln2,
     &                           wkstr(sbn2:snd2))
        if (rcode.ne.NF_NOERR) then
          write(stdout,940) 'icoast:long_name',grdname(sbgn:send),
     &                      nf_strerror(rcode)
          call exitus('WRITE_MASK')
        endif
        rcode = nf_put_att_int (ncid,csegxid,'valid_min',NF_INT,1,1)
        if (rcode.ne.NF_NOERR) then
          write(stdout,940) 'icoast:valid_min',grdname(sbgn:send),
     &                      nf_strerror(rcode)
          call exitus('WRITE_MASK')
        endif
        rcode = nf_put_att_int (ncid,csegxid,'valid_max',NF_INT,1,im)
        if (rcode.ne.NF_NOERR) then
          write(stdout,940) 'icoast:valid_max',grdname(sbgn:send),
     &                      nf_strerror(rcode)
          call exitus('WRITE_MASK')
        endif
        rcode = nf_put_att_int (ncid,csegxid,'_FillValue',NF_INT,1,0)
        if (rcode.ne.NF_NOERR) then
          write(stdout,940) 'icoast:_FillValue',grdname(sbgn:send),
     &                      nf_strerror(rcode)
          call exitus('WRITE_MASK')
        endif
c
        rcode = nf_def_var (ncid,'jcoast',NF_INT,2,fdim,csegyid)
        if (rcode.ne.NF_NOERR) then
          write(stdout,930) 'jcoast',grdname(sbgn:send),
     &                      nf_strerror(rcode)
          call exitus('WRITE_MASK')
        endif
        wkstr = 'coastal segment y-index coordinate'
        call length (wkstr,sln2,sbn2,snd2)
        rcode = nf_put_att_text (ncid,csegyid,'long_name',sln2,
     &                           wkstr(sbn2:snd2))
        if (rcode.ne.NF_NOERR) then
          write(stdout,940) 'jcoast:long_name',grdname(sbgn:send),
     &                      nf_strerror(rcode)
          call exitus('WRITE_MASK')
        endif
        rcode = nf_put_att_int (ncid,csegyid,'valid_min',NF_INT,1,1)
        if (rcode.ne.NF_NOERR) then
          write(stdout,940) 'jcoast:valid_min',grdname(sbgn:send),
     &                      nf_strerror(rcode)
          call exitus('WRITE_MASK')
        endif
        rcode = nf_put_att_int (ncid,csegyid,'valid_max',NF_INT,1,jm)
        if (rcode.ne.NF_NOERR) then
          write(stdout,940) 'jcoast:valid_max',grdname(sbgn:send),
     &                      nf_strerror(rcode)
          call exitus('WRITE_MASK')
        endif
        rcode = nf_put_att_int (ncid,csegyid,'_FillValue',NF_INT,1,0)
        if (rcode.ne.NF_NOERR) then
          write(stdout,940) 'jcoast:_FillValue',grdname(sbgn:send),
     &                      nf_strerror(rcode)
          call exitus('WRITE_MASK')
        endif
      endif
c
c  Define Land/Sea mask at the tracer points.
c
      if(.not.llandt) then
        fdim(1)=tlondim
        fdim(2)=tlatdim
        rcode = nf_def_var (ncid,'landt',NF_INT,2,fdim,landtid)
        if (rcode.ne.NF_NOERR) then
          write(stdout,930) 'landt',grdname(sbgn:send),
     &                      nf_strerror(rcode)
          call exitus('WRITE_MASK')
        endif
        wkstr = 'land/sea mask at tracer points'
        call length (wkstr,sln2,sbn2,snd2)
        rcode = nf_put_att_text (ncid,landtid,'long_name',sln2,
     &                           wkstr(sbn2:snd2))
        if (rcode.ne.NF_NOERR) then
          write(stdout,940) 'landt:long_name',grdname(sbgn:send),
     &                      nf_strerror(rcode)
          call exitus('WRITE_MASK')
        endif
        wkstr = 'land'
        call length (wkstr,sln2,sbn2,snd2)
        rcode = nf_put_att_text (ncid,landtid,'option_0',sln2,
     &                           wkstr(sbn2:snd2))
        if (rcode.ne.NF_NOERR) then
          write(stdout,940) 'landt:option_0',grdname(sbgn:send),
     &                      nf_strerror(rcode)
          call exitus('WRITE_MASK')
        endif
        wkstr = 'sea'
        call length (wkstr,sln2,sbn2,snd2)
        rcode = nf_put_att_text (ncid,landtid,'option_1',sln2,
     &                           wkstr(sbn2:snd2))
        if (rcode.ne.NF_NOERR) then
          write(stdout,940) 'landt:option_1',grdname(sbgn:send),
     &                      nf_strerror(rcode)
          call exitus('WRITE_MASK')
        endif
        wkstr = 'Tmask, scalar'
        call length (wkstr,sln2,sbn2,snd2)
        rcode = nf_put_att_text (ncid,landtid,'field',sln2,
     &                           wkstr(sbn2:snd2))
        if (rcode.ne.NF_NOERR) then
          write(stdout,940) 'landt:field',grdname(sbgn:send),
     &                      nf_strerror(rcode)
          call exitus('WRITE_MASK')
        endif
        wkstr = 'tgrid2'
        call length (wkstr,sln2,sbn2,snd2)
        rcode = nf_put_att_text (ncid,landtid,'positions',sln2,
     &                           wkstr(sbn2:snd2))
        if (rcode.ne.NF_NOERR) then
          write(stdout,940) 'landt:positions',grdname(sbgn:send),
     &                      nf_strerror(rcode)
          call exitus('WRITE_MASK')
        endif
      endif
      rcode = nf_put_att_int (ncid,landtid,'pe_seaseg',NF_INT,1,
     &                        pe_seaseg(landt,im,jm,work))
      if (rcode.ne.NF_NOERR) then
        write(stdout,940) 'landt:pe_seaseg',grdname(sbgn:send),
     &                    nf_strerror(rcode)
        call exitus('WRITE_MASK')
      endif
c
c  Define Land/Sea mask at the velocity points.
c
      if(.not.llandv) then
        fdim(1)=vlondim
        fdim(2)=vlatdim
        rcode = nf_def_var (ncid,'landv',NF_INT,2,fdim,landvid)
        if (rcode.ne.NF_NOERR) then
          write(stdout,930) 'landv',grdname(sbgn:send),
     &                      nf_strerror(rcode)
          call exitus('WRITE_MASK')
        endif
        wkstr = 'land/sea mask at velocity points'
        call length (wkstr,sln2,sbn2,snd2)
        rcode = nf_put_att_text (ncid,landvid,'long_name',sln2,
     &                           wkstr(sbn2:snd2))
        if (rcode.ne.NF_NOERR) then
          write(stdout,940) 'landv:long_name',grdname(sbgn:send),
     &                      nf_strerror(rcode)
          call exitus('WRITE_MASK')
        endif
        wkstr = 'land'
        call length (wkstr,sln2,sbn2,snd2)
        rcode = nf_put_att_text (ncid,landvid,'option_0',sln2,
     &                           wkstr(sbn2:snd2))
        if (rcode.ne.NF_NOERR) then
          write(stdout,940) 'landv:option_0',grdname(sbgn:send),
     &                      nf_strerror(rcode)
          call exitus('WRITE_MASK')
        endif
        wkstr = 'boundary'
        call length (wkstr,sln2,sbn2,snd2)
        rcode = nf_put_att_text (ncid,landvid,'option_1',sln2,
     &                           wkstr(sbn2:snd2))
        if (rcode.ne.NF_NOERR) then
          write(stdout,940) 'landv:option_1',grdname(sbgn:send),
     &                      nf_strerror(rcode)
          call exitus('WRITE_MASK')
        endif
        wkstr = 'sea'
        call length (wkstr,sln2,sbn2,snd2)
        rcode = nf_put_att_text (ncid,landvid,'option_2',sln2,
     &                           wkstr(sbn2:snd2))
        if (rcode.ne.NF_NOERR) then
          write(stdout,940) 'landv:option_2',grdname(sbgn:send),
     &                      nf_strerror(rcode)
          call exitus('WRITE_MASK')
        endif
        wkstr = 'Vmask, scalar'
        call length (wkstr,sln2,sbn2,snd2)
        rcode = nf_put_att_text (ncid,landvid,'field',sln2,
     &                           wkstr(sbn2:snd2))
        if (rcode.ne.NF_NOERR) then
          write(stdout,940) 'landv:field',grdname(sbgn:send),
     &                      nf_strerror(rcode)
          call exitus('WRITE_MASK')
        endif
        wkstr = 'vgrid2'
        call length (wkstr,sln2,sbn2,snd2)
        rcode = nf_put_att_text (ncid,landvid,'positions',sln2,
     &                           wkstr(sbn2:snd2))
        if (rcode.ne.NF_NOERR) then
          write(stdout,940) 'landv:positions',grdname(sbgn:send),
     &                      nf_strerror(rcode)
          call exitus('WRITE_MASK')
        endif
      endif
c
c  Define corners of the island boxes.
c
      if((.not.lisbox).and.(nisle.gt.0)) then
        rcode = nf_def_var (ncid,'isis',NF_INT,1,isledim,isisid)
        if (rcode.ne.NF_NOERR) then
          write(stdout,930) 'isis',grdname(sbgn:send),
     &                      nf_strerror(rcode)
          call exitus('WRITE_MASK')
        endif
        wkstr = 'starting x-index coordinate of island box'
        call length (wkstr,sln2,sbn2,snd2)
        rcode = nf_put_att_text (ncid,isisid,'long_name',sln2,
     &                           wkstr(sbn2:snd2))
        if (rcode.ne.NF_NOERR) then
          write(stdout,940) 'isis:long_name',grdname(sbgn:send),
     &                      nf_strerror(rcode)
          call exitus('WRITE_MASK')
        endif
        rcode = nf_put_att_int (ncid,isisid,'valid_min',NF_INT,1,1)
        if (rcode.ne.NF_NOERR) then
          write(stdout,940) 'isis:valid_min',grdname(sbgn:send),
     &                      nf_strerror(rcode)
          call exitus('WRITE_MASK')
        endif
        rcode = nf_put_att_int (ncid,isisid,'valid_max',NF_INT,1,im)
        if (rcode.ne.NF_NOERR) then
          write(stdout,940) 'isis:valid_max',grdname(sbgn:send),
     &                      nf_strerror(rcode)
          call exitus('WRITE_MASK')
        endif
c
        rcode = nf_def_var (ncid,'ieis',NF_INT,1,isledim,ieisid)
        if (rcode.ne.NF_NOERR) then
          write(stdout,930) 'ieis',grdname(sbgn:send),
     &                      nf_strerror(rcode)
          call exitus('WRITE_MASK')
        endif
        wkstr = 'ending x-index coordinate of island box'
        call length (wkstr,sln2,sbn2,snd2)
        rcode = nf_put_att_text (ncid,ieisid,'long_name',sln2,
     &                           wkstr(sbn2:snd2))
        if (rcode.ne.NF_NOERR) then
          write(stdout,940) 'ieis:long_name',grdname(sbgn:send),
     &                      nf_strerror(rcode)
          call exitus('WRITE_MASK')
        endif
        rcode = nf_put_att_int (ncid,ieisid,'valid_min',NF_INT,1,1)
        if (rcode.ne.NF_NOERR) then
          write(stdout,940) 'ieis:valid_min',grdname(sbgn:send),
     &                      nf_strerror(rcode)
          call exitus('WRITE_MASK')
        endif
        rcode = nf_put_att_int (ncid,ieisid,'valid_max',NF_INT,1,im)
        if (rcode.ne.NF_NOERR) then
          write(stdout,940) 'ieis:valid_max',grdname(sbgn:send),
     &                      nf_strerror(rcode)
          call exitus('WRITE_MASK')
        endif
c
        rcode = nf_def_var (ncid,'jsis',NF_INT,1,isledim,jsisid)
        if (rcode.ne.NF_NOERR) then
          write(stdout,930) 'jsis',grdname(sbgn:send),
     &                      nf_strerror(rcode)
          call exitus('WRITE_MASK')
        endif
        wkstr = 'starting y-index coordinate of island box'
        call length (wkstr,sln2,sbn2,snd2)
        rcode = nf_put_att_text (ncid,jsisid,'long_name',sln2,
     &                           wkstr(sbn2:snd2))
        if (rcode.ne.NF_NOERR) then
          write(stdout,940) 'jsis:long_name',grdname(sbgn:send),
     &                      nf_strerror(rcode)
          call exitus('WRITE_MASK')
        endif
        rcode = nf_put_att_int (ncid,jsisid,'valid_min',NF_INT,1,1)
        if (rcode.ne.NF_NOERR) then
          write(stdout,940) 'jsis:valid_min',grdname(sbgn:send),
     &                      nf_strerror(rcode)
          call exitus('WRITE_MASK')
        endif
        rcode = nf_put_att_int (ncid,jsisid,'valid_max',NF_INT,1,jm)
        if (rcode.ne.NF_NOERR) then
          write(stdout,940) 'jsis:valid_max',grdname(sbgn:send),
     &                      nf_strerror(rcode)
          call exitus('WRITE_MASK')
        endif
c
        rcode = nf_def_var (ncid,'jeis',NF_INT,1,isledim,jeisid)
        if (rcode.ne.NF_NOERR) then
          write(stdout,930) 'jeis',grdname(sbgn:send),
     &                      nf_strerror(rcode)
          call exitus('WRITE_MASK')
        endif
        wkstr = 'ending y-index coordinate of island box'
        call length (wkstr,sln2,sbn2,snd2)
        rcode = nf_put_att_text (ncid,jeisid,'long_name',sln2,
     &                           wkstr(sbn2:snd2))
        if (rcode.ne.NF_NOERR) then
          write(stdout,940) 'jeis:long_name',grdname(sbgn:send),
     &                      nf_strerror(rcode)
          call exitus('WRITE_MASK')
        endif
        rcode = nf_put_att_int (ncid,jeisid,'valid_min',NF_INT,1,1)
        if (rcode.ne.NF_NOERR) then
          write(stdout,940) 'jeis:valid_min',grdname(sbgn:send),
     &                      nf_strerror(rcode)
          call exitus('WRITE_MASK')
        endif
        rcode = nf_put_att_int (ncid,jeisid,'valid_max',NF_INT,1,jm)
        if (rcode.ne.NF_NOERR) then
          write(stdout,940) 'jeis:valid_max',grdname(sbgn:send),
     &                      nf_strerror(rcode)
          call exitus('WRITE_MASK')
        endif
      endif
c
c  Leave define mode.
c
      rcode = nf_enddef (ncid)
c
      if (rcode.eq.NF_NOERR) then
        ncstat = 2
       else
        write(stdout,950) grdname(sbgn:send),nf_strerror(rcode)
        call exitus('WRITE_MASK')
      endif
c
c-----------------------------------------------------------------------
c  Write out Land/Sea mask data.
c-----------------------------------------------------------------------
c
c  Write out number of coastal segments, maximum length of coastal
c  segments and number of islands.
c
      rcode = nf_inq_varid (ncid,'ncseg',varid)
      if (rcode.ne.NF_NOERR) then
        write(stdout,960) 'ncseg',grdname(sbgn:send),nf_strerror(rcode)
        call exitus('WRITE_MASK')
      endif
      rcode = nf_put_var1_int (ncid,varid,1,nseg)
      if (rcode.ne.NF_NOERR) then
        write(stdout,970) 'ncseg',grdname(sbgn:send),nf_strerror(rcode)
        call exitus('WRITE_MASK')
      endif
c
      rcode = nf_inq_varid (ncid,'lcseg',varid)
      if (rcode.ne.NF_NOERR) then
        write(stdout,960) 'lcseg',grdname(sbgn:send),nf_strerror(rcode)
        call exitus('WRITE_MASK')
      endif
      rcode = nf_put_var1_int (ncid,varid,1,lsegmx)
      if (rcode.ne.NF_NOERR) then
        write(stdout,970) 'lcseg',grdname(sbgn:send),nf_strerror(rcode)
        call exitus('WRITE_MASK')
      endif
c
      if(nisle.gt.0) then
        rcode = nf_inq_varid (ncid,'nisle',varid)
        if (rcode.ne.NF_NOERR) then
          write(stdout,960) 'nisle',grdname(sbgn:send),
     &                      nf_strerror(rcode)
          call exitus('WRITE_MASK')
        endif
        rcode = nf_put_var1_int (ncid,varid,1,nisle)
        if (rcode.ne.NF_NOERR) then
          write(stdout,970) 'nisle',grdname(sbgn:send),
     &                      nf_strerror(rcode)
          call exitus('WRITE_MASK')
        endif
      endif
c
c  Write out length and indices for the coastal segments.
c
      start(1)=1
      count(1)=ncseg_def
      rcode = nf_inq_varid (ncid,'lencoast',varid)
      if (rcode.ne.NF_NOERR) then
        write(stdout,960) 'lencoast',grdname(sbgn:send),
     &                    nf_strerror(rcode)
        call exitus('WRITE_MASK')
      endif
      rcode = nf_put_vara_int (ncid,varid,start,count,lenseg)
      if (rcode.ne.NF_NOERR) then
        write(stdout,970) 'lencoast',grdname(sbgn:send),
     &                    nf_strerror(rcode)
        call exitus('WRITE_MASK')
      endif
c
      do 50 n=1,ncseg_def
        start(1)=1
        count(1)=lcseg_def
        start(2)=n
        count(2)=1
        rcode = nf_put_vara_int (ncid,csegxid,start,count,cstsegx(1,n))
        if (rcode.ne.NF_NOERR) then
          write(stdout,980) 'icoast',n,grdname(sbgn:send),
     &                      nf_strerror(rcode)
          call exitus('WRITE_MASK')
        endif
c
        rcode = nf_put_vara_int (ncid,csegyid,start,count,cstsegy(1,n))
        if (rcode.ne.NF_NOERR) then
          write(stdout,980) 'jcoast',n,grdname(sbgn:send),
     &                      nf_strerror(rcode)
          call exitus('WRITE_MASK')
        endif
  50  continue 
c
c  Write out Land/Sea mask at tracer and velocity points.
c
      rcode = nf_put_var_int (ncid,landtid,landt)
      if (rcode.ne.NF_NOERR) then
        write(stdout,970) 'landt',grdname(sbgn:send),
     &                    nf_strerror(rcode)
        call exitus('WRITE_MASK')
      endif
c
      rcode = nf_put_var_int (ncid,landvid,landv)
      if (rcode.ne.NF_NOERR) then
        write(stdout,970) 'landv',grdname(sbgn:send),
     &                    nf_strerror(rcode)
        call exitus('WRITE_MASK')
      endif
c
c  Write out starting and ending incides for the island boxes.
c
      if(nisle.gt.0) then
        start(1)=1
        count(1)=nisle_def
        rcode = nf_put_vara_int (ncid,isisid,start,count,isis)
        if (rcode.ne.NF_NOERR) then
          write(stdout,970) 'isis',grdname(sbgn:send),
     &                      nf_strerror(rcode)
          call exitus('WRITE_MASK')
        endif
c
        rcode = nf_put_vara_int (ncid,ieisid,start,count,ieis)
        if (rcode.ne.NF_NOERR) then
          write(stdout,970) 'ieis',grdname(sbgn:send),
     &                      nf_strerror(rcode)
          call exitus('WRITE_MASK')
        endif
c
        rcode = nf_put_vara_int (ncid,jsisid,start,count,jsis)
        if (rcode.ne.NF_NOERR) then
          write(stdout,970) 'jsis',grdname(sbgn:send),
     &                      nf_strerror(rcode)
          call exitus('WRITE_MASK')
        endif
c
        rcode = nf_put_vara_int (ncid,jeisid,start,count,jeis)
        if (rcode.ne.NF_NOERR) then
          write(stdout,970) 'jeis',grdname(sbgn:send),
     &                      nf_strerror(rcode)
          call exitus('WRITE_MASK')
        endif
      endif
c
c-----------------------------------------------------------------------
c  Write new global attribute.
c-----------------------------------------------------------------------
c
c  Put in define mode.
c
c
      rcode = nf_redef (ncid)
c
      if (rcode.eq.NF_NOERR) then
        ncstat = 1
       else
        write(stdout,900) grdname(sbgn:send),nf_strerror(rcode)
        call exitus('WRITE_MASK')
      endif
c
c  Put new global attribute: MASK.
c
      call length (history,sln2,sbn2,snd2)
      rcode = nf_put_att_text (ncid,ncglobal,'mask',sln2,
     &                         history(sbn2:snd2))
      if (rcode.ne.NF_NOERR) then
        write(stdout,990) 'mask',grdname(sbgn:send),nf_strerror(rcode)
        call exitus('WRITE_MASK')
      endif
c
c  Leave define mode.
c
      rcode = nf_enddef (ncid)
c
      if (rcode.eq.NF_NOERR) then
        ncstat = 2
       else
        write(stdout,950) grdname(sbgn:send),nf_strerror(rcode)
        call exitus('WRITE_MASK')
      endif
c
 900  format(/' WRITE_MASK - unable to put into define mode',
     *        ' the open NetCDF file: ',a/13x,a)
 910  format(/' WRITE_MASK - too small parameter value for: ',a,
     *        2i6,5x,' change file  param.h  and recompile.')
 920  format(/' WRITE_MASK - unable to create dimension ',a,2x,
     *        ' in NetCDF file: ',a/13x,a)
 930  format(/' WRITE_MASK - unable to create variable ',a,2x,
     *        ' in NetCDF file: ',a/13x,a)
 940  format(/' WRITE_MASK - unable to create attribute ',a,2x,
     *        ' in NetCDF file: ',a/13x,a)
 950  format(/' WRITE_MASK - unable to get out of define mode',
     *        ' the open NetCDF file: ',a/13x,a)
 955  format(/' WRITE_MASK - unable to find dimension ',a,2x,
     *        ' in NetCDF file: ',a/13x,a)
 960  format(/' WRITE_MASK - unable to find variable ',a,2x,
     *        ' in NetCDF file: ',a/13x,a)
 965  format(/' WRITE_MASK - unable to read dimension ',a,2x,
     *        ' in NetCDF file: ',a/13x,a)
 970  format(/' WRITE_MASK - unable to write variable ',a,2x,
     *        ' into NetCDF file: ',a/13x,a)
 980  format(/' WRITE_MASK - error while writing variable: ',a,
     *        ' at INDEX = ',i5,2x,'into NetCDF file: ',a/13x,a)
 990  format(/' WRITE_MASK - unable to write attribute ',a,2x,
     *        ' into NetCDF file: ',a/13x,a)
      return
      end
