      subroutine xtr_cst (ist,jst,cstptr,wkptr,mxlst,nfld,cstnodes,
     &                    mxlen,cstlen,iseg,jseg)
c
c=======================================================================
c                                                                    ===
c  This routine extracts a coastline starting at the given point.    ===
c                                                                    ===
c  ------                                                            ===
c  Input:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     IST        X-starting index for coast.      (integer)          ===
c     JST        Y-starting index for coast.      (integer)          ===
c     CSTPTR     Pointer to coastal nodes.        (integer)          ===
c     WKPTR      Pointer to work space.           (integer)          ===
c     MXLST      Maximum length of BNDNODES.      (integer)          ===
c     NFLD       Number of fields in BNDNODES.    (integer)          ===
c     CSTNODES   List of remaining coast nodes.   (integer array)    ===
c     MXLEN      Maximum length for coastline.    (integer)          ===
c                                                                    ===
c  -------                                                           ===
c  Output:                                                           ===
c  -------                                                           ===
c                                                                    ===
c     CSTPTR     Updated coast pointer.           (integer)          ===
c     WKPTR      Updated work space pointer.      (integer)          ===
c     CSTNODES   Updated list.                    (integer array)    ===
c     CSTLEN     Length of coastline.             (integer)          ===
c     ISEG       X-indices of coastline.          (integer vector)   ===
c     JSEG       Y-indices of coastline.          (integer vector)   ===
c                                                                    ===
c  ------                                                            ===
c  Calls:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     HOPS:  REM_ILIST                                               ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer cstlen,cstptr,ist,jst,mxlen,mxlst,nfld,wkptr
      integer cstnodes(mxlst,nfld),iseg(mxlen),jseg(mxlen),vals(2)
      logical found
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c-----------------------------------------------------------------------
c  Remove starting point from list of remaining coastal nodes.
c-----------------------------------------------------------------------
c
      cstlen = 0
c
      vals(1) = ist
      vals(2) = jst
      call rem_ilist (mxlst,nfld,cstptr,wkptr,cstnodes,vals,found)
c
c-----------------------------------------------------------------------
c  Extract remaing coastal nodes.
c-----------------------------------------------------------------------
c
      do 10 while (found)
c
c  Load current point into coastline.
c
         cstlen       = cstlen + 1
         iseg(cstlen) = vals(1)
         jseg(cstlen) = vals(2)
c
c  Attempt to remove point to EAST.
c
         vals(1) = iseg(cstlen) + 1
         vals(2) = jseg(cstlen)
         call rem_ilist (mxlst,nfld,cstptr,wkptr,cstnodes,vals,found)
c
c  Attempt to remove point to NORTH.
c
         if (.not.found) then
            vals(1) = iseg(cstlen)
            vals(2) = jseg(cstlen) + 1
            call rem_ilist (mxlst,nfld,cstptr,wkptr,cstnodes,vals,found)
         end if
c
c  Attempt to remove point to WEST.
c
         if (.not.found) then
            vals(1) = iseg(cstlen) - 1
            vals(2) = jseg(cstlen)
            call rem_ilist (mxlst,nfld,cstptr,wkptr,cstnodes,vals,found)
         end if
c
c  Attempt to move SOUTH.
c
         if (.not.found) then
            vals(1) = iseg(cstlen)
            vals(2) = jseg(cstlen) - 1
            call rem_ilist (mxlst,nfld,cstptr,wkptr,cstnodes,vals,found)
         end if
c
  10  continue
c
      return
      end
