      subroutine areafill(icolor,fill)
c
c=======================================================================
c                                                                    ===
c  This routine fills with color or with the selected pattern the    ===
c  section area masked by routine AREAMASK.                          ===
c                                                                    ===
c  On Input:                                                         ===
c                                                                    ===
c     ICOLOR   switch indicating type of section:                    ===
c              ICOLOR=0    noncolor section                          ===
c              ICOLOR=1    color section                             ===
c     FILL     switch indicating color of area file:                 ===
c              Noncolor Section:                                     ===
c                 FILL=1  default dot pattern.                       ===
c                 FILL=2  dots, square and cross patterns.           ===
c                 FILL=3  dots, slanted square pattern.              ===
c                 FILL=4  vertical lines and dots.                   ===
c                 FILL=5  vertical lines.                            ===
c                 FILL=6  tree pattern.                              ===
c              Color Section:                                        ===
c                 FILL=1  grey fill.                                 ===
c                 FILL=2  tan fill.                                  ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <param.h>
#include <pconst.h>
#include <cntwkspa.h>
#include <colpal.h>
#include <pltio.h>
#include <pltncar.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer fill,ici,icolor,ity,nst,nnd
      integer id1(8,8),id2(8,8),id3(8,8),ind(mcs)
#ifdef blckndwht
      real idum,qdum,ydum
#endif
      real dst(mcs)
      data id1 /1,1,0,0,0,0,1,1,
     *          1,1,0,1,1,0,1,1,
     *          0,0,0,1,1,0,0,0,
     *          0,1,1,1,1,1,1,0,
     *          0,1,1,1,1,1,1,0,
     *          0,0,0,1,1,0,0,0,
     *          1,1,0,1,1,0,1,1,
     *          1,1,0,0,0,0,1,1/
      data id2 /0,0,0,0,0,0,0,0,
     *          0,1,1,1,1,1,1,0,
     *          0,1,1,1,1,1,1,0,
     *          0,1,1,0,0,1,1,0,
     *          0,1,1,0,0,1,1,0,
     *          0,1,1,1,1,1,1,0,
     *          0,1,1,1,1,1,1,0,
     *          0,0,0,0,0,0,0,0/
      data id3 /0,0,0,0,0,0,0,0,
     *          0,0,0,0,1,0,0,0,
     *          0,0,0,1,1,1,0,0,
     *          0,1,0,0,1,0,0,1,
     *          0,0,1,1,1,1,1,0,
     *          0,0,0,0,1,0,0,0,
     *          0,0,0,1,0,1,0,0,
     *          0,1,1,0,0,0,1,1/
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c  Check size of work space arrays.
c
      nst=mcs
      nnd=mcs
      if(nst.lt.2*nra) then
        write(stdout,10) 2*nra,mcs
  10    format(/' AREAFILL - array size too small, NST: ',2i6)
        call exitus('AREAFILL')
      elseif(nnd.lt.nra+2*nra) then
        write(stdout,20) nra+2*nra,mcs
 20     format(/' AREAFILL - array size too small, NND: ',2i6)
        call exitus('AREAFILL')
      endif
c
c----------------------------------------------------------------------
c  Fill below water column with the default dot pattern, increasing
c  the inter-dot spacing considerably for noncolor section.  Use color
c  fill on color sections.
c----------------------------------------------------------------------
c
c  Noncolor sections.
c
      if(icolor.eq.0) then
c
c  Draw topography isoline.
c
        call curve(xra(2),yra(2),nra-1)
c
c  Fill blank and white plot.
c
        if(fill.eq.1) then
          call sfsetr('SP - spacing of fill lines',r200)
          call sfseti('AN - angle of fill lines',0)
          call sfseti('DO - dot-fill flag',1)
          call sfwrld(xra,yra,nra,dst,nst,ind,nnd)
        elseif(fill.eq.2) then
          call sfsetr('SP - spacing of fill lines',r250)
          call sfseti('DO - dot-fill flag',1)
          call sfsetp(id1)
          call sfwrld(xra,yra,nra,dst,nst,ind,nnd)
        elseif(fill.eq.3) then
          call sfseti('AN - angle of fill lines',45)
          call sfseti('DO - dot-fill flag',1)
          call sfsetp(id2)
          call sfwrld(xra,yra,nra,dst,nst,ind,nnd)
        elseif(fill.eq.4) then
          call sfsetr('SP - spacing of fill lines',p012)
          call sfseti('AN - angle of fill lines',90)
          call sfseti('DO - dot-fill flag',0)
          call sfwrld(xra,yra,nra,dst,nst,ind,nnd)
          call sfsetr('SP - spacing of fill lines',p006)
          call sfseti('AN - angle of fill lines',90)
          call sfseti('DO - dot-fill flag',1)
          call sfnorm(xra,yra,nra,dst,nst,ind,nnd)
        elseif(fill.eq.5) then
          call sfsetr('SP - spacing of fill lines',r200)
          call sfseti('AN - angle of fill lines',90)
          call sfwrld(xra,yra,nra,dst,nst,ind,nnd)
        elseif(fill.eq.6) then
          call gschh(r250)
          call sfsetr('SP - spacing of fill lines',r250)
          call sfseti('AN - angle of fill lines',0)
          call sfseti('DO - dot-fill flag',1)
          call sfsetc('CH - character specifier','o')
          call sfsetp(id3)
          call sfwrld(xra,yra,nra,dst,nst,ind,nnd)
        endif
c
c-----------------------------------------------------------------------
c  Color section.
c-----------------------------------------------------------------------
c
      elseif(icolor.eq.1) then
c
c  Fill area with color indicated in FILL.
c
        ity=0
        ici=ncl+2
        if(fill.eq.1) then
          call gscr(1,ici,0.4,0.4,0.4)
        elseif(fill.eq.2) then
#ifndef blckndwht
          call gscr(1,ici,0.86,0.58,0.44)
# else
          call rgbyiq (0.86,0.58,0.44,ydum,idum,qdum)
          call gscr(1,ici,ydum,ydum,ydum)
#endif
        endif
        call set(fl,fr,fb,ft,ul,ur,ub,ut,1)
        call sfseti('TY - type of fill',ity)
        call sfsgfa(xra,yra,nra,dst,nst,ind,nnd,ici)
c       call sfnorm(xra,yra,nra,dst,nst,ind,nnd)
      endif
      return
      end
