      subroutine areamask(f,n,itopo)
c
c=======================================================================
c                                                                    ===
c  This subroutine builds the coordinates of the area to mask due to ===
c  flagged data values  or the imposition of the provided bathymetry ===
c  data.  These coordinates will be used in routine AREAFILL.        ===
c                                                                    ===
c  On Input:                                                         ===
c                                                                    ===
c     F        section field to process (real array).                ===
c     N        number of points in F (integer).                      ===
c     ITOPO    switch to mask below bathymetry data (integer):       ===
c              ITOPO=0    no                                         ===
c              ITOPO=1    yes                                        ===
c                                                                    ===
c  On Output: (common block "cntwkspa")                              ===
c                                                                    ===
c     NRA     number of points in arrays XRA and YRA.                ===
c     XRA     X-coordinate of section area masking (real array).     ===
c     YRA     Y-coordinate of section area masking (real array).     ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <param.h>
#include <pconst.h>
#include <cntwkspa.h>
#include <fldpos.h>
#include <secpos.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer i,ic,ip,itopo,k,n
      real f(n)
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c  Get the coordinates of the polygon to fill from the masked field or
c  impose provided bathymetry data.
c
      ic=1
      if(itopo.eq.0) then
        do 20 i=1,ims
          ic=ic+1
          yra(ic)=-abs(szbot)
          do 10 k=kms,1,-1
            ip=i+(k-1)*ims
            xra(ic)=x(ip)
            if(f(ip).gt.spval0) then
              yra(ic)=y(ip)
            else
              goto 20
            endif
  10      continue
  20    continue
      else
        do 30 i=1,ims
          ic=ic+1
          xra(ic)=x(i)
          if(abs(sbth(i)).lt.abs(szbot)) then
            yra(ic)=sbth(i)
          else
            yra(ic)=-abs(szbot)
          endif
  30    continue
      endif
      nra=ic+2
      xra(1)=xra(2)
      yra(1)=-abs(szbot)
      xra(nra-1)=xra(ic)
      yra(nra-1)=-abs(szbot)
      xra(nra)=xra(1)
      yra(nra)=yra(1)
c
c  Check dimensions of work arrays.
c
      if(nra.gt.mcs) then
        print 40, nra, mcs
  40    format(/' AREAMASK - underdimension array, NRA,MCS = ',2i6)
        call exitus('AREAMASK')
      endif
      return
      end
