      subroutine balnam (varnam,trcindx,trmindx,balstr,untstr)
c
c=======================================================================
c                                                                    ===
c  This routine extracts tracer term balance meta-data directly from ===
c  one of the open netCDF files.                                     ===
c                                                                    ===
c  ------                                                            ===
c  Input:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     VARNAM    NetCDF variable name.               (character)      ===
c     TRCINDX   Index of particular tracer.         (integer)        ===
c     TRMINDX   Index of particular balance term.   (integer)        ===
c                                                                    ===
c  Common Blocks:                                                    ===
c                                                                    ===
c  /INPCDF/                                                          ===
c                                                                    ===
c     NCINP1ID  NetCDF ID for primary file.     (integer)            ===
c     NCINP2ID  NetCDF ID for secondary file.   (integer)            ===
c     RCODE     Generic error code.             (integer)            ===
c     VARID     Generic variable ID.            (integer)            ===
c                                                                    ===
c  /PEFLDID/                                                         ===
c                                                                    ===
c     TNAME    Default tracer meta-data.     (string array)          ===
c     TBTERM   Default balance term names.   (string vector)         ===
c                                                                    ===
c  -------                                                           ===
c  Output:                                                           ===
c  -------                                                           ===
c                                                                    ===
c     BALSTR   Name of particular balance term.     (character)      ===
c     UNTSTR   Units for particular balance term.   (character)      ===
c                                                                    ===
c  ------                                                            ===
c  Calls:                                                            ===
c  ------                                                            ===
c                                                                    ===
c  HOPS:    LENGTH                                                   ===
c  NetCDF:  NCAGTC,  NCVID                                           ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <param.h>
#include <inpcdf.h>
#include <netcdf.inc>
#include <pefldid.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer ncid,sbn,sln,snd,trcindx,trmindx
      logical       fndbal,fndfyl,fndunt
      character*(*) balstr,untstr,varnam
      character*256 attnam
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c-----------------------------------------------------------------------
c  Initialize output and test flags.
c-----------------------------------------------------------------------
c
      balstr = ' '
      untstr = ' '
      fndbal = .false.
      fndunt = .false.
c
c-----------------------------------------------------------------------
c  Determine which netCDF file has the necessary data.
c-----------------------------------------------------------------------
c
      call length (varnam,sln,sbn,snd)
      ncid   = ncinp1id
      varid  = ncvid (ncid,varnam(sbn:snd),rcode)
      fndfyl = rcode .eq. 0
c
      if (.not.fndfyl) then
         ncid   = ncinp2id
         varid  = ncvid (ncid,varnam(sbn:snd),rcode)
         fndfyl = rcode .eq. 0
      endif
c
c-----------------------------------------------------------------------
c  Get descriptive name for balance term.
c-----------------------------------------------------------------------
c
      if (fndfyl) then
         write (attnam,10) trmindx
  10     format ('term',i2.2)
         call length (attnam,sln,sbn,snd)
         sln = len(balstr)
         call ncagtc (ncid,varid,attnam(sbn:snd),balstr,sln,rcode)
         fndbal = rcode .eq. 0
      endif
c
      if (.not.fndbal) then
         balstr = tbterm(trmindx)
      endif
c
c-----------------------------------------------------------------------
c  Get units for balance term.
c-----------------------------------------------------------------------
c
      if (fndfyl) then
         sln = len(untstr)
         call ncagtc (ncid,varid,'units',untstr,sln,rcode)
         fndunt = rcode .eq. 0
      endif
c
      if (.not.fndunt) then
         call length (tname(3,trcindx),sln,sbn,snd)
         untstr = tname(3,trcindx)(sbn:snd)//' second-1'
      endif
c
      return
      end
