      function bes2de(x,y,f,im,jm,spv,spval)
c
c=======================================================================
c                                                                    ===
c  This routine performs a 16-point cubic bessel interpolation at    ===
c  the grid locations X and Y from a regularly grided 2-D field F.   ===
c  If values in the outer 12 points are missing (F=SPV), and         ===
c  the values of F for the four interior points are avaialble, then  ===
c  the needed exterior values are obtained by extrapolation.         ===
c                                                                    ===
c     On Input:                                                      ===
c                                                                    ===
c     F        field to interpolate from (real array)                ===
c     IM, JM   first and second dimensions of F (integer)            ===
c     X, Y     position a wich the field is interpolated (grid       ===
c              units; real)                                          ===
c     SPV      field special value used during checking (real).      ===
c     SPVAL    field special value used during masking (real).       ===
c                                                                    ===
c     On Output:                                                     ===
c                                                                    ===
c     BES2D    interpolated value (real)                             ===
c                                                                    ===
c     Calls:      BES1D                                              ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer i1,i2,i3,i4,ibry,im,ix,iy,j1,j2,j3,j4,jbry,jm
      real    f1,f2,f3,f4,s,spv,spval,t,x,y
      real    bes1d,bes2de
      integer jbry1
      real    z1,z2,z3,z4
      real    f(im,jm)
c
c-----------------------------------------------------------------------
c  Begin executable code.
c-----------------------------------------------------------------------
c
c-----------------------------------------------------------------------
c  Find the grid coordinates of lower left corner of the box that
c  contains the point to interpolate.
c-----------------------------------------------------------------------
c
      ix=int(x)
      iy=int(y)
      if(ix.lt.1.or.ix.ge.im.or.iy.lt.1.or.iy.ge.jm) then
         bes2de=spval
      else
         s=x-ix
         t=y-iy
c
c
c-----------------------------------------------------------------------
c  Get the indices for the 4 x 4 raw data window.
c-----------------------------------------------------------------------
c
         i1=ix-1
         i2=ix
         i3=ix+1
         i4=ix+2
         j1=iy-1
         j2=iy
         j3=iy+1
         j4=iy+2
c
         if((f(i2,j2).gt.spv).or.(f(i3,j2).gt.spv).or.
     *      (f(i2,j3).gt.spv).or.(f(i3,j3).gt.spv)     ) then
            bes2de=spval
         else
c
c
c-----------------------------------------------------------------------
c  Check left and right boundaries.
c-----------------------------------------------------------------------
c
            ibry=0
            if(ix.eq.1) then
               ibry=1
               i1=2
            elseif(ix.eq.im-1) then
               ibry=2
               i4=im-1
            endif
c
c-----------------------------------------------------------------------
c  Check bottom and top boundaries.
c-----------------------------------------------------------------------
c
            jbry=0
            if(iy.eq.1) then
               jbry=1
               j1=2
            elseif(iy.eq.jm-1) then
               jbry=2
               j4=jm-1
            endif
c
c-----------------------------------------------------------------------
c  Achieve the two-dimendional interpolation by a series one-dimensional
c  interpolations.
c-----------------------------------------------------------------------
c
            jbry1=max(0,jbry)
            z1=f(i2,j1)
            if(z1.gt.spv) then
               z1=f(i2,j2)
               jbry1=1
            endif
            z4=f(i2,j4)
            if(z4.gt.spv) then
               z4=f(i2,j3)
               jbry1=2
            endif
            f2=bes1d(t,z1,f(i2,j2),f(i2,j3),z4,jbry1)
c
            jbry1=max(0,jbry)
            z1=f(i3,j1)
            if(z1.gt.spv) then
               z1=f(i3,j2)
               jbry1=1
            endif
            z4=f(i3,j4)
            if(z4.gt.spv) then
               z4=f(i3,j3)
               jbry1=2
            endif
            f3=bes1d(t,z1,f(i3,j2),f(i3,j3),z4,jbry1)
c
c
            if (f(i1,j2).gt.spv) then
               z2=f(i2,j2)
            else
               z2=f(i1,j2)
            endif
            if (f(i1,j3).gt.spv) then
               z3=f(i2,j3)
            else
               z3=f(i1,j3)
            endif
c
            jbry1=0
            if(f(i1,j1).gt.spv) then
               jbry1=1
               z1=z2
            else
               z1=f(i1,j1)
            endif
c
            if(f(i1,j4).gt.spv) then
               jbry1=2
               z4=z3
            else
               z4=f(i1,j4)
            endif
c
            f1=bes1d(t,z1,z2,z3,z4,jbry1)
c
c
            if (f(i4,j2).gt.spv) then
               z2=f(i3,j2)
            else
               z2=f(i4,j2)
            endif
            if (f(i4,j3).gt.spv) then
               z3=f(i3,j3)
            else
               z3=f(i4,j3)
            endif
c
            jbry1=0
            if(f(i4,j1).gt.spv) then
               jbry1=1
               z1=z2
            else
               z1=f(i4,j1)
            endif
c
            if(f(i4,j4).gt.spv) then
               jbry1=2
               z4=z3
            else
               z4=f(i4,j4)
            endif
c
            f4=bes1d(t,z1,z2,z3,z4,jbry1)
c
            bes2de=bes1d(s,f1,f2,f3,f4,ibry)
         endif
      endif
      return
      end
