      function bilin (x,y,f,im,jm,spv,spval)
c
c=======================================================================
c                                                                    ===
c  This subroutine does a bilinear interpolation to compute  bilin   ===
c  at (x,y) given the scalar array f of size imXjm.                  ===
c  If interpolation is not possible then bilin is set to spval.      ===
c  The interpolation is not possible if:                             ===
c  The point (x,y) is not in a cell                                  ===
c           i<=x<i+1;j<=y<j+1; 1<=i<=im-1; 1<=j<=jm-1.               ===
c  At least one value of f at the corners of the cell = spv.         ===
c                                                                    ===
c  On Input:                                                         ===
c                                                                    ===
c     X       section x-coordinate (nondimensional, grid units).     ===
c     Y       section y-coordinate (nondimensional, grid units).     ===
c     F       field from which the section is extracted.             ===
c     SPV     special value to flag missing data in F.               ===
c     IM      number of field points in the 1st index                ===
c     JM      number of field points in the 2nd index                ===
c     SPVAL   special value to flag missing data.                    ===
c                                                                    ===
c  On Output:                                                        ===
c                                                                    ===
c     BILIN     extracted section (real).                            ===
c                                                                    ===
c  Calls:                                                            ===
c                                                                    ===
c    NONE                                                            ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer im,jm
      real    x,y,f(im,jm),spv,spval
#ifdef pe_xtrp
      real    val(2,2)
      logical xtrp(2,2)
#endif
      real    bilin
c
      real    s,t,f1,f2,c1
      integer ibry,ix,iy,i2,i3,j2,j3
c
      parameter (c1=1.0)
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c-----------------------------------------------------------------------
c  Find the grid coordinates of lower left corner of the box that
c  contains the point to interpolate.
c-----------------------------------------------------------------------
c
      ix=int(x)
      iy=int(y)
c
c-----------------------------------------------------------------------
c  Get the indices for the 4 x 4 raw data window.
c-----------------------------------------------------------------------
c
      ibry=0
      i2=ix
      i3=ix+1
      j2=iy
      j3=iy+1
c
c-----------------------------------------------------------------------
c  Check left and right boundaries.
c-----------------------------------------------------------------------
c
      if(x.lt.c1) then
        ibry=1
       elseif(x.ge.float(im)) then
        ibry=1
      endif
c
c-----------------------------------------------------------------------
c  Check bottom and top boundaries.
c-----------------------------------------------------------------------
c
      if(y.lt.c1) then
        ibry=1
      elseif(y.ge.float(jm)) then
        ibry=1
      endif
c
      if(ibry.eq.1) then
         bilin=spval
      else
c
c-----------------------------------------------------------------------
c     bilinear interpolation
c-----------------------------------------------------------------------
c
#ifdef pe_xtrp
         val(1,1)  = f(i2,j2)
         xtrp(1,1) = f(i2,j2).gt.spv
         val(1,2)  = f(i2,j3)
         xtrp(1,2) = f(i2,j3).gt.spv
         val(2,1)  = f(i3,j2)
         xtrp(2,1) = f(i3,j2).gt.spv
         val(2,2)  = f(i3,j3)
         xtrp(2,2) = f(i3,j3).gt.spv
         call extrap (4,val,xtrp)
         f(i2,j2) = val(1,1)
         f(i3,j2) = val(2,1)
         f(i2,j3) = val(1,2)
         f(i3,j3) = val(2,2)
#endif
         s=x-ix
         t=y-iy
         if(
     *        (f(i2,j2).gt.spv).or.(f(i3,j2).gt.spv).or.
     *        (f(i2,j3).gt.spv).or.(f(i3,j3).gt.spv)    ) then
            bilin=spval
         else
            f1=(c1-t)*f(i2,j2)+t*f(i2,j3)
            f2=(c1-t)*f(i3,j2)+t*f(i3,j3)
            bilin=(c1-s)*f1+s*f2
         endif
      endif
c
      return
      end
