       program ccntmd_ncar
c
c=======================================================================
c                                                                    ===
c  This program N different data domains in the same page according  ===
c  to the number of plots per page.   Input data is in  netCDF       ===
c  format                                                            ===
c                                                                    ===
c  Hernan G. Arango  21/12/93                                        ===
c  Harvard University                                                ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <pltio.h>
#include <inpcdf.h>
#include <ndimen.h>
#include <pltfld.h>
#include <pltncar.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
       integer ios
       character*80 filename
#ifdef sunfpe
      integer ieeer,ieee_handler,my_handler
      external my_handler
#endif
c
c=======================================================================
c  Begin executable code.
c=======================================================================
#ifdef sunfpe
c
c  Set trap for floating point exceptions.
c
      ieeer=ieee_handler('set','common',my_handler)
      if(ieeer.ne.0) print *,' IEEE_HANDLER cannot set my_handler'
#endif
c
c-----------------------------------------------------------------------
c  Initialize NCAR GKS plotting package.
c-----------------------------------------------------------------------
c
      call headln (stdout)
      call gksinit
      call pcsetc ('FC - Function Code delimiter',esc_char)
c
c-----------------------------------------------------------------------
c  Initialize frame counter.  Reset standard input.
c-----------------------------------------------------------------------
c
      nframe=0
      stdinp=7
c
c-----------------------------------------------------------------------
c  Process each data file.
c-----------------------------------------------------------------------
c
      read (5,20,iostat=ios) filename
c
      do 10 while (ios.eq.0)
c
         open (stdinp,file=filename,form='formatted',status='old')
         km = 0
c
         call ccnt_plt
c
         call ncclos(ncinp1id,rcode)
         if((iref.eq.2).or.(iref.eq.3)) call ncclos(ncinp2id,rcode)
         close (stdinp)
         close (inppal)
         close (inppar)
         close (inpcst)
         close (inpbth)
         close (inpgeo)
         close (inptrk)
         close (inprng)
c
         read (5,20,iostat=ios) filename
c
  10  continue
c
c-----------------------------------------------------------------------
c  Close GKS software and datasets.
c-----------------------------------------------------------------------
c
      call exitus('DONE')
c
  20  format(a)
      end
c
c
c
      subroutine ccnt_plt
c
c=======================================================================
c                                                                    ===
c  This routine contours the desired  field(s) at the given depth    ===
c  level(s) and time(s) using  NCAR  GKS plotting  package (color    ===
c  version). It uses QG and/or PE field classification. The input    ===
c  data is assumed to be in NetCDF format.                           ===
c                                                                    ===
c  Hernan G. Arango  21/09/94                                        ===
c  Harvard University                                                ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <param.h>
#include <pconst.h>
#include <fldpos.h>
#include <inpcdf.h>
#include <ndimen.h>
#include <pltfld.h>
#include <pltio.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer class,file,i,ictime,idfld,level,m,n
      real day,f1(nh),f2(nh),f3(nh),f4(nh)
      real get_pltday
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c  Read in plot job parameters.
c
      call get_parm
c
c-----------------------------------------------------------------------
c  Read in fields at the specified time.
c-----------------------------------------------------------------------
c
      day=frstd
      ictime=0
      do 30 while ((frstd.le.day).and.(day.le.lastd))
        ictime=ictime+1
        do 20 n=1,nlevels
        do 20 m=1,nfields
          idfld=fldid(m)
          level=fldlev(n)
          file=1
          if(dskip.le.c0) day=get_pltday(ictime,idfld,class1,file)
          call get_cdf2dat(day,x,y,f1,f2,np,file,class,idfld,level)
          if(iref.eq.3) then
            file=2
            call get_cdf2dat(day,x,y,f3,f4,np,file,class,idfld,level)
            call flddif (np,f1,f3)
            call flddif (np,f2,f4)
          elseif(iref.eq.4) then
            file=1
            call get_cdf2dat(frstd,x,y,f3,f4,np,file,class,idfld,level)
            call flddif (np,f3,f1)
            call flddif (np,f4,f2)
            do 10 i=1,np
              f1(i)=f3(i)
              f2(i)=f4(i)
  10        continue
          endif
c
c-----------------------------------------------------------------------
c  Plot requested field(s).
c-----------------------------------------------------------------------
c
          call pltfield(day,f1,f2,f3,np,file,class,idfld,level)
  20    continue
c
c-----------------------------------------------------------------------
c  Set next day to plot or terminate plotting.
c-----------------------------------------------------------------------
c
        if(dskip.gt.c0) day=day+dskip
  30  continue
c
      return
      end
c
c
c
      subroutine get_parm
c
c=======================================================================
c                                                                    ===
c  This routine reads in input parameters from standard input        ===
c  script and sets various parameters and switches needed for        ===
c  plotting.                                                         ===
c                                                                    ===
c  Required common blocks:                                           ===
c                                                                    ===
c    DOMDAT, NDIMEN, PEFLDID, PLTFLD, PLTIO, PLTLAB, PLTNCAR, ZDAT   ===
c                                                                    ===
c  Requied parameter statement:                                      ===
c                                                                    ===
c    "param.h"                                                       ===
c                                                                    ===
c  Calls:  GET_DATE, OPENCDF, READPAL, SETCOLPAL                     ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define Global data.
c-----------------------------------------------------------------------
c
#include <param.h>
#include <pconst.h>
#include <domdat.h>
#include <inpcdf.h>
#include <ndimen.h>
#include <pefldid.h>
#include <pltfld.h>
#include <pltio.h>
#include <pltlab.h>
#include <pltncar.h>
#include <zdat.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer i,iflds,ilevs,j,k
      real        scle
      character*1  ans
      character*40 proj
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c-----------------------------------------------------------------------
c  Read in input parameters and switches for standard input.
c-----------------------------------------------------------------------
c
c  Read in year and starting year day.
c
      read(stdinp,*) iyear,yday
      wdate=.true.
      if(yday.lt.c0) wdate=.false.
c
c  Read in plot titles.
c
      read(stdinp,'(a)') pltitle(1)
      read(stdinp,'(a)') pltitle(2)
      read(stdinp,'(a)') pltitle(3)
      read(stdinp,'(a)') pltitle(4)
c
c  Read in field ID classification for primary file.
c
      read(stdinp,*) class1
c
c  Read in number of different fields to plot.
c
      read(stdinp,*) nfields
c
c  Read in field(s) identification.
c
      read(stdinp,*) (fldid(i),i=1,nfields)
c
c  Read in number of different levels to plot.
c
      read(stdinp,*) nlevels
c
c  Read in field level(s) to plot.
c
      read(stdinp,*) (fldlev(i),i=1,nlevels)
c
c  Read in first and last day to plot.
c
      read(stdinp,*) frstd
      read(stdinp,*) lastd
c
c  Read in interval between plots (days). If zero or negative, the
c  data is plotted at their own time frequency.
c
      read(stdinp,*) dskip
c
c  Read in field minimum and maximum limit values for color palette.
c
      read(stdinp,*) pmin
      read(stdinp,*) pmax
c
c  Read in switch to put contour lines over color bands:
c           [0] no, [1] yes.
c
      read(stdinp,*) icnt
c
c  Read in maximum vector magnitude for scaling and location of the
c  for the reference scale.
c
      read(stdinp,*) vscle
      read(stdinp,*) vlat
      read(stdinp,*) vlng
c
c  Read in switch to plot secondary field:
c           [0] no secondary or reference field to plot
c           [1] primary file overlay
c           [2] secondary file overlay
c           [3] primary - secondary (field subtaction)
c           [4] Day0 - DayN (field subtraction)
c
      read(stdinp,*) iref
c
c  Read in field ID classification for secondary file.
c
      read(stdinp,*) class2
c
c  Read in overlay field identification.
c
      read(stdinp,*) idover
c
c  Read in level of the field to overlay.  If LEVOVER is zero, the
c  level selected is the same as the current primary field.
c
      read(stdinp,*) levover
c
c  Read in overlay field minimum and maximum limit values to contour.
c
      read(stdinp,*) rmin
      read(stdinp,*) rmax
c
c  Read in desired longitude/latitude grid spacing (degrees).
c
      read(stdinp,*) igrid
c
c  Read in map projection switch:
c              [1] cylindrical equidistant
c              [2] Mercator
c              [3] Lambert conformal conical
c
      read(stdinp,*) iproj
      if(iproj.eq.1) proj='cylindrical equidistant'
      if(iproj.eq.2) proj='Mercator'
      if(iproj.eq.3) proj='Lambert conformal conical'
c
c  Read in switch to color mask land:
c              [0] no land masking
c              [1] mask land with dark brown color
c              [2] mask land with brown color
c              [3] mask land with tan color
c
      read(stdinp,*) lmsk
c
c  Read in number of plots per page: 1, 2, or 4.
c
      read(stdinp,*) npage
c
c  Read in logical switch to activate drawing of Harvard Logo.
c
      read(stdinp,'(l1)') pltlogo
c
c  Read in logical switch to activate writing of plot header titles.
c
      read(stdinp,'(l1)') wrthdr
c
c  Read in logical switch to activate writing of plot bottom title.
c
      read(stdinp,'(l1)') wrtblab
c
c  Read in logical switch to activate writing of information about the
c  range values of the plotted data and the contour interval.
c
      read(stdinp,'(l1)') wrtrang
c
c  Read in logical switch to activate writing of input filename.
c
      read(stdinp,'(l1)') wrtfnam
c
c  Read in logical switch to activate writing of current plotting date.
c
      read(stdinp,'(l1)') wrtdate
c
c  Read in map coordinates (bottom, top, left, and right edges).
c
      read(stdinp,*) pblat,ptlat
      read(stdinp,*) pllon,prlon
c
c  Read in filename for color palette.
c
      read(stdinp,'(a)') fname(1)
c
c  Read and set color palette indices.
c
      open(inppal,file=fname(1),form='formatted',status='old')
      call readpal(inppal)
      call setcolpal(lmsk)
c
c  Read in filename for plotting parameters.
c
      read(stdinp,'(a)') fname(2)
c
c  Read in plot parameters: vector sampling and length factors, and
c  contour interval as function of field tyep and level.
c
      open(inppar,file=fname(2),form='formatted',status='old')
      read(inppar,*) iskip,jskip
      read(inppar,*) asize,vper
      read(inppar,*) iflds,ilevs
      do 10 i=1,iflds
        read(inppar,*) j,(cont(j,k),k=1,ilevs)
  10  continue
      if(km.gt.ilevs) then
        write(stdout,20) ilevs,km
  20    format(' GET_PARM: number of model levels greater than',/,
     *         '           those in contour interval array: ',2i4)
        stop
       endif
c
c  Read in primary filename.
c
      read(stdinp,'(a)') fname(3)
c
c  Read in secondary filename.
c
      read(stdinp,'(a)') fname(4)
c
c  Read in coastline switch and filename.
c
      read(stdinp,'(a)') ans
      read(stdinp,'(a)') fname(5)
      cst=.false.
      if((ans.eq.'Y').or.(ans.eq.'y')) then
        cst=.true.
        open(inpcst,file=fname(5),form='formatted',status='old')
      endif
c
c  Read in isobath switch and filename.
c
      read(stdinp,'(a)') ans
      read(stdinp,'(a)') fname(6)
      bth=.false.
      if((ans.eq.'Y').or.(ans.eq.'y')) then
        bth=.true.
        open(inpbth,file=fname(6),form='formatted',status='old')
      endif
c
c  Read in Geosat track switch and filename.
c
      read(stdinp,'(a)') ans
      read(stdinp,'(a)') fname(7)
      geo=.false.
      if((ans.eq.'Y').or.(ans.eq.'y')) then
        geo=.true.
        open(inpgeo,file=fname(7),form='formatted',status='old')
      endif
c
c  Read in trajectories or hydrographic stations switch and filename.
c
      read(stdinp,'(a)') ans
      read(stdinp,'(a)') fname(8)
      trk=.false.
      if((ans.eq.'Y').or.(ans.eq.'y')) then
        trk=.true.
        open(inptrk,file=fname(8),form='formatted',status='old')
      endif
c
c  Read in rings labels switch and filename.
c
      read(stdinp,'(a)') ans
      read(stdinp,'(a)') fname(9)
      rng=.false.
      if((ans.eq.'Y').or.(ans.eq.'y')) then
        rng=.true.
        open(inprng,file=fname(9),form='formatted',status='old')
      endif
c
c-----------------------------------------------------------------------
c  Set execution date label
c-----------------------------------------------------------------------
c
      call get_date(date_str)
c
c-----------------------------------------------------------------------
c  Open primary and secondary (if any) input NetCDF files and get the
c  necessary information for plotting.
c-----------------------------------------------------------------------
c
      call opencdf(fname(3),fname(4))
c
c-----------------------------------------------------------------------
c  Report plotting parameters.
c-----------------------------------------------------------------------
c
      if (coord.eq.0) then
         scle = m2km
        else
         scle = c1
      endif
      write(stdout,100) im,jm,km,xbasin*scle,ybasin*scle,dx*scle,
     *                  dy*scle,thetad,clngd,clatd,pllon,prlon,pblat,
     *                  ptlat,proj
 100  format(//,'  Parameters: ',//,
     *       5x,' number of points (im,jm,km) = ',3i4,/,
     *       5x,'    basin dimensions (Lx,Ly) = ',2f10.3,/,
     *       5x,'        grid spacing (dx,dy) = ',2f10.3,/,
     *       5x,'     domain rotation (theta) = ', f10.3,/,
     *       5x,'      centroid (rlng0,rlat0) = ',2f10.3,/,
     *       5x,' map coordinates (Rlon,Llon) = ',2f10.3,/,
     *       5x,'                 (Blat,Tlat) = ',2f10.3,/,
     *       5x,'              map projection = ',a,/)
      write(stdout,110) pltitle(1)
      write(stdout,110) pltitle(2)
      write(stdout,110) pltitle(3)
      write(stdout,110) pltitle(4)
 110  format(a)
      return
      end
      subroutine pltfield(day,f1,f2,f3,n,file,fclas1,idfld,level)
c
c=======================================================================
c                                                                    ===
c  This routine contours scalar and/or draws vector fields.   It     ===
c  also contours scalar overlays or draws vector overlays in the     ===
c  same map.                                                         ===
c                                                                    ===
c  On Input:                                                         ===
c                                                                    ===
c     DAY     time of the field(s) to plot (real).                   ===
c     F1      scalar or vector x-component (real array).             ===
c     F2      vector y-component (real array).                       ===
c     F3      scrath space (real array).                             ===
c     N       number points in field (integer)                       ===
c     FILE    NetCDF file to plot (primary or secondary).            ===
c     FCLAS1  field classification for primary file (PE or QG).      ===
c     IDFLD   field identification (integer).                        ===
c     LEVEL   field depth level (integer).                           ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <param.h>
#include <pconst.h>
#include <domdat.h>
#include <fdiagn.h>
#include <fldpos.h>
#include <inpcdf.h>
#include <ndimen.h>
#include <pefldid.h>
#include <pltfld.h>
#include <pltio.h>
#include <pltlab.h>
#include <pltncar.h>
#include <qgfldid.h>
#include <zdat.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer fclas1,fclas2,file,icolor,idfld,idmag1,idmag2,ii1,ii2,
     *        ipos,jj1,jj2,lev,level,mask,mid,n,vlabel
      real day,cint,cmax,cmin,cntint,scl,vmax,vmin,vls,vsmall,x1,x2,y1,
     *     y2
      real f1(n),f2(n),f3(n)
      parameter (icolor=1,ipos=1,mask=0)
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c-----------------------------------------------------------------------
c  Draw only trajectories or hydrographic stations.
c-----------------------------------------------------------------------
c
      if(fclas1.eq.peclass) then
        if((idfld.eq.peltrk).or.(idfld.eq.pehsta)) goto 10
      elseif(fclas1.eq.qgclass) then
        if((idfld.eq.qgltrk).or.(idfld.eq.qghsta)) goto 10
      endif
c
c=======================================================================
c  Plot primary field (scalar or vector).
c=======================================================================
c
c  Determine primary field switches.
c
      scalar1=.false.
      vector1=.false.
      levless=.false.
      if(fclas1.eq.peclass) then
        if((idfld.eq.pegvec).or.(idfld.eq.peivec).or.
     *     (idfld.eq.petvec).or.(idfld.eq.pedevc).or.
     *     (idfld.eq.peugeo).or.(idfld.eq.pevgeo).or.
     *     (idfld.eq.peuhat).or.(idfld.eq.pevhat).or.
     *     (idfld.eq.peutot).or.(idfld.eq.pevtot).or.
     *     (idfld.eq.peevec).or.(idfld.eq.petdvc)) then
          ii1=im-1
          jj1=jm-1
        else
          ii1=im
          jj1=jm
        endif
        if(idfld.eq.pegvec) then
          vector1=.true.
          idmag1=pegmag
          vsmall=r10
          vlabel=0
        elseif(idfld.eq.peivec) then
          vector1=.true.
          idmag1=peimag
          vsmall=r10
          vlabel=0
        elseif(idfld.eq.petvec) then
          vector1=.true.
          idmag1=petmag
          vsmall=r10
          vlabel=0
        elseif(idfld.eq.petdvc) then
          vector1=.true.
          idmag1=petdmg
          vsmall=r10
          vlabel=0
        elseif(idfld.eq.pedevc) then
          vector1=.true.
          idmag1=pedemg
          levless=.true.
          vsmall=r10
          vlabel=0
        elseif(idfld.eq.peevec) then
          vector1=.true.
          idmag1=peemag
          levless=.true.
          vsmall=r10
          vlabel=0
        elseif(idfld.eq.pesmfv) then
          vector1=.true.
          idmag1=pesmfm
          levless=.true.
          vsmall=r1000
          vlabel=2
        elseif ((idfld.eq.pepbar).or.(idfld.eq.pebvor).or.
     &          (idfld.eq.pebath).or.(idfld.eq.pedemg).or.
     &          (idfld.eq.peubar).or.(idfld.eq.pevbar).or.
     &          (idfld.eq.pedubr).or.(idfld.eq.pedvbr).or.
     &          (idfld.eq.pemldh).or.(idfld.eq.pemxld).or.
     &          (idfld.eq.peshfx).or.(idfld.eq.pesmfx).or.
     &          (idfld.eq.pesmfy).or.(idfld.eq.peswfx).or.
     &          (idfld.eq.pesrad).or.(idfld.eq.pesprs).or.
     &          (idfld.eq.peemag)) then
          scalar1=.true.
          levless=.true.
        else
          scalar1=.true.
        endif
      elseif(fclas1.eq.qgclass) then
        ii1=im
        jj1=jm
        if(idfld.eq.qgevec) then
          vector1=.true.
          idmag1=qgemag
          vsmall=r10
          vlabel=0
        elseif(idfld.eq.qgpvec) then
          vector1=.true.
          idmag1=qgvmag
          vsmall=r10
          vlabel=0
        elseif(idfld.eq.qgvvec) then
          vector1=.true.
          idmag1=qgvmag
          vsmall=r10
          vlabel=0
        elseif(idfld.eq.qgwshv) then
          vector1=.true.
          idmag1=qgwsvm
          vsmall=r1000
          vlabel=2
        elseif((idfld.eq.qgbath).or.(idfld.eq.qgdenb).or.
     *         (idfld.eq.qgdent).or.(idfld.eq.qgmsse).or.
     *         (idfld.eq.qgsblh).or.(idfld.eq.qgmmlt).or.
     *         (idfld.eq.qgmmlb)) then
          scalar1=.true.
          levless=.true.
        else
          scalar1=.true.
        endif
      endif
c
c-----------------------------------------------------------------------
c  Draw vector field (color vector magnitude contours inthe background).
c-----------------------------------------------------------------------
c
      if(vector1) then
        call vecmag(f3,f1,f2,im,ii1,jj1,vmin,vmax,spval0,spval1)
        call fdiag(f3,im,ii1,jj1,fclas1,idmag1,level,day,stdout)
        call mskscl(f3,im*jm,fclas1,ncinp1id,idmag1,spval1,spval1)
        mid=(im-1)/2+((jm-1)/2-1)*im
        call cnt_frame(icolor)
        call maptrn(y(mid),x(mid),x1,y1)
        call maptrn(y(mid+1),x(mid+1),x2,y2)
        ds=sqrt((x2-x1)**2+(y2-y1)**2)
        if(vscle.gt.c0) then
          vls=vscle
        else
          vls=vmax
        endif
        scl=abs(asize*ds/vls)
#ifndef pfjl_vper
        vmin=vmax*abs(vper)
# else
        vmin=abs(vper)
#endif
        if(vmin.lt.vsmall) vmin=vsmall
        fmin=vmin
        fmax=vmax
        if (pmin.eq.pmax) then
           call cntcolor(f3,im,ii1,jj1,vmin,vmax,icnt,ipos,lmsk)
         else
           call cntcolor(f3,im,ii1,jj1,pmin,pmax,icnt,ipos,lmsk)
        endif
        call set(fl,fr,fb,ft,ul,ur,ub,ut,1)
        call pltvec(f1,f2,x,y,im,ii1,jj1,iskip,jskip,vmin,vmax,scl,
     *              vscle,vlng,vlat,thetad,vlabel)
c
c-----------------------------------------------------------------------
c  Contour scalar field (color)
c-----------------------------------------------------------------------
c
      elseif(scalar1) then
        call fdiag(f1,im,ii1,jj1,fclas1,idfld,level,day,stdout)
        if((pmin.eq.c0).and.(pmax.eq.c0)) then
          cmin=fmin
          cmax=fmax
        else
          cmin=pmin
          cmax=pmax
        endif
        call cnt_frame(icolor)
        call cntcolor(f1,im,ii1,jj1,cmin,cmax,icnt,ipos,lmsk)
      endif
c
c=======================================================================
c  Plot secondary (overlay) field (scalar or vector).
c=======================================================================
c
      if((iref.eq.1).or.(iref.eq.2)) then
c
c-----------------------------------------------------------------------
c  Read in secondary overlay field.
c-----------------------------------------------------------------------
c
        if(iref.eq.1) file=1
        if(iref.eq.2) file=2
        if(levover.eq.0) then
          lev=level
        else
          lev=levover
        endif
        call get_cdf2dat(day,x,y,f1,f2,np,file,fclas2,idover,lev)
c
c-----------------------------------------------------------------------
c  Determine overlay field switches.
c-----------------------------------------------------------------------
c
        scalar2=.false.
        vector2=.false.
        if(fclas2.eq.peclass) then
          if((idover.eq.pegvec).or.(idover.eq.peivec).or.
     *       (idover.eq.petvec).or.(idover.eq.pedevc).or.
     *       (idover.eq.peugeo).or.(idover.eq.pevgeo).or.
     *       (idover.eq.peuhat).or.(idover.eq.pevhat).or.
     *       (idover.eq.peutot).or.(idover.eq.pevtot).or.
     *       (idover.eq.peevec).or.(idover.eq.petdvc)) then
            ii2=im-1
            jj2=jm-1
          else
            ii2=im
            jj2=jm
          endif
          if(idover.eq.pegvec) then
            vector2=.true.
            idmag2=pegmag
            vsmall=r10
            vlabel=0
          elseif(idover.eq.peivec) then
            vector2=.true.
            idmag2=peimag
            vsmall=r10
            vlabel=0
          elseif(idover.eq.petvec) then
            vector2=.true.
            idmag2=petmag
            vsmall=r10
            vlabel=0
          elseif(idover.eq.petdvc) then
            vector2=.true.
            idmag2=petdmg
            vsmall=r10
            vlabel=0
          elseif(idover.eq.pedevc) then
            vector2=.true.
            idmag2=pedemg
            vsmall=r10
            vlabel=0
          elseif(idover.eq.peevec) then
            vector2=.true.
            idmag2=peemag
            vsmall=r10
            vlabel=0
          elseif(idover.eq.pesmfv) then
            vector2=.true.
            idmag2=pesmfm
            vsmall=r1000
            vlabel=2
          else
            scalar2=.true.
          endif
        elseif(fclas2.eq.qgclass) then
          ii2=im
          jj2=jm
          if(idover.eq.qgevec) then
            vector2=.true.
            idmag2=qgemag
            vsmall=r10
            vlabel=0
          elseif(idover.eq.qgpvec) then
            vector2=.true.
            idmag2=qgvmag
            vsmall=r10
            vlabel=0
          elseif(idover.eq.qgvvec) then
            vector2=.true.
            idmag2=qgvmag
            vsmall=r10
            vlabel=0
          elseif(idover.eq.qgwshv) then
            vector2=.true.
            idmag2=qgwsvm
            vsmall=r1000
            vlabel=2
          else
            scalar2=.true.
          endif
        endif
c
c-----------------------------------------------------------------------
c  Draw vector overlay, if any.
c-----------------------------------------------------------------------
c
        if(vector2) then
          call vecmag(f3,f1,f2,im,ii2,jj2,vmin,vmax,spval0,spval1)
          call fdiag(f3,im,ii2,jj2,fclas2,idmag2,lev,day,stdout)
          call mskscl(f3,im*jm,fclas2,ncinp1id,idmag2,spval1,spval1)
          mid=(im-1)/2+((jm-1)/2-1)*im
          call maptrn(y(mid),x(mid),x1,y1)
          call maptrn(y(mid+1),x(mid+1),x2,y2)
          ds=sqrt((x2-x1)**2+(y2-y1)**2)
          if(vscle.gt.c0) then
            vls=vscle
          else
            vls=vmax
          endif
          scl=abs(asize*ds/vls)
#ifndef pfjl_vper
          vmin=vmax*abs(vper)
# else
          vmin=abs(vper)
#endif
          if(vmin.lt.vsmall) vmin=vsmall
          fmin=vmin
          fmax=vmax
          call set(fl,fr,fb,ft,ul,ur,ub,ut,1)
          call pltvec(f1,f2,x,y,im,ii2,jj2,iskip,jskip,vmin,vmax,scl,
     *                vscle,vlng,vlat,thetad,vlabel)
c
c------------------------------------------------------------------------
c  Contour scalar overlay, if any.
c------------------------------------------------------------------------
c
        elseif(scalar2) then
          call fdiag(f1,im,ii2,jj2,fclas2,idover,lev,day,stdout)
          if((rmin.eq.c0).and.(rmax.eq.c0)) then
            cmin=fmin
            cmax=fmax
          else
            cmin=rmin
            cmax=rmax
          endif
          cint=cntint(idover,lev,cmin,cmax,zmid,km,cont,cfld,clev)
          call set(fl,fr,fb,ft,ul,ur,ub,ut,1)
          call cntpack(f1,im,ii2,jj2,cmin,cmax,cint,mask)
        endif
      endif
c
c-----------------------------------------------------------------------
c  Draw background plot and advance frame when appropriate.
c-----------------------------------------------------------------------
c
  10  call hbackground(day,cint,fmin,fmax,frms,icolor,fclas1,idfld,
     *                 level)
      nframe=nframe+1
      if(mod(nframe,npage).eq.0) call frame
      return
      end
