      subroutine cell (x,y,ix,iy,s,t,im,jm,node,hintrp,nk,fcel,spval,
     &                 good)
c
c=======================================================================
c                                                                    ===
c  This subroutine extracts the cell of model points surrounding the ===
c  given horizontal point.                                           ===
c                                                                    ===
c  On Input:                                                         ===
c                                                                    ===
c     X       point x-coordinate.         (real; grid units)         ===
c     Y       point y-coordinate.         (real; grid units)         ===
c     IM      number of x-grids points.   (integer)                  ===
c     JM      number of y-grids points.   (integer)                  ===
c     HINTRP  interpolation method.       (integer)                  ===
c             [0] bilinear  [1] 2d bessel                            ===
c                                                                    ===
c  On Output:                                                        ===
c                                                                    ===
c     IX      cell i-points in grid.      (integer array; grid units)===
c     IY      cell j-points in grid.      (integer array; grid units)===
c     S       point x-location in cell.   (real; cell units)         ===
c     T       point y-location in cell.   (real; cell units)         ===
c     NODE    number of points in cell.   (integer)                  ===
c     NK      # Cell vert. levels.        (integer)
c     FCEL    Cell data storage.          (real array)
c     SPVAL   Special value.              (real)
c     GOOD    valid cell flag.            (logical)                  ===
c             [t] cell is valid                                      ===
c             [f] cell is NOT valid                                  ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer hintrp,i,im,j,jm,nk,node
      integer ix(16),iy(16)
      real    c1,c2,s,spval,t,x,y
      real    fcel(16,nk)
      logical good
c
      parameter (c1=1.0, c2=2.0)
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c-----------------------------------------------------------------------
c  Initialize cell storage with flag values.
c-----------------------------------------------------------------------
c
      do 10 j = 1, nk
      do 10 i = 1, 16
         fcel(i,j) = spval
  10  continue
c
c-----------------------------------------------------------------------
c  Examine cell for utility.
c-----------------------------------------------------------------------
c
      good=.true.
c
      if (hintrp.eq.0) then
c
c Bilinear interpolation cell requested
c
         if (c1.le.y.and.y.lt.float(jm).and.
     *       c1.le.x.and.x.lt.float(im)  ) then
            node=4
            ix(1)=int(x)
            ix(2)=ix(1)+1
            ix(3)=ix(1)
            ix(4)=ix(1)+1
c
            iy(1)=int(y)
            iy(2)=iy(1)
            iy(3)=iy(1)+1
            iy(4)=iy(1)+1
c
            s=c1+x-float(ix(1))
            t=c1+y-float(iy(1))
         else
            good=.false.
         endif
c
      elseif (hintrp.eq.1) then
c
c 2D Bessel interpolation cell requested
c
         if(c2.le.y.and.y.lt.float(jm-1).and.
     *      c2.le.x.and.x.lt.float(im-1)  ) then
            node=16
c
            ix(1)=int(x)-1
            ix(2)=ix(1)+1
            ix(3)=ix(1)+2
            ix(4)=ix(1)+3
            do 30 j=1,3
               do 20 i=1,4
                  ix(i+4*j)=ix(i)
 20            continue
 30         continue
c
            iy(1)=int(y)-1
            iy(5)=iy(1)+1
            iy(9)=iy(1)+2
            iy(13)=iy(1)+3
            do 50 j=1,13,4
               do 40 i=1,3
                  iy(j+i)=iy(j)
 40            continue
 50         continue
c
            s=c2+x-float(ix(6))
            t=c2+y-float(iy(6))
         else
            good=.false.
         endif
c
      else
c
c Invalid interpolation cell request
c
         good=.false.
c
      endif
c
      return
      end
