      subroutine cnt_frame(icolor)
c
c=======================================================================
c                                                                    ===
c  This routine sets viewport space for the current map on the       ===
c  page.                                                             ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <pconst.h>
#include <domdat.h>
#include <ndimen.h>
#include <pltio.h>
#include <pltncar.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      real    cenlat,cenlon,gdelx,gdely,gdx,gdy
      logical debug
      integer icolor
c
      save debug
c
      data debug /.false./
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c-----------------------------------------------------------------------
c  Set viewport according to the number of maps per page.
c-----------------------------------------------------------------------
c
      call viewport(fl,fr,fb,ft,sclmap,ipltpg,npage,icolor,wrthdr,
     *               pltlogo)
#ifdef geo_aspect
      call resetview (fl,fr,fb,ft,pllon,prlon,pblat,ptlat)
#endif
c
c-----------------------------------------------------------------------
c  Use EZMAP to set the map viewport acconding with the map projection.
c-----------------------------------------------------------------------
c
      call mapint
      call mappos(fl,fr,fb,ft)
      if(iproj.eq.1) then
        call maproj('CE - cylindrical equidistant',c0,c0,c0)
      elseif(iproj.eq.2) then
        call maproj('ME - Mercator',c0,c0,c0)
      elseif(iproj.eq. 3) then
        if(coord.eq.0) then
          gdx   = dx*m2cm
          gdy   = dy*m2cm
          gdelx = delx*m2cm
          gdely = dely*m2cm
         else
          gdx   = dx
          gdy   = dy
          gdelx = delx
          gdely = dely
        endif
        call xy2ll (p5*float(im+1),p5*float(jm+1),coord,im,jm,gdx,gdy,
     *              clngd,clatd,gdelx,gdely,thetad,cenlon,cenlat)
        call maproj('LC - Lambert conformal conic',cenlat,cenlon,cenlat)
      endif
      call mapset('CO - corners',pblat,pllon,ptlat,prlon)
c     call mapstr('GR - grid spacing in degrees',float(igrid))
      call mapstl('PE - draw map perimeter',.false.)
      if(icolor.eq.0) then
        call mapsti('DA - solid dash patern for grids',65535)
      elseif(icolor.eq.1) then
        call mapstl('DL - draw dotted lines',.true.)
        call mapsti('DD - distance between dots',4)
      endif
      call mapstc('OU - outline data set','CO')
      call mapsti('VS - vertical stripping',0)
      call mapint
c
c-----------------------------------------------------------------------
c  Set plotting frame.
c-----------------------------------------------------------------------
c
      call maptra(pblat,pllon,ul,ub)
      call maptra(ptlat,prlon,ur,ut)
      call set(fl,fr,fb,ft,ul,ur,ub,ut,1)
c
c-----------------------------------------------------------------------
c  If coastlines and islands data is not provided, use EZMAP defaults.
c  (noncolor only).
c-----------------------------------------------------------------------
c
c     if((.not.cst).and.(icolor.eq.0)) call mapdrw
c
c-----------------------------------------------------------------------
c  Report viewport information.
c-----------------------------------------------------------------------
c
      if(debug) then
        write(6,900) 'plots/page  ',npage
        write(6,910) 'current plot',ipltpg
        write(6,920) 'frame left  ',fl
        write(6,920) 'frame right ',fr
        write(6,920) 'frame bottom',fb
        write(6,920) 'frame top   ',ft
        write(6,920) 'left Lon    ',pllon
        write(6,920) 'right Lon   ',prlon
        write(6,920) 'bottom Lat  ',pblat
        write(6,920) 'top Lat     ',ptlat
        write(6,920) 'box Xmin    ',ul
        write(6,920) 'box Xmax    ',ur
        write(6,920) 'box Ymin    ',ub
        write(6,930) 'box Ymax    ',ut
      endif
c
      return
c
 900  format (/' CNT_FRAME - ',a,' = ',i4)
 910  format (' CNT_FRAME - ',a,' = ',i4)
 920  format (' CNT_FRAME - ',a,' = ',f9.4)
 930  format (' CNT_FRAME - ',a,' = ',f9.4/)
c
      end
