      subroutine cntpack(f,mm,m,n,fmin,fmax,cint,imask)
c
c=======================================================================
c                                                                    ===
c  This routine uses  NCAR  CONPACK  utility to  contour the grided  ===
c  field F(M,N). It assumes that the user has call FRAME previously  ===
c  for properly positioning of the color levels.                     ===
c                                                                    ===
c=======================================================================
c
#include <param.h>
#include <pconst.h>
#include <cntwkspa.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      logical nozero
      integer i,imask,isu,liwku,lrwku,m,mm,n,nocl,radx,rady
      real cint,clev,fmax,fmin
      real f(*)
      parameter (radx=2,rady=2)
      external drawcl,cpdrpl
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c  Prevent CONPACK from setting the viewport.
c
      call cpseti('SET - do-set-call flag',0)
c
c  Set mapping to that provided by the User.
c
      call cpseti('MAP - mapping flag',3)
c
c  Set "out of range" value to control contouring.
c
      call cpsetr ('ORV - Out of Range Value',orval)
c
c  Set special value feature.
c
      call cpsetr('SPV - special value',spval1)
c
c  Set contour interval and specify the interval between labelled
c  contours.
c
      call cpsetr('CIS - contour interval selector',abs(cint))
      call cpseti('LIS - label interval specifier',4)
c
c  Set high/low label information.
c
c     call cpsetc('HIT - High label test string','D$B$$ZDVU$m$E$')
c     call cpsetc('LOT - Low label text string','S$B$$ZDVU$m$E$')
      call cpsetr('HLS - High/Low label size',p009)
      call cpsetr('HLW - High/Low white space width',r400)
      call cpseti('HLX - High/Low search radius in x',radx)
      call cpseti('HLY - High/Low search radius in y',rady)
c
c  Make PLOTCHAR use high-quality character.
c
      call pcseti('QU - quality flag',0)
c
c  Make all CONPACK-written characters a little bigger.
c
      call cpsetr('CWM - character width multiplier',1.25)
c
c  Provide more room for X and Y coordinates defining contours lines.
c
      call cpseti('RWC - real workspace for contours',300)
c
c  Initialize the drawing of the contour plot.
c
      call cprect(f(1),mm,m,n,rwrk,lrwk,iwrk,liwk)
c
c-----------------------------------------------------------------------
c  Set contour levels.
c-----------------------------------------------------------------------
c
      call cppkcl(f(1),rwrk,iwrk)
      call cpgeti('NCL - number of contour levels',nocl)
      call cpgetr('CIU - contour interval used',abs(cint))
      nozero=.false.
      if(cint.lt.c0) nozero=.true.
      do 10 i=1,nocl
        call cpseti('PAI - parameter array index',i)
c
c  If requested, ommit the drawing of zero-contour lines.
c
        call cpgetr('CLV - contour level value',clev)
        if((clev.eq.c0).and.nozero) then
          call cpseti('CLU - contour level use flags',0)
        endif
c
c  Set solid lines for positive contour levels and dash pattern
c  for negative contour levels.
c
        if(clev.ge.0) then
          call cpseti('CLD - contour line solid pattern',65535)
        else
          call cpseti('CLD - contour line dash pattern',43690)
        endif
c
c  Increase line width for labelled levels.
c
c       call cpgeti('CLU - contour level use flag',iclu)
c       if(iclu.eq.3) then
c         call cpseti('CLL - contour-line line width',2)
c       endif
  10  continue
c
c-----------------------------------------------------------------------
c  Draw masked or unmasked contour lines.
c-----------------------------------------------------------------------
c
      if(imask.eq.1) then
c
c  Initialize area map.
c
        call arinam(iam,lam)
c
c  Define mask area edges.
c
        call aredam(iam,xcs,ycs,nxy,5,0,-1)
c
c  Pre-process the area map.
c
        call arpram(iam,0,0,0)
c
c  Draw masked countour lines.
c
        call cpcldm(f(1),rwrk,iwrk,iam,drawcl)
c
c  Draw regular contour lines but bock the drawing of contour lines
c  through High/Low labels.
c
      elseif(imask.lt.0) then
        call arinam(iam,lam)
        call cplbdr(f(1),rwrk,iwrk)
        call cplbam(f(1),rwrk,iwrk,iam)
        call arpram(iam,0,0,0)
        call cpcldm(f(1),rwrk,iwrk,iam,cpdrpl)
c
c  Draw regular contour lines.
c
      else
        call cpcldr(f(1),rwrk,iwrk)
      endif
c
c-----------------------------------------------------------------------
c  Give the work space used.
c-----------------------------------------------------------------------
c
      call cpgeti('RWU - real workspace usage',lrwku)
      call cpgeti('IWU - integer workspace usage',liwku)
      write(6,20) lrwku,lrwk,liwku,liwk
  20  format(/' CONPACK - real workspace used: ',4x,i6,5x,'given: ',
     *       i6,/9x, '- integer workspace used: ',i7,5x,'given: ',i6)
      if(imask.gt.0) then
        isu=lam-(iam(6)-iam(5)-1)
        write(6,30) isu,lam
  30    format(9x, '- space used in area mask: ',i6,5x,'given: ',i7)
      endif
      return
      end
