      subroutine colorbar(ncl,fmin,fmax,ipos)
c
c=======================================================================
c                                                                    ===
c  This routine draws color bar at the bottom (IPOS=0) or at the     ===
c  right (IPOS=1) of the map.                                        ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <cdefs.h>
#include <pconst.h>
#include <pltncar.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      logical out_size
      integer i,ipos,ncl,lenlab,pwr
      integer great_int
      real bb,bl,br,bt,delta,fmax,fmin,fval,max_abs,scl,wb,wl,
     *     wr,wt,xlab,ylab
      real xb(5),yb(5)
      character*10 lab
      character*15 scl_str
      character*40 fmt
      real fontsizeb,cint
      integer ifont
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c-----------------------------------------------------------------------
c  Set parameters for horizontal (IPOS=0) or vertical (IPOS=1)
c  color bar.
c-----------------------------------------------------------------------
c
#ifdef mediumfont
c Medium size fonts
      ifont=0
#else
c Default fonts
      ifont=1
#endif
c
      delta=c1/float(ncl)
      if(ipos.eq.0) then
        bl=fl
        br=fr
        bb=p06*sclmap
        bt=bb+p08*sclmap
        wl=c0
        wr=c1
        wb=c0
        wt=c1
        xb(1)=wl
        xb(2)=wl
        xb(3)=wl+delta
        xb(4)=wl+delta
        xb(5)=xb(1)
        yb(1)=wt
        yb(2)=wb
        yb(3)=wb
        yb(4)=wt
        yb(5)=yb(1)
      elseif(ipos.eq.1) then
        bl=fr+r50*sclmap
        br=fr+p08*sclmap
        bb=fb
        bt=ft
        wl=c0
        wr=c1
        wb=c0
        wt=c1
        xb(1)=wl
        xb(2)=wl
        xb(3)=wr
        xb(4)=wr
        xb(5)=xb(1)
        yb(1)=wb+delta
        yb(2)=wb
        yb(3)=wb
        yb(4)=wb+delta
        yb(5)=yb(1)
      endif
c
c-----------------------------------------------------------------------
c  Set color bar frame.
c-----------------------------------------------------------------------
c
      call set(bl,br,bb,bt,wl,wr,wb,wt,1)
c
c-----------------------------------------------------------------------
c  Determine scaling for labelling.
c-----------------------------------------------------------------------
c
      max_abs=max(abs(fmin),abs(fmax))
      out_size=((max_abs.lt.r10).and.(max_abs.gt.c0)).or.
     *          (max_abs.ge.c10000)
      if(out_size) then
        pwr=great_int(log10(max_abs))
        scl=c10**(-pwr)
      else
        scl=c1
      endif
c
c-----------------------------------------------------------------------
c  Draw color bar.
c-----------------------------------------------------------------------
c
      cint=(fmax-fmin)/float(ncl)
      do 20 i=1,ncl
#ifdef whitelines
        if (icnt.eq.1) then
           call gsplci(0)
        else
           call gsplci(i+1)
        endif
#else
        if (icnt.ne.1) then
           call gsplci(i+1)
        endif
#endif
        call clrbox(xb,yb,5,i+1)
#ifdef whitelines
        call gsplci(1)
#else
        if (icnt.ne.1) then
           call gsplci(1)
        endif
#endif
        if(ipos.eq.0) then
          xlab=xb(3)
          ylab=wb-r100
          xb(1)=xb(4)
          xb(2)=xb(1)
          xb(3)=xb(1)+delta
          xb(4)=xb(3)
          xb(5)=xb(1)
        elseif(ipos.eq.1) then
          xlab=wr+r10
          ylab=yb(1)
          yb(1)=yb(1)+delta
          yb(2)=yb(1)-delta
          yb(3)=yb(2)
          yb(4)=yb(1)
          yb(5)=yb(1)
        else
          write(6,10) ipos
  10      format(/' COLORBAR: illegal position, IPOS=',i4)
        endif
        if (ifont.eq.0) then
           fontsizeb=16.0
        else
           fontsizeb=12.0
        endif
#ifdef lowchr
        fontsizeb=1.2*fontsizeb
#endif
        if(allbarlab) then
          if(i.le.ncl-1) then
            fval=fmin+float(i)*cint
            call barlab(lab,lenlab,fval,cint,scl)
            call PLTCHR(xlab,ylab,lab(1:lenlab),fontsizeb,c0,cm1)
          endif
        else
          if(i.eq.1) then
            fval=fmin+cint
            call barlab(lab,lenlab,fval,cint,scl)
            call PLTCHR(xlab,ylab,lab(1:lenlab),fontsizeb,c0,cm1)
          elseif(i.eq.ncl/4) then
            fval=fmin+float(ncl/4)*cint
            call barlab(lab,lenlab,fval,cint,scl)
            call PLTCHR(xlab,ylab,lab(1:lenlab),fontsizeb,c0,cm1)
          elseif(i.eq.ncl/2) then
            fval=fmin+float(ncl/2)*cint
            call barlab(lab,lenlab,fval,cint,scl)
            call PLTCHR(xlab,ylab,lab(1:lenlab),fontsizeb,c0,cm1)
          elseif(i.eq.3*ncl/4) then
            fval=fmin+float(3*ncl/4)*cint
            call barlab(lab,lenlab,fval,cint,scl)
            call PLTCHR(xlab,ylab,lab(1:lenlab),fontsizeb,c0,cm1)
          elseif(i.eq.ncl-1) then
            fval=fmin+float(ncl-1)*cint
            call barlab(lab,lenlab,fval,cint,scl)
            call PLTCHR(xlab,ylab,lab(1:lenlab),fontsizeb,c0,cm1)
          endif
        endif
  20  continue
c
c-----------------------------------------------------------------------
c  Write label scaling(if needed).
c-----------------------------------------------------------------------
c
      if(out_size) then
        if((pwr.lt.100).and.(pwr.gt.9)) then
          write(fmt,30) 2
#if !defined medchr & !defined lowchr
  30      format('(a,',1h','R',1h',',a,',1h','x10',1h',',a,',1h','S',1h'
     &           ,',a,i',i2,',a,',1h','N',1h',',a)')
# else
  30      format('(4hx10^,i',i2,')')
#endif
        elseif(pwr.ge.0) then
          write(fmt,30) 1
        elseif(pwr.gt.-10) then
          write(fmt,30) 2
        else
          write(fmt,30) 3
        endif
#if !defined medchr & !defined lowchr
        write(scl_str,fmt) esc_char,esc_char,esc_char,esc_char,pwr,
     &                                                 esc_char,esc_char
# else
        write(scl_str,fmt) pwr
#endif
        if(ipos.eq.0) then
          xlab=xb(3)
          ylab=p5*(wb+wt)
        elseif(ipos.eq.1) then
          xlab=p5*(wl+wr)
          ylab=wb-r20
        endif
        call PLTCHR(xlab,ylab,scl_str,fontsizeb,c0,cm1)
      endif
c
c-----------------------------------------------------------------------
c  Draw color bar box.
c-----------------------------------------------------------------------
c
      call gslwsc(c2)
      call box(1)
      call gslwsc(c1)
      return
      end
