      subroutine cpmpxy(imap,xinp,yinp,xotp,yotp)
c
c=======================================================================
c                                                                    ===
c  This routine is used to locate contours in the map defined by     ===
c  the user.                                                         ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <param.h>
#include <pconst.h>
#include <domdat.h>
#include <fldpos.h>
#include <ndimen.h>
#include <pltncar.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer i,ip,j,imap
      real u,v,xinp,xotp,x1,x2,x3,x4,yinp,yotp,y1,y2,y3,y4
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c-----------------------------------------------------------------------
c  Inquiring about capabilities of this routine.  nint(XINP) is the
c  code of the mapping being inquired about.  YINP returns one of the
c  following 4 results
c     [0]  Neither forward nor inverse mapping defined
c     [1]  Forward mapping defined.
c     [2]  Inverse Mapping defined.
c     [3]  Both forward and inverse mappings defined.
c-----------------------------------------------------------------------
c
      if(imap.eq.0) then
        if ((nint(xinp).ge.1) .and. (nint(xinp).le.4)) then
           yinp = 3.0
         else
           yinp = 0.0
        end if
c
c-----------------------------------------------------------------------
c  The incoming XINP and YINP coordinates are assumed to represent
c  longitude and latitude, respectively.  The EZMAP routine MAPTRN
c  is called to find the X- and Y-coordinates of the projection of
c  the specified point on the globe,  and those coordinates are
c  returned as the outgoing XOTP and YOTP.
c-----------------------------------------------------------------------
c
      elseif(abs(imap).eq.1) then
         if (imap.gt.0) then
            call maptra(yinp,xinp,xotp,yotp)
            if (icfell('CPMPXY',1).ne.0) return
          else
            call maptri(xinp,yinp,yotp,xotp)
            if (icfell('CPMPXY',2).ne.0) return
         end if
c
c-----------------------------------------------------------------------
c  The incoming XINP and YINP coordinates are assumed to represent
c  RHO and THETA (in degrees) in polar coordinates. The output XINP
c  and YINP coordinates are computed from these.
c-----------------------------------------------------------------------
c
      elseif(abs(imap).eq.2) then
         if (imap.gt.0) then
           xotp=xinp*cos(0.017453292519943*yinp)
           yotp=xinp*sin(0.017453292519943*yinp)
          else
           xotp=sqrt(xinp*xinp+yinp*yinp)
           yotp=57.2957795130823*atan2(yinp,xinp)
         end if
c
c-----------------------------------------------------------------------
c  User coordinate mapping.  Interpolate from User grid.
c-----------------------------------------------------------------------
c
      elseif(abs(imap).eq.3) then
         if (imap.gt.0) then
c
c   Forward mapping.
c
            i = min( max(int(xinp), 1), (im-1) )
            j = min( max(int(yinp), 1), (jm-1) )
            u=xinp-float(i)
            v=yinp-float(j)
            ip=i+(j-1)*im
            call maptra(y(ip),x(ip),x1,y1)
            if (icfell('CPMPXY',1).ne.0) return
            call maptra(y(ip+1),x(ip+1),x2,y2)
            if (icfell('CPMPXY',1).ne.0) return
            call maptra(y(ip+im+1),x(ip+im+1),x3,y3)
            if (icfell('CPMPXY',1).ne.0) return
            call maptra(y(ip+im),x(ip+im),x4,y4)
            if (icfell('CPMPXY',1).ne.0) return
            xotp=(c1-u)*(c1-v)*x1+u*(c1-v)*x2+u*v*x3+v*(c1-u)*x4
            yotp=(c1-u)*(c1-v)*y1+u*(c1-v)*y2+u*v*y3+v*(c1-u)*y4
c
c    Check for "out of bounds"
c
            if ((xinp.lt.c1).or.(xinp.gt.float(im))) xotp = orval
            if ((yinp.lt.c1).or.(yinp.gt.float(jm))) yotp = orval
c
            if ((xotp.lt.ul).or.(xotp.gt.ur)) xotp = orval
            if ((yotp.lt.ub).or.(yotp.gt.ut)) yotp = orval
c
          else
c
c   Base Inverse mapping on HOPS domains.
c
            call maptri(xinp,yinp,y1,x1)
            if (icfell('CPMPXY',2).ne.0) return
            call ll2xy (x1,y1,coord,im,jm,dx,dy,clngd,clatd,
     &                  delx,dely,thetad,x2,y2)
c
c     Account for Tgrid/Vgrid offsets
c
            call ll2xy (x(1),y(1),coord,im,jm,dx,dy,clngd,clatd,
     &                  delx,dely,thetad,x3,y3)
            xotp = x2 + (c1-x3)
            yotp = y2 + (c1-y3)
         end if
c
c-----------------------------------------------------------------------
c  If IMAP is anything else, the input XINP and YINP coordinates are
c  simply returned.
c-----------------------------------------------------------------------
c
      else
        xotp=xinp
        yotp=yinp
      endif
      return
      end
