      program csec_ncar
c
c=======================================================================
c                                                                    ===
c  This program contours a vertical section of the desired field(s)  ===
c  at the given  time(s) using  NCAR  GKS  plotting  package (color  ===
c  version).  It uses QG and/or PE field classification.  The input  ===
c  data is assumed to be in NetCDF format.                           ===
c                                                                    ===
c  Hernan G. Arango  15/05/95                                        ===
c  Harvard University                                                ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <param.h>
#include <pconst.h>
#include <inpcdf.h>
#include <ndimen.h>
#include <pltfld.h>
#include <pltio.h>
#include <pltncar.h>
#include <secpos.h>
c
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer fclas1,fclas2,file,i,ictime,idfld,m,np
      real day
      real f1(nv),f2(nv),f3(nv),f4(nv),x(nv),y(nv),z(nv)
      real get_pltday
#ifdef sunfpe
      integer ieeer,ieee_handler,my_handler
      external my_handler
#endif
c
c=======================================================================
c  Begin executable code.
c=======================================================================
#ifdef sunfpe
c
c  Set trap for floating point exceptions.
c
      ieeer=ieee_handler('set','common',my_handler)
      if(ieeer.ne.0) print *,' IEEE_HANDLER cannot set my_handler'
#endif
c
c  Initialize NCAR GKS plotting package.
c
      call headln (stdout)
      call gksinit
      call pcsetc ('FC - Function Code delimiter',esc_char)
c
c  Read in plot job parameters.
c
      call get_parm
c
c-----------------------------------------------------------------------
c  Read in fields at the specified time.
c-----------------------------------------------------------------------
c
      day=frstd
      ictime=0
      do 30 while ((frstd.le.day).and.(day.le.lastd))
        ictime=ictime+1
        do 20 m=1,nfields
          idfld=fldid(m)
          file=1
          if(dskip.le.c0) day=get_pltday(ictime,idfld,class1,file)
          call get_cdf3dat(day,x,y,z,f1,f2,np,file,fclas1,idfld)
          if(iref.eq.3) then
            file=2
            call get_cdf3dat(day,x,y,z,f3,f4,np,file,fclas2,idfld)
            call flddif (np,f1,f3)
            call flddif (np,f2,f4)
          elseif(iref.eq.4) then
            file=1
            call get_cdf3dat(frstd,x,y,z,f3,f4,np,file,fclas1,idfld)
            call flddif (np,f3,f1)
            call flddif (np,f4,f2)
            do 10 i=1,np
              f1(i)=f3(i)
              f2(i)=f4(i)
  10        continue
          endif
c
c  Get section coordinates and extract/interpolate requested section
c  for primary field.
c
          call get_scoor(idfld,itopo,spval1)
          call xsection(f2,xsec,ysec,zsec,ims,kms,f1,z,im,jm,km,vintrp,
     *                  spval1)
c
c  Read in overlay field, if any.
c
          if((iref.eq.1).or.(iref.eq.2)) then
            if(iref.eq.1) file=1
            if(iref.eq.2) file=2
            call get_cdf3dat(day,x,y,z,f3,f4,np,file,fclas2,idover)
c
c  Get section coordinates and extract/interpolate requested section
c  for primary field.
c
            call get_scoor(idover,itopo,spval1)
            call xsection(f4,xsec,ysec,zsec,ims,kms,f3,z,im,jm,km,
     *                    vintrp,spval1)
          endif
c
c-----------------------------------------------------------------------
c  Plot requested field(s).
c-----------------------------------------------------------------------
c
          call pltsec(day,f2,f4,ims*kms,file,fclas1,fclas2,idfld)
  20    continue
c
c-----------------------------------------------------------------------
c  Set next day to plot or terminate plotting.
c-----------------------------------------------------------------------
c
        if(dskip.gt.c0) day=day+dskip
  30  continue
c
c-----------------------------------------------------------------------
c  Close GKS software and datasets.
c-----------------------------------------------------------------------
c
      call exitus('DONE')
      stop
      end
      subroutine get_parm
c
c=======================================================================
c                                                                    ===
c  This routine reads in input parameters from standard input        ===
c  script and sets various parameters and switches needed for        ===
c  plotting.                                                         ===
c                                                                    ===
c  Required common blocks:                                           ===
c                                                                    ===
c    DOMDAT, NDIMEN, PEFLDID, PLTFLD, PLTIO, PLTLAB, PLTNCAR, ZDAT   ===
c                                                                    ===
c  Required parameter statement:                                     ===
c                                                                    ===
c    param.h                                                         ===
c                                                                    ===
c  Calls:  GET_DATE, OPENCDF, READPAL, READTOPO, SETCOLPAL           ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define Global data.
c-----------------------------------------------------------------------
c
#include <param.h>
#include <pconst.h>
#include <domdat.h>
#include <inpcdf.h>
#include <ndimen.h>
#include <pltfld.h>
#include <pltio.h>
#include <pltlab.h>
#include <pltncar.h>
#include <secpos.h>
#include <zdat.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer i,iflds,ilevs,j,k
      real    scle
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c-----------------------------------------------------------------------
c  Read in input parameters and switches for standard input.
c-----------------------------------------------------------------------
c
c  Read in year and starting year day.
c
      read(stdinp,*) iyear,yday
      wdate=.true.
      if(yday.lt.c0) wdate=.false.
c
c  Read in plot titles.
c
      read(stdinp,'(a)') pltitle(1)
      read(stdinp,'(a)') pltitle(2)
      read(stdinp,'(a)') pltitle(3)
      read(stdinp,'(a)') pltitle(4)
c
c  Read in field ID classification for primary file.
c
      read(stdinp,*) class1
c
c  Read in number of different fields to plot.
c
      read(stdinp,*) nfields
c
c  Read in field(s) identification.
c
      read(stdinp,*) (fldid(i),i=1,nfields)
c
c  Read in first and last day to plot.
c
      read(stdinp,*) frstd
      read(stdinp,*) lastd
c
c  Read in interval between plots (days). If zero or negative, the
c  data is plotted at their own time frequency.
c
      read(stdinp,*) dskip
c
c  Read in the coordinates (lon,lat) of the two points defining the
c  section.
c
      read(stdinp,*) slon1
      read(stdinp,*) slat1
      read(stdinp,*) slon2
      read(stdinp,*) slat2
c
c  Read in spacing (degrees) used to compute section points between
c  (SLON1,SLAT1) and (SLON2,SLAT2).
c
      read(stdinp,*) dels
c
c  Read in section minimum and maximun depths (meters) to consider.
c
      read(stdinp,*) sztop
      read(stdinp,*) szbot
c
c  Read number of refiment levels to interpolate section between SZTOP
c  and SZBOT.
c
      read(stdinp,*) kms
c
c  Read in switch for vertical interpolation scheme to use during
c  section extraction: [0] linear, [1] cubic spline.
c
      read(stdinp,*) vintrp
c
c  Read in field minimum and maximum limit values for color palette.
c
      read(stdinp,*) pmin
      read(stdinp,*) pmax
c
c  Read in switch to put contour lines over color bands:
c           [0] no, [1] yes.
c
      read(stdinp,*) icnt
c
c  Read in switch to plot secondary field:
c           [0] no secondary or reference field to plot
c           [1] primary file overlay
c           [2] secondary file overlay
c           [3] primary - secondary (field subtaction)
c           [4] Day0 - DayN (field subtraction)
c
      read(stdinp,*) iref
c
c  Read in field ID classification for secondary file.
c
      read(stdinp,*) class2
c
c  Read in overlay field identification.
c
      read(stdinp,*) idover
c
c  Read in overlay field minimum and maximum limit values to contour.
c
      read(stdinp,*) rmin
      read(stdinp,*) rmax
c
c  Read in number of plots per page: 1, 2, or 4.
c
      read(stdinp,*) npage
      nframe=0
c
c  Read in switch to mask area below of water column: [0] no, [1] yes.
c
      read(stdinp,*) ifill
c
c  Read in switch to super-impose and mask real bathymetry:
c  [0] no, [1] yes.
c
      read(stdinp,*) itopo
c
c  Read in logical switch to activate drawing of Harvard Logo.
c
      read(stdinp,'(l1)') pltlogo
c
c  Read in logical switch to activate writing of plot header titles.
c
      read(stdinp,'(l1)') wrthdr
c
c  Read in logical switch to activate writing of plot bottom title.
c
      read(stdinp,'(l1)') wrtblab
c
c  Read in logical switch to activate writing of information about the
c  range values of the plotted data and the contour interval.
c
      read(stdinp,'(l1)') wrtrang
c
c  Read in logical switch to activate writing of input filename.
c
      read(stdinp,'(l1)') wrtfnam
c
c  Read in logical switch to activate writing of current plotting date.
c
      read(stdinp,'(l1)') wrtdate
c
c  Read in filename for color palette.
c
      read(stdinp,'(a)') fname(1)
c
c  Read and set color palette indices.
c
      open(inppal,file=fname(1),form='formatted',status='old')
      call readpal(inppal)
      call setcolpal(lmsk)
c
c  Read in filename for plotting parameters.
c
      read(stdinp,'(a)') fname(2)
c
c  Read in plot parameters: vector sampling and length factors, and
c  contour interval as function of field tyep and level.
c
      open(inppar,file=fname(2),form='formatted',status='old')
      read(inppar,*) iskip,jskip
      read(inppar,*) asize,vper
      read(inppar,*) iflds,ilevs
      do 10 i=1,iflds
        read(inppar,*) j,(cont(j,k),k=1,ilevs)
  10  continue
      if(km.gt.ilevs) then
        write(stdout,20) ilevs,km
  20    format(' GET_PARM: number of model levels greater than',/,
     *         '           those in contour interval array: ',2i4)
        stop
       endif
c
c  Read in primary filename.
c
      read(stdinp,'(a)') fname(3)
c
c  Read in secondary filename.
c
      read(stdinp,'(a)') fname(4)
c
c  Read in bottom topography filename.
c
      read(stdinp,'(a)') fname(5)
c
c-----------------------------------------------------------------------
c  Set execution date label
c-----------------------------------------------------------------------
c
      call get_date(date_str)
c
c-----------------------------------------------------------------------
c  Open primary and secondary (if any) input NetCDF files and get the
c  necessary information for plotting.
c-----------------------------------------------------------------------
c
      call opencdf(fname(3),fname(4))
c
c-----------------------------------------------------------------------
c  Read in bottom topography.
c-----------------------------------------------------------------------
c
      if ((itopo.gt.0).and.(itopo.lt.4)) then
        call readtopo (bath,im,jm,fname(5),itopo,stdout)
        itopo = 1
       else
        itopo = 0
      endif
c
c-----------------------------------------------------------------------
c  Report plotting parameters.
c-----------------------------------------------------------------------
c
      if (coord.eq.0) then
         scle = m2km
        else
         scle = c1
      endif
      write(stdout,100) im,jm,km,xbasin*scle,ybasin*scle,dx*scle,
     *                  dy*scle,thetad,clngd,clatd
 100  format(//,'  Parameters: ',//,
     *       5x,' number of points (im,jm,km) = ',3i4,/,
     *       5x,'    basin dimensions (Lx,Ly) = ',2f10.3,/,
     *       5x,'        grid spacing (dx,dy) = ',2f10.3,/,
     *       5x,'     domain rotation (theta) = ', f10.3,/,
     *       5x,'      centroid (clngd,clatd) = ',2f10.3)
      write(stdout,110) pltitle(1)
      write(stdout,110) pltitle(2)
      write(stdout,110) pltitle(3)
      write(stdout,110) pltitle(4)
 110  format(a)
      return
      end
      subroutine pltsec(day,f1,f2,n,file,fclas1,fclas2,idfld)
c
c=======================================================================
c                                                                    ===
c  This routine contours scalar cross-sections.  It also contours    ===
c  scalar overlays in the same map.                                  ===
c                                                                    ===
c  On Input:                                                         ===
c                                                                    ===
c     DAY     time of the field(s) to plot (real).                   ===
c     F1      primary scalar field (real array).                     ===
c     F2      scondary scalar field (real array).                    ===
c     N       number points in field (integer)                       ===
c     FILE    NetCDF file to plot (primary or secondary).            ===
c     FCLAS1  field classification for primary field (PE or QG).     ===
c     FCLAS2  field classification for secondary field (PE or QG).   ===
c     IDFLD   field identification (integer).                        ===
c     LEVEL   field depth level (integer).                           ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <param.h>
#include <pconst.h>
#include <fdiagn.h>
#include <ndimen.h>
#include <secpos.h>
#include <pltfld.h>
#include <pltio.h>
#include <pltncar.h>
#include <zdat.h>
c
c=======================================================================
c  Define local data.
c=======================================================================
c
      integer fclas1,fclas2,file,icolor,idfld,ipos,level,mask,n
      real day,cint,cmax,cmin,cntint
      real f1(n),f2(n)
      parameter (icolor=1,ipos=1,level=0,mask=0)
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c
c=======================================================================
c  Plot scalar primary field.
c=======================================================================
c
c-----------------------------------------------------------------------
c  Set area mask, if any.
c-----------------------------------------------------------------------
c
      lmsk=0
      call areamask(f1,n,itopo)
c
c-----------------------------------------------------------------------
c  Set section frame.
c-----------------------------------------------------------------------
c
      call sec_frame(icolor)
c
c-----------------------------------------------------------------------
c  Contour primary scalar field (color)
c-----------------------------------------------------------------------
c
      scalar1=.true.
      call fdiag(f1,ims,ims,kms,fclas1,idfld,level,day,stdout)
      if((pmin.eq.c0).and.(pmax.eq.c0)) then
        cmin=fmin
        cmax=fmax
      else
        cmin=pmin
        cmax=pmax
      endif
      call cntcolor(f1,ims,ims,kms,cmin,cmax,icnt,ipos,lmsk)
c
c=======================================================================
c  Plot secondary (overlay) field (scalar or vector).
c=======================================================================
c
      if((iref.eq.1).or.(iref.eq.2)) then
        scalar2=.true.
        call fdiag(f2,ims,ims,kms,fclas2,idover,level,day,stdout)
        if((rmin.eq.c0).and.(rmax.eq.c0)) then
          cmin=fmin
          cmax=fmax
        else
          cmin=rmin
          cmax=rmax
        endif
        cint=cntint(idover,1,cmin,cmax,zmid,km,cont,cfld,clev)
        call set(fl,fr,fb,ft,ul,ur,ub,ut,1)
        call cntpack(f2,ims,ims,kms,cmin,cmax,cint,mask)
      endif
c
c-----------------------------------------------------------------------
c  Area fill the section below water column.
c-----------------------------------------------------------------------
c
      if(ifill.ge.1) call areafill(icolor,ifill)
c
c-----------------------------------------------------------------------
c  Draw vertical background plot and advance frame when appropriate.
c-----------------------------------------------------------------------
c
      call vbackground(day,cint,fmin,fmax,frms,icolor,fclas1,idfld)
      nframe=nframe+1
      if(mod(nframe,npage).eq.0) call frame
      return
      end
