      subroutine depth_lab(class,idfld,level,botlab)
c
c=======================================================================
c                                                                    ===
c  This routine creates the bottom label of the current field.  The  ===
c  bottom label consists of the field name and the depth (or level)  ===
c  of the field.                                                     ===
c                                                                    ===
c  On Input:                                                         ===
c                                                                    ===
c     CLASS    classification of current field (integer; PE or QG).  ===
c     IDFLD    identification of current field (integer).            ===
c     LEVEL    depth level of current field (integer).               ===
c                                                                    ===
c  On Output:                                                        ===
c                                                                    ===
c     BOTLAB   bottom label (character).                             ===
c                                                                    ===
c  Calls:   NCVID   (NetCDF library)                                 ===
c           EXITUS, ID2FLDNAM, LNBLK, NCVGET                         ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <param.h>
#include <pconst.h>
#include <hybrid.h>
#include <inpcdf.h>
#include <ndimen.h>
#include <netcdf.inc>
#include <pefldid.h>
#include <pltfld.h>
#include <pltio.h>
#include <qgfldid.h>
#include <zdat.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer class,idfld,idpth,lenfld,lenstr,level,modlev,n,ndig,vindx
      integer lnblk,no_digit
      real depth
      real sig_fig
      logical      graph,spflat
      character*21  fmt
      character*128 varnam
      character*256 dpthlab,fldlab
      character*(*) botlab
c
      parameter (graph=.true.)
c
      no_digit(n)=int(log10(float(max(abs(n),1))))+(1+max(-sign(1,n),0))
c
c-----------------------------------------------------------------------
c  Get field label.
c-----------------------------------------------------------------------
c
      if(class.eq.peclass) then
        call id2fldnam(idfld,peclass,graph,varnam,vindx,fldlab)
      elseif(class.eq.qgclass) then
        call id2fldnam(idfld,qgclass,graph,varnam,vindx,fldlab)
      endif
      lenfld=lnblk(fldlab,len(fldlab))
c
c  PE classification field.
c
      if(class.eq.peclass) then
        spflat = (idfld.eq.pvfvec) .or. (idfld.eq.pvfmag) .or.
     &           (idfld.eq.peuflt) .or. (idfld.eq.pevflt)
        if(.not.levless) then
          if((type1(1:ltype1).eq.'PE MODEL').or.
     *       (type1(1:ltype1).eq.'PE ENERGY')) then
            modlev=abs(level)
          elseif(type1(1:ltype1).eq.'PE_INITIAL') then
            modlev=abs(level)
          endif
          if ( ((modlev.gt.kc).or.(idblsigma.eq.1)) .and.
     &       (modlev.le.pelev) .and. (level.gt.0) .and..not.spflat) then
            write (fmt,10) no_digit(modlev)
            write (dpthlab,fmt) modlev
  10        format ('(',1h',' at Level ',1h',',i',i2,')')
          elseif ( ((modlev.gt.pelev).or.(level.le.0)) .and.
     &                                                 .not.spflat) then
            write (fmt,20) no_digit(modlev)
            write(dpthlab,fmt) modlev
  20        format ('(',1h',' at ',1h',',i',i2,',',1h',' m ',1h',')')
          else
            if (.not.spflat) then
               depth = abs(zmid(modlev))
            else
               depth = abs(zflat(modlev))
            endif
            if (depth.ne.c0) then
               ndig = int(log10(depth))+3
               depth = sig_fig(depth,ndig-1)
               ndig  = int(log10(depth))+3
            else
               ndig = 4
            endif
            write (fmt,30) ndig
  30        format ('(',1h',' at ',1h',',f',i3,'.1,',1h',' m ',1h',')')
            write(dpthlab,fmt) depth
          endif
        else
          dpthlab='                    '
        endif
c
c  QG classification field.
c
      elseif(class.eq.qgclass) then
        if(.not.levless) then
          if(type1(1:ltype1).eq.'QG MODEL') then
            if(((idfld.eq.qgmmlb).or.(idfld.eq.qgsblt))
     &                                           .and.(level.gt.0)) then
              varid=ncvid(ncinp1id,'zsblout',rcode)
              if(rcode.eq.0) then
                start(1)=zindx
                count(1)=1
                start(2)=level
                count(2)=1
                call ncvget(ncinp1id,varid,start,count,depth,rcode)
                if(rcode.ne.0) then
                  write(stdout,900) 'zsblout'
                  call exitus('DEPTH_LAB')
                endif
              else
                write(stdout,901) 'zsblout'
                call exitus('DEPTH_LAB')
              endif
            elseif ((idfld.eq.qgsblw).and.(level.gt.0)) then
              varid=ncvid(ncinp1id,'zsblwout',rcode)
              if(rcode.eq.0) then
                start(1)=zindx
                count(1)=1
                start(2)=level
                count(2)=1
                call ncvget(ncinp1id,varid,start,count,depth,rcode)
                if(rcode.ne.0) then
                  write(stdout,900) 'zsblwout'
                  call exitus('DEPTH_LAB')
                endif
              else
                write(stdout,901) 'zsblwout'
                call exitus('DEPTH_LAB')
              endif
            elseif(((idfld.eq.qgsbl1).or.(idfld.eq.qgsbl2).or.
     *             (idfld.eq.qgsbl3).or.(idfld.eq.qgsbl4).or.
     *             (idfld.eq.qgsbl5).or.(idfld.eq.qgsbl6).or.
     *             (idfld.eq.qgsbl7).or.(idfld.eq.qgsbl8)) .and.
     &                                                (level.gt.0)) then
              varid=ncvid(ncinp1id,'zbioout',rcode)
              if(rcode.eq.0) then
                start(1)=zindx
                count(1)=1
                start(2)=level
                count(2)=1
                call ncvget(ncinp1id,varid,start,count,depth,rcode)
                if(rcode.ne.0) then
                  write(stdout,900) 'zbioout'
                  call exitus('DEPTH_LAB')
                endif
              else
                write(stdout,901) 'zbioout'
                call exitus('DEPTH_LAB')
              endif
            elseif (level.le.0) then
              depth=level
            else
              depth=zmid(level)
            endif
          elseif (level.le.0) then
            depth=level
          else
            depth=zmid(level)
          endif
          idpth=nint(abs(depth))
          write (fmt,20) no_digit(idpth)
          write(dpthlab,fmt) idpth
        else
          dpthlab='                    '
        endif
      endif
c
c  Generate bottom label.
c
      lenstr=lnblk(dpthlab,len(dpthlab))
      if(lenstr.ne.0) then
        botlab=fldlab(1:lenfld)//dpthlab(1:lenstr)
      else
        botlab=fldlab(1:lenfld)
      endif
c
 900  format(/' DEPTH_LAB - error while reading variable: ',a,2x,
     *        ' in primary NetCDF file.')
 901  format(/' DEPTH_LAB - unable to find variable: ',a,2x,
     *        ' in primary NetCDF file.')
      return
      end
