      subroutine draw_line(iunit,kind)
c
c=======================================================================
c                                                                    ===
c  This routine reads and draws map attribute data.                  ===
c                                                                    ===
c  On Input:                                                         ===
c                                                                    ===
c     KIND    [0] coastlines, islands and lakes                      ===
c                 or isobaths (lat,lon)                              ===
c             [1] Lagrangian trajectories (lat,lon,z,time)           ===
c             [2] hydrographic stations                              ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <cdefs.h>
#include <pconst.h>
#include <pltncar.h>
c
c   Cludge to enable animation of drifters.
c
#include <pltfld.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      logical pen_up
      integer ios,ista,itime,iunit,julday,kind,npts
      real day,lon,lat,time,x,y,z
#ifdef diffsta
      integer itype
      real c12p5
      parameter (c12p5=12.5)
#endif
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c  Turn on the clipping indicator.
c
      call sflush
      call gsclip (1)
c
c  Read and draw coastlines, islands and lakes or isobath.
c
      if(kind.eq.0) then
        read(iunit,*,iostat=ios) lat,lon
        do 10 while (ios.eq.0)
          if ((lon.eq.spvgeo).and.(lat.eq.spvgeo)) then
            pen_up=.true.
          else
c          elseif ((pblat.le.lat).and.(lat.le.ptlat).and.
c     &            (pllon.le.lon).and.(lon.le.prlon)) then
            call maptrn(lat,lon,x,y)
            if(pen_up) then
              call frstpt(x,y)
              pen_up=.false.
            else
              call vector(x,y)
            endif
c          else
c            pen_up=.true.
          endif
          read(iunit,*,iostat=ios) lat,lon
  10    continue
c
c-----------------------------------------------------------------------
c  Draw Lagrangian trajectories.
c-----------------------------------------------------------------------
c
      elseif(kind.eq.1) then
        read(iunit,*,iostat=ios) lat,lon,z,time
        do 20 while (ios.eq.0)
c
c   Cludge to enable animation of drifters.
c
#ifdef anilag
          if ( ((lon.ge.spvgeo).and.(lat.ge.spvgeo)) .or.
     &         (time.gt.ltcut) .or. (time.lt.ltcold) ) then
#else
          if ((lon.ge.spvgeo).and.(lat.ge.spvgeo)) then
#endif
            pen_up=.true.
          else
c          elseif ((pblat.le.lat).and.(lat.le.ptlat).and.
c     &            (pllon.le.lon).and.(lon.le.prlon)) then
            call maptrn(lat,lon,x,y)
            if(pen_up) then
c
c   Cludge to enable animation of drifters.
c   Uncomment the following for non-animated plots.
c
#ifndef anilag
#  if !defined medchr & !defined lowchr
              call PLTCHR(x,y,esc_char//'1256'//esc_char,c5,c0,c0)
#   else
              call PLTCHR(x,y,'+',c5,c0,c0)
#  endif
#endif
              call frstpt(x,y)
              pen_up=.false.
              day=float(int(time))+c1
            else
              call vector(x,y,2)
            endif
c
c   Cludge to enable animation of drifters & because I do not understand it.
c
#ifndef anilag
            if(time.gt.day) then
              day=day+c1
#  if !defined medchr & !defined lowchr
              call PLTCHR(x,y,esc_char//'1245'//esc_char,c5,c0,c0)
#   else
              call PLTCHR(x,y,'*',c5,c0,c0)
#  endif
            endif
#endif
c
c   Weak clipping change.
c
c          else
c            pen_up=.true.
          endif
          read(iunit,*,iostat=ios) lat,lon,z,time
  20    continue
c
c-----------------------------------------------------------------------
c  Draw cruise track stations. (itype=1=CTD; itype=2=XBT)
c-----------------------------------------------------------------------
c
      elseif(kind.eq.2) then
#ifndef diffsta
        read(iunit,*,iostat=ios) lat,lon,z,julday,itime,npts,ista
# else
        read(iunit,*,iostat=ios) lat,lon,z,julday,itime,npts,ista,itype
#endif
        do 30 while (ios.eq.0)
c
c  Weak clipping change.
c
c          if ((pblat.le.lat).and.(lat.le.ptlat).and.
c     &        (pllon.le.lon).and.(lon.le.prlon)) then
            call maptrn(lat,lon,x,y)
#ifndef diffsta
#  if !defined medchr & !defined lowchr
            call PLTCHR(x,y,esc_char//'1245'//esc_char,c5,c0,c0)
#   else
            call PLTCHR(x,y,'*',c5,c0,c0)
#  endif
# else
#  if !defined medchr & !defined lowchr
            if(itype.eq.1) then
              call PLTCHR(x,y,esc_char//'1256'//esc_char,c12p5,c0,c0)
            elseif(itype.eq.2) then
              call PLTCHR(x,y,esc_char//'0045'//esc_char,c5,c0,c0)
            else
              call PLTCHR(x,y,esc_char//'1245'//esc_char,c5,c0,c0)
            endif
#   else
            if(itype.eq.1) then
              call PLTCHR(x,y,'+',c12p5,c0,c0)
            elseif(itype.eq.2) then
              call PLTCHR(x,y,'o',c5,c0,c0)
            else
              call PLTCHR(x,y,'*',c5,c0,c0)
            endif
#  endif
#endif
c          endif
#ifndef diffsta
          read(iunit,*,iostat=ios) lat,lon,z,julday,itime,npts,ista
# else
          read(iunit,*,iostat=ios)lat,lon,z,julday,itime,npts,ista,itype
#endif
  30    continue
      endif
c
c  Turn off the clipping indicator.
c
      call sflush
      call gsclip (0)
c
      rewind(iunit)
c
      return
      end
