      subroutine fld_type(ncinpid,idfld,idfld1,idfld2,class,status)
c
c=======================================================================
c                                                                    ===
c  This routine determines the field type for current field.         ===
c                                                                    ===
c  On Input:                                                         ===
c                                                                    ===
c     NCINPID open NetCDF file ID (integer).                         ===
c     IDFLD   identification of current field (integer).             ===
c     CLASS   current field classification (integer; PE or QG).      ===
c                                                                    ===
c  On Output:                                                        ===
c                                                                    ===
c     IDFLD1  identification for primary field component 1.          ===
c     IDFLD2  identification for primary field component 2.          ===
c     STATUS  current field type status:                             ===
c             STATUS = 1   scalar field.                             ===
c             STATUS = 2   2D vector field.                          ===
c             STATUS = 3   derived field from two primary fields.    ===
c             STATUS = 4   derived field from streamfunction.        ===
c                                                                    ===
c  Required common blocks:                                           ===
c                                                                    ===
c     INPCDF, PEFLDID, QGFLDID, PLTIO                                ===
c                                                                    ===
c  Calls:                                                            ===
c                                                                    ===
c     EXITUS, LNBLK, NCINQ, NCVINQ                                   ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <param.h>
#include <inpcdf.h>
#include <pefldid.h>
#include <pltio.h>
#include <qgfldid.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer maxvar
      parameter (maxvar=150)
c
      integer class,idfld,idfld1,idfld2,lenvar,n,ncinpid,ndims,
     *        ngatts,nvars,nvatts,recdim,status,trcindx,vartyp
      integer nvdims(maxvar),vdims(6,maxvar)
      integer lnblk
      logical fnd
      character*128 varnam(maxvar)
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
      idfld1=0
      idfld2=0
      status=0
c
c  PE field classification.
c
      if(class.eq.peclass) then
        if(idfld.eq.petvec) then
          status=2
          idfld1=peutot
          idfld2=pevtot
        elseif(idfld.eq.pedevc) then
          status=4
          idfld1=pepbar
        elseif(idfld.eq.pegvec) then
          status=2
          idfld1=peugeo
          idfld2=pevgeo
        elseif(idfld.eq.peivec) then
          status=2
          idfld1=peuhat
          idfld2=pevhat
        elseif(idfld.eq.peevec) then
          status=2
          idfld1=peubar
          idfld2=pevbar
        elseif(idfld.eq.petdvc) then
          status=2
          idfld1=peutid
          idfld2=pevtid
        elseif(idfld.eq.pesmfv) then
          status=2
          idfld1=pesmfx
          idfld2=pesmfy
        elseif(idfld.eq.pvfvec) then
          status=2
          idfld1=peuflt
          idfld2=pevflt
        elseif(idfld.eq.pb1vec) then
          status=2
          idfld1=peub1
          idfld2=pevb1
        elseif(idfld.eq.pb2vec) then
          status=2
          idfld1=peub2
          idfld2=pevb2
        elseif(idfld.eq.pb3vec) then
          status=2
          idfld1=peub3
          idfld2=pevb3
        elseif(idfld.eq.pecden) then
          status=3
          idfld1=pesalt
          idfld2=petemp
        elseif(idfld.eq.pesigt) then
          status=3
          idfld1=pesalt
          idfld2=petemp
        elseif(idfld.eq.pesnds) then
          status=3
          idfld1=pesalt
          idfld2=petemp
        elseif ((idfld.eq.petmag).or.(idfld.eq.pevnrm).or.
     &                               (idfld.eq.pevtng)) then
          status=3
          idfld1=peutot
          idfld2=pevtot
        elseif(idfld.eq.pedemg) then
          status=4
          idfld1=pepbar
        elseif ((idfld.eq.pegmag).or.(idfld.eq.pegvnm).or.
     &                               (idfld.eq.pegvtg)) then

          status=3
          idfld1=peugeo
          idfld2=pevgeo
        elseif ((idfld.eq.peimag).or.(idfld.eq.peivnm).or.
     &                               (idfld.eq.peivtg)) then

          status=3
          idfld1=peuhat
          idfld2=pevhat
        elseif (idfld.eq.peemag) then
          status=3
          idfld1=peubar
          idfld2=pevbar
        elseif ((idfld.eq.petdmg).or.(idfld.eq.petvnm).or.
     &                               (idfld.eq.petvtg)) then

          status=3
          idfld1=peutid
          idfld2=pevtid
        elseif(idfld.eq.pesmfm) then
          status=3
          idfld1=pesmfx
          idfld2=pesmfy
        elseif (idfld.eq.pvfmag) then
          status=3
          idfld1=peuflt
          idfld2=pevflt
        elseif (idfld.eq.pb1mag) then
          status=3
          idfld1=peub1
          idfld2=pevb1
        elseif (idfld.eq.pb2mag) then
          status=3
          idfld1=peub2
          idfld2=pevb2
        elseif (idfld.eq.pb3mag) then
          status=3
          idfld1=peub3
          idfld2=pevb3
        elseif(idfld.eq.pedubr) then
          status=4
          idfld1=pepbar
        elseif(idfld.eq.pedvbr) then
          status=4
          idfld1=pepbar
        else
          status=1
        endif
c
c  QG field classification
c
      elseif(class.eq.qgclass) then
        if ((idfld.eq.qgpvec).or.(idfld.eq.qgpvnm).or.
     &                           (idfld.eq.qgpvtn)) then
          status=4
          idfld1=qgmpsi
        elseif ((idfld.eq.qgvvec).or.(idfld.eq.qgvnrm).or.
     &                               (idfld.eq.qgvtng)) then
          status=3
          idfld1=qguvel
          idfld2=qgvvel
        elseif ((idfld.eq.qgevec).or.(idfld.eq.qgevnm).or.
     &                               (idfld.eq.qgevtn)) then
          status=3
          idfld1=qgevxc
          idfld2=qgevyc
        elseif(idfld.eq.qgwshv) then
          status=3
          idfld1=qgwsxc
          idfld2=qgwsyc
        elseif(idfld.eq.qgdano) then
          status=3
          idfld1=qgsalt
          idfld2=qgtemp
        elseif(idfld.eq.qgsigt) then
          status=3
          idfld1=qgsalt
          idfld2=qgtemp
        elseif(idfld.eq.qgsnds) then
          status=3
          idfld1=qgsalt
          idfld2=qgtemp
        elseif(idfld.eq.qgmsse) then
          status=3
          idfld1=qgmpsi
          idfld2=qgdent
        elseif(idfld.eq.qgdhsr) then
          status=3
          idfld1=qgdher
          idfld2=qgdhrs
        elseif(idfld.eq.qgp2dh) then
          status=4
          idfld1=qgmpsi
        elseif(idfld.eq.qgsnsr) then
          status=3
          idfld1=qgsnmr
          idfld2=qgsnms
        else
          fnd     = .false.
          trcindx = 1
          do 10 while ( (.not.fnd) .and. (trcindx.le.maxtrc) )
            if (idfld.eq.qserid(trcindx)) then
              fnd = .true.
              status=3
              idfld1=qterid(trcindx)
              idfld2=qrmsid(trcindx)
            end if
            trcindx = trcindx + 1
  10      continue
          if (.not.fnd) status=1
        endif
      else
        write(stdout,900) idfld,class
        call exitus('FLD_TYPE')
      endif
c
c  Check if secondary field already exits in the NetCDF file.
c
      call ncinq(ncinpid,ndims,nvars,ngatts,recdim,rcode)
      if(rcode.eq.0) then
c
c  Inquire about the variables.
c
        do 20 n=1,nvars
          varid=n
          call ncvinq(ncinpid,varid,varnam(n),vartyp,nvdims(n),
     *                vdims(1,n),nvatts,rcode)
          if(rcode.ne.0) then
            write(stdout,901) n,ncinpid
            call exitus('FLD_TYPE')
          endif
          lenvar=lnblk(varnam(n),len(varnam(n)))
          if(((class.eq.peclass).and.(idfld.eq.pesigt)).or.
     *       ((class.eq.qgclass).and.(idfld.eq.qgsigt))) then
            if(varnam(n)(1:lenvar).eq.'sigma-t') status=1
          elseif(((class.eq.peclass).and.(idfld.eq.pecden)).or.
     *           ((class.eq.qgclass).and.(idfld.eq.qgdano))) then
            if(varnam(n)(1:lenvar).eq.'dena') status=1
          endif
  20    continue
      else
        write(stdout,902) varid
        call exitus('FLD_TYPE')
      endif
c
 900  format(/' FLD_TYPE - unable to determine type in field ID = ',i4,
     *       2x,' CLASSIFICATION = ',i2)
 901  format(/' FLD_TYPE - unable to inquire about of contents of',
     *        ' input NetCDF file ID = ',i3)
 902  format(/' FLD_TYPE - error while inquiring information for',
     *        ' variable ID = ',i3)
      return
      end
