      function fldnam2id(varnam,class)
c
c=======================================================================
c                                                                    ===
c  This routine returns the field identification of classification   ===
c  CLASS for NetCDF Variable VARNAM.                                 ===
c                                                                    ===
c  On Input:                                                         ===
c                                                                    ===
c     VARNAM     NetCDF variable name (character).                   ===
c     CLASS      field classification (integer):                     ===
c                CLASS=1   PE classification.                        ===
c                CLASS=2   QG classification.                        ===
c                                                                    ===
c  On Output:                                                        ===
c                                                                    ===
c     FLDNAM2ID  field identification (integer).                     ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <param.h>
#include <pefldid.h>
#include <qgfldid.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer class,idfld,lenvar,peclass,qgclass,sb1,se1,sl1
      integer fldnam2id,lnblk,trcindx
      logical       fnd
      character*(*) varnam
      character*128 wkstr
      parameter (peclass=1,qgclass=2)
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
      idfld=-99
      lenvar=lnblk(varnam,len(varnam))
      if(lenvar.eq.0) then
        fldnam2id=idfld
        return
      endif
c
c-----------------------------------------------------------------------
c  PE classification fields.
c-----------------------------------------------------------------------
c
      if(class.eq.peclass) then
        if(varnam(1:lenvar).eq.'dena') then
          idfld=pedano
        elseif(varnam(1:lenvar).eq.'sigma-t') then
          idfld=pesigt
        elseif(varnam(1:lenvar).eq.'pbar') then
          idfld=pepbar
        elseif(varnam(1:lenvar).eq.'pbarerr') then
          idfld=pepoer
        elseif(varnam(1:lenvar).eq.'pbarferr') then
          idfld=pepfer
        elseif(varnam(1:lenvar).eq.'srfpress') then
          idfld=pesprs
        elseif(varnam(1:lenvar).eq.'qbar') then
          idfld=pebvor
        elseif(varnam(1:lenvar).eq.'vgeo') then
          idfld=pegvec
        elseif(varnam(1:lenvar).eq.'vtot') then
          idfld=petvec
        elseif(varnam(1:lenvar).eq.'vclin') then
          idfld=peivec
        elseif(varnam(1:lenvar).eq.'vbaro') then
          idfld=peevec
        elseif(varnam(1:lenvar).eq.'vtide') then
          idfld=petdvc
        elseif(varnam(1:lenvar).eq.'vflt') then
          idfld=pvfvec
        elseif(varnam(1:lenvar).eq.'vb1st') then
          idfld=pb1vec
        elseif(varnam(1:lenvar).eq.'vb2nd') then
          idfld=pb2vec
        elseif(varnam(1:lenvar).eq.'vb3rd') then
          idfld=pb3vec
        elseif(varnam(1:lenvar).eq.'shflux') then
          idfld=peshfx
        elseif(varnam(1:lenvar).eq.'smflux') then
          idfld=pesmfv
        elseif(varnam(1:lenvar).eq.'swflux') then
          idfld=peswfx
        elseif(varnam(1:lenvar).eq.'swrad') then
          idfld=pesrad
        elseif(varnam(1:lenvar).eq.'mld') then
          idfld=pemldh
        elseif(varnam(1:lenvar).eq.'mxld') then
          idfld=pemxld
        elseif(varnam(1:lenvar).eq.'srftide') then
          idfld=petdsf
        elseif(varnam(1:lenvar).eq.'NH4pr') then
          idfld=penh4p
        elseif(varnam(1:lenvar).eq.'NO3pr') then
          idfld=peno3p
        elseif(varnam(1:lenvar).eq.'zoogr') then
          idfld=pezoog
        elseif(varnam(1:lenvar).eq.'wvst') then
          idfld=pewvst
        elseif(varnam(1:lenvar).eq.'wvsv') then
          idfld=pewvsv
        elseif(varnam(1:lenvar).eq.'wvzt') then
          idfld=pewvzt
        elseif(varnam(1:lenvar).eq.'wvzv') then
          idfld=pewvzv
        elseif(varnam(1:lenvar).eq.'tbath') then
          idfld=pebath
        elseif(varnam(1:lenvar).eq.'landt') then
          idfld=petmsk
        elseif(varnam(1:lenvar).eq.'landv') then
          idfld=pevmsk
        elseif(varnam(1:lenvar).eq.'buoyp') then
          idfld=pebuoy
        elseif(varnam(1:lenvar).eq.'ke_tot') then
          idfld=peteke
        elseif(varnam(1:lenvar).eq.'ke_terms') then
          idfld=pekets
        elseif(varnam(1:lenvar).eq.'vdc') then
          idfld=pevdc
        elseif(varnam(1:lenvar).eq.'vvc') then
          idfld=pevvc
        elseif(varnam(1:lenvar).eq.'ross') then
          idfld=peross
        else
          fnd     = .false.
          trcindx = 1
          do 10 while ( (.not.fnd) .and. (trcindx.le.maxtrc) )
            call length (tname(1,trcindx),sl1,sb1,se1)
            if(varnam(1:lenvar).eq.tname(1,trcindx)(sb1:se1)) then
              fnd = .true.
              idfld=tid(trcindx)
            end if
            if (.not.fnd) then
              call length (tname(1,trcindx),sl1,sb1,se1)
              wkstr = tname(1,trcindx)(sb1:se1)//'err'
              call length (wkstr,sl1,sb1,se1)
              if(varnam(1:lenvar).eq.wkstr(sb1:se1)) then
                fnd = .true.
                idfld=toerid(trcindx)
              end if
            end if
            if (.not.fnd) then
              call length (tname(1,trcindx),sl1,sb1,se1)
              wkstr = tname(1,trcindx)(sb1:se1)//'ferr'
              call length (wkstr,sl1,sb1,se1)
              if(varnam(1:lenvar).eq.wkstr(sb1:se1)) then
                fnd = .true.
                idfld=tferid(trcindx)
              end if
            end if
            if (.not.fnd) then
              call length (tname(1,trcindx),sl1,sb1,se1)
              wkstr = tname(1,trcindx)(sb1:se1)//'_bterms'
              call length (wkstr,sl1,sb1,se1)
              if(varnam(1:lenvar).eq.wkstr(sb1:se1)) then
                fnd = .true.
                idfld=tbalid(1,trcindx)
              end if
            end if
            trcindx = trcindx + 1
  10      continue
        endif
c
c-----------------------------------------------------------------------
c  QG field classification.
c-----------------------------------------------------------------------
c
      elseif(class.eq.qgclass) then
        if(varnam(1:lenvar).eq.'stream') then
          idfld=qgmpsi
        elseif(varnam(1:lenvar).eq.'rfstrm') then
          idfld=qgapsi
        elseif(varnam(1:lenvar).eq.'vort') then
          idfld=qgmvor
        elseif(varnam(1:lenvar).eq.'rfvort') then
          idfld=qgavor
        elseif(varnam(1:lenvar).eq.'tden') then
          idfld=qgdent
        elseif(varnam(1:lenvar).eq.'bden') then
          idfld=qgdenb
        elseif(varnam(1:lenvar).eq.'dynht') then
          idfld=qgdynh
        elseif(varnam(1:lenvar).eq.'dynhtmean') then
          idfld=qgdhmn
        elseif(varnam(1:lenvar).eq.'dynhterr') then
          idfld=qgdher
        elseif(varnam(1:lenvar).eq.'dynhtrmsdev') then
          idfld=qgdhrs
        elseif(varnam(1:lenvar).eq.'sigma-t') then
          idfld=qgsigt
        elseif(varnam(1:lenvar).eq.'sbl_buoy') then
          idfld=qgmmlb
        elseif(varnam(1:lenvar).eq.'sbl_temp') then
          idfld=qgsblt
        elseif(varnam(1:lenvar).eq.'sbl_wvel') then
          idfld=qgsblw
        elseif(varnam(1:lenvar).eq.'ml_depth') then
          idfld=qgsblh
        elseif(varnam(1:lenvar).eq.'ml_temp') then
          idfld=qgmmlt
        elseif(varnam(1:lenvar).eq.'surf_temp') then
          idfld=qgmsst
        elseif(varnam(1:lenvar).eq.'eq_depth') then
          idfld=qgsblm
        elseif(varnam(1:lenvar).eq.'Ek_vel') then
          idfld=qgevec
        elseif(varnam(1:lenvar).eq.'wind_stress') then
          idfld=qgwshv
        elseif(varnam(1:lenvar).eq.'bath') then
          idfld=qgbath
        elseif(varnam(1:lenvar).eq.'mask') then
          idfld=qgmask
        elseif(varnam(1:lenvar).eq.'surfnm') then
          idfld=qgsnm
        elseif(varnam(1:lenvar).eq.'surfnmerr') then
          idfld=qgsnmr
        elseif(varnam(1:lenvar).eq.'surfnmmean') then
          idfld=qgsnmm
        elseif(varnam(1:lenvar).eq.'surfnmrmsdev') then
          idfld=qgsnms
        else
          fnd     = .false.
          trcindx = 1
          do 20 while ( (.not.fnd) .and. (trcindx.le.maxtrc) )
            call length (tname(1,trcindx),sl1,sb1,se1)
            if(varnam(1:lenvar).eq.tname(1,trcindx)(sb1:se1)) then
              fnd = .true.
              idfld=qtid(trcindx)
            end if
            if (.not.fnd) then
              call length (tname(1,trcindx),sl1,sb1,se1)
              wkstr = tname(1,trcindx)(sb1:se1)//'err'
              call length (wkstr,sl1,sb1,se1)
              if(varnam(1:lenvar).eq.wkstr(sb1:se1)) then
                fnd = .true.
                idfld=qterid(trcindx)
              end if
            end if
            if (.not.fnd) then
              call length (tname(1,trcindx),sl1,sb1,se1)
              wkstr = tname(1,trcindx)(sb1:se1)//'mean'
              call length (wkstr,sl1,sb1,se1)
              if(varnam(1:lenvar).eq.wkstr(sb1:se1)) then
                fnd = .true.
                idfld=qtmnid(trcindx)
              end if
            end if
            if (.not.fnd) then
              call length (tname(1,trcindx),sl1,sb1,se1)
              wkstr = tname(1,trcindx)(sb1:se1)//'rmsdev'
              call length (wkstr,sl1,sb1,se1)
              if(varnam(1:lenvar).eq.wkstr(sb1:se1)) then
                fnd = .true.
                idfld=qrmsid(trcindx)
              end if
            end if
            trcindx = trcindx + 1
  20      continue
        endif
      endif
      fldnam2id=idfld
      return
      end
