      subroutine get_2dpos(xpos,ypos,np,ncinpid,ncvarid,idfld,level,
     *                     class)
c
c=======================================================================
c                                                                    ===
c  This routine reads in the 2D positions for the current field.     ===
c                                                                    ===
c  On Input:                                                         ===
c                                                                    ===
c     NP       number of points to read.                             ===
c     NCINPID  NetCDF ID for input file (integer).                   ===
c     NCVARID  current variable ID in NetCDf file (integer).         ===
c     IDFLD    identification of current field (integer).            ===
c     LEVEL    level of current field (integer).                     ===
c     CLASS    current field classification (integer; PE or QG)      ===
c                                                                    ===
c  On Output:                                                        ===
c                                                                    ===
c     XPOS     longitude positions of current field.                 ===
c     YPOS     latitude positions of current field.                  ===
c                                                                    ===
c  Require common blocks:                                            ===
c                                                                    ===
c     HYBRID, INPCDF, NETCDF, PLTIO                                  ===
c                                                                    ===
c  Calls:                                                            ===
c                                                                    ===
c     NCAGTC, NCDINQ, NCVINQ (NetCDF library)                        ===
c     EXITUS, LNBLK, NCVGET                                          ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <param.h>
#include <hybrid.h>
#include <inpcdf.h>
#include <netcdf.inc>
#include <pefldid.h>
#include <pltio.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer axindx,class,idfld,im,jm,k,n,ncinpid,ncposid,ncvarid,np,
     *        nvatts,nvdims,lenpos,lenstr,level,vartyp
      integer dims(maxvdims),vdims(maxvdims)
      integer lnblk
      real xpos(np),ypos(np)
      character*128  posnam
c
c=======================================================================
c  Begin Executable code.
c=======================================================================
c
c  Get attribute "position" for current field.
c
      if((class.eq.peclass).and.
     *   ((idfld.eq.pedevc).or.(idfld.eq.pedemg).or.
     *    (idfld.eq.pedubr).or.(idfld.eq.pedvbr).or.
     *    (idfld.eq.peevec).or.(idfld.eq.peemag).or.
     *    (idfld.eq.peubar).or.(idfld.eq.pevbar))) then
        posnam='vgrid2'
      else
        call ncagtc(ncinpid,ncvarid,'positions',posnam,len(posnam),
     *              rcode)
        if(rcode.ne.0) then
          write(stdout,900) ncvarid,idfld
          call exitus('GET_2DPOS')
        endif
      endif
c
c  Inquire ID of requested field in input NetCDF file.
c
      lenpos=index(posnam,',')
      if (lenpos.gt.0) then
        lenpos=lenpos-1
      else
        lenpos=lnblk(posnam,len(posnam))
      endif
      ncposid=ncvid(ncinpid,posnam(1:lenpos),rcode)
      if(rcode.ne.0) then
        write(stdout,901) posnam(1:lenpos)
        call exitus('GET_2DPOS')
      endif
c
c  Inquire information about requested positions in input NetCDF file.
c
      axindx=0
      call ncvinq(ncinpid,ncposid,posnam(1:lenpos),vartyp,nvdims,vdims,
     *            nvatts,rcode)
      if(rcode.eq.0) then
        lenpos=lnblk(posnam,len(posnam))
        do 20 n=1,nvdims
          call ncdinq(ncinpid,vdims(n),dimnam,dims(n),rcode)
          if(rcode.ne.0) then
            write(stdout,901) dimnam,posnam(1:lenpos)
            call exitus('GET_2DPOS')
          endif
          if(class.eq.peclass) then
            lenstr=lnblk(dimnam,len(dimnam))
            if((dimnam(1:lenstr).eq.'axis').or.
     *         (dimnam(1:lenstr).eq.'axis2').or.
     *         (dimnam(1:lenstr).eq.'axis3').or.
     *         (dimnam(1:lenstr).eq.'naxis')) then
              axindx=n
            elseif((dimnam(1:lenstr).eq.'outlev').or.
     *             (dimnam(1:lenstr).eq.'level')) then
              if ((peoutlev.ne.0).and.(level.gt.0)) then
                start(n)=0
                do 10 k=1,peoutlev
                  if(peout(k).gt.0) then
                     if(level.eq.peout(k)) start(n)=k
                  else
                     if(level.eq.k) start(n)=k
                  endif
  10            continue
              elseif (level.le.0) then
                start(n)=1
              else
                start(n)=level
              endif
              count(n)=1
            elseif((dimnam(1:lenstr).eq.'lon').or.
     *             (dimnam(1:lenstr).eq.'tlon').or.
     *             (dimnam(1:lenstr).eq.'vlon')) then
              start(n)=1
              count(n)=dims(n)
              im=dims(n)
            elseif((dimnam(1:lenstr).eq.'lat').or.
     *             (dimnam(1:lenstr).eq.'tlat').or.
     *             (dimnam(1:lenstr).eq.'vlat')) then
              start(n)=1
              count(n)=dims(n)
              jm=dims(n)
            endif
          elseif(class.eq.qgclass) then
            lenstr=lnblk(dimnam,len(dimnam))
            if((dimnam(1:lenstr).eq.'axis').or.
     *         (dimnam(1:lenstr).eq.'axis2').or.
     *         (dimnam(1:lenstr).eq.'axis3').or.
     *         (dimnam(1:lenstr).eq.'naxis')) then
              axindx=n
            elseif((dimnam(1:lenstr).eq.'lon').or.
     *             (dimnam(1:lenstr).eq.'tlon').or.
     *             (dimnam(1:lenstr).eq.'vlon')) then
              start(n)=1
              count(n)=dims(n)
              im=dims(n)
            elseif((dimnam(1:lenstr).eq.'lat').or.
     *             (dimnam(1:lenstr).eq.'tlat').or.
     *             (dimnam(1:lenstr).eq.'vlat')) then
              start(n)=1
              count(n)=dims(n)
              jm=dims(n)
            endif
          endif
  20    continue
c
c-----------------------------------------------------------------------
c  Read in 2D positions.
c-----------------------------------------------------------------------
c
        if(np.ne.(im*jm)) then
          write(stdout,902) np,im*jm
          call exitus('GET_2DPOS')
        endif
        start(axindx)=1
        count(axindx)=1
        call ncvget(ncinpid,ncposid,start,count,xpos,rcode)
        if(rcode.ne.0) then
          write(stdout,903) posnam(1:lenpos)//' x-axis'
          call exitus('GET_2DPOS')
        endif
        start(axindx)=2
        count(axindx)=1
        call ncvget(ncinpid,ncposid,start,count,ypos,rcode)
        if(rcode.ne.0) then
          write(stdout,903) posnam(1:lenpos)//' y-axis'
          call exitus('GET_2DPOS')
        endif
c
c-----------------------------------------------------------------------
c  Information for positions variable not found.  Terminate execution.
c-----------------------------------------------------------------------
c
      else
        write(stdout,904) posnam(1:lenpos)
        call exitus('GET_2DPOS')
      endif
c
 900  format(/' GET_2DPOS - error while reading positions attribute for'
     *        ' field IDs: ',2i4)
 901  format(/' GET_2DPOS - cannot find position variable: ',a)
 902  format(/' GET_2DPOS - inconsistent dimension size for position'
     *        ' arrays, NP, IM*JM = ',2i6)
 903  format(/' GET_2DPOS - error while reading positions variable: ',a)
 904  format(/' GET_2DPOS - error while inquiring information for'
     *        ' position variable: ',a)
      return
      end
