      subroutine get_3dpos (xpos,ypos,zpos,np,ncinpid,ncvarid,idfld,
     *                      class)
c
c=======================================================================
c                                                                    ===
c  This routine reads in the 3D positions for the current field.     ===
c                                                                    ===
c  On Input:                                                         ===
c                                                                    ===
c     NP       number of points to read.                             ===
c     NCINPID  NetCDF ID for input file (integer).                   ===
c     NCVARID  current variable ID in NetCDf file (integer).         ===
c     IDFLD    identification of current field (integer).            ===
c     LEVEL    level of current field (integer).                     ===
c     CLASS    current field classification (integer; PE or QG)      ===
c                                                                    ===
c  On Output:                                                        ===
c                                                                    ===
c     XPOS     longitude positions of current field.                 ===
c     YPOS     latitude positions of current field.                  ===
c     ZPOS     depths of current field.                              ===
c                                                                    ===
c  Require common blocks:                                            ===
c                                                                    ===
c     INPCDF, NETCDF, PLTIO                                          ===
c                                                                    ===
c  Calls:                                                            ===
c                                                                    ===
c     NCAGTC, NCDINQ, NCVINQ, (NetCDF library)                       ===
c     EXITUS, LNBLK, NCVGET                                          ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <param.h>
#include <hybrid.h>
#include <inpcdf.h>
#include <netcdf.inc>
#include <pefldid.h>
#include <pltio.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer axindx,class,endpos,idfld,im,ip,istr,jm,k,km,n,ncinpid,
     *        ncposid,ncvarid,nczposid,np,nvatts,nvdims,lendim,lenpos,
     *        lenstr,lindx,pbgn,pln,pnd,strpos,vartyp
      integer dims(maxvdims),vdims(maxvdims)
      integer lnblk
      logical terrfoll
      real xpos(np),ypos(np),zpos(np),zwrk(nk)
      character*128  posnam,zposnam
c
c=======================================================================
c  Begin Executable code.
c=======================================================================
c
c  Get attribute "position" for current field.
c
      if((class.eq.peclass).and.
     *   ((idfld.eq.pecden).or.(idfld.eq.pesnds))) then
        posnam='tgrid3'
      elseif((class.eq.peclass).and.
     *      ((idfld.eq.petmag).or.(idfld.eq.pegmag).or.
     *       (idfld.eq.peimag).or.(idfld.eq.pevnrm).or.
     *       (idfld.eq.peivnm).or.(idfld.eq.pevtng).or.
     *       (idfld.eq.peivtg))) then
        posnam='vgrid3'
      else
        call ncagtc(ncinpid,ncvarid,'positions',posnam,len(posnam),
     *              rcode)
        if(rcode.ne.0) then
          write(stdout,900) ncvarid,idfld
          call exitus('GET_3DPOS')
        endif
      endif
c
c  Determine if dealing with terrain-following coordinate system.
c
      call length (posnam,pln,pbgn,pnd)
      terrfoll = index(posnam(pbgn:pnd),'product') .eq. 0
c
c  Inquire ID of requested field in input NetCDF file.
c
      if (terrfoll) then
        lenpos=lnblk(posnam,len(posnam))
      else
        lenstr=lnblk(posnam,len(posnam))
        strpos=index(posnam(1:lenstr),';')+2
        endpos=index(posnam(strpos:lenstr),',')+strpos-2
        zposnam=posnam(strpos:endpos)
        lenpos=index(posnam(1:lenstr),',')-1
        lenstr=lnblk(zposnam,len(zposnam))
        nczposid=ncvid(ncinpid,zposnam(1:lenstr),rcode)
        if(rcode.ne.0) then
          write(stdout,910) zposnam(1:lenstr)
          call exitus('GET_3DPOS')
        endif
      endif
      ncposid=ncvid(ncinpid,posnam(1:lenpos),rcode)
      if(rcode.ne.0) then
        write(stdout,910) posnam(1:lenpos)
        call exitus('GET_3DPOS')
      endif
c
c  Get z-positions for flat levels.
c
      if (.not.terrfoll) then
        axindx=0
        lenstr=lnblk(zposnam,len(zposnam))
        call ncvinq(ncinpid,nczposid,zposnam(1:lenstr),vartyp,nvdims,
     *              vdims,nvatts,rcode)
        if(rcode.eq.0) then
          do 10 n=1,nvdims
            call ncdinq(ncinpid,vdims(n),dimnam,dims(n),rcode)
            if(rcode.ne.0) then
              write(stdout,910) dimnam,zposnam(1:lenstr)
              call exitus('GET_3DPOS')
            endif
            lendim=lnblk(dimnam,len(dimnam))
            if((dimnam(1:lendim).eq.'axis').or.
     *         (dimnam(1:lendim).eq.'axis2').or.
     *         (dimnam(1:lendim).eq.'axis3').or.
     *         (dimnam(1:lendim).eq.'naxis')) then
              axindx=n
            elseif((dimnam(1:lendim).eq.'level').or.
     &             (dimnam(1:lendim).eq.'level1').or.
     &             (dimnam(1:lendim).eq.'flatlevel')) then
              start(n)=1
              count(n)=dims(n)
              km=dims(n)
            endif
  10      continue
        endif
c
c  Read in flat level depths.
c
        start(axindx)=zindx
        count(axindx)=1
        call ncvget(ncinpid,nczposid,start,count,zwrk,rcode)
        if(rcode.ne.0) then
          write(stdout,930) zposnam(1:lenstr)//' z-axis'
          call exitus('GET_3DPOS')
        endif
      endif
c
c  Inquire information about requested positions in input NetCDF file.
c
      axindx=0
      lindx=0
      call ncvinq(ncinpid,ncposid,posnam(1:lenpos),vartyp,nvdims,vdims,
     *            nvatts,rcode)
      if(rcode.eq.0) then
        lenpos=lnblk(posnam,len(posnam))
        do 30 n=1,nvdims
          call ncdinq(ncinpid,vdims(n),dimnam,dims(n),rcode)
          if(rcode.ne.0) then
            write(stdout,910) dimnam,posnam(1:lenpos)
            call exitus('GET_3DPOS')
          endif
          if (terrfoll) then
            lendim=lnblk(dimnam,len(dimnam))
            if((dimnam(1:lendim).eq.'axis').or.
     *         (dimnam(1:lendim).eq.'axis2').or.
     *         (dimnam(1:lendim).eq.'axis3').or.
     *         (dimnam(1:lendim).eq.'naxis')) then
              axindx=n
            elseif((dimnam(1:lendim).eq.'outlev').or.
     *             (dimnam(1:lendim).eq.'level')) then
              if(peoutlev.ne.0) then
                start(n)=0
                do 20 k=1,peoutlev
                  if(peout(k).le.pelev) count(n)=k
  20            continue
                lindx=n
                km=count(n)
              else
                lindx=n
                km=dims(n)
              endif
            elseif((dimnam(1:lendim).eq.'lon').or.
     *             (dimnam(1:lendim).eq.'tlon').or.
     *             (dimnam(1:lendim).eq.'vlon')) then
              start(n)=1
              count(n)=dims(n)
              im=dims(n)
            elseif((dimnam(1:lendim).eq.'lat').or.
     *             (dimnam(1:lendim).eq.'tlat').or.
     *             (dimnam(1:lendim).eq.'vlat')) then
              start(n)=1
              count(n)=dims(n)
              jm=dims(n)
            endif
          else
            lendim=lnblk(dimnam,len(dimnam))
            if((dimnam(1:lendim).eq.'axis').or.
     *         (dimnam(1:lendim).eq.'axis2').or.
     *         (dimnam(1:lendim).eq.'axis3').or.
     *         (dimnam(1:lendim).eq.'naxis')) then
              axindx=n
            elseif((dimnam(1:lendim).eq.'lon').or.
     *             (dimnam(1:lendim).eq.'tlon').or.
     *             (dimnam(1:lendim).eq.'vlon')) then
              start(n)=1
              count(n)=dims(n)
              im=dims(n)
            elseif((dimnam(1:lendim).eq.'lat').or.
     *             (dimnam(1:lendim).eq.'tlat').or.
     *             (dimnam(1:lendim).eq.'vlat')) then
              start(n)=1
              count(n)=dims(n)
              jm=dims(n)
            endif
          endif
  30    continue
c
c-----------------------------------------------------------------------
c  Read in 3D positions.
c-----------------------------------------------------------------------
c
        if(np.ne.(im*jm*km)) then
          write(stdout,920) np,im*jm*km
          call exitus('GET_3DPOS')
        endif
        do 50 k=1,km
          istr=1+(k-1)*im*jm
          if ((terrfoll).or.(lindx.gt.0)) then
            start(lindx)=k
            count(lindx)=1
          end if
          start(axindx)=xindx
          count(axindx)=1
          call ncvget(ncinpid,ncposid,start,count,xpos(istr),rcode)
          if(rcode.ne.0) then
            write(stdout,930) posnam(1:lenpos)//' x-axis'
            call exitus('GET_3DPOS')
          endif
          start(axindx)=yindx
          count(axindx)=1
          call ncvget(ncinpid,ncposid,start,count,ypos(istr),rcode)
          if(rcode.ne.0) then
            write(stdout,930) posnam(1:lenpos)//' y-axis'
            call exitus('GET_3DPOS')
          endif
          if (terrfoll) then
            start(axindx)=zindx
            count(axindx)=1
            call ncvget(ncinpid,ncposid,start,count,zpos(istr),rcode)
            if(rcode.ne.0) then
              write(stdout,930) posnam(1:lenpos)//' z-axis'
              call exitus('GET_3DPOS')
            endif
          else
            do 40 n=1,im*jm
              ip=n+(k-1)*im*jm
              zpos(ip)=zwrk(k)
  40        continue
          endif
  50    continue
c
c-----------------------------------------------------------------------
c  Information for positions variable not found.  Terminate execution.
c-----------------------------------------------------------------------
c
      else
        write(stdout,940) posnam(1:lenpos)
        call exitus('GET_3DPOS')
      endif
c
 900  format(/' GET_3DPOS - error while reading positions attribute for'
     *        ' field IDs: ',2i4)
 910  format(/' GET_3DPOS - cannot find position variable: ',a)
 920  format(/' GET_3DPOS - inconsistent dimension size for position'
     *        ' arrays, NP, IM*JM*KM = ',2i6)
 930  format(/' GET_3DPOS - error while reading positions variable: ',a)
 940  format(/' GET_3DPOS - error while inquiring information for'
     *        ' position variable: ',a)
      return
      end
