      subroutine get_cdf2dat(day,xpos,ypos,f1,f2,np,file,class,idfld,
     *                       level)
c
c=======================================================================
c                                                                    ===
c  This routine reads in the requested field, at the requested level ===
c  and time from input NetCDF file.                                  ===
c                                                                    ===
c  On Input:                                                         ===
c                                                                    ===
c     DAY      day to read (real)                                    ===
c     FILE     NetCDF file to read (primary or secondary; integer)   ===
c     IDFLD    identification of field to read (integer)             ===
c     LEVEL    field depth level to read (integer)                   ===
c                                                                    ===
c  On Output:                                                        ===
c                                                                    ===
c     XPOS     x-positions of the requested field (real array)       ===
c     YPOS     y-positions of the requested field (real array)       ===
c     F1       scalar or vector x-component field (real array)       ===
c     F2       vector y-component (real array)                       ===
c     NP       number of points in requested field (integer)         ===
c     CLASS    field classification (integer; PE or QG)              ===
c                                                                    ===
c  Required common blocks:                                           ===
c                                                                    ===
c     DOMDAT, INPCDF, NDIMEN, NETCDF, PEFLDID, QGFLDID               ===
c                                                                    ===
c  Calls:                                                            ===
c                                                                    ===
c     NCVID  (NetCDF library)                                        ===
c     EXITUS, FLD_TYPE, GET_PE2DAT, GET_QG2DAT, GET_2DPOS, MSKSCL,   ===
c     NCVGET, PSI2DYNH, SEA_ELEV, SVAN, SVEL, TIME_INDX, VELOCITY    ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <param.h>
#include <pconst.h>
#include <inpcdf.h>
#include <ndimen.h>
#include <netcdf.inc>
#include <pefldid.h>
#include <pltio.h>
#include <qgfldid.h>
#include <zdat.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      logical pe_class,qg_class
      integer class,file,idfld,idfld1,idfld2,level,n,nc_fid,nc_vid,np,
     *        status
      real day,depth,fval,rho,spv
      real xpos(*),ypos(*),f1(*),f2(*),f3(nh),f4(nh)
      real svan,svel
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c  Determine NetCDF ID for input file to read, time index of the field
c  to read, and field classification (PE or QG) to adopt.
c
      class=0
      if(file.eq.1) then
        nc_fid=ncinp1id
        if(type1(1:ltype1).eq.'PE FORCING') then
          if(idfld.eq.peshfx) then
            call time_indx(tindx,day,t1shf,nt1shf,type1,ltype1)
          elseif(idfld.eq.peswfx) then
            call time_indx(tindx,day,t1swf,nt1swf,type1,ltype1)
          elseif(idfld.eq.pesrad) then
            call time_indx(tindx,day,t1swr,nt1swr,type1,ltype1)
          else
            call time_indx(tindx,day,t1smf,nt1smf,type1,ltype1)
          endif
        else
          call time_indx(tindx,day,time1,ntime1,type1,ltype1)
        endif
        if((type1(1:ltype1).eq.'PE MODEL').or.
     *     (type1(1:ltype1).eq.'PE ENERGY').or.
     *     (type1(1:ltype1).eq.'PE_INITIAL').or.
     *     (type1(1:ltype1).eq.'PE FORCING')) then
          class=peclass
        elseif((type1(1:ltype1).eq.'QG MODEL').or.
     *         (type1(1:ltype1).eq.'OTIS').or.
     *         (type1(1:ltype1).eq.'FM MODEL')) then
          qg_class=.true.
          class=qgclass
        else
          class=class1
        endif
      elseif(file.eq.2) then
        nc_fid=ncinp2id
        if(type2(1:ltype2).eq.'PE FORCING') then
          if(idfld.eq.peshfx) then
            call time_indx(tindx,day,t2shf,nt2shf,type2,ltype2)
          elseif(idfld.eq.peswfx) then
            call time_indx(tindx,day,t2swf,nt2swf,type2,ltype2)
          elseif(idfld.eq.pesrad) then
            call time_indx(tindx,day,t2swr,nt2swr,type2,ltype2)
          else
            call time_indx(tindx,day,t2smf,nt2smf,type2,ltype2)
          endif
        else
          call time_indx(tindx,day,time2,ntime2,type2,ltype2)
        endif
        if((type2(1:ltype2).eq.'PE MODEL').or.
     *     (type2(1:ltype2).eq.'PE ENERGY').or.
     *     (type2(1:ltype2).eq.'PE_INITIAL').or.
     *     (type2(1:ltype2).eq.'PE FORCING')) then
          class=peclass
        elseif((type2(1:ltype2).eq.'QG MODEL').or.
     *         (type2(1:ltype2).eq.'FM MODEL')) then
          class=qgclass
        else
          class=class2
        endif
      else
        write(stdout,900) file
        call exitus('GET_CDF2DAT')
      endif
      pe_class=.false.
      qg_class=.false.
      if(class.eq.peclass) pe_class=.true.
      if(class.eq.qgclass) qg_class=.true.
c
c-----------------------------------------------------------------------
c  Process fields having a PE classification.  First, determine the
c  field type (1: scalar, 2: vector, 3: derived). Second, read field(s);
c  if the requested field is secondary, then compute it from just read
c  primary field(s). Third, mask/scale read field(s) if appropriate. And
c  fourth, read field positions.
c-----------------------------------------------------------------------
c
      if(pe_class) then
c
c  Determine field type.
c
        call fld_type(nc_fid,idfld,idfld1,idfld2,class,status)
c
c  2D scalar field.
c
        if(status.eq.1) then
          call get_pe2dat(f1,np,nc_fid,tindx,idfld,level,nc_vid,spv)
          call mskscl(f1,np,class,nc_fid,idfld,spv,spval1)
c
c  2D vector field.
c
        elseif(status.eq.2) then
          call get_pe2dat(f1,np,nc_fid,tindx,idfld1,level,nc_vid,spv)
          call get_pe2dat(f2,np,nc_fid,tindx,idfld2,level,nc_vid,spv)
          call mskscl(f1,np,class,nc_fid,idfld,spv,spval1)
          call mskscl(f2,np,class,nc_fid,idfld,spv,spval1)
c
c  Derive secondary field from two primary fields.
c
        elseif(status.eq.3) then
          call get_pe2dat(f2,np,nc_fid,tindx,idfld2,level,nc_vid,spv)
          call get_pe2dat(f1,np,nc_fid,tindx,idfld1,level,nc_vid,spv)
c
c  Compute density anomaly from temperature and salinity.
c
          if(idfld.eq.pecden) then
            call get_pe2dat(f3,np,nc_fid,tindx,pebtht,level,varid,spv)
            do 10 n=1,np
              if((f1(n).ge.spv).or.(f2(n).ge.spv)) then
                f1(n)=spval1
              else
                fval=svan(f1(n),f2(n),abs(f3(n)),rho)
                f1(n)=rho
              endif
  10        continue
c
c  Compute sigma-t from temperature and salinity.
c
          elseif(idfld.eq.pesigt) then
            do 20 n=1,np
              if((f1(n).ge.spv).or.(f2(n).ge.spv)) then
                f1(n)=spval1
              else
                fval=svan(f1(n),f2(n),c0,rho)
                f1(n)=rho
              endif
  20        continue
c
c  Compute sound speed (m/s) from temperature and salinity.
c
          elseif(idfld.eq.pesnds) then
            if (level.gt.0) then
              call get_pe2dat(f3,np,nc_fid,tindx,pebtht,level,varid,spv)
            else
              do 25 n=1,np
                 f3(n) = level
  25          continue
            endif
            do 30 n=1,np
              if((f1(n).ge.spv).or.(f2(n).ge.spv)) then
                f1(n)=spval1
              else
                fval=svel(f1(n),f2(n),abs(f3(n)))
                f1(n)=fval
              endif
  30        continue
c
c  Compute velocity vector magnitude.
c
          elseif((idfld.eq.petmag).or.(idfld.eq.pegmag).or.
     &           (idfld.eq.peimag).or.(idfld.eq.petdmg).or.
     &           (idfld.eq.pvfmag).or.(idfld.eq.pb1mag).or.
     &           (idfld.eq.pb2mag).or.(idfld.eq.pb3mag)) then
            do 40 n=1,np
              if((f1(n).ge.spv).or.(f2(n).ge.spv)) then
                f1(n)=spval1
              else
                fval=sqrt(f1(n)*f1(n)+f2(n)*f2(n))
                f1(n)=fval
              endif
  40        continue
          endif
          call mskscl(f1,np,class,nc_fid,idfld,spv,spval1)
c
c  Derive field from transport streamfunction.
c
        elseif(status.eq.4) then
          call get_pe2dat(f3,np,nc_fid,tindx,idfld1,level,nc_vid,spv)
          call get_pe2dat(f4,np,nc_fid,tindx,pebath,level,varid,spv)
          call external(f1,f2,f3,f4,im,jm,nc_fid)
          if (idfld.eq.pedvbr) then
            do 50 n=1,np
                f1(n)=f2(n)
  50        continue
           elseif (idfld.eq.pedemg) then
            do 60 n=1,np
              if((f1(n).ge.spv).or.(f2(n).ge.spv)) then
                f1(n)=spval1
              else
                fval=sqrt(f1(n)*f1(n)+f2(n)*f2(n))
                f1(n)=fval
              endif
  60        continue
          endif
          call mskscl(f1,np,class,nc_fid,idfld,spv,spval1)
          if (idfld.eq.pedevc) then
             call mskscl(f2,np,class,nc_fid,idfld,spv,spval1)
          endif
        endif
c
c  Read in field positions.
c
        call get_2dpos(xpos,ypos,np,nc_fid,nc_vid,idfld,level,class)
c
c-----------------------------------------------------------------------
c  Process fields having a QG classification.  First, determine the
c  field type (1: scalar, 2: vector, 3: derived, 4: derived from
c  streamfunction). Second, read field(s); if the requested field is
c  secondary, then compute it from just read primary field(s). Third,
c  mask/scale read field(s) if appropriate. And fourth, read field
c  positions.
c-----------------------------------------------------------------------
c
      elseif(qg_class) then
c
c  Determine field type.
c
        call fld_type(nc_fid,idfld,idfld1,idfld2,class,status)
c
c  2D scalar field.
c
        if(status.eq.1) then
          call get_qg2dat(f1,np,nc_fid,tindx,idfld,level,nc_vid,spv)
          call mskscl(f1,np,class,nc_fid,idfld,spv,spval1)
c
c  2D Vector field .
c
       elseif(status.eq.2) then
          call get_qg2dat(f1,np,nc_fid,tindx,idfld1,level,nc_vid,spv)
          call get_qg2dat(f2,np,nc_fid,tindx,idfld2,level,nc_vid,spv)
          call mskscl(f1,np,class,nc_fid,idfld,spv,spval1)
          call mskscl(f2,np,class,nc_fid,idfld,spv,spval1)
c
c  Secondary field derieved from two primary fields.
c
        elseif(status.eq.3) then
          call get_qg2dat(f2,np,nc_fid,tindx,idfld2,level,nc_vid,spv)
          call get_qg2dat(f1,np,nc_fid,tindx,idfld1,level,nc_vid,spv)
c
c  Compute density anomaly from temperature and salinity.
c
          if(idfld.eq.qgdano) then
            start(1)=level
            count(1)=1
            varid=ncvid(nc_fid,'zqg',rcode)
            if(rcode.eq.0) then
              call ncvget(nc_fid,varid,count,start,depth,rcode)
              if(rcode.ne.0) then
                write(stdout,901) 'zqg',level,file
                call exitus('GET_CDF2DAT')
              endif
            else
c             write(stdout,902) 'zqg',file
c             call exitus('GET_CDF2DAT')
              depth=zmid(level)
            endif
            do 70 n=1,np
              if((f1(n).ge.spv).or.(f2(n).ge.spv)) then
                f1(n)=spval1
              else
                fval=svan(f1(n),f2(n),abs(depth),rho)
                f1(n)=rho
              endif
  70        continue
c
c  Compute sigma-t from temperature and salinity.
c
          elseif(idfld.eq.qgsigt) then
            do 80 n=1,np
              if((f1(n).ge.spv).or.(f2(n).ge.spv)) then
                f1(n)=spval1
              else
                fval=svan(f1(n),f2(n),c0,rho)
                f1(n)=rho
              endif
  80        continue
c
c  Compute sound speed (m/s) from temperature and salinity.
c
          elseif(idfld.eq.qgsnds) then
            start(1)=level
            count(1)=1
            varid=ncvid(nc_fid,'zqg',rcode)
            if(rcode.eq.0) then
              call ncvget(nc_fid,varid,count,start,depth,rcode)
              if(rcode.ne.0) then
                write(stdout,901) 'zqg',level,file
                call exitus('GET_CDF2DAT')
              endif
            else
c             write(stdout,902) 'zqg',file
c             call exitus('GET_CDF2DAT')
              depth=zmid(level)
            endif
            do 90 n=1,np
              if((f1(n).ge.spv).or.(f2(n).ge.spv)) then
                f1(n)=spval1
              else
                fval=svel(f1(n),f2(n),abs(depth))
                f1(n)=fval
              endif
  90        continue
c
c  Compute sea surface elevation from QG streamfunction and top density.
c
          elseif(idfld.eq.qgmsse) then
            call sea_elev(f1,f2,im,jm,nc_fid,spv,spval1)
c
c  Rescale error fields.
c
          elseif((idfld.eq.qgdhsr).or.(idfld.eq.qgsser).or.
     &           (idfld.eq.qgtser).or.(idfld.eq.qg1ser).or.
     &           (idfld.eq.qg2ser).or.(idfld.eq.qg3ser).or.
     &           (idfld.eq.qg4ser).or.(idfld.eq.qg5ser).or.
     &           (idfld.eq.qg6ser).or.(idfld.eq.qg7ser).or.
     &           (idfld.eq.qg8ser).or.(idfld.eq.qgsnsr)) then
            do 100 n=1,np
              if((f1(n).ge.spv).or.(f2(1).ge.spv)) then
                f1(n)=spval1
              else
                f1(n)=(f1(n)/f2(1))**2
              endif
 100        continue
          endif
          call mskscl(f1,np,class,nc_fid,idfld,spv,spval1)
c
c  Derive fields from QG streamfunction.
c
        elseif(status.eq.4) then
          call get_qg2dat(f3,np,nc_fid,tindx,idfld1,level,nc_vid,spv)
c
c  Compute dynamic height from QG streamfunction.
c
          if(idfld.eq.qgp2dh) then
            call psi2dynh(f1,f3,im,jm,nc_fid,spv,spval1)
            call mskscl(f1,np,class,nc_fid,idfld,spv,spval1)
c
c  Compute velocity components from QG streamfunction.
c
          elseif(idfld.eq.qgpvec) then
            call velocity(f3,f1,f2,im,jm,nc_fid,spv,spval1)
            call mskscl(f1,np,class,nc_fid,idfld,spv,spval1)
            call mskscl(f2,np,class,nc_fid,idfld,spv,spval1)
          endif
        endif
c
c  Read in field positions.
c
        call get_2dpos(xpos,ypos,np,nc_fid,nc_vid,idfld,level,class)
      endif
c
 900  format(/' GET_CDF2DAT - unable to determine file type in input'
     *        ' NetCDF file: ',i2)
 901  format(/' GET_CDF2DAT - error while reading variable: ',a,2x,
     *        ' at LEVEL = ',i4,2x,' in input NetCDF file: ',i2)
 902  format(/' GET_CDF2DAT - cannot find variable: ',a,2x,
     *        ' in input NetCDF file: ',i2)
      return
      end
