      subroutine get_cdf3dat(day,xpos,ypos,zpos,f1,f2,np,file,class,
     *                       idfld)
c
c=======================================================================
c                                                                    ===
c  This routine reads in the requested 3-D field at the requested    ===
c  time from input NetCDF file.                                      ===
c                                                                    ===
c  On Input:                                                         ===
c                                                                    ===
c     DAY      day to read (real)                                    ===
c     FILE     NetCDF file to read (primary or secondary; integer)   ===
c     IDFLD    identification of field to read (integer)             ===
c                                                                    ===
c  On Output:                                                        ===
c                                                                    ===
c     XPOS     x-positions of the requested field (real array)       ===
c     YPOS     y-positions of the requested field (real array)       ===
c     ZPOS     z-positions of the requested field (real array)       ===
c     F1       scalar or vector x-component field (real array)       ===
c     F2       vector y-component (real array)                       ===
c     NP       number of points in requested field (integer)         ===
c     CLASS    field classification (integer; PE or QG)              ===
c                                                                    ===
c  Required common blocks:                                           ===
c                                                                    ===
c     FMASK, INPCDF, NDIMEN, NETCDF, PEFLDID, QGFLDID                ===
c                                                                    ===
c  Calls:                                                            ===
c                                                                    ===
c     NCVID  (NetCDF library)                                        ===
c     EXITUS, FLD_TYPE, GET_PE3DAT, GET_QG3DAT, GET_2DPOS, MSKSCL,   ===
c     NCVGET, PSI2DYNH, SEA_ELEV, SVAN, SVEL, TIME_INDX, VELOCITY    ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <param.h>
#include <pconst.h>
#include <fmask.h>
#include <inpcdf.h>
#include <ndimen.h>
#include <netcdf.inc>
#include <pefldid.h>
#include <pltio.h>
#include <qgfldid.h>
#include <zdat.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      logical pe_class,qg_class
      integer class,file,idfld,idfld1,idfld2,ip,is,k,n,nc_fid,nc_vid,
     *        normal,np,status,tangent
      real day,fval,rho,spv
      real depth(nk),f1(*),f2(*),f3(nv),xpos(*),ypos(*),zpos(*)
      real svan,svel
c
      parameter (normal=0, tangent=1)
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c  Determine NetCDF ID for input file to read, time index of the field
c  to read, and field classification (PE or QG) to adopt.
c
      class=0
      if(file.eq.1) then
        nc_fid=ncinp1id
        call time_indx(tindx,day,time1,ntime1,type1,ltype1)
        if((type1(1:ltype1).eq.'PE MODEL').or.
     *     (type1(1:ltype1).eq.'PE ENERGY').or.
     *     (type1(1:ltype1).eq.'PE_INITIAL')) then
          class=peclass
        elseif((type1(1:ltype1).eq.'QG MODEL').or.
     *         (type1(1:ltype1).eq.'FM MODEL')) then
          class=qgclass
        else
          class=class1
        endif
      elseif(file.eq.2) then
        nc_fid=ncinp2id
        call time_indx(tindx,day,time2,ntime2,type2,ltype2)
        if((type2(1:ltype2).eq.'PE MODEL').or.
     *     (type2(1:ltype2).eq.'PE ENERGY').or.
     *     (type2(1:ltype2).eq.'PE_INITIAL')) then
          class=peclass
        elseif((type2(1:ltype2).eq.'QG MODEL').or.
     *         (type2(1:ltype2).eq.'FM MODEL')) then
          class=qgclass
        else
          class=class2
        endif
      else
        write(stdout,900) file
        call exitus('GET_CDF3DAT')
      endif
      pe_class=.false.
      qg_class=.false.
      if(class.eq.peclass) pe_class=.true.
      if(class.eq.qgclass) qg_class=.true.
c
c  Activate switch for masking 3D (volume) fields.
c
      msk3d=.true.
c
c-----------------------------------------------------------------------
c  Process fields having a PE classification.  First, determine the
c  field type (1: scalar, 2: vector, 3: derived). Second, read field(s);
c  if the requested field is secondary, then compute it from just read
c  primary field(s). Third, mask/scale read field(s) if appropriate. And
c  fourth, read field positions.
c-----------------------------------------------------------------------
c
      if(pe_class) then
c
c  Determine field type.
c
        call fld_type(nc_fid,idfld,idfld1,idfld2,class,status)
c
c  Scalar field.
c
        if(status.eq.1) then
          call get_pe3dat(f1,np,nc_fid,tindx,idfld,nc_vid,spv)
          call mskscl(f1,np,class,nc_fid,idfld,spv,spval1)
c
c  Vector field.
c
        elseif(status.eq.2) then
          call get_pe3dat(f1,np,nc_fid,tindx,idfld1,nc_vid,spv)
          call get_pe3dat(f2,np,nc_fid,tindx,idfld2,nc_vid,spv)
          call mskscl(f1,np,class,nc_fid,idfld,spv,spval1)
          call mskscl(f2,np,class,nc_fid,idfld,spv,spval1)
c
c  Derive secondary field from two primary fields.
c
        elseif(status.eq.3) then
          call get_pe3dat(f2,np,nc_fid,tindx,idfld2,nc_vid,spv)
          call get_pe3dat(f1,np,nc_fid,tindx,idfld1,nc_vid,spv)
c
c  Compute density anomaly from temperature and salinity.
c
          if(idfld.eq.pecden) then
            call get_pe3dat(f3,np,nc_fid,tindx,pebtht,nc_vid,spv)
            do 10 n=1,np
              if((f1(n).ge.spv).or.(f2(n).ge.spv)) then
                f1(n)=spval1
              else
                fval=svan(f1(n),f2(n),abs(f3(n)),rho)
                f1(n)=rho
              endif
  10        continue
c
c  Compute sigma-t from temperature and salinity.
c
          elseif(idfld.eq.pesigt) then
            do 20 n=1,np
              if((f1(n).ge.spv).or.(f2(n).ge.spv)) then
                f1(n)=spval1
              else
                fval=svan(f1(n),f2(n),abs(f3(n)),rho)
                f1(n)=rho
              endif
  20        continue
c
c  Compute sound speed (m/s) from temperature and salinity.
c
          elseif(idfld.eq.pesnds) then
            call get_pe3dat(f3,np,nc_fid,tindx,pebtht,nc_vid,spv)
            do 30 n=1,np
              if((f1(n).ge.spv).or.(f2(n).ge.spv)) then
                f1(n)=spval1
              else
                fval=svel(f1(n),f2(n),abs(f3(n)))
                f1(n)=fval
              endif
  30        continue
c
c  Compute velocity vector magnitude.
c
          elseif((idfld.eq.petmag).or.(idfld.eq.pegmag).or.
     *           (idfld.eq.peimag).or.(idfld.eq.petdmg)) then
            do 40 n=1,np
              if((f1(n).ge.spv).or.(f2(n).ge.spv)) then
                f1(n)=spval1
              else
                fval=sqrt(f1(n)*f1(n)+f2(n)*f2(n))
                f1(n)=fval
              endif
  40        continue
c
c  Compute velocity normal to section.
c
          elseif((idfld.eq.pevnrm).or.(idfld.eq.peivnm).or.
     *           (idfld.eq.pegvnm).or.(idfld.eq.petvnm)) then
            call vel_nt (np,f1,f2,normal)
c
c  Compute velocity tangential to section.
c
          elseif((idfld.eq.pevtng).or.(idfld.eq.peivtg).or.
     *           (idfld.eq.pegvtg).or.(idfld.eq.petvtg)) then
            call vel_nt (np,f1,f2,tangent)
          endif
          call mskscl(f1,np,class,nc_fid,idfld,spv,spval1)
        endif
c
c  Read in field positions.
c
        call get_3dpos(xpos,ypos,zpos,np,nc_fid,nc_vid,idfld,class)
c
c-----------------------------------------------------------------------
c  Process fields having a QG classification.  First, determine the
c  field type (1: scalar, 2: vector, 3: derived, 4: derived from
c  streamfunction). Second, read field(s); if the requested field is
c  secondary, then compute it from just read primary field(s). Third,
c  mask/scale read field(s) if appropriate. And fourth, read field
c  positions.
c-----------------------------------------------------------------------
c
      elseif(qg_class) then
c
c  Determine field type.
c
        call fld_type(nc_fid,idfld,idfld1,idfld2,class,status)
c
c  Scalar field.
c
        if(status.eq.1) then
          call get_qg3dat(f1,np,nc_fid,tindx,idfld,nc_vid,spv)
          call mskscl(f1,np,class,nc_fid,idfld,spv,spval1)
c
c  Vector field .
c
        elseif(status.eq.2) then
          call get_qg3dat(f1,np,nc_fid,tindx,idfld1,nc_vid,spv)
          call get_qg3dat(f2,np,nc_fid,tindx,idfld2,nc_vid,spv)
          call mskscl(f1,np,class,nc_fid,idfld,spv,spval1)
          call mskscl(f2,np,class,nc_fid,idfld,spv,spval1)
c
c  Secondary field derieved from two primary fields.
c
        elseif(status.eq.3) then
          call get_qg3dat(f2,np,nc_fid,tindx,idfld2,nc_vid,spv)
          call get_qg3dat(f1,np,nc_fid,tindx,idfld1,nc_vid,spv)
c
c  Compute density anomaly from temperature and salinity.
c
          if(idfld.eq.qgdano) then
            start(1)=1
            count(1)=km
            varid=ncvid(nc_fid,'zqg',rcode)
            if(rcode.eq.0) then
              call ncvget(nc_fid,varid,count,start,depth,rcode)
              if(rcode.ne.0) then
                write(stdout,901) 'zqg',file
                call exitus('GET_CDF3DAT')
              endif
            else
c             write(stdout,902) 'zqg',file
c             call exitus('GET_CDF3DAT')
            endif
            do 50 k=1,km
              depth(k)=zmid(k)
            do 50 n=1,im*jm
              ip=n+(k-1)*im*jm
              f3(ip)=depth(k)
  50        continue
c
            do 60 n=1,np
              if((f1(n).ge.spv).or.(f2(n).ge.spv)) then
                f1(n)=spval1
              else
                fval=svan(f1(n),f2(n),f3(n),rho)
                f1(n)=rho
              endif
  60        continue
c
c  Compute sigma-t from temperature and salinity.
c
          elseif(idfld.eq.qgsigt) then
            do 70 n=1,np
              if((f1(n).ge.spv).or.(f2(n).ge.spv)) then
                f1(n)=spval1
              else
                fval=svan(f1(n),f2(n),c0,rho)
                f1(n)=rho
              endif
  70        continue
c
c  Compute sound speed (m/s) from temperature and salinity.
c
          elseif(idfld.eq.qgsnds) then
            start(1)=1
            count(1)=km
            varid=ncvid(nc_fid,'zqg',rcode)
            if(rcode.eq.0) then
              call ncvget(nc_fid,varid,count,start,depth,rcode)
              if(rcode.ne.0) then
                write(stdout,901) 'zqg',file
                call exitus('GET_CDF3DAT')
              endif
            else
c             write(stdout,902) 'zqg',file
c             call exitus('GET_CDF3DAT')
            endif
            do 80 k=1,km
              depth(k)=zmid(k)
            do 80 n=1,im*jm
              ip=n+(k-1)*im*jm
              f3(ip)=depth(k)
  80        continue
c
            do 90 n=1,np
              if((f1(n).ge.spv).or.(f2(n).ge.spv)) then
                f1(n)=spval1
              else
                fval=svel(f1(n),f2(n),f3(n))
                f1(n)=fval
              endif
  90        continue
c
c  Compute sea surface elevation from QG streamfunction and top density.
c
          elseif(idfld.eq.qgmsse) then
            call sea_elev(f1,f2,im*jm,km,nc_fid,spv,spval1)
c
c  Compute normal velocity or Ekman velocity.
c
          elseif ((idfld.eq.qgvnrm).or.(idfld.eq.qgevnm)) then
            call vel_nt (np,f1,f2,normal)
c
c  Compute tangential velocity or Ekman velocity.
c
          elseif ((idfld.eq.qgvtng).or.(idfld.eq.qgevtn)) then
            call vel_nt (np,f1,f2,tangent)
c
c  Rescale error fields
c
          elseif((idfld.eq.qgdhsr).or.(idfld.eq.qgsser).or.
     &           (idfld.eq.qgtser).or.(idfld.eq.qg1ser).or.
     &           (idfld.eq.qg2ser).or.(idfld.eq.qg3ser).or.
     &           (idfld.eq.qg4ser).or.(idfld.eq.qg5ser).or.
     &           (idfld.eq.qg6ser).or.(idfld.eq.qg7ser).or.
     &           (idfld.eq.qg8ser)) then
            do 110 k = 1, km
               is = 1 + (k-1)*im*jm
               do 100 n=1,im*jm
                 ip = n + (k-1)*im*jm
                 if((f1(ip).ge.spv).or.(f2(is).ge.spv)) then
                   f1(ip)=spval1
                 else
                   f1(ip)=(f1(ip)/f2(is))**2
          endif
 100           continue
 110        continue
          endif
          call mskscl(f1,np,class,nc_fid,idfld,spv,spval1)
c
c  Derive fields from QG streamfunction.
c
        elseif(status.eq.4) then
          call get_qg3dat(f3,np,nc_fid,tindx,idfld1,nc_vid,spv)
c
c  Compute dynamic height from QG streamfunction.
c
          if(idfld.eq.qgp2dh) then
            call psi2dynh(f1,f3,im*jm,km,nc_fid,spv,spval1)
            call mskscl(f1,np,class,nc_fid,idfld,spv,spval1)
c
c  Compute velocity components from QG streamfunction.
c
          elseif ((idfld.eq.qgpvec).or.(idfld.eq.qgpvnm).or.
     &                                 (idfld.eq.qgpvtn)) then
            do 120 k=1,km
              is=1+(k-1)*im*jm
              call velocity(f3(is),f1(is),f2(is),im,jm,nc_fid,spv,
     *                      spval1)
 120        continue
            if (idfld.eq.qgpvnm) then
              call vel_nt (np,f1,f2,normal)
             else if (idfld.eq.qgpvtn) then
              call vel_nt (np,f1,f2,tangent)
            end if
            call mskscl(f1,np,class,nc_fid,idfld,spv,spval1)
            if (idfld.eq.qgpvec) then
              call mskscl(f2,np,class,nc_fid,idfld,spv,spval1)
            endif
          endif
        endif
c
c  Read in field positions.
c
        call get_3dpos(xpos,ypos,zpos,np,nc_fid,nc_vid,idfld,class)
      endif
c
 900  format(/' GET_CDF3DAT - unable to determine file type in input'
     *        ' NetCDF file: ',i2)
 901  format(/' GET_CDF3DAT - error while reading variable: ',a,2x,
     *        ' in input NetCDF file: ',i2)
 902  format(/' GET_CDF3DAT - cannot find variable: ',a,2x,
     *        ' in input NetCDF file: ',i2)
      return
      end
