      subroutine get_pe2dat(f,np,ncinpid,tindx,idfld,level,ncvarid,spv)
c
c=======================================================================
c                                                                    ===
c  This routine sets up the necessary information to read field      ===
c  IDFLD (PE model classification) from input NetCDF file.           ===
c                                                                    ===
c  On Input:                                                         ===
c                                                                    ===
c     NCINPID  NetCDF ID for input file (integer).                   ===
c     TINDX    time dimension index (integer).                       ===
c     IDFLD    identification of field to plot (integer).            ===
c     LEVEL    field level to read (integer).                        ===
c                                                                    ===
c  On Output:                                                        ===
c                                                                    ===
c     F        requested field (real array).                         ===
c     NP       number of points in requested field (integer).        ===
c     NCVARID  variable ID in input NetCDF file.                     ===
c     SPV      missing data/fill data value (real).                  ===
c                                                                    ===
c  Required common blocks:                                           ===
c                                                                    ===
c     NDIMEN, NETCDF, PLTIO                                          ===
c                                                                    ===
c  Calls:                                                            ===
c                                                                    ===
c     NCAGT, NCANAM, NCDINQ, NCVGET, NCVID, NCVINQ  (NetCDF library) ===
c     EXITUS, ID2FLDNAM, INTERP32, LNBLK                             ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <param.h>
#include <pconst.h>
#include <hybrid.h>
#include <ndimen.h>
#include <netcdf.inc>
#include <pltio.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer idfld,istr,k,lindx,n,ncinpid,ncvarid,np,nvatts,nvdims,
     *        lenfld,lenstr,lenvar,level,peclass,rcode,threed,tindx,
     *        vartyp,vindx
      integer count(10),dims(maxvdims),start(10),vdims(maxvdims)
      integer lnblk
      real f(*),f2(nv),spv
      logical       nograph
      character*128 varnam,dimnam(maxvdims)
      character*128 attnam,fldnam
      parameter (peclass=1, nograph=.false.)
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c  Get variable name from field identification.
c
      call id2fldnam(idfld,peclass,nograph,varnam,vindx,fldnam)
      lenfld=lnblk(fldnam,len(fldnam))
      lenvar=lnblk(varnam,len(varnam))
      threed = 0
c
c-----------------------------------------------------------------------
c  Read in requested field.
c-----------------------------------------------------------------------
c
      if(lenvar.gt.0) then
c
c  Inquire ID of requested field in input NetCDF file.
c
        ncvarid=ncvid(ncinpid,varnam(1:lenvar),rcode)
        if(rcode.ne.0) then
          write(stdout,900) varnam(1:lenvar),fldnam(1:lenfld)
          call exitus('GET_PE2DAT')
        endif
c
c  Inquire information about requested field in input NetCDF file.
c
        call ncvinq(ncinpid,ncvarid,varnam,vartyp,nvdims,vdims,nvatts,
     *              rcode)
        if(rcode.eq.0) then
          lenvar=lnblk(varnam,len(varnam))
          do 20 n=1,nvdims
            call ncdinq(ncinpid,vdims(n),dimnam(n),dims(n),rcode)
            if(rcode.ne.0) then
              write(stdout,901) dimnam(n),varnam(1:lenvar)
              call exitus('GET_PE2DAT')
            endif
            lenstr=lnblk(dimnam(n),len(dimnam(n)))
            if(dimnam(n)(1:lenstr).eq.'axis2') then
              start(n)=vindx
              count(n)=1
            elseif(dimnam(n)(1:lenstr).eq.'axis3') then
              start(n)=vindx
              count(n)=1
            elseif(dimnam(n)(1:lenstr).eq.'vector') then
              start(n)=vindx
              count(n)=1
            elseif((dimnam(n)(1:lenstr).eq.'tterm').or.
     *             (dimnam(n)(1:lenstr).eq.'mterm').or.
     *             (dimnam(n)(1:lenstr).eq.'mtermm3'))then
              start(n)=vindx
              count(n)=1
            elseif((dimnam(n)(1:lenstr).eq.'outlev').or.
     *             (dimnam(n)(1:lenstr).eq.'level')) then
              if (level.gt.0) then
                if (peoutlev.ne.0) then
                  start(n)=0
                  do 10 k=1,peoutlev
                    if(peout(k).gt.0) then
                       if(level.eq.peout(k)) start(n)=k
                    else
                       if (level.eq.k) start(n)=k
                    endif
  10              continue
                else
                  start(n)=level
                endif
                count(n)=1
              else
                start(n)=1
                count(n)=1
                threed=1
                lindx=n
              endif
              km=dims(n)
            elseif (dimnam(n)(1:lenstr).eq.'flatlevel') then
              if (level.gt.0) then
                start(n)=level
                count(n)=1
              else
                start(n)=1
                count(n)=1
                threed=1
                lindx=n
              endif
              km=dims(n)
            elseif((dimnam(n)(1:lenstr).eq.'tlon').or.
     *             (dimnam(n)(1:lenstr).eq.'vlon')) then
              start(n)=1
              count(n)=dims(n)
              im=dims(n)
            elseif((dimnam(n)(1:lenstr).eq.'tlat').or.
     *             (dimnam(n)(1:lenstr).eq.'vlat')) then
              start(n)=1
              count(n)=dims(n)
              jm=dims(n)
            elseif((dimnam(n)(1:lenstr).eq.'time').or.
     *             (dimnam(n)(1:lenstr).eq.'time0').or.
     *             (dimnam(n)(1:lenstr).eq.'shf_time').or.
     *             (dimnam(n)(1:lenstr).eq.'smf_time').or.
     *             (dimnam(n)(1:lenstr).eq.'swf_time').or.
     *             (dimnam(n)(1:lenstr).eq.'swr_time')) then
              start(n)=tindx
              count(n)=1
            endif
  20      continue
        else
          write(stdout,902) varnam(1:lenvar)
          call exitus('GET_PE2DAT')
        endif
c
c  Inquire "missing value" or "fill value" for the requested field.
c
        spv=spval1
        do 30 n=1,nvatts
          call ncanam(ncinpid,ncvarid,n,attnam,rcode)
          if(rcode.eq.0) then
            lenstr=lnblk(attnam,len(attnam))
            if((attnam(1:lenstr).eq.'missing_value').or.
     *         (attnam(1:lenstr).eq.'_FillValue')) then
              call ncagt(ncinpid,ncvarid,attnam(1:lenstr),spv,rcode)
              if(rcode.ne.0) then
                write(stdout,903) attnam(1:lenstr),varnam(1:lenvar)
                call exitus('GET_PE2DAT')
              endif
            endif
          endif
  30    continue
c
c  Read in requested field.
c
        np=im*jm
        if (threed.ne.1) then
          call ncvget(ncinpid,ncvarid,start,count,f,rcode)
          if(rcode.ne.0) then
            write(stdout,904) varnam(1:lenvar),fldnam(1:lenfld)
            call exitus('GET_PE2DAT')
          endif
        else
          do 40 k=1,km
            start(lindx)=k
            istr=1+(k-1)*im*jm
            call ncvget(ncinpid,ncvarid,start,count,f2(istr),rcode)
            if(rcode.ne.0) then
              write(stdout,906) varnam(1:lenvar),fldnam(1:lenfld),k
              call exitus('GET_PE2DAT')
            endif
  40      continue
          call interp32 (im,jm,km,f2,ncinpid,ncvarid,idfld,peclass,level
     &                                                           ,spv,f)
        endif
c
c-----------------------------------------------------------------------
c  Requested field not found.
c-----------------------------------------------------------------------
c
      else
        write(stdout,905) varnam(1:lenvar),fldnam(1:lenfld)
        call exitus('GET_PE2DAT')
      endif
c
 900  format(/' GET_PE2DAT - cannot inquiring ID for variable: ',a,
     *        ' [',a,']')
 901  format(/' GET_PE2DAT - error while inquiring dimension: ',a,2x,
     *        ' for variable: ',a,2x,' in input NetCDF file.' )
 902  format(/' GET_PE2DAT - error while inquiring information for',
     *        ' variable: ',a,2x,' in input NetCDF file.')
 903  format(/' GET_PE2DAT - error while reading attribute: 'a,2x,
     *        ' for variable: ',a)
 904  format(/' GET_PE2DAT - error while reading variable: ',a,
     *        ' [',a,']')
 905  format(/' GET_PE2DAT - cannot find variable: ',a,' [',a,']')
 906  format(/' GET_PE2DAT - error while reading variable: ',a,
     *        ' [',a,']',2x,' at LEVEL = ',i3)
      return
      end
