      function get_pltday(index,idfld,class,file)
c
c=======================================================================
c                                                                    ===
c  This routine returns the day to plot according to the field type  ===
c  and the time index counter.   This routine is only used when the  ===
c  plotting parameters DSKIP is set to zero or negative by the User. ===
c  Then, the requested field is plotted at their own time frequency. ===
c                                                                    ===
c  On Input:                                                         ===
c                                                                    ===
c     INDEX        time index counter (integer).                     ===
c     IDFLD        field identification (integer).                   ===
c     CLASS        field classification (integer):                   ===
c                  CLASS=1  PE                                       ===
c                  CLASS=2  QG                                       ===
c     FILE         input NetCDF file (integer):                      ===
c                  FILE=1  primary                                   ===
c                  FILE=2  secondary                                 ===
c                                                                    ===
c  On Output:                                                        ===
c                                                                    ===
c     GET_PLTDAY   day to plot (real).                               ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <param.h>
#include <pconst.h>
#include <inpcdf.h>
#include <pefldid.h>
#include <pltfld.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer class,file,i,idfld,index
      real day,get_pltday
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c-----------------------------------------------------------------------
c  If not first index, find correct day from times read from netCDF file.
c-----------------------------------------------------------------------
c
      if(index.gt.1) then
c
c     Get time from primary NetCDF file.
c
         if(file.eq.1) then
           if((type1(1:ltype1).eq.'PE MODEL').or.
     *        (type1(1:ltype1).eq.'QG MODEL')) then
             if(index.gt.ntime1) call exitus('DONE')
             day=time1(index)*sec2day
           elseif((type1(1:ltype1).eq.'PE_INITIAL').or.
     *            (type1(1:ltype1).eq.'FM MODEL').or.
     *            (type1(1:ltype1).eq.'OA')) then
             if(index.gt.ntime1) call exitus('DONE')
             day=time1(index)
           elseif(type1(1:ltype1).eq.'PE FORCING') then
             if((class.eq.peclass).and.(idfld.eq.peshfx)) then
               if(index.gt.nt1shf) call exitus('DONE')
               day=t1shf(index)
             elseif((class.eq.peclass).and.(
     *              (idfld.eq.pesmfv).or.(idfld.eq.pesmfm).or.
     *              (idfld.eq.pesmfx).or.(idfld.eq.pesmfy))) then
               if(index.gt.nt1smf) call exitus('DONE')
               day=t1smf(index)
             elseif((class.eq.peclass).and.(idfld.eq.peswfx)) then
               if(index.gt.nt1swf) call exitus('DONE')
               day=t1swf(index)
             elseif((class.eq.peclass).and.(idfld.eq.pesrad)) then
               if(index.gt.nt1swr) call exitus('DONE')
               day=t1swr(index)
             endif
           endif
c
c     Get time from secondary NetCDF file.
c
         elseif(file.eq.2) then
           if((type2(1:ltype2).eq.'PE MODEL').or.
     *        (type2(1:ltype2).eq.'QG MODEL')) then
             if(index.gt.ntime2) call exitus('DONE')
             day=time2(index)*sec2day
           elseif((type2(1:ltype2).eq.'PE_INITIAL').or.
     *            (type2(1:ltype2).eq.'FM MODEL').or.
     *            (type2(1:ltype2).eq.'OA')) then
             if(index.gt.ntime2) call exitus('DONE')
             day=time2(index)
           elseif(type2(1:ltype2).eq.'PE FORCING') then
             if((class.eq.peclass).and.(idfld.eq.peshfx)) then
               if(index.gt.nt2shf) call exitus('DONE')
               day=t2shf(index)
             elseif((class.eq.peclass).and.(
     *              (idfld.eq.pesmfv).or.(idfld.eq.pesmfm).or.
     *              (idfld.eq.pesmfx).or.(idfld.eq.pesmfy))) then
               if(index.gt.nt2smf) call exitus('DONE')
               day=t2smf(index)
             elseif((class.eq.peclass).and.(idfld.eq.peswfx)) then
               if(index.gt.nt2swf) call exitus('DONE')
               day=t2swf(index)
             elseif((class.eq.peclass).and.(idfld.eq.pesrad)) then
               if(index.gt.nt2swr) call exitus('DONE')
               day=t2swr(index)
             endif
           endif
         endif
         get_pltday=day
c
c-----------------------------------------------------------------------
c  If first index, return User requested first day to plot and reset
c  index to reflect proper location in file.
c-----------------------------------------------------------------------
c
      else
        get_pltday=frstd
c
c     Get index from primary NetCDF file.
c
         if(file.eq.1) then
           if((type1(1:ltype1).eq.'PE MODEL').or.
     *        (type1(1:ltype1).eq.'QG MODEL')) then
             day=abs(time1(1)*sec2day-frstd)
             do i = 2, ntime1
                if (abs(time1(i)*sec2day-frstd).lt.day) then
                   index = i
                   day=abs(time1(i)*sec2day-frstd)
                end if
             end do
           elseif((type1(1:ltype1).eq.'PE_INITIAL').or.
     *            (type1(1:ltype1).eq.'FM MODEL').or.
     *            (type1(1:ltype1).eq.'OA')) then
             day=abs(time1(1)-frstd)
             do i = 2, ntime1
                if (abs(time1(i)-frstd).lt.day) then
                   index = i
                   day=abs(time1(i)-frstd)
                end if
             end do
           elseif(type1(1:ltype1).eq.'PE FORCING') then
             if((class.eq.peclass).and.(idfld.eq.peshfx)) then
               day=abs(t1shf(1)-frstd)
               do i = 2, nt1shf
                  if (abs(t1shf(i)-frstd).lt.day) then
                     index = i
                     day=abs(t1shf(i)-frstd)
                  end if
               end do
             elseif((class.eq.peclass).and.(
     *              (idfld.eq.pesmfv).or.(idfld.eq.pesmfm).or.
     *              (idfld.eq.pesmfx).or.(idfld.eq.pesmfy))) then
               day=abs(t1smf(1)-frstd)
               do i = 2, nt1smf
                  if (abs(t1smf(i)-frstd).lt.day) then
                     index = i
                     day=abs(t1smf(i)-frstd)
                  end if
               end do
             elseif((class.eq.peclass).and.(idfld.eq.peswfx)) then
               day=abs(t1swf(1)-frstd)
               do i = 2, nt1swf
                  if (abs(t1swf(i)-frstd).lt.day) then
                     index = i
                     day=abs(t1swf(i)-frstd)
                  end if
               end do
             elseif((class.eq.peclass).and.(idfld.eq.pesrad)) then
               day=abs(t1swr(1)-frstd)
               do i = 2, nt1swr
                  if (abs(t1swr(i)-frstd).lt.day) then
                     index = i
                     day=abs(t1swr(i)-frstd)
                  end if
               end do
             endif
           endif
c
c     Get time from secondary NetCDF file.
c
         elseif(file.eq.2) then
           if((type2(1:ltype2).eq.'PE MODEL').or.
     *        (type2(1:ltype2).eq.'QG MODEL')) then
             day=abs(time2(1)*sec2day-frstd)
             do i = 2, ntime2
                if (abs(time2(i)*sec2day-frstd).lt.day) then
                   index = i
                   day=abs(time2(i)*sec2day-frstd)
                end if
             end do
           elseif((type2(1:ltype2).eq.'PE_INITIAL').or.
     *            (type2(1:ltype2).eq.'FM MODEL').or.
     *            (type2(1:ltype2).eq.'OA')) then
             day=abs(time2(1)-frstd)
             do i = 2, ntime2
                if (abs(time2(i)-frstd).lt.day) then
                   index = i
                   day=abs(time2(i)-frstd)
                end if
             end do
           elseif(type2(1:ltype2).eq.'PE FORCING') then
             if((class.eq.peclass).and.(idfld.eq.peshfx)) then
               day=abs(t2shf(1)-frstd)
               do i = 2, nt2shf
                  if (abs(t2shf(i)-frstd).lt.day) then
                     index = i
                     day=abs(t2shf(i)-frstd)
                  end if
               end do
             elseif((class.eq.peclass).and.(
     *              (idfld.eq.pesmfv).or.(idfld.eq.pesmfm).or.
     *              (idfld.eq.pesmfx).or.(idfld.eq.pesmfy))) then
               day=abs(t2smf(1)-frstd)
               do i = 2, nt2smf
                  if (abs(t2smf(i)-frstd).lt.day) then
                     index = i
                     day=abs(t2smf(i)-frstd)
                  end if
               end do
             elseif((class.eq.peclass).and.(idfld.eq.peswfx)) then
               day=abs(t2swf(1)-frstd)
               do i = 2, nt2swf
                  if (abs(t2swf(i)-frstd).lt.day) then
                     index = i
                     day=abs(t2swf(i)-frstd)
                  end if
               end do
             elseif((class.eq.peclass).and.(idfld.eq.pesrad)) then
               day=abs(t2swr(1)-frstd)
               do i = 2, nt2swr
                  if (abs(t2swr(i)-frstd).lt.day) then
                     index = i
                     day=abs(t2swr(i)-frstd)
                  end if
               end do
             endif
           endif
         endif
      endif
c
      return
      end
