      subroutine get_qg3dat(f,np,ncinpid,tindx,idfld,ncvarid,spv)
c
c=======================================================================
c                                                                    ===
c  This routine sets up the necessary information and reads field    ===
c  IDFLD (QG model classification) from input NetCDF file.           ===
c                                                                    ===
c  On Input:                                                         ===
c                                                                    ===
c     NCINPID  NetCDF ID for input file (integer).                   ===
c     TINDX    time dimension index (integer).                       ===
c     IDFLD    identification of field to plot (integer).            ===
c                                                                    ===
c  On Output:                                                        ===
c                                                                    ===
c     F        requested field (real array).                         ===
c     NP       number of points in requested field (integer).        ===
c     NCVARID  variable ID in input NetCDF file.                     ===
c     SPV      missing data/fill data value (real).                  ===
c                                                                    ===
c  Required common blocks:                                           ===
c                                                                    ===
c     NDIMEN, NETCDF, PLTIO                                          ===
c                                                                    ===
c  Calls:                                                            ===
c                                                                    ===
c     NCAGT, NCANAM, NCDINQ, NCVID, NCVINQ  (NetCDF library)         ===
c     EXITUS, ID2FLDNAM, LNBLK, NCVGET                               ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <param.h>
#include <pconst.h>
#include <ndimen.h>
#include <netcdf.inc>
#include <pltio.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer idfld,istr,k,n,ncinpid,ncvarid,np,nvatts,nvdims,lenfld,
     *        lenstr,lenvar,lindx,qgclass,rcode,tindx,vartyp,vindx
      integer count(10),dims(maxvdims),start(10),vdims(maxvdims)
      integer lnblk
      real f(*),spv
      logical      nograph
      character*128 varnam,dimnam(maxvdims)
      character*128 attnam,fldnam
      parameter (qgclass=2, nograph=.false.)
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c  Get variable name from field identification.
c
      call id2fldnam(idfld,qgclass,nograph,varnam,vindx,fldnam)
      lenfld=lnblk(fldnam,len(fldnam))
      lenvar=lnblk(varnam,len(varnam))
c
c-----------------------------------------------------------------------
c  Read in requested field.
c-----------------------------------------------------------------------
c
      if(lenvar.gt.0) then
c
c  Inquire ID of requested field in input NetCDF file.
c
        ncvarid=ncvid(ncinpid,varnam(1:lenvar),rcode)
        if(rcode.ne.0) then
          write(stdout,900) varnam(1:lenvar),fldnam(1:lenfld)
          call exitus('GET_QG3DAT')
        endif
c
c  Inquire information about requested field in input NetCDF file.
c
        call ncvinq(ncinpid,ncvarid,varnam,vartyp,nvdims,vdims,nvatts,
     *              rcode)
        if(rcode.eq.0) then
          lenvar=lnblk(varnam,len(varnam))
          do 10 n=1,nvdims
            call ncdinq(ncinpid,vdims(n),dimnam(n),dims(n),rcode)
            if(rcode.ne.0) then
              write(stdout,901) dimnam(n),varnam(1:lenvar)
              call exitus('GET_QG3DAT')
            endif
            lenstr=lnblk(dimnam(n),len(dimnam(n)))
            if((dimnam(n)(1:lenstr).eq.'axis2').or.
     *         (dimnam(n)(1:lenstr).eq.'axis3').or.
     *         (dimnam(n)(1:lenstr).eq.'vector')) then
              start(n)=vindx
              count(n)=1
            elseif((dimnam(n)(1:lenstr).eq.'level').or.
     *             (dimnam(n)(1:lenstr).eq.'outlev').or.
     *             (dimnam(n)(1:lenstr).eq.'biolev')) then
              lindx=n
              km=dims(n)
            elseif((dimnam(n)(1:lenstr).eq.'lon').or.
     *             (dimnam(n)(1:lenstr).eq.'tlon').or.
     *             (dimnam(n)(1:lenstr).eq.'vlon')) then
              start(n)=1
              count(n)=dims(n)
              im=dims(n)
            elseif((dimnam(n)(1:lenstr).eq.'lat').or.
     *             (dimnam(n)(1:lenstr).eq.'tlat').or.
     *             (dimnam(n)(1:lenstr).eq.'vlat')) then
              start(n)=1
              count(n)=dims(n)
              jm=dims(n)
            elseif(dimnam(n)(1:lenstr).eq.'time') then
              start(n)=tindx
              count(n)=1
            endif
  10      continue
        else
          write(stdout,902) varnam(1:lenvar)
          call exitus('GET_QG3DAT')
        endif
c
c  Inquire "missing value" or "fill value" for the requested field.
c
        spv=spval1
        do 20 n=1,nvatts
          call ncanam(ncinpid,ncvarid,n,attnam,rcode)
          if(rcode.eq.0) then
            lenstr=lnblk(attnam,len(attnam))
            if((attnam(1:lenstr).eq.'missing_value').or.
     *         (attnam(1:lenstr).eq.'_FillValue')) then
              call ncagt(ncinpid,ncvarid,attnam(1:lenstr),spv,rcode)
              if(rcode.ne.0) then
                write(stdout,903) attnam(1:lenstr),varnam(1:lenvar)
                call exitus('GET_QG3DAT')
              endif
            endif
          endif
  20    continue
c
c  Check if allocated array space is sufficient.
c
        np=im*jm*km
        if(np.gt.nv) then
          write(stdout,904) np,nv
          call exitus('GET_QG3DAT')
        endif
c
c  Read in requested field.
c
        do 30 k=1,km
          start(lindx)=k
          count(lindx)=1
          istr=1+(k-1)*im*jm
          call ncvget(ncinpid,ncvarid,start,count,f(istr),rcode)
          if(rcode.ne.0) then
            write(stdout,905) varnam(1:lenvar),k,fldnam(1:lenfld)
            call exitus('GET_QG3DAT')
          endif
  30    continue
c
c-----------------------------------------------------------------------
c  Requested field not found.
c-----------------------------------------------------------------------
c
      else
        write(stdout,906) varnam(1:lenvar),fldnam(1:lenfld)
        call exitus('GET_QG3DAT')
      endif
c
 900  format(/' GET_QG3DAT - cannot inquiring ID for variable: ',a,
     *        ' [',a,']')
 901  format(/' GET_QG3DAT - error while inquiring dimension: ',a,2x,
     *        ' for variable: ',a,2x,' in input NetCDF file.' )
 902  format(/' GET_QG3DAT - error while inquiring information for',
     *        ' variable: ',a,2x,' in input NetCDF file.')
 903  format(/' GET_QG3DAT - error while reading attribute: 'a,2x,
     *        ' for variable: ',a)
 904  format(/' GET_QG3DAT - required array size = ',i6,2x,
     *        ' is bigger than that allocated = ',i6,/,14x,
     *        ' Change parameter NV and recompile.')
 905  format(/' GET_QG3DAT - error while reading variable: ',a,
     *        ' [',a,']',2x,' at LEVEL = ',i3)
 906  format(/' GET_QG3DAT - cannot find variable: ',a,' [',a,']',/,14x,
     *        ' Requested variable may not have z-dimension.')
      return
      end
