      subroutine get_scoor(fldid,itopo,spval)
c
c=======================================================================
c  This routine sets the section coordinates.                        ===
c                                                                    ===
c  On Input:                                                         ===
c                                                                    ===
c     FLDID    field identification.                                 ===
c     ITOPO    switch to process provided bathymetry:                ===
c              ITOPO=0   no                                          ===
c              ITOP0=1   yes                                         ===
c     SPVAL    field special value used for masking (real).          ===
c                                                                    ===
c  Calls:                                                            ===
c                                                                    ===
c     BILIN, EXITUS, LL2XY                                           ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <param.h>
#include <pconst.h>
#include <domdat.h>
#include <fldpos.h>
#include <inpcdf.h>
#include <ndimen.h>
#include <pefldid.h>
#include <secpos.h>
#include <zdat.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      logical pe_class,qg_class
      integer fldid,i,ip,itopo,j,k,n,nin,tvgrid
      real ber,ddeg,dnrm,dlat,dlon,ddst,dist,delz,gdelx,gdely,gdx,gdy,
     &     spv,spval
      real hv(nh)
      real bilin,gcircle
      parameter (spv=spval0)
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c-----------------------------------------------------------------------
c  Determine grid type.
c-----------------------------------------------------------------------
c
c  Determine field classification.
c
      pe_class=.false.
      qg_class=.false.
      if((type1(1:ltype1).eq.'PE MODEL').or.
     *   (type1(1:ltype1).eq.'PE ENERGY').or.
     *   (type1(1:ltype1).eq.'PE_INITIAL')) then
        pe_class=.true.
      elseif((type1(1:ltype1).eq.'QG MODEL').or.
     *       (type1(1:ltype1).eq.'OTIS').or.
     *       (type1(1:ltype1).eq.'FM MODEL')) then
        qg_class=.true.
      endif
c
c  Determine grid type.
c
      tvgrid=0
      if(pe_class) then
        if((fldid.eq.peimag).or.(fldid.eq.peivec).or.
     *     (fldid.eq.peivnm).or.(fldid.eq.peivtg).or.
     *     (fldid.eq.peuhat).or.(fldid.eq.pevhat).or.
     *     (fldid.eq.pegmag).or.(fldid.eq.pegvec).or.
     *     (fldid.eq.peugeo).or.(fldid.eq.pevgeo).or.
     *     (fldid.eq.pegvnm).or.(fldid.eq.pegvtg).or.
     *     (fldid.eq.petmag).or.(fldid.eq.petvec).or.
     *     (fldid.eq.peutot).or.(fldid.eq.pevtot).or.
     *     (fldid.eq.pevnrm).or.(fldid.eq.pevtng).or.
     *     (fldid.eq.petdmg).or.(fldid.eq.petdvc).or.
     *     (fldid.eq.peutid).or.(fldid.eq.pevtid).or.
     *     (fldid.eq.petvnm).or.(fldid.eq.petvtg).or.
     *     (fldid.eq.peufer).or.(fldid.eq.pevfer).or.
     *     (fldid.eq.pewvsv).or.(fldid.eq.pewvzv)) then
          tvgrid=2
        elseif(
     *     (fldid.eq.pekets).or.(fldid.eq.peket1).or.
     *     (fldid.eq.peket2).or.(fldid.eq.peket3).or.
     *     (fldid.eq.peket4).or.(fldid.eq.peket5).or.
     *     (fldid.eq.peket6).or.(fldid.eq.peket7).or.
     *     (fldid.eq.peket8).or.(fldid.eq.peket9).or.
     *     (fldid.eq.pekt10).or.(fldid.eq.pekt11).or.
     *     (fldid.eq.petdsf)) then
          tvgrid=2
        else
          tvgrid=1
        endif
      endif
      if(qg_class) then
        tvgrid=0
      endif
c
c-----------------------------------------------------------------------
c  Set section horizontal coordinates.
c-----------------------------------------------------------------------
c
c  Compute step sizes in ordinal directions.
c
      dlon = slon2 - slon1
      dlat = slat2 - slat1
      dnrm = sqrt ( dlon*dlon + dlat*dlat )
      dlon = dels*(dlon/dnrm)
      dlat = dels*(dlat/dnrm)
c
c  Compute number of interior points
c
      nin = int (dnrm/dels)
c
c  Set section lat/lon.
c
      slon(1) = slon1
      slat(1) = slat1
c
      do 10 n = 2, nin+1
         slon(n) = slon1 + float(n-1)*dlon
         slat(n) = slat1 + float(n-1)*dlat
  10  continue
c
      ims = nin+2
      slon(ims) = slon2
      slat(ims) = slat2
c
c-----------------------------------------------------------------------
c  Set section vertical coordinate.
c-----------------------------------------------------------------------
c
      delz=(abs(szbot)-abs(sztop))/float(kms-1)
      do 30 k=1,kms
        zsec(k)=abs(sztop)+float(k-1)*delz
        zsec(k)=-zsec(k)
  30  continue
c
c-----------------------------------------------------------------------
c  Get section positions (grid units) with respect input grided data.
c  This nondimensional positions will be used in the horizontal Bessel
c  interpolation. It assumes uniform horizontal grid spacing so DX and
c  DY are constant and may differ.
c-----------------------------------------------------------------------
c
      if(coord.eq.0) then
        gdx   = dx*m2cm
        gdy   = dy*m2cm
        gdelx = delx*m2cm
        gdely = dely*m2cm
       else
        gdx   = dx
        gdy   = dy
        gdelx = delx
        gdely = dely
      endif
      do 40 i=1,ims
        call ll2xy (slon(i),slat(i),coord,im,jm,gdx,gdy,clngd,clatd,
     *              gdelx,gdely,thetad,xsec(i),ysec(i))
        if(tvgrid.eq.2) then
          xsec(i) = xsec(i)-p5
          ysec(i) = ysec(i)-p5
        endif
  40  continue
c
c-----------------------------------------------------------------------
c  Set section grid to be used by the contour location routine CPMPXY.
c-----------------------------------------------------------------------
c
      do 60 i=1,ims
        if (i.eq.1) then
           dist = c0
         else
           ddeg = gcircle (slon(i-1),slat(i-1),slon(i),slat(i),ddst,ber)
           dist = dist + ddst
        end if
        do 50 k=1,kms
          ip=i+(k-1)*ims
          x(ip)=dist
          y(ip)=zsec(k)
  50    continue
  60  continue
      np=ims*kms
c
c-----------------------------------------------------------------------
c  Extract the bathymetry for the section.
c-----------------------------------------------------------------------
c
      if(itopo.eq.1) then
c
c -- Select topography type.
c
        if (tvgrid.eq.2) then
          do 80 j = 1, jm-1
            do 70 i = 1, im-1
              ip = i + (j-1)*im
              hv(ip) = p25*(bath(ip)+bath(ip+1)+bath(ip+im)
     &                      +bath(ip+im+1))
  70        continue
            ip = j*im
            hv(ip) = p5*(bath(ip)+bath(ip+im))
  80      continue
          do 90 i = 1, im-1
            ip = i + (jm-1)*im
            hv(ip) = p5*(bath(ip)+bath(ip+1))
  90      continue
          ip = im*jm
          hv(ip) = bath(ip)
         else
          do 100 i = 1, im*jm
            hv(i) = bath(i)
 100      continue
        endif
c
c -- Interpolate to section.
c
        do 110 i=1,ims
          if((c1.le.ysec(i)).and.(ysec(i).le.float(jm)).and.
     *       (c1.le.xsec(i)).and.(xsec(i).le.float(im))) then
            sbth(i)=bilin(xsec(i),ysec(i),hv,im,jm,spv,spval)
            sbth(i)=-abs(sbth(i))
          else
            print 910, xsec(i),ysec(i)
          endif
 110    continue
      endif
c
 910  format('GET_SCOOR: section out of bounds at point X,Y = ',2f10.4)
      return
      end
