      subroutine id2fldnam(idfld,class,grfflg,varnam,vindx,fldnam)
c
c=======================================================================
c                                                                    ===
c  This routine returns the NetCDF variable name VARNAM and field    ===
c  long name FLDNAM associated to field identification  IDFLD  of    ===
c  classification CLASS.                                             ===
c                                                                    ===
c  On Input:                                                         ===
c                                                                    ===
c     IDFLD    field identification (integer).                       ===
c     CLASS    field classification (integer):                       ===
c              CLASS=1   PE classification.                          ===
c              CLASS=2   QG classification.                          ===
c     GRFFLG   Flag to indicate whether to print as graphics or      ===
c              plain.                                                ===
c              [.true.]   print as graphics                          ===
c              [.false.]  print as plain                             ===
c                                                                    ===
c  On Output:                                                        ===
c                                                                    ===
c     VARNAM   NetCDF variable name (character).                     ===
c     VINDX    component index in NetCDF file for vector and         ===
c              tensor variables (integer).                           ===
c     FLDNAM   field long name (character).                          ===
c                                                                    ===
c  Calls:  LENGTH, SET_UNITS                                         ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <param.h>
#include <pefldid.h>
#include <pltncar.h>
#include <qgfldid.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer class,idfld,lenfld,lenvar,n,peclass,qgclass,sb1,sb2,sb3,
     &        se1,se2,se3,sl1,sl2,sl3,trcindx,trmindx,vindx
      logical       fnd,grfflg
      character*(*) fldnam,varnam
      character*256 wkstr
      parameter (peclass=1,qgclass=2)
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c  Initialize variables.
c
      vindx=0
      lenfld=len(fldnam)
      lenvar=len(varnam)
      do 10 n=1,lenfld
        fldnam(n:n)=' '
  10  continue
      do 20 n=1,lenvar
        varnam(n:n)=' '
  20  continue
c
c-----------------------------------------------------------------------
c  PE classification fields.
c-----------------------------------------------------------------------
c
      if(class.eq.peclass) then
        if(idfld.eq.pedano) then
          varnam='dena'
          call set_units ('kilogram meter-3',grfflg,wkstr)
          call length (wkstr,sl1,sb1,se1)
          fldnam='PE Density Anomaly'//' '//wkstr(sb1:se1)
        elseif(idfld.eq.pecden) then
          call set_units ('kilogram meter-3',grfflg,wkstr)
          call length (wkstr,sl1,sb1,se1)
          fldnam='Density Anomaly from T,S'//' '//wkstr(sb1:se1)
        elseif(idfld.eq.pedbar) then
          call set_units ('kilogram meter-3',grfflg,wkstr)
          call length (wkstr,sl1,sb1,se1)
          fldnam='Mean Density Anomaly'//' '//wkstr(sb1:se1)
        elseif(idfld.eq.pesigt) then
          varnam='sigma-t'
          call set_units ('kilogram meter-3',grfflg,wkstr)
          call length (wkstr,sl1,sb1,se1)
#if !defined medchr & !defined lowchr
          if (grfflg) then
            fldnam=esc_char//'PGL'//esc_char//'R'//esc_char//'PRUB'
     &             //esc_char//'t'//esc_char//'N'//esc_char//' '//
     &            wkstr(sb1:se1)
          else
            fldnam='Sigma-t'//' '//wkstr(sb1:se1)
          endif
# else
          fldnam='Sigma-t'//' '//wkstr(sb1:se1)
#endif
        elseif(idfld.eq.pesnds) then
          fldnam='Sound Speed (m/s)'
        elseif(idfld.eq.pepbar) then
          fldnam='Transport Streamfunction (Sv)'
          varnam='pbar'
        elseif(idfld.eq.pepoer) then
          fldnam='Transport Streamfunction observation Error'
          varnam='pbarerr'
        elseif(idfld.eq.pepfer) then
          fldnam='Transport Streamfunction Forecast Error'
          varnam='pbarferr'
        elseif(idfld.eq.pesprs) then
          varnam='srfpress'
          call set_units ('dyne centimeter-2',grfflg,wkstr)
          call length (wkstr,sl1,sb1,se1)
          fldnam='surface pressure'//' '//wkstr(sb1:se1)
        elseif(idfld.eq.pehspr) then
          varnam='srfpress'
          fldnam='Surface Elevation (m)'
        elseif(idfld.eq.pebvor) then
          fldnam='barotropic vorticity rate'
          varnam='qbar'
        elseif(idfld.eq.peugeo) then
          fldnam='Zonal Geostrophic Shear (cm/s)'
          varnam='vgeo'
          vindx=1
        elseif(idfld.eq.pevgeo) then
          fldnam='Meridional Geostrophic Shear (cm/s)'
          varnam='vgeo'
          vindx=2
        elseif(idfld.eq.pegmag) then
          fldnam='Geostrophic Shear (cm/s)'
        elseif(idfld.eq.pegvec) then
          fldnam='Geostrophic Shear Velocity (cm/s)'
        elseif(idfld.eq.pegvnm) then
          fldnam='Geostrophic Normal Velocity Component (cm/s)'
        elseif(idfld.eq.pegvtg) then
          fldnam='Geostrophic Tangential Velocity Component (cm/s)'
        elseif(idfld.eq.peutot) then
          fldnam='Total Zonal Velocity (cm/s)'
          varnam='vtot'
          vindx=1
        elseif(idfld.eq.pevtot) then
          fldnam='Total Meridional Velocity (cm/s)'
          varnam='vtot'
          vindx=2
        elseif(idfld.eq.petmag) then
          fldnam='Total Velocity Magnitude (cm/s)'
        elseif(idfld.eq.petvec) then
          fldnam='Total Velocity (cm/s)'
        elseif(idfld.eq.pevnrm) then
          fldnam='Normal Velocity Component (cm/s)'
        elseif(idfld.eq.pevtng) then
          fldnam='Tangential Velocity Component (cm/s)'
        elseif(idfld.eq.peuhat) then
          fldnam='Internal Mode, Zonal Velocity (cm/s)'
          varnam='vclin'
          vindx=1
        elseif(idfld.eq.pevhat) then
          fldnam='Internal Mode, Meridional Velocity (cm/s)'
          varnam='vclin'
          vindx=2
        elseif(idfld.eq.peuoer) then
          fldnam='Internal Mode, Zonal Velocity Observation Error'
          varnam='vclinerr'
          vindx=1
        elseif(idfld.eq.pevoer) then
          fldnam='Internal Mode, Meridional Velocity Observation Error'
          varnam='vclinerr'
          vindx=2
        elseif(idfld.eq.peubar) then
          fldnam='External Mode, Zonal Velocity (cm/s)'
          varnam='vbaro'
          vindx=1
        elseif(idfld.eq.pevbar) then
          fldnam='External Mode, Meridional Velocity (cm/s)'
          varnam='vbaro'
          vindx=2
        elseif(idfld.eq.peufer) then
          fldnam='Internal Mode, Zonal Velocity Forecast Error'
          varnam='vclinferr'
          vindx=1
        elseif(idfld.eq.pevfer) then
          fldnam='Internal Mode, Meridional Velocity Forecast Error'
          varnam='vclinferr'
          vindx=2
        elseif(idfld.eq.peimag) then
          fldnam='Internal Velocity Magnitude (cm/s)'
        elseif(idfld.eq.peivec) then
          fldnam='Internal Mode Velocity (cm/s)'
        elseif(idfld.eq.peivnm) then
          fldnam='Internal Normal Velocity Component (cm/s)'
        elseif(idfld.eq.peivtg) then
          fldnam='Internal Tangential Velocity Component (cm/s)'
        elseif(idfld.eq.pedubr) then
          fldnam='External Mode, Zonal Velocity (cm/s)'
        elseif(idfld.eq.pedvbr) then
          fldnam='External Mode, Meridional Velocity (cm/s)'
        elseif((idfld.eq.peemag).or.(idfld.eq.pedemg)) then
          fldnam='External Velocity Magnitude (cm/s)'
        elseif((idfld.eq.peevec).or.(idfld.eq.pedevc)) then
          fldnam='External Mode Velocity (cm/s)'
        elseif(idfld.eq.peutid) then
          fldnam='Tidal Zonal Velocity (cm/s)'
          varnam='vtide'
          vindx=1
        elseif(idfld.eq.pevtid) then
          fldnam='Tidal Meridional Velocity (cm/s)'
          varnam='vtide'
          vindx=2
        elseif(idfld.eq.petdmg) then
          fldnam='Tidal Velocity Magnitude (cm/s)'
        elseif(idfld.eq.petdvc) then
          fldnam='Tidal Velocity (cm/s)'
        elseif(idfld.eq.petvnm) then
          fldnam='Tidal Normal Velocity Component (cm/s)'
        elseif(idfld.eq.petvtg) then
          fldnam='Tidal Tangential Velocity Component (cm/s)'
        elseif(idfld.eq.peuflt) then
          fldnam='Zonal Flat Velocity (cm/s)'
          varnam='vflt'
          vindx=1
        elseif(idfld.eq.pevflt) then
          fldnam='Meridional Flat Velocity (cm/s)'
          varnam='vflt'
          vindx=2
        elseif(idfld.eq.pvfmag) then
          fldnam='Flat Speed (cm/s)'
        elseif(idfld.eq.pvfvec) then
          fldnam='Flat Velocity (cm/s)'
        elseif(idfld.eq.pefvnm) then
          fldnam='Flat Normal Velocity Component (cm/s)'
        elseif(idfld.eq.pefvtg) then
          fldnam='Flat Tangential Velocity Component (cm/s)'
        elseif(idfld.eq.peub1) then
          fldnam='Zonal 1st guess Barotropic Velocity (cm/s)'
          varnam='vb1st'
          vindx=1
        elseif(idfld.eq.pevb1) then
          fldnam='Meridional 1st guess Barotropic Velocity (cm/s)'
          varnam='vb1st'
          vindx=2
        elseif(idfld.eq.pb1mag) then
          fldnam='1st guess Barotropic Speed (cm/s)'
        elseif(idfld.eq.pb1vec) then
          fldnam='1st guess Barotropic Velocity (cm/s)'
        elseif(idfld.eq.peub2) then
          fldnam='Zonal 2nd guess Barotropic Velocity (cm/s)'
          varnam='vb2nd'
          vindx=1
        elseif(idfld.eq.pevb2) then
          fldnam='Meridional 2nd guess Barotropic Velocity (cm/s)'
          varnam='vb2nd'
          vindx=2
        elseif(idfld.eq.pb2mag) then
          fldnam='2nd guess Barotropic Speed (cm/s)'
        elseif(idfld.eq.pb2vec) then
          fldnam='2nd guess Barotropic Velocity (cm/s)'
        elseif(idfld.eq.peub3) then
          fldnam='Zonal 3rd guess Barotropic Velocity (cm/s)'
          varnam='vb3rd'
          vindx=1
        elseif(idfld.eq.pevb3) then
          fldnam='Meridional 3rd guess Barotropic Velocity (cm/s)'
          varnam='vb3rd'
          vindx=2
        elseif(idfld.eq.pb3mag) then
          fldnam='3rd guess Barotropic Speed (cm/s)'
        elseif(idfld.eq.pb3vec) then
          fldnam='3rd guess Barotropic Velocity (cm/s)'
        elseif(idfld.eq.peshfx) then
          varnam='shflux'
          call set_units ('Watt meter-2',grfflg,wkstr)
          call length (wkstr,sl1,sb1,se1)
          fldnam='Surface Net Heat Flux'//' '//wkstr(sb1:se1)
        elseif(idfld.eq.pesmfx) then
          varnam='smflux'
          call set_units ('dyne centimeter-2',grfflg,wkstr)
          call length (wkstr,sl1,sb1,se1)
          fldnam='Zonal Wind Stress'//' '//wkstr(sb1:se1)
          vindx=1
        elseif(idfld.eq.pesmfy) then
          varnam='smflux'
          call set_units ('dyne centimeter-2',grfflg,wkstr)
          call length (wkstr,sl1,sb1,se1)
          fldnam='Meridional Wind Stress'//' '//wkstr(sb1:se1)
          vindx=2
        elseif(idfld.eq.pesmfv) then
          call set_units ('dyne centimeter-2',grfflg,wkstr)
          call length (wkstr,sl1,sb1,se1)
          fldnam='Wind Stress'//' '//wkstr(sb1:se1)
          varnam='smflux'
        elseif(idfld.eq.pesmfm) then
          call set_units ('dyne centimeter-2',grfflg,wkstr)
          call length (wkstr,sl1,sb1,se1)
          fldnam='Wind Stress Vector Magnitude'//' '//wkstr(sb1:se1)
          varnam='smflux'
        elseif(idfld.eq.peswfx) then
          fldnam='Surface Water Flux, E-P (cm/day)'
          varnam='swflux'
        elseif(idfld.eq.pesrad) then
          varnam='swrad'
          call set_units ('Watt meter-2',grfflg,wkstr)
          call length (wkstr,sl1,sb1,se1)
          fldnam='Shortwave Radiation'//' '//wkstr(sb1:se1)
        elseif(idfld.eq.pemldh) then
          fldnam='Mixed-layer Depth (m)'
          varnam='mld'
        elseif(idfld.eq.pemxld) then
          fldnam='Mixing Layer Depth (m)'
          varnam='mxld'
        elseif(idfld.eq.petdsf) then
          fldnam='Tidal Surface Elevation (m)'
          varnam='srftide'
        elseif(idfld.eq.penh4p) then
          varnam='NH4pr'
          call set_units ('micromole Nitrogen day-1',grfflg,wkstr)
          call length (wkstr,sl1,sb1,se1)
          fldnam='Recycled Production'//' '//wkstr(sb1:se1)
        elseif(idfld.eq.peno3p) then
          varnam='NO3pr'
          call set_units ('micromole Nitrogen day-1',grfflg,wkstr)
          call length (wkstr,sl1,sb1,se1)
          fldnam='New Production'//' '//wkstr(sb1:se1)
        elseif(idfld.eq.pezoog) then
          varnam='zoogr'
          call set_units ('micromole liter-1 day-1',grfflg,wkstr)
          call length (wkstr,sl1,sb1,se1)
          fldnam='Zooplankton grazing rate'//' '//wkstr(sb1:se1)
        elseif(idfld.eq.pewvst) then
          fldnam='Omega Velocity  [T pts.] (m/day)'
          varnam='wvst'
        elseif(idfld.eq.pewvsv) then
          fldnam='Omega Velocity  [V pts.] (m/day)'
          varnam='wvsv'
        elseif(idfld.eq.pewvzt) then
          fldnam='Vertical Velocity [T pts.] (m/day)'
          varnam='wvzt'
        elseif(idfld.eq.pewvzv) then
          fldnam='Vertical Velocity [V pts.] (m/day)'
          varnam='wvzv'
        elseif(idfld.eq.pebath) then
          fldnam='Bathymetry (m)'
          varnam='tbath'
        elseif(idfld.eq.petmsk) then
          fldnam='Land/Sea Mask at T points'
          varnam='landt'
        elseif(idfld.eq.pevmsk) then
          fldnam='Land/Sea Mask at V points'
          varnam='landv'
        elseif(idfld.eq.pebtht) then
          fldnam='depth of each tracer point'
          varnam='tgrid3'
          vindx=3
        elseif(idfld.eq.pebthv) then
          fldnam='depth of each velocity point'
          varnam='vgrid3'
          vindx=3
        elseif(idfld.eq.peltrk) then
          fldnam='Lagrangian Trajectories'
        elseif(idfld.eq.pehsta) then
          fldnam='Hydrographic Stations'
        elseif(idfld.eq.pebuoy) then
          varnam='buoyp'
          call set_units ('centimeter2 second-3',grfflg,wkstr)
          call length (wkstr,sl1,sb1,se1)
          fldnam='Buoyancy Work'//' '//wkstr(sb1:se1)
        elseif(idfld.eq.peteke) then
          varnam='ke_tot'
          call set_units ('centimeter2 second-2',grfflg,wkstr)
          call length (wkstr,sl1,sb1,se1)
          fldnam='Total Kinetic Energy'//' '//wkstr(sb1:se1)
        elseif(idfld.eq.peket1) then
          fldnam='Change of KE due to pressure'
          varnam='ke_terms'
          vindx=1
        elseif(idfld.eq.peket2) then
          fldnam='Change of KE due to zonal advection'
          varnam='ke_terms'
          vindx=2
        elseif(idfld.eq.peket3) then
          fldnam='Change of KE due to meridional advection'
          varnam='ke_terms'
          vindx=3
        elseif(idfld.eq.peket4) then
          fldnam='Change of KE due to vertical advection'
          varnam='ke_terms'
          vindx=4
        elseif(idfld.eq.peket5) then
          fldnam='Change of KE due to zonal diffusion'
          varnam='ke_terms'
          vindx=5
        elseif(idfld.eq.peket6) then
          fldnam='Change of KE due to meridional diffusion'
          varnam='ke_terms'
          vindx=6
        elseif(idfld.eq.peket7) then
          fldnam='Change of KE due to vertical diffusion'
          varnam='ke_terms'
          vindx=7
        elseif(idfld.eq.peket8) then
          fldnam='Change of KE due to metric diffusion'
          varnam='ke_terms'
          vindx=8
        elseif(idfld.eq.peket9) then
          fldnam='Change of KE due to Coriolis'
          varnam='ke_terms'
          vindx=9
        elseif(idfld.eq.pekt10) then
          fldnam='Change of KE due to boundary relaxation'
          varnam='ke_terms'
          vindx=10
        elseif(idfld.eq.pekt11) then
          fldnam='Change of KE due to tidal acceleration'
          varnam='ke_terms'
          vindx=11
        elseif(idfld.eq.pevdc) then
          varnam='vdc'
          call set_units ('centimeter2 second-1',grfflg,wkstr)
          call length (wkstr,sl1,sb1,se1)
          fldnam='vertical eddy diffusion'//' '//wkstr(sb1:se1)
        elseif(idfld.eq.pevvc) then
          varnam='vvc'
          call set_units ('centimeter2 second-1',grfflg,wkstr)
          call length (wkstr,sl1,sb1,se1)
          fldnam='vertical eddy viscosity'//' '//wkstr(sb1:se1)
        elseif(idfld.eq.peross) then
          varnam='ross'
          call set_units ('kilometer',grfflg,wkstr)
          call length (wkstr,sl1,sb1,se1)
          fldnam='Rossby radius'//' '//wkstr(sb1:se1)
        else
          fnd     = .false.
          trcindx = 1
          do 40 while ( (.not.fnd) .and. (trcindx.le.maxtrc) )
            if (idfld.eq.tid(trcindx)) then
              fnd = .true.
              call length (tname(1,trcindx),sl1,sb1,se1)
              varnam = tname(1,trcindx)(sb1:se1)
              call length (tname(2,trcindx),sl1,sb1,se1)
              call set_units (tname(3,trcindx),grfflg,wkstr)
              call length (wkstr,sl2,sb2,se2)
              fldnam=tname(2,trcindx)(sb1:se1)//' '//wkstr(sb2:se2)
             elseif (idfld.eq.toerid(trcindx)) then
              fnd = .true.
              call length (tname(1,trcindx),sl1,sb1,se1)
              varnam = tname(1,trcindx)(sb1:se1)//'err'
              call length (tname(2,trcindx),sl1,sb1,se1)
              fldnam=tname(2,trcindx)(sb1:se1)//
     &               ' Observation Error'
             elseif (idfld.eq.tferid(trcindx)) then
              fnd = .true.
              call length (tname(1,trcindx),sl1,sb1,se1)
              varnam = tname(1,trcindx)(sb1:se1)//'ferr'
              call length (tname(2,trcindx),sl1,sb1,se1)
              fldnam=tname(2,trcindx)(sb1:se1)//
     &               ' Forecast Error'
             else
              trmindx = 1
              do 30 while ( (.not.fnd) .and. (trmindx.le.tterms) )
                if (idfld.eq.tbalid(trmindx,trcindx)) then
                  fnd = .true.
                  call length (tname(1,trcindx),sl1,sb1,se1)
                  varnam = tname(1,trcindx)(sb1:se1)//'_bterms'
                  call length (tname(2,trcindx),sl1,sb1,se1)
                  call length (tname(3,trcindx),sl2,sb2,se2)
                  call set_units (tname(3,trcindx)(sb2:se2)//' second-1'
     &                                                    ,grfflg,wkstr)
                  call length (wkstr,sl2,sb2,se2)
                  call length (tbterm(trmindx),sl3,sb3,se3)
                  fldnam=tname(2,trcindx)(sb1:se1)//'  Change: '//
     &                   tbterm(trmindx)(sb3:se3)//' '//wkstr(sb2:se2)
                  vindx=trmindx
                end if
                trmindx = trmindx + 1
  30          continue
            end if
            trcindx = trcindx + 1
  40      continue
        endif
c
c-----------------------------------------------------------------------
c  QG field classification.
c-----------------------------------------------------------------------
c
      elseif(class.eq.qgclass) then
        if(idfld.eq.qgmpsi) then
          fldnam='Streamfunction'
          varnam='stream'
        elseif(idfld.eq.qgapsi) then
          fldnam='Analized Streamfunction'
          varnam='rfstrm'
        elseif(idfld.eq.qgmvor) then
          fldnam='Vorticity'
          varnam='vort'
        elseif(idfld.eq.qgavor) then
          fldnam='Analized Vorticity'
          varnam='rfvort'
        elseif(idfld.eq.qgmsse) then
          fldnam='Sea Surface Elevation (cm)'
        elseif(idfld.eq.qgdent) then
          fldnam='Top Density'
          varnam='tden'
        elseif(idfld.eq.qgdenb) then
          fldnam='Bottom Density'
          varnam='bden'
        elseif(idfld.eq.qgpvec) then
          fldnam='Horizontal Velocity (cm/s)'
        elseif ((idfld.eq.qgvnrm).or.(idfld.eq.qgpvnm)) then
          fldnam='Normal Horizontal Velocity component (cm/s)'
        elseif ((idfld.eq.qgvtng).or.(idfld.eq.qgpvtn)) then
          fldnam='Tangential Horizontal Velocity component (cm/s)'
        elseif(idfld.eq.qguvel) then
          fldnam='Zonal Velocity component (cm/s)'
        elseif(idfld.eq.qgvvel) then
          fldnam='Meridional Velocity component (cm/s)'
        elseif(idfld.eq.qgvmag) then
          fldnam='Horizontal Velocity Magnitude (cm/s)'
        elseif(idfld.eq.qgvvec) then
          fldnam='Horizontal Velocity (cm/s)'
        elseif(idfld.eq.qgdano) then
          call set_units ('kilogram meter-3',grfflg,wkstr)
          call length (wkstr,sl1,sb1,se1)
          fldnam='Density Anomaly'//' '//wkstr(sb1:se1)
        elseif(idfld.eq.qgsnds) then
          fldnam='Sound Speed (m/s)'
        elseif(idfld.eq.qgdynh) then
          fldnam='Dynamic Height'
          varnam='dynht'
        elseif(idfld.eq.qgp2dh) then
          fldnam='Dynamic Height (dyn m)'
        elseif(idfld.eq.qgdhmn) then
          fldnam='Dynamic Height Mean'
          varnam='dynhtmean'
        elseif(idfld.eq.qgdher) then
          fldnam='Dynamic Height Error'
          varnam='dynhterr'
        elseif(idfld.eq.qgdhrs) then
          fldnam='Dynamic Height RMS Deviation (dyn m)'
          varnam='dynhtrmsdev'
        elseif(idfld.eq.qgdhsr) then
          fldnam='Scaled Dynamic Height Error'
        elseif(idfld.eq.qgmsss) then
          fldnam='Sea Surface Salinity (PSU)'
        elseif(idfld.eq.qgsigt) then
          varnam='sigma-t'
          call set_units ('kilogram meter-3',grfflg,wkstr)
          call length (wkstr,sl1,sb1,se1)
#if !defined medchr & !defined lowchr
          if (grfflg) then
            fldnam=esc_char//'PGL'//esc_char//'R'//esc_char//'PRUB'
     &             //esc_char//'t'//esc_char//'N'//esc_char//' '//
     &            wkstr(sb1:se1)
          else
            fldnam='Sigma-t'//' '//wkstr(sb1:se1)
          endif
# else
          fldnam='Sigma-t'//' '//wkstr(sb1:se1)
#endif
        elseif(idfld.eq.qgmmlb) then
          fldnam='SBL Buoyancy'
          varnam='sbl_buoy'
        elseif(idfld.eq.qgsblt) then
          fldnam='SBL temperature'
          varnam='sbl_temp'
        elseif(idfld.eq.qgsbls) then
          fldnam='SBL Salinity (PSU)'
        elseif(idfld.eq.qgsblb) then
          call set_units ('meter second-2',grfflg,wkstr)
          call length (wkstr,sl1,sb1,se1)
          fldnam='SBL Buoyancy'//' '//wkstr(sb1:se1)
        elseif(idfld.eq.qgsble) then
          fldnam='Entrainment Rate'
        elseif(idfld.eq.qgsblw) then
          fldnam='SBL vertical velocity'
          varnam='sbl_wvel'
        elseif(idfld.eq.qgsblh) then
          fldnam='Mixed Layer Depth'
          varnam='ml_depth'
        elseif(idfld.eq.qgmmlt) then
          fldnam='Mixed Layer Temperature'
          varnam='ml_temp'
        elseif(idfld.eq.qgmsst) then
          fldnam='Sea Surface Temperature'
          varnam='surf_temp'
        elseif(idfld.eq.qgsblm) then
          fldnam='Equilibrium Depth'
          varnam='eq_depth'
        elseif(idfld.eq.qgevxc) then
          fldnam='Surface Ekman Zonal Velocity'
          varnam='Ek_vel'
          vindx=1
        elseif(idfld.eq.qgevyc) then
          fldnam='Surface Ekman Meridional Velocity'
          varnam='Ek_vel'
          vindx=2
        elseif(idfld.eq.qgemag) then
          fldnam='Ekman velocity vector magnitude (m/s)'
        elseif(idfld.eq.qgevec) then
          fldnam='Horizontal Ekman Velocity (cm/s)'
        elseif(idfld.eq.qgevnm) then
          fldnam='Normal Horizontal Ekman Velocity component (cm/s)'
        elseif(idfld.eq.qgevtn) then
          fldnam='Tangential Horizontal Ekman Velocity component (cm/s)'
        elseif(idfld.eq.qgwsxc) then
          fldnam='Surface Zonal Wind Stress'
          varnam='wind_stress'
          vindx=1
        elseif(idfld.eq.qgwsyc) then
          fldnam='Surface Meridional Wind Stress'
          varnam='wind_stress'
          vindx=2
        elseif(idfld.eq.qgwsvm) then
          fldnam='Horizontal Wind Stress vector magnitude (Pa)'
        elseif(idfld.eq.qgwshv) then
          fldnam='Horizontal Wind Stress (Pa)'
        elseif(idfld.eq.qgfxep) then
          call set_units ('Watt meter-2',grfflg,wkstr)
          call length (wkstr,sl1,sb1,se1)
          fldnam='Water Flux: E-P'//' '//wkstr(sb1:se1)
        elseif(idfld.eq.qgfxby) then
          call set_units ('Watt meter-2',grfflg,wkstr)
          call length (wkstr,sl1,sb1,se1)
          fldnam='Buoyancy Flux'//' '//wkstr(sb1:se1)
        elseif(idfld.eq.qgfxth) then
          call set_units ('Watt meter-2',grfflg,wkstr)
          call length (wkstr,sl1,sb1,se1)
          fldnam='Total Heat Flux'//' '//wkstr(sb1:se1)
        elseif(idfld.eq.qgfxlh) then
          call set_units ('Watt meter-2',grfflg,wkstr)
          call length (wkstr,sl1,sb1,se1)
          fldnam='Latent Heat Flux'//' '//wkstr(sb1:se1)
        elseif(idfld.eq.qgfxsh) then
          call set_units ('Watt meter-2',grfflg,wkstr)
          call length (wkstr,sl1,sb1,se1)
          fldnam='Sensible Heat Flux'//' '//wkstr(sb1:se1)
        elseif(idfld.eq.qgfxsw) then
          call set_units ('Watt meter-2',grfflg,wkstr)
          call length (wkstr,sl1,sb1,se1)
          fldnam='Short Wave Radiation'//' '//wkstr(sb1:se1)
        elseif(idfld.eq.qgfxlw) then
          call set_units ('Watt meter-2',grfflg,wkstr)
          call length (wkstr,sl1,sb1,se1)
          fldnam='Long Wave Radiation'//' '//wkstr(sb1:se1)
        elseif(idfld.eq.qgfxns) then
          call set_units ('Watt meter-2',grfflg,wkstr)
          call length (wkstr,sl1,sb1,se1)
          fldnam='Net Surface Heat Flux'//' '//wkstr(sb1:se1)
        elseif(idfld.eq.qgfxah) then
          call set_units ('Watt meter-2',grfflg,wkstr)
          call length (wkstr,sl1,sb1,se1)
          fldnam='Accumulated Heat Flux'//' '//wkstr(sb1:se1)
        elseif(idfld.eq.qgwvzt) then
          fldnam='QG Vertical Velocity at PE tracer points'
        elseif(idfld.eq.qgwvzv) then
          fldnam='QG Vertical Velocity at PE velocity points'
        elseif(idfld.eq.qgbath) then
          fldnam='Bathymetry'
          varnam='bath'
        elseif(idfld.eq.qgmask) then
          fldnam='Land/Sea Mask'
          varnam='mask'
        elseif(idfld.eq.qgsnm) then
          fldnam='Surface of No-Motion (m)'
          varnam='surfnm'
        elseif(idfld.eq.qgsnmm) then
          fldnam='Mean Surface of No-Motion (m)'
          varnam='surfnmmean'
        elseif(idfld.eq.qgsnmr) then
          fldnam='Surface of No-Motion Observation Error (m)'
          varnam='surfnmerr'
        elseif(idfld.eq.qgsnms) then
          fldnam='Surface of No-Motion RMS Deviation (m)'
          varnam='surfnmrmsdev'
        elseif(idfld.eq.qgltrk) then
          fldnam='Lagrangian Trajectories'
        elseif(idfld.eq.qghsta) then
          fldnam='Hydrographic Stations'
        else
          fnd     = .false.
          trcindx = 1
          do 50 while ( (.not.fnd) .and. (trcindx.le.maxtrc) )
            if (idfld.eq.qtid(trcindx)) then
              fnd = .true.
              call length (tname(1,trcindx),sl1,sb1,se1)
              varnam = tname(1,trcindx)(sb1:se1)
              call length (tname(2,trcindx),sl1,sb1,se1)
              call set_units (tname(3,trcindx),grfflg,wkstr)
              call length (wkstr,sl2,sb2,se2)
              fldnam=tname(2,trcindx)(sb1:se1)//' '//wkstr(sb2:se2)
             elseif (idfld.eq.qterid(trcindx)) then
              fnd = .true.
              call length (tname(1,trcindx),sl1,sb1,se1)
              varnam = tname(1,trcindx)(sb1:se1)//'err'
              call length (tname(2,trcindx),sl1,sb1,se1)
              fldnam=tname(2,trcindx)(sb1:se1)//
     &               ' Observation Error'
             elseif (idfld.eq.qtmnid(trcindx)) then
              fnd = .true.
              call length (tname(1,trcindx),sl1,sb1,se1)
              varnam = tname(1,trcindx)(sb1:se1)//'mean'
              call length (tname(2,trcindx),sl1,sb1,se1)
              fldnam='Mean '//tname(2,trcindx)(sb1:se1)
             elseif (idfld.eq.qserid(trcindx)) then
              fnd = .true.
              call length (tname(1,trcindx),sl1,sb1,se1)
              varnam = tname(1,trcindx)(sb1:se1)//'err'
              call length (tname(2,trcindx),sl1,sb1,se1)
              fldnam=tname(2,trcindx)(sb1:se1)//
     &               ' Scaled Error'
             elseif (idfld.eq.qrmsid(trcindx)) then
              fnd = .true.
              call length (tname(1,trcindx),sl1,sb1,se1)
              varnam = tname(1,trcindx)(sb1:se1)//'rmsdev'
              call length (tname(2,trcindx),sl1,sb1,se1)
              call set_units (tname(3,trcindx),grfflg,wkstr)
              call length (wkstr,sl2,sb2,se2)
              fldnam=tname(2,trcindx)(sb1:se1)//
     &               ' RMS Deviation '//wkstr(sb2:se2)
            end if
            trcindx = trcindx + 1
  50      continue
        endif
      endif
      return
      end
