      subroutine interp32 (im,jm,km,f2,ncinpid,ncvarid,idfld,class,level
     &                                                           ,spv,f)
c
c=======================================================================
c                                                                    ===
c  This routine interpolates a 3D field to the requested flat level. ===
c                                                                    ===
c  Input:                                                            ===
c                                                                    ===
c     IM       Number of x-grid points.           (integer)          ===
c     JM       Number of y-grid points.           (integer)          ===
c     KM       Number of z-grid points.           (integer)          ===
c     F2       Volume field.                      (real array)       ===
c     NCINPID  NetCDF ID for input file.          (integer)          ===
c     NCVARID  NetCDF ID for field.               (integer)          ===
c     IDFLD    identification of field to plot.   (integer)          ===
c     LEVEL    depth level to interpolate.        (integer)          ===
c     CLASS    Type of netCDF file.               (integer)          ===
c     SPV      missing data/fill data value.      (real)             ===
c                                                                    ===
c  Output:                                                           ===
c                                                                    ===
c     F        interpolated field.                (real array)       ===
c                                                                    ===
c  Calls:                                                            ===
c                                                                    ===
c     GET_3DPOS, LINTRP_SP                                           ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <param.h>
#ifdef vertavg
# include <inpcdf.h>
# include <pefldid.h>
#endif
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer class,idfld,i,ip,im,j,jm,k,km,level,ncinpid,ncvarid,np
      real    spv,z
      real    f(im,jm),f2(im,jm,km)
      real    fk(nk),xpos(nv),ypos(nv),zk(nk),zpos(nv)
c
c=======================================================================
c  Begin Executable code.
c=======================================================================
c
c-----------------------------------------------------------------------
c  Read in 3D positions.
c-----------------------------------------------------------------------
c
      np = im*jm*km
      call get_3dpos (xpos,ypos,zpos,np,ncinpid,ncvarid,idfld,class)
c
c-----------------------------------------------------------------------
c  Linearly interpolate to requested depth.
c-----------------------------------------------------------------------
c
      z = abs(float(level))
c
      do 20 j = 1, jm
      do 20 i = 1, im
         do 10 k = 1, km
            ip = i + (j-1)*im + (k-1)*im*jm
            zk(k) = abs(zpos(ip))
            fk(k) = f2(i,j,k)
 10      continue
#ifndef vertavg
         call lintrp_sp (km,zk,fk,spv,1,z,f(i,j))
#else
         if ((class.eq.peclass).and.(idfld.ne.pvfvec).and.
     &       (idfld.eq.pvfmag).and.(idfld.ne.peuflt).and.
     &       (idfld.ne.pevflt)) then
            call pevintsp (km,zk,fk,spv,1,z,f(i,j))
         else
            call qgvintsp (km,zk,fk,spv,1,z,f(i,j))
         end if
#endif
 20   continue
c
      return
      end
