      function intrpindx(f,km,spv,kstr,kend)
c
c=======================================================================
c                                                                    ===
c  This routine checks the contents of profile  F(z) and extracts    ===
c  the starting and ending indices in such a way that masked data    ===
c  will excluded and either end. This routine is used in the high    ===
c  order vertical interpolation of cross-sections.                   ===
c                                                                    ===
c  On Input                                                          ===
c                                                                    ===
c     F            field vertical profile (real array).              ===
c     KM           number of points in F (integer).                  ===
c     SPV          field special value used during checking (real).  ===
c                                                                    ===
c  On Output                                                         ===
c                                                                    ===
c     KSTR         starting index (integer).                         ===
c     KEND         ending index (integer).                           ===
c     INTRPINDX    check status (integer):                           ===
c                  INTRPINDX=0  successful extraction.               ===
c                  INTERINDX=1  all profile is masked.               ===
c                  INTERINDX=2  only one or two points viable.       ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer k,kend,km,kstr
      integer intrpindx
      real f(km),spv
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
      intrpindx=1
      kstr=km
      kend=km
c
c  Get starting index.
c
      do 10 k=1,km
c        if(f(k).ne.spv) then
        if(f(k).lt.spv) then
          kstr=k
          goto 20
        endif
  10  continue
  20  continue
      if(kstr.eq.km) return
c
c  Get ending index.
c
      do 30 k=km,kstr+1,-1
c        if(f(k).ne.spv) then
        if(f(k).lt.spv) then
          kend=k
          goto 40
        endif
  30  continue
  40  continue
c
c  Check extracted indices.
c
      if((kend-kstr).le.1) then
        intrpindx=2
      else
        intrpindx=0
      endif
      return
      end
