      subroutine mskscl(f,np,class,ncinpid,idfld,spv,spval)
c
c=======================================================================
c                                                                    ===
c  This routine masks or scales current field F.                     ===
c                                                                    ===
c  On Input:                                                         ===
c                                                                    ===
c     F        field to scale and/or mask (real array).              ===
c     NP       number of points in field F (integer).                ===
c     CLASS    current field classification (integer; PE or QG).     ===
c     NCINPID  NetCDF ID for input file (integer).                   ===
c     IDFLD    identification of field to plot (integer).            ===
c     SPV      missing data/fill data value (real).                  ===
c     SPVAL    mask special value (real).                            ===
c                                                                    ===
c  On Output:                                                        ===
c                                                                    ===
c     F        masked and/or scale field (real array).               ===
c                                                                    ===
c  Required common blocks:                                           ===
c                                                                    ===
c     FMASK, NDIMEN, NETCDF, INPCDF, PEFLDID, PLTIO                  ===
c                                                                    ===
c  Calls:                                                            ===
c                                                                    ===
c     NCDINQ, NCDID, NCVGT, NCVINQ  (NetCDF library)                 ===
c     EXITUS, LNBLK                                                  ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <param.h>
#include <pconst.h>
#include <fmask.h>
#include <ndimen.h>
#include <netcdf.inc>
#include <inpcdf.h>
#include <pefldid.h>
#include <pltio.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer class,idfld,ip,k,lenvar,n,ncinpid,np,nvatts,nvdims,trcindx
     &        ,trmindx,vartyp
      integer dims(maxvdims),vdims(maxvdims)
      integer lnblk
      logical fnd
      real scale,spv,spval
      real f(np)
      character*128 varnam
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c-----------------------------------------------------------------------
c  Scale fields.
c-----------------------------------------------------------------------
c
      if(class.eq.peclass) then
c
c  Scale transport streamfunction to Sverdrups.
c
        if (idfld.eq.pepbar) then
          scale=c1em12
          do 10 n=1,np
            if(f(n).ne.spv) f(n)=scale*f(n)
  10      continue
c
c  Scale vertical velocity to m/d.
c
        elseif ((idfld.eq.pewvst).or.(idfld.eq.pewvzt).or.
     &          (idfld.eq.pewvsv).or.(idfld.eq.pewvzv)) then
          scale=day2sec*cm2m
          do 20 n=1,np
            if(f(n).ne.spv) f(n)=scale*f(n)
  20      continue
c
c  Scale mixed-layer depth or tidal surface elevation to m.
c
c        elseif ((idfld.eq.pemldh).or.(idfld.eq.pemxld).or.
c     &          (idfld.eq.petdsf)) then
        elseif (idfld.eq.petdsf) then
          scale=cm2m
          do 30 n=1,np
            if(f(n).ne.spv) f(n)=scale*f(n)
  30      continue
c
c  Convert kinematic surface pressure (cm^2/s^2) to surface elevation (m).
c
        elseif (idfld.eq.pehspr) then
          scale=cm2m*cm2m/grav
          do 40 n=1,np
            if(f(n).ne.spv) f(n)=scale*f(n)
  40      continue
        endif
      endif
c
c-----------------------------------------------------------------------
c  Mask field, if appropriate.
c-----------------------------------------------------------------------
c
c  Determine land/sea mask field.
c
      if(class.eq.peclass) then
        if((idfld.eq.pecden).or.(idfld.eq.pedano).or.
     *     (idfld.eq.pesigt).or.(idfld.eq.pesnds).or.
     *     (idfld.eq.penh4p).or.(idfld.eq.peno3p).or.
     *     (idfld.eq.pezoog).or.(idfld.eq.peshfx).or.
     *     (idfld.eq.peswfx).or.(idfld.eq.pesrad).or.
     *     (idfld.eq.pebuoy).or.(idfld.eq.pepbar).or.
     *     (idfld.eq.pepoer).or.(idfld.eq.pepfer).or.
     *     (idfld.eq.pesprs).or.(idfld.eq.pebath)) then
          varnam='landt'
          mskval=1
        else
          fnd     = .false.
          trcindx = 1
          do 60 while ( (.not.fnd) .and. (trcindx.le.maxtrc) )
            if ((idfld.eq.tid(trcindx)).or.(idfld.eq.toerid(trcindx))
     &                              .or.(idfld.eq.tferid(trcindx))) then
              fnd = .true.
             else
              trmindx = 1
              do 50 while ( (.not.fnd) .and. (trmindx.le.tterms) )
                if (idfld.eq.tbalid(trmindx,trcindx)) then
                  fnd = .true.
                end if
                trmindx = trmindx + 1
  50          continue
            end if
            trcindx = trcindx + 1
  60      continue
          if (fnd) then
            varnam='landt'
            mskval=1
           else
            varnam='landv'
            mskval=vmskvl
          endif
        endif
      elseif(class.eq.qgclass) then
        varnam='mask'
        mskval=1
      endif
c
c  Inquire if mask field is available.
c
      if(mskinp1.and.(ncinpid.eq.ncinp1id)) then
        msk=.true.
      elseif(mskinp2.and.(ncinpid.eq.ncinp2id)) then
        msk=.true.
      else
        msk=.false.
      endif
c
c  Inquire information about mask field.
c
      if(msk) then
        lenvar=lnblk(varnam,len(varnam))
        varid=ncvid(ncinpid,varnam(1:lenvar),rcode)
        if(rcode.eq.0) then
          call ncvinq(ncinpid,varid,varnam,vartyp,nvdims,vdims,nvatts,
     *                rcode)
          if(rcode.eq.0) then
            lenvar=lnblk(varnam,len(varnam))
            do 70 n=1,nvdims
              call ncdinq(ncinpid,vdims(n),dimnam,dims(n),rcode)
              if(rcode.ne.0) then
                write(stdout,900) dimnam,varnam(1:lenvar)
                call exitus('MSKSCL')
              endif
              start(n)=1
              count(n)=dims(n)
  70        continue
          else
            write(stdout,901) varnam(1:lenvar)
            call exitus('MSKSCL')
          endif
        else
          write(stdout,902) varnam(1:lenvar)
          call exitus('MSKSCL')
        endif
c
c   Read in land/sea mask data.
c
        call ncvgt(ncinpid,varid,start,count,mask,rcode)
        if(rcode.ne.0) then
          write(stdout,903) varnam(1:lenvar)
          call exitus('MSKSCL')
        endif
c
c  Mask 2D or 3D field, if appropriated.
c
        if(msk3d) then
          do 80 k=1,km
          do 80 n=1,im*jm
            ip=n+(k-1)*im*jm
            if(mask(n).ne.mskval) f(ip)=spval
  80      continue
        else
          do 90 n=1,np
            if(mask(n).ne.mskval) f(n)=spval
  90      continue
        endif
      endif
c
 900  format(/' MSKSCL - error while inquiring dimension: ',a,2x,
     *        ' for variable: ',a)
 901  format(/' MSKSCL - error while inquiring information for'
     *        ' variable: ',a)
 902  format(/' MSKSCL - cannot find variable: ',a)
 903  format(/' MSKSCL - error while reading variable: ',a)
      return
      end
