      subroutine ncvget(ncid,varid,start,count,valsgl,rcode)
c
c=======================================================================
c                                                                    ===
c  This subroutine is an interphase to  NetCDF  routine  NCVGT.  It  ===
c  reads a hyperslab of values.  If the values are stored in double  ===
c  precision, it converts them to single precision.                  ===
c                                                                    ===
c  On Input:                                                         ===
c                                                                    ===
c     NCID    NetCDF ID for input file (integer).                    ===
c     VARID   NetCDF varaible ID (integer).                          ===
c     START   a vector specifying the multidimensional index of the  ===
c             corner of the hyperslab where the first of the data    ===
c             values will read (integer array).                      ===
c     COUNT   a vector specifying the multidimensional edge lengths  ===
c             from the corner of the hyperslab where the first of    ===
c             the data values will be read (integer array).          ===
c                                                                    ===
c  On Output:                                                        ===
c                                                                    ===
c     VALSGL  read values (real array; single precision).            ===
c     RCODE   returned NetCDF error code (integer).                  ===
c                                                                    ===
c  CALLS:  EXITUS, LNBLK, NCVGET, NCVINQ                             ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <param.h>
#include <netcdf.inc>
#include <pltio.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer lenvar,n,ncid,npts,nvatts,nvdims,rcode,varid,vartyp
      integer count(*),start(*),vdims(maxvdims)
      integer lnblk
      real   valsgl(*)
      double precision valdbl(nv)
      character*128 varnam
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c  Inquire varaible type.
c
      call ncvinq(ncid,varid,varnam,vartyp,nvdims,vdims,nvatts,rcode)
      lenvar=lnblk(varnam,len(varnam))
      if(rcode.ne.0) then
        write(stdout,900) varnam(1:lenvar)
        call exitus('NCVGET')
      endif
c
c-----------------------------------------------------------------------
c  Read single precision data.
c-----------------------------------------------------------------------
c
      if(vartyp.eq.ncfloat) then
        call ncvgt(ncid,varid,start,count,valsgl,rcode)
        if(rcode.ne.0) then
          write(stdout,901) 'single',varnam(1:lenvar)
        endif
c
c-----------------------------------------------------------------------
c  Read double precision data.
c-----------------------------------------------------------------------
c
      elseif(vartyp.eq.ncdouble) then
        call ncvgt(ncid,varid,start,count,valdbl,rcode)
        if(rcode.ne.0) then
          write(stdout,901) 'double',varnam
        endif
c
c  Convert to single precision.
c
        npts=1
        do 10 n=1,nvdims
          npts=npts*count(n)
  10    continue
        do 20 n=1,npts
          valsgl(n)=sngl(valdbl(n))
  20    continue
      endif
c
 900  format(/' NCVGET - error while inquiring information for',
     *        ' variable: ',a)
 901  format(/' NCVGET - error while reading ',a,' precision',
     *        ' variable: ',a)
      return
      end
