      subroutine ncvget1(ncid,varid,mindex,valsgl,rcode)
c
c=======================================================================
c                                                                    ===
c  This subroutine is an interphase to  NetCDF  routine  NCVGT1. It  ===
c  reads a single data value.   If the  value is  stored in  double  ===
c  precision, it converts it to single precision.                    ===
c                                                                    ===
c  On Input:                                                         ===
c                                                                    ===
c     NCID    NetCDF ID for input file (integer).                    ===
c     VARID   NetCDF varaible ID (integer).                          ===
c     MINDEX  the multidimensional index of the data value to be     ===
c             read (integer).                                        ===
c                                                                    ===
c  On Output:                                                        ===
c                                                                    ===
c     VALSGL  read values (real; single precision).                  ===
c     RCODE   returned NetCDF error code (integer).                  ===
c                                                                    ===
c  CALLS:  EXITUS, LNBLK, NCVGET1, NCVINQ                            ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <netcdf.inc>
#include <pltio.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer lenvar,ncid,nvatts,nvdims,rcode,varid,vartyp
      integer mindex(*),vdims(maxvdims)
      integer lnblk
      real   valsgl
      double precision valdbl
      character*128 varnam
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c  Inquire variable type.
c
      call ncvinq(ncid,varid,varnam,vartyp,nvdims,vdims,nvatts,rcode)
      lenvar=lnblk(varnam,len(varnam))
      if(rcode.ne.0) then
        write(stdout,900) varnam(1:lenvar)
        call exitus('NCVGET')
      endif
c
c-----------------------------------------------------------------------
c  Read single precision data.
c-----------------------------------------------------------------------
c
      if(vartyp.eq.ncfloat) then
        call ncvgt1(ncid,varid,mindex,valsgl,rcode)
        if(rcode.ne.0) then
          write(stdout,901) 'single',varnam(1:lenvar)
        endif
c
c-----------------------------------------------------------------------
c  Read double precision data.
c-----------------------------------------------------------------------
c
      elseif(vartyp.eq.ncdouble) then
        call ncvgt1(ncid,varid,mindex,valdbl,rcode)
        if(rcode.ne.0) then
          write(stdout,901) 'double',varnam
        endif
c
c  Convert to single precision.
c
        valsgl=sngl(valdbl)
      endif
c
 900  format(/' NCVGET - error while inquiring information for',
     *        ' variable: ',a)
 901  format(/' NCVGET - error while reading ',a,' precision',
     *        ' variable: ',a)
      return
      end
