      subroutine opencdf(inp1name,inp2name)
c
c=======================================================================
c                                                                    ===
c  This routine opens existing primary and secondary (if any) NetCDF ===
c  files for data access  and reads in necessary information for the ===
c  plotting of the User requested fields.                            ===
c                                                                    ===
c  On Input:                                                         ===
c                                                                    ===
c     INP1NAME   primary NetCDF filename (character)                 ===
c     INP2NAME   secondary NetCDF filename (character)               ===
c                                                                    ===
c  Required common blocks:                                           ===
c                                                                    ===
c     DOMDAT, INPCDF, NETCDF, PLTFLD, PLTIO, SCALES, VERNUM          ===
c                                                                    ===
c  Calls:                                                            ===
c                                                                    ===
c     NCAGTC, NCAINQ, NCDID, NCDINQ, NCOPN, NCPOPT, NCVGT, NCVGT1,   ===
c     NCVID  (NetCDF library)                                        ===
c     EXITUS, NCVGET, NCVGET1, WHAT_FLDS                             ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <param.h>
#include <pconst.h>
#include <domdat.h>
#include <fmask.h>
#include <hybrid.h>
#include <inpcdf.h>
#include <ndimen.h>
#include <netcdf.inc>
#include <pltfld.h>
#include <pltio.h>
#include <scales.h>
#include <zdat.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer maxvar
      parameter (maxvar=150)
c
      logical fndx,fndy,scwdx,scwdy,timevar
      integer attype,dimid,dimsiz,iday,ihr,imi,imo,iptr,isec,k,lendim,
     &        lenvar,n,ndims,ngatts,nvars,nvatts,recdim,rel1,rel2,sbgn,
     &        send,slen,vartyp,ver1,ver2,kmflat
      integer mora(12),nvdims(maxvar),vdims(6,maxvar)
      integer lnblk
      real scle,vdum
      double precision dvdum
      character*128  vstr,wkstr
      character*128  varnam(maxvar)
      character*(*) inp1name,inp2name
c
      data mora/31,28,31,30,31,30,31,31,30,31,30,31/
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c  Open primary input NetCDF file.
c
      call ncpopt(ncverbos)
      ncinp1id=ncopn(inp1name,ncnowrit,rcode)
      if(rcode.ne.0) then
        write(stdout,900) inp1name
        call exitus('OPENCDF')
      endif
c
c  Open secondary input NetCDF file, if any.
c
      if((iref.eq.2).or.(iref.eq.3)) then
        ncinp2id=ncopn(inp2name,ncnowrit,rcode)
        if(rcode.ne.0) then
          write(stdout,900) inp2name
          call exitus('OPENCDF')
        endif
      endif
c
c  Initialize special flags.
c
      fndx  = .false.
      fndy  = .false.
      scwdx = .false.
      scwdy = .false.
c
c  Inquire and get input "type" global attribute.
c
      call ncainq(ncinp1id,ncglobal,'type',attype,ltype1,rcode)
      if(rcode.eq.0) then
        call ncagtc(ncinp1id,ncglobal,'type',type1,ltype1,rcode)
        if(rcode.ne.0) then
          write(stdout,901) 'type (global)',inp1name
          call exitus('OPENCDF')
        endif
      else
        write(stdout,902) 'type (global)',inp1name
        call exitus('OPENCDF')
      endif
      if((iref.eq.2).or.(iref.eq.3)) then
        call ncainq(ncinp2id,ncglobal,'type',attype,ltype2,rcode)
        if(rcode.eq.0) then
          call ncagtc(ncinp2id,ncglobal,'type',type2,ltype2,rcode)
          if(rcode.ne.0) then
            write(stdout,901) 'type (global)',inp2name
            call exitus('OPENCDF')
          endif
        else
          write(stdout,902) 'type (global)',inp2name
          call exitus('OPENCDF')
        endif
      endif
c
c  Inquire and get input "version" global attribute.
c
      call ncainq(ncinp1id,ncglobal,'version',attype,lenvar,rcode)
      if(rcode.eq.0) then
        if (attype.eq.ncfloat) then
           call ncagt (ncinp1id,ncglobal,'version',vdum,rcode)
         elseif (attype.eq.ncdouble) then
           call ncagt (ncinp1id,ncglobal,'version',dvdum,rcode)
           vdum = real(dvdum)
         else
           call ncagtc(ncinp1id,ncglobal,'version',vstr,lenvar,rcode)
        end if
        if(rcode.ne.0) then
          write(stdout,901) 'version (global)',inp1name
          call exitus('OPENCDF')
        endif
        if ((attype.ne.ncfloat).and.(attype.ne.ncdouble)) then
           call vernum (vstr,ver1,rel1)
         else
           ver1 = int(vdum)
           rel1 = nint((vdum-float(ver1))*c100)
        end if
      else
        write(stdout,902) 'version (global)',inp1name
        call exitus('OPENCDF')
      endif
c
      if((iref.eq.2).or.(iref.eq.3)) then
        call ncainq(ncinp2id,ncglobal,'version',attype,lenvar,rcode)
        if(rcode.eq.0) then
          if (attype.eq.ncfloat) then
             call ncagt (ncinp2id,ncglobal,'version',vdum,rcode)
           elseif (attype.eq.ncdouble) then
             call ncagt (ncinp2id,ncglobal,'version',dvdum,rcode)
             vdum = real(dvdum)
           else
             call ncagtc(ncinp2id,ncglobal,'version',vstr,lenvar,rcode)
          end if
          if(rcode.ne.0) then
            write(stdout,901) 'version (global)',inp2name
            call exitus('OPENCDF')
          endif
          if ((attype.ne.ncfloat).and.(attype.ne.ncdouble)) then
             call vernum (vstr,ver2,rel2)
           else
             ver2 = int(vdum)
             rel2 = nint((vdum-float(ver2))*c100)
          end if
        else
          write(stdout,902) 'version (global)',inp2name
          call exitus('OPENCDF')
        endif
      endif
c
c-----------------------------------------------------------------------
c  Inquire about the contents of input NetCDF file:  Inquire about the
c  dimensions and variables.
c-----------------------------------------------------------------------
c
      call ncinq(ncinp1id,ndims,nvars,ngatts,recdim,rcode)
      if(rcode.eq.0) then
c
c  Inquire about dimensions.
c
        do 10 n=1,ndims
          dimid=n
          call ncdinq(ncinp1id,dimid,dimnam,dimsiz,rcode)
          if(rcode.ne.0) then
            write(stdout,903) n,inp1name
            call exitus('OPENCDF')
          endif
          lendim=lnblk(dimnam,len(dimnam))
          if((dimnam(1:lendim).eq.'lon').or.
     *       (dimnam(1:lendim).eq.'tlon').or.
     *       (dimnam(1:lendim).eq.'vlon')) then
            im=dimsiz
          elseif((dimnam(1:lendim).eq.'lat').or.
     *           (dimnam(1:lendim).eq.'tlat').or.
     *           (dimnam(1:lendim).eq.'vlat')) then
            jm=dimsiz
          elseif((dimnam(1:lendim).eq.'level').or.
     *           (dimnam(1:lendim).eq.'level1')) then
            km=dimsiz
          elseif (dimnam(1:lendim).eq.'flatlevel') then
            kmflat=dimsiz
          endif
  10    continue
        if((type1(1:ltype1).eq.'PE MODEL').or.
     *     (type1(1:ltype1).eq.'PE_INITIAL')) then
          pelev=km
        else
          qglev=km
        endif
c
c  Inquire about variables.
c
        do 20 n=1,nvars
          varid=n
          call ncvinq(ncinp1id,varid,varnam(n),vartyp,nvdims(n),
     *                vdims(1,n),nvatts,rcode)
          if(rcode.ne.0) then
            write(stdout,904) n,inp1name
            call exitus('OPENCDF')
          endif
  20    continue
      else
        write(stdout,905) inp1name
        call exitus('OPENCDF')
      endif
c
c-----------------------------------------------------------------------
c  Get information about various parameters: model domain and scales.
c  Scale to CGS when appropriate.
c-----------------------------------------------------------------------
c
      mskinp1=.false.
      timevar=.false.
      coord=0
      do 30 n=1,nvars
        varid=n
        lenvar=lnblk(varnam(n),len(varnam(n)))
        if(varnam(n)(1:lenvar).eq.'rlngd') then
          call ncvget1(ncinp1id,varid,1,clngd,rcode)
        elseif(varnam(n)(1:lenvar).eq.'rlatd') then
          call ncvget1(ncinp1id,varid,1,clatd,rcode)
        elseif(varnam(n)(1:lenvar).eq.'delx') then
          call ncvget1(ncinp1id,varid,1,delx,rcode)
          fndx = .true.
        elseif(varnam(n)(1:lenvar).eq.'dely') then
          call ncvget1(ncinp1id,varid,1,dely,rcode)
          fndy = .true.
        elseif(varnam(n)(1:lenvar).eq.'thetad') then
          call ncvget1(ncinp1id,varid,1,thetad,rcode)
        elseif(varnam(n)(1:lenvar).eq.'xbasin') then
          call ncvget1(ncinp1id,varid,1,xbasin,rcode)
        elseif(varnam(n)(1:lenvar).eq.'ybasin') then
          call ncvget1(ncinp1id,varid,1,ybasin,rcode)
        elseif((varnam(n)(1:lenvar).eq.'dx').or.
     *         (varnam(n)(1:lenvar).eq.'gridx')) then
          call ncvget1(ncinp1id,varid,1,dx,rcode)
          scwdx = .false.
        elseif((varnam(n)(1:lenvar).eq.'dy').or.
     *         (varnam(n)(1:lenvar).eq.'gridy')) then
          call ncvget1(ncinp1id,varid,1,dy,rcode)
          scwdy = .false.
        elseif(varnam(n)(1:lenvar).eq.'dxt') then
          start(1)=1
          count(1)=1
          call ncvget(ncinp1id,varid,start,count,dx,rcode)
          scwdx = .true.
        elseif(varnam(n)(1:lenvar).eq.'dyt') then
          start(1)=1
          count(1)=1
          call ncvget(ncinp1id,varid,start,count,dy,rcode)
          scwdy = .true.
        elseif(varnam(n)(1:lenvar).eq.'coord') then
          call ncvgt1(ncinp1id,varid,1,coord,rcode)
        elseif(varnam(n)(1:lenvar).eq.'dt') then
          call ncvget1(ncinp1id,varid,1,qgdt,rcode)
        elseif(varnam(n)(1:lenvar).eq.'dtts') then
          call ncvget1(ncinp1id,varid,1,dtts,rcode)
        elseif(varnam(n)(1:lenvar).eq.'dhor') then
          call ncvget1(ncinp1id,varid,1,dhor,rcode)
        elseif(varnam(n)(1:lenvar).eq.'ht') then
          call ncvget1(ncinp1id,varid,1,ht,rcode)
        elseif(varnam(n)(1:lenvar).eq.'v0') then
          call ncvget1(ncinp1id,varid,1,v0,rcode)
        elseif(varnam(n)(1:lenvar).eq.'r0') then
          call ncvget1(ncinp1id,varid,1,r0,rcode)
        elseif(varnam(n)(1:lenvar).eq.'t0') then
          call ncvget1(ncinp1id,varid,1,t0,rcode)
        elseif(varnam(n)(1:lenvar).eq.'time') then
          timevar=.true.
        elseif(varnam(n)(1:lenvar).eq.'time0') then
          call ncvget1(ncinp1id,varid,1,time0,rcode)
        elseif(varnam(n)(1:lenvar).eq.'iflag') then
          start(1)=8
          count(1)=1
          call ncvgt(ncinp1id,varid,start,count,kc,rcode)
          start(1)=9
          count(1)=1
          call ncvgt(ncinp1id,varid,start,count,idblsigma,rcode)
        elseif((varnam(n)(1:lenvar).eq.'landt').or.
     *         (varnam(n)(1:lenvar).eq.'landv').or.
     *         (varnam(n)(1:lenvar).eq.'mask')) then
          mskinp1=.true.
        endif
        if(rcode.ne.0) then
          write(stdout,906) varnam(n)(1:lenvar),inp1name
          call exitus('OPENCDF')
        endif
  30  continue
c
c  Ensure backward compatibility
c
      if (.not.(fndx.and.fndy)) then
         if (coord.ne.1) then
            delx = c0
            dely = c0
           else
            delx  = clngd
            dely  = clatd
            clngd = c0
            clatd = c0
         end if
      end if
c
c  Ensure PE grid spacing has "correct" units.
c
      if (scwdx.and.(coord.ne.0)) dx = dx/re*rad2deg
      if (scwdy.and.(coord.ne.0)) dy = dy/re*rad2deg
c
      if (scwdx.and.(coord.eq.0).and.
     &    ((ver1.lt.7).or.((ver1.eq.7).and.(rel1.lt.28)))) then
         dx = dx*cos(clatd*deg2rad)
      end if
c
c  Scale some relevant parameters.
c
      if ( ((type1(1:ltype1).eq.'PE MODEL').or.
     *      (type1(1:ltype1).eq.'PE ENERGY').or.
     *      (type1(1:ltype1).eq.'PE_INITIAL')).and.(coord.eq.0)) then
        scle=cm2m
      else
        scle=c1
      endif
      dx   = dx*scle
      dy   = dy*scle
      delx = delx*scle
      dely = dely*scle
      if(xbasin.eq.c0) xbasin=float(im-1)*dx
      if(ybasin.eq.c0) ybasin=float(jm-1)*dy
c
c  Ensure backward compatible masking.
c
      if ( ((type1(1:ltype1).eq.'PE MODEL').or.
     &      (type1(1:ltype1).eq.'PE ENERGY')) .and.
     &     ((ver1.lt.7).or.((ver1.eq.7).and.(rel1.lt.28)))) then
c
c     Actually, PFJL is keeping up with the current convention
c
c        vmskvl=0
        vmskvl=2
      else
        vmskvl=2
      endif
c
c-----------------------------------------------------------------------
c  Read in depths at the center of the flat vertical boxes.
c-----------------------------------------------------------------------
c
      if(type1(1:ltype1).eq.'PE_INITIAL') then
        scle=cm2m
      else
        scle=c1
      endif
c
      do 60 n=1,nvars
        varid=n
        lenvar=lnblk(varnam(n),len(varnam(n)))
        if((varnam(n)(1:lenvar).eq.'zqg').or.
     *     (varnam(n)(1:lenvar).eq.'refz')) then
          call ncdinq(ncinp1id,vdims(1,n),dimnam,dimsiz,rcode)
          if(rcode.eq.0) then
            start(1)=1
            count(1)=dimsiz
            call ncvget(ncinp1id,varid,start,count,zmid,rcode)
            if(rcode.ne.0) then
              write(stdout,906) varnam(n)(1:lenvar),inp1name
              call exitus('OPENCDF')
            endif
            do 40 k=1,dimsiz
              zmid(k)=abs(zmid(k))*scle
  40        continue
          else
            write(stdout,907) varnam(n)(1:lenvar),inp1name
            call exitus('OPENCDF')
          endif
        elseif (varnam(n)(1:lenvar).eq.'zout')  then
          call ncdinq(ncinp1id,vdims(2,n),dimnam,dimsiz,rcode)
          if(rcode.eq.0) then
            start(1)=zindx
            count(1)=1
            start(2)=1
            count(2)=dimsiz
            call ncvget(ncinp1id,varid,start,count,zmid,rcode)
            if(rcode.ne.0) then
              write(stdout,906) varnam(n)(1:lenvar),inp1name
              call exitus('OPENCDF')
            endif
            do 50 k=1,dimsiz
              zmid(k)=abs(zmid(k))*scle
  50        continue
          else
            write(stdout,907) varnam(n)(1:lenvar),inp1name
            call exitus('OPENCDF')
          endif
        elseif (varnam(n)(1:lenvar).eq.'zflat')  then
          call ncdinq(ncinp1id,vdims(2,n),dimnam,dimsiz,rcode)
          if(rcode.eq.0) then
            start(1)=zindx
            count(1)=1
            start(2)=1
            count(2)=dimsiz
            call ncvget(ncinp1id,varid,start,count,zflat,rcode)
            if(rcode.ne.0) then
              write(stdout,906) varnam(n)(1:lenvar),inp1name
              call exitus('OPENCDF')
            endif
            do 55 k=1,dimsiz
              zflat(k)=abs(zflat(k))
  55        continue
          else
            write(stdout,907) varnam(n)(1:lenvar),inp1name
            call exitus('OPENCDF')
          endif
        elseif(varnam(n)(1:lenvar).eq.'outlev') then
          call ncdinq(ncinp1id,vdims(1,n),dimnam,dimsiz,rcode)
          if(rcode.eq.0) then
            start(1)=1
            count(1)=dimsiz
            peoutlev=dimsiz
            call ncvgt(ncinp1id,varid,start,count,peout,rcode)
            if(rcode.ne.0) then
              write(stdout,906) varnam(n)(1:lenvar),inp1name
              call exitus('OPENCDF')
            endif
          else
            write(stdout,907) varnam(n)(1:lenvar),inp1name
            call exitus('OPENCDF')
          endif
        endif
  60  continue
c
c-----------------------------------------------------------------------
c  Inquire size of unlimited record dimension TIME and read its values.
c-----------------------------------------------------------------------
c
c      if(recdim.ne.-1) then
      if(recdim.gt.0) then
        call ncdinq(ncinp1id,recdim,dimnam,ntime1,rcode)
        if (rcode.ne.0) then
           write(stdout,907) 'time',inp1name
           call exitus ('OPENCDF')
        elseif (ntime1.gt.maxtim) then
           write(stdout,910) 'NTIME1',ntime1,'MAXTIM',maxtim,
     &                       'INPCDF.H'
           call exitus ('OPENCDF')
        endif
        varid=ncvid(ncinp1id,'time',rcode)
        if (rcode.eq.0) then
           start(1)=1
           count(1)=ntime1
           call ncvget(ncinp1id,varid,start,count,time1,rcode)
           if (rcode.ne.0) then
             write(stdout,906) 'time',inp1name
             call exitus('OPENCDF')
           endif
        else
           write(stdout,908) 'time',inp1name
           call exitus('OPENCDF')
        endif
      elseif(timevar) then
        varid=ncvid(ncinp1id,'time',rcode)
        if(rcode.eq.0) then
          call ncvget1(ncinp1id,varid,1,time1(1),rcode)
          if(rcode.ne.0) then
            write(stdout,906) 'time',inp1name
            call exitus('OPENCDF')
          endif
          ntime1=1
        else
          write(stdout,908) 'time',inp1name
          call exitus('OPENCDF')
        endif
      endif
c
c  Check newer PE models for absolute time.
c
      if (type1(1:ltype1).eq.'PE MODEL') then
         lenvar = len(wkstr)
         call ncagtc(ncinp1id,varid,'units',wkstr,lenvar,rcode)
         if (rcode.eq.0) then
            iptr = index (wkstr,'since')
            if (iptr.gt.0) then
               call length (wkstr,slen,sbgn,send)
               call length (wkstr((iptr+5):send),slen,sbgn,send)
               iptr = iptr + 4 + sbgn
               call length (wkstr,slen,sbgn,send)
               read (wkstr(iptr:send),'(i4,5(1x,i2))') iyear,imo,iday,
     &                                                ihr,imi,isec
               iptr = iptr + 4 + sbgn
               if (((mod(iyear,4).eq.0).and.(mod(iyear,100).ne.0)) .or.
     &             (mod(iyear,400).eq.0) ) then
                  mora(2) = 29
                else
                  mora(2) = 28
               endif
               do n = 1, (imo-1)
                  iday = iday + mora(n)
               enddo
               yday = ((float(isec)/60.0+float(imi))/60.0+float(ihr))
     &                /24.0 + float(iday)
            endif
         endif
      endif
c
c-----------------------------------------------------------------------
c  Read other time dimension variables.
c-----------------------------------------------------------------------
c
      if(type1(1:ltype1).eq.'PE FORCING') then
        do 70 n=1,nvars
          varid=n
          call ncvinq(ncinp1id,varid,varnam(n),vartyp,nvdims(n),
     *                vdims(1,n),nvatts,rcode)
          lenvar=lnblk(varnam(n),len(varnam(n)))
          if(varnam(n)(1:lenvar).eq.'smf_time') then
            call ncdinq(ncinp1id,vdims(1,n),dimnam,dimsiz,rcode)
            if (rcode.eq.0) then
               if (dimsiz.le.maxtim) then
                 start(1)=1
                 count(1)=dimsiz
                 call ncvget(ncinp1id,varid,start,count,t1smf,rcode)
                 nt1smf=dimsiz
                 if(rcode.ne.0) then
                   write(stdout,906) varnam(n)(1:lenvar),inp1name
                   call exitus('OPENCDF')
                 endif
               else
                 write(stdout,910) 'NT1SMF',nt1smf,'MAXTIM',maxtim,
     &                             'INPCDF.H'
                 call exitus ('OPENCDF')
               endif
            else
              write(stdout,907) varnam(n)(1:lenvar),inp1name
              call exitus('OPENCDF')
            endif
          elseif(varnam(n)(1:lenvar).eq.'shf_time') then
            call ncdinq(ncinp1id,vdims(1,n),dimnam,dimsiz,rcode)
            if(rcode.eq.0) then
               if (dimsiz.le.maxtim) then
                 start(1)=1
                 count(1)=dimsiz
                 call ncvget(ncinp1id,varid,start,count,t1shf,rcode)
                 nt1shf=dimsiz
                 if(rcode.ne.0) then
                   write(stdout,906) varnam(n)(1:lenvar),inp1name
                   call exitus('OPENCDF')
                 endif
               else
                 write(stdout,910) 'NT1SHF',nt1shf,'MAXTIM',maxtim,
     &                             'INPCDF.H'
                 call exitus ('OPENCDF')
               endif
            else
              write(stdout,907) varnam(n)(1:lenvar),inp1name
              call exitus('OPENCDF')
            endif
          elseif(varnam(n)(1:lenvar).eq.'swf_time') then
            call ncdinq(ncinp1id,vdims(1,n),dimnam,dimsiz,rcode)
            if (rcode.eq.0) then
               if (dimsiz.le.maxtim) then
                 start(1)=1
                 count(1)=dimsiz
                 call ncvget(ncinp1id,varid,start,count,t1swf,rcode)
                 nt1swf=dimsiz
                 if(rcode.ne.0) then
                   write(stdout,906) varnam(n)(1:lenvar),inp1name
                   call exitus('OPENCDF')
                 endif
               else
                 write(stdout,910) 'NT1SWF',nt1swf,'MAXTIM',maxtim,
     &                             'INPCDF.H'
                 call exitus ('OPENCDF')
               endif
            else
              write(stdout,907) varnam(n)(1:lenvar),inp1name
              call exitus('OPENCDF')
            endif
          elseif(varnam(n)(1:lenvar).eq.'swr_time') then
            call ncdinq(ncinp1id,vdims(1,n),dimnam,dimsiz,rcode)
            if (rcode.eq.0) then
               if (dimsiz.le.maxtim) then
                 start(1)=1
                 count(1)=dimsiz
                 call ncvget(ncinp1id,varid,start,count,t1swr,rcode)
                 nt1swr=dimsiz
                 if(rcode.ne.0) then
                   write(stdout,906) varnam(n)(1:lenvar),inp1name
                   call exitus('OPENCDF')
                 endif
               else
                 write(stdout,910) 'NT1SWR',nt1swr,'MAXTIM',maxtim,
     &                             'INPCDF.H'
                 call exitus ('OPENCDF')
               endif
            else
              write(stdout,907) varnam(n)(1:lenvar),inp1name
              call exitus('OPENCDF')
            endif
          endif
  70    continue
      endif
c
c-----------------------------------------------------------------------
c  Report plottable fields in primary file.
c-----------------------------------------------------------------------
c
      call what_flds(ncinp1id,nvars,1,inp1name)
c
c=======================================================================
c  Inquire about the secondary file, if applicable.
c=======================================================================
c
      if((iref.eq.2).or.(iref.eq.3)) then
c
c  Inquire about the contents of the secondary file.
c
        call ncinq(ncinp2id,ndims,nvars,ngatts,recdim,rcode)
c
c  Check for field masking and time variables in secondary file.
c
        mskinp2=.false.
        timevar=.false.
        do 80 n=1,nvars
          varid=n
          call ncvinq(ncinp2id,varid,varnam(n),vartyp,nvdims(n),
     *                vdims(1,n),nvatts,rcode)
          if(rcode.eq.0) then
            lenvar=lnblk(varnam(n),len(varnam(n)))
            if((varnam(n)(1:lenvar).eq.'landt').or.
     *         (varnam(n)(1:lenvar).eq.'landv').or.
     *         (varnam(n)(1:lenvar).eq.'mask')) then
              mskinp2=.true.
            elseif(varnam(n)(1:lenvar).eq.'time') then
              timevar=.true.
            endif
          else
            write(stdout,909) varid,inp2name
            call exitus('OPENCDF')
          endif
  80    continue
c
c  Inquire size of unlimited record dimension TIME and read its values.
c
c        if(recdim.ne.-1) then
        if(recdim.gt.0) then
          call ncdinq(ncinp2id,recdim,dimnam,ntime2,rcode)
          if (rcode.ne.0) then
             write(stdout,907) 'time',inp2name
             call exitus('OPENCDF')
          elseif (ntime2.gt.maxtim) then
             write(stdout,910) 'NTIME2',ntime2,'MAXTIM',maxtim,
     &                         'INPCDF.H'
             call exitus ('OPENCDF')
          endif
          varid=ncvid(ncinp2id,'time',rcode)
          if(rcode.eq.0) then
            start(1)=1
            count(1)=ntime2
            call ncvget(ncinp2id,varid,start,count,time2,rcode)
            if(rcode.ne.0) then
              write(stdout,906) 'time',inp2name
              call exitus('OPENCDF')
            endif
          else
            write(stdout,908) 'time',inp2name
            call exitus('OPENCDF')
          endif
        elseif(timevar) then
          varid=ncvid(ncinp2id,'time',rcode)
          if(rcode.eq.0) then
            call ncvget1(ncinp2id,varid,1,time2(1),rcode)
            if(rcode.ne.0) then
              write(stdout,906) 'time',inp2name
              call exitus('OPENCDF')
            endif
            ntime2=1
          else
            write(stdout,908) 'time',inp2name
            call exitus('OPENCDF')
          endif
        endif
c
c  Read other time dimension variables.
c
        if(type2(1:ltype2).eq.'PE FORCING') then
          do 90 n=1,nvars
            varid=n
            call ncvinq(ncinp2id,varid,varnam(n),vartyp,nvdims(n),
     *                  vdims(1,n),nvatts,rcode)
            lenvar=lnblk(varnam(n),len(varnam(n)))
            if(varnam(n)(1:lenvar).eq.'smf_time') then
              call ncdinq(ncinp2id,vdims(1,n),dimnam,dimsiz,rcode)
              if(rcode.eq.0) then
                if (dimsiz.le.maxtim) then
                   start(1)=1
                   count(1)=dimsiz
                   call ncvget(ncinp2id,varid,start,count,t2smf,rcode)
                   nt2smf=dimsiz
                   if(rcode.ne.0) then
                     write(stdout,906) varnam(n)(1:lenvar),inp2name
                     call exitus('OPENCDF')
                   endif
                else
                  write(stdout,910) 'NT2SMF',nt2smf,'MAXTIM',maxtim,
     &                              'INPCDF.H'
                  call exitus ('OPENCDF')
                endif
              else
                write(stdout,907) varnam(n)(1:lenvar),inp2name
                call exitus('OPENCDF')
              endif
            elseif(varnam(n)(1:lenvar).eq.'shf_time') then
              call ncdinq(ncinp2id,vdims(1,n),dimnam,dimsiz,rcode)
              if(rcode.eq.0) then
                if (dimsiz.le.maxtim) then
                   start(1)=1
                   count(1)=dimsiz
                   call ncvget(ncinp2id,varid,start,count,t2shf,rcode)
                   nt2shf=dimsiz
                   if(rcode.ne.0) then
                     write(stdout,906) varnam(n)(1:lenvar),inp2name
                     call exitus('OPENCDF')
                   endif
                else
                  write(stdout,910) 'NT2SHF',nt2shf,'MAXTIM',maxtim,
     &                              'INPCDF.H'
                  call exitus ('OPENCDF')
                endif
              else
                write(stdout,907) varnam(n)(1:lenvar),inp2name
                call exitus('OPENCDF')
              endif
            elseif(varnam(n)(1:lenvar).eq.'swf_time') then
              call ncdinq(ncinp2id,vdims(1,n),dimnam,dimsiz,rcode)
              if(rcode.eq.0) then
                if (dimsiz.le.maxtim) then
                   start(1)=1
                   count(1)=dimsiz
                   call ncvget(ncinp2id,varid,start,count,t2swf,rcode)
                   nt2swf=dimsiz
                   if(rcode.ne.0) then
                     write(stdout,906) varnam(n)(1:lenvar),inp2name
                     call exitus('OPENCDF')
                   endif
                else
                  write(stdout,910) 'NT2SWF',nt2swf,'MAXTIM',maxtim,
     &                              'INPCDF.H'
                  call exitus ('OPENCDF')
                endif
              else
                write(stdout,907) varnam(n)(1:lenvar),inp2name
                call exitus('OPENCDF')
              endif
            elseif(varnam(n)(1:lenvar).eq.'swr_time') then
              call ncdinq(ncinp2id,vdims(1,n),dimnam,dimsiz,rcode)
              if(rcode.eq.0) then
                if (dimsiz.le.maxtim) then
                   start(1)=1
                   count(1)=dimsiz
                   call ncvget(ncinp2id,varid,start,count,t2swr,rcode)
                   nt2swr=dimsiz
                   if(rcode.ne.0) then
                     write(stdout,906) varnam(n)(1:lenvar),inp2name
                     call exitus('OPENCDF')
                   endif
                else
                  write(stdout,910) 'NT2SWR',nt2swr,'MAXTIM',maxtim,
     &                              'INPCDF.H'
                  call exitus ('OPENCDF')
                endif
              else
                write(stdout,907) varnam(n)(1:lenvar),inp2name
                call exitus('OPENCDF')
              endif
            endif
  90      continue
        endif
c
c-----------------------------------------------------------------------
c  Report plottable fields in secondary file.
c-----------------------------------------------------------------------
c
        call what_flds(ncinp2id,nvars,2,inp2name)
      endif
c
 900  format(/' OPENCDF - unable to open NetCDF file: ',a)
 901  format(/' OPENCDF - error while reading attribute: ',a,2x
     *        ' in input NetCDF file: ',a)
 902  format(/' OPENCDF - cannot find attribute: ',a,2x
     *        ' in input NetCDF file: ',a)
 903  format(/' OPENCDF - error while reading dimension: ',a,2x
     *        ' in input NetCDF file: ',a)
 904  format(/' OPENCDF - error inquiring information for variable: ',
     *       a,2x,' in input NetCDF file: ',a)
 905  format(/' OPENCDF - unable to inquire about contents of',
     *        ' input NetCDF file: ',a)
 906  format(/' OPENCDF - error while reading variable: ',a,2x
     *        ' in input NetCDF file: ',a)
 907  format(/' OPENCDF - error inquiring dimension for variable: ',a,
     *       2x,' in input NetCDF file: ',a)
 908  format(/' OPENCDF - cannot find variable: ',a,2x
     *        ' in input NetCDF file: ',a)
 909  format(/' OPENCDF - error while inquiring information for',
     *        ' NetCDF variable ID = ',i3,2x,' in file: ',a)
 910  format(/'***Error: OPENCDF - insufficient space:'/
     &        2(11x,a,' = ',i10/),11x,'Edit ',a,' and recompile.')
      return
      end
