c
c=======================================================================
c  Include file "pefldid.h".
c=======================================================================
c
#ifndef rmdocinc
c  PE fields classification:
c
c   PB1MAG  first guess barotropic velocity vector magnitude (cm/s).
c   PB1VEC  first guess barotropic velocity vectors (cm/s).
c   PB2MAG  second guess barotropic velocity vector magnitude (cm/s).
c   PB2VEC  second guess barotropic velocity vectors (cm/s).
c   PB3MAG  third guess barotropic velocity vector magnitude (cm/s).
c   PB3VEC  third guess barotropic velocity vectors (cm/s).
c   PEBATH  bottom topography at the tracer points (m).
c   PEBTHT  depth of each tracer point (m).
c   PEBTHV  depth of each velocity point (m).
c   PEBUOY  buoyancy work (gigaWatts)
c   PEBVOR  rate of change of barotropic vorticity.
c   PECDEN  density anomaly computed from PE temperature and salinity.
c   PEDANO  PE density anomaly (sigma-1000) g/cm^3.
c   PEDBAR  mean PE density anomaly (sigma-1000) g/cm^3.
c   PEDEMG  derived external mode, velocity vectors magnitude (cm/s).
c   PEDEVC  derived external mode, velocity vectors (cm/s).
c   PEDUBR  derived external mode, zonal velocity (cm/s).
c   PEDVBR  derived external mode, meridional velocity (cm/s).
c   PEEVEC  external mode velocity vectors (cm/s).
c   PEEMAG  external mode velocity vector magnitude (cm/s).
c   PEFVNM  flat-level velocity normal to section (cm/s).
c   PEFVTG  flat-level velocity tangential to section (cm/s).
c   PEGMAG  internal mode, geostrophic velocity vector magnitude (cm/s).
c   PEGVEC  internal mode, geostrophic velocity vectors (cm/s).
c   PEGVNM  internal mode, geostrophic velocity normal to section (cm/s).
c   PEGVTG  internal mode, geo. velocity tangential to section (cm/s).
c   PEHSPR  surface elevation from kinematic surface pressure.  (m)
c   PEHSTA  hydrographic cruise track stations.
c   PEIMAG  internal mode, velocity vector magnitude (cm/s).
c   PEIVEC  internal mode, velocity vectors (cm/s).
c   PEIVNM  total velocity normal to section (cm/s).
c   PEIVTG  total velocity tangential to section (cm/s).
c   PEKETS  time rate of change of KE.
c   PEKET1  time rate of change of KE due to pressure term.
c   PEKET2  time rate of change of KE due to zonal advection.
c   PEKET3  time rate of change of KE due to meridional advection.
c   PEKET4  time rate of change of KE due to vertical advection.
c   PEKET5  time rate of change of KE due to zonal diffusion.
c   PEKET6  time rate of change of KE due to meridional diffusion.
c   PEKET7  time rate of change of KE due to vertical diffusion.
c   PEKET8  time rate of change of KE due to metric diffusion.
c   PEKET9  time rate of change of KE due to Coriolis term.
c   PEKT10  time rate of change of KE due to Boundary Relaxation.
c   PEKT11  time rate of change of KE due to local tidal acceleration.
c   PELTRK  Lagrangian drifter trajectories.
c   PEMLDH  mixed-layer depth (meter).
c   PEMXLD  mixing layer depth (meters).
c   PENH4p  NH4 production rate (umoles/l/s).
c   PENO3p  NO3 production rate (umoles/l/s).
c   PEPBAR  barotropic transport streamfunction (cm^3/s).
c   PEPFER  forecast error for transport streamfunction.
c   PEPOER  observation error for transport streamfunction.
c   PEROSS  Rossby radius of deformation.  (km)
c   PERCBV  rate of change of barotropic vorticity at the boundaries.
c   PESALT  salinity (PSS).
c   PESFER  forecast error for salinity.
c   PESHFX  surface (net) heat flux (W/m^2).
c   PESIGT  sigma-t (kg/m^3).
c   PESMFM  wind stress vector magnitude (dynes/cm^2).
c   PESMFV  wind stress vectors (dynes/cm^2).
c   PESMFX  meridional wind stress (dynes/cm^2).
c   PESMFY  zonal wind stress (dynes/cm^2).
c   PESNDS  sound speed (m/s).
c   PESOER  observation error for salinity.
c   PESPRS  surface pressure (dyne/cm^2).
c   PESRAD  shortwave radiation (W/m^2).
c   PESWFX  surface water flux, E-P (cm/day).
c   PETDMG  tidal velocity vector magnitude (cm/s).
c   PETDSF  tidal surface elevation (meters).
c   PETDVC  tidal velocity vectors (cm/s).
c   PETEKE  total kinetic energy (petaJoules).
c   PETEMP  temperature (deg C).
c   PETFER  forecast error for temperature.
c   PETOER  observation error for temperature.
c   PETMAG  total velocity vector magnitude (cm/s).
c   PETMSK  land/sea mask at tracer points.
c   PETVEC  total velocity vectors (cm/s).
c   PETVNM  tidal velocity normal to section (cm/s).
c   PETVTG  tidal velocity tangential to section (cm/s).
c   PETRC1  phytoplankton concentration (umoles/l).
c   PETRC2  zooplankton concentration (umoles/l).
c   PETRC3  nitrate concentration (umoles/l).
c   PETRC4  ammonium concentration (umoles/l).
c   PETRC5  detritus concentration (umoles/l).
c   PETRC6  particulate organic nitrogen concentration (umoles/l).
c   PETRC7  dissolved organic nitrogen concentration (umoles/l).
c   PETRC8  bacteria concentration (umoles/l).
c   PETRC9  chlorophyll concentration (umoles/l).
c   PET1FE  forecast error for tracer 1.
c   PET1OE  observation error for tracer 1.
c   PET2FE  forecast error for tracer 2.
c   PET2OE  observation error for tracer 2.
c   PET3FE  forecast error for tracer 3.
c   PET3OE  observation error for tracer 3.
c   PET4FE  forecast error for tracer 4.
c   PET4OE  observation error for tracer 4.
c   PET5FE  forecast error for tracer 5.
c   PET5OE  observation error for tracer 5.
c   PET6FE  forecast error for tracer 6.
c   PET6OE  observation error for tracer 6.
c   PET7FE  forecast error for tracer 7.
c   PET7OE  observation error for tracer 7.
c   PET8FE  forecast error for tracer 8.
c   PET8OE  observation error for tracer 8.
c   PET9FE  forecast error for tracer 9.
c   PET9OE  observation error for tracer 9.
c   PEUB1   first guess barotropic, zonal velocity (cm/s).
c   PEUB2   second guess barotropic, zonal velocity (cm/s).
c   PEUB3   third guess barotropic, zonal velocity (cm/s).
c   PEUBAR  external mode, zonal velocity (cm/s).
c   PEUFER  forecast error for internal mode zonal velocity.
c   PEUFLT  flat-level, zonal velocity (cm/s).
c   PEUGEO  internal mode, zonal geostrophic velocity (cm/s).
c   PEUHAT  internal mode, zonal velocity (cm/s).
c   PEUOER  observation error for internal mode zonal velocity.
c   PEUTID  tidal zonal velocity (cm/s).
c   PEUTOT  total zonal velocity (cm/s).
c   PEVB1   first guess barotropic, meridional velocity (cm/s).
c   PEVB2   second guess barotropic, meridional velocity (cm/s).
c   PEVB3   third guess barotropic, meridional velocity (cm/s).
c   PEVBAR  external mode, meridional velocity (cm/s).
c   PEVDC   vertical eddy diffusion coefficient (cm^2/s).
c   PEVFER  forecast error for internal mode meridional velocity.
c   PEVFLT  flat-level, meridional velocity (cm/s).
c   PEVGEO  internal mode, meridional geostrophic velocity (cm/s).
c   PEVHAT  internal mode, meridional velocity (cm/s).
c   PEVMSK  land/sea mask at tracer points.
c   PEVNRM  total velocity normal to section (cm/s).
c   PEVOER  observation error for internal mode meridional velocity.
c   PEVTID  tidal meridional velocity (cm/s).
c   PEVTNG  total velocity tangential to section (cm/s).
c   PEVTOT  total meridional velocity (cm/s).
c   PEVVC   vertical eddy viscosity coefficient (cm^2/s).
c   PEWVST  vertical "omega" velocity at tracer points (cm/s).
c   PEWVSV  vertical "omega" velocity at velocity points (cm/s).
c   PEWVZT  vertical "flat" velocity at tracer points (cm/s).
c   PEWVZV  vertical "flat" velocity at velocity points (cm/s).
c   PEZOOG  zooplankton grazing rate (umoles/l/s).
c   PT10FE  forecast error for tracer 10.
c   PT10OE  observation error for tracer 10.
c   PTRC10  cod concentration (umoles/l).
c   PVFMAG  flat-level velocity vector magnitude (cm/s).
c   PVFVEC  flat-level velocity vectors (cm/s).
c
c=======================================================================
c
#endif
      integer pebath,pebtht,pebthv,pebuoy,pebvor,pecden,pedano,pedbar
      integer pedemg,pedevc,pedubr,pedvbr,peevec,peemag,pegmag,pegvec,
     *        pegvnm,pegvtg,pehsta,peimag,peivec,peivnm,peivtg,pekets,
     *        peket1,peket2,peket3,peket4,peket5,peket6,peket7,peket8,
     *        peket9,pekt10,pekt11,peltrk,pemldh,pemxld,penh4p,peno3p,
     *        pepbar,pepoer,pepfer,percbv,pesalt,pesfer,peshfx,pesigt,
     *        pesmfm,pesmfv,pesmfx,pesmfy,pesnds,pesoer,pesrad,peswfx,
     *        petdmg,petdsf,petdvc,peteke,petemp,petfer,petmag,petmsk,
     *        petoer,petrc1,petrc2,petrc3,petrc4,petrc5,petrc6,petrc7,
     *        petrc8,petrc9,petvec,petvnm,petvtg,pet1fe,pet1oe,pet2fe,
     *        pet2oe,pet3fe,pet3oe,pet4fe,pet4oe,pet5fe,pet5oe,pet6fe,
     *        pet6oe,pet7fe,pet7oe,pet8fe,pet8oe,pet9fe,pet9oe,peubar,
     *        peufer,peugeo,peuhat,peuoer,peutid,peutot,pevbar,pevdc,
     *        pevfer,pevgeo,pevhat,pevmsk,pevnrm,pevoer,pevtid,pevtng,
     *        pevtot,pevvc, pewvst,pewvsv,pewvzt,pewvzv,pezoog,pt10fe,
     &        pt10oe,ptrc10,pt11fe,pt11oe,ptrc11,pt12fe,pt12oe,ptrc12
      integer ptrc13,ptrc14,ptrc15,ptrc16,ptrc17,ptrc18,ptrc19,ptrc20,
     &        ptrc21,ptrc22,ptrc23,ptrc24,ptrc25,ptrc26,ptrc27,ptrc28,
     &        ptrc29,ptrc30,ptrc31,ptrc32,ptrc33,ptrc34,ptrc35,ptrc36,
     &        ptrc37,ptrc38,ptrc39,ptrc40,ptrc41,ptrc42,ptrc43,ptrc44,
     &        ptrc45
      integer pesprs,peross,pehspr
      integer pettb1,pettb2,pettb3,pettb4,pettb5,pettb6,pettb7,pettb8,
     *        pettb9
      integer petsb1,petsb2,petsb3,petsb4,petsb5,petsb6,petsb7,petsb8,
     *        petsb9
      integer pet1b1,pet1b2,pet1b3,pet1b4,pet1b5,pet1b6,pet1b7,pet1b8,
     *        pet1b9
      integer pet2b1,pet2b2,pet2b3,pet2b4,pet2b5,pet2b6,pet2b7,pet2b8,
     *        pet2b9
      integer pet3b1,pet3b2,pet3b3,pet3b4,pet3b5,pet3b6,pet3b7,pet3b8,
     *        pet3b9
      integer pet4b1,pet4b2,pet4b3,pet4b4,pet4b5,pet4b6,pet4b7,pet4b8,
     *        pet4b9
      integer pet5b1,pet5b2,pet5b3,pet5b4,pet5b5,pet5b6,pet5b7,pet5b8,
     *        pet5b9
      integer pet6b1,pet6b2,pet6b3,pet6b4,pet6b5,pet6b6,pet6b7,pet6b8,
     *        pet6b9
      integer pet7b1,pet7b2,pet7b3,pet7b4,pet7b5,pet7b6,pet7b7,pet7b8,
     *        pet7b9
      integer pet8b1,pet8b2,pet8b3,pet8b4,pet8b5,pet8b6,pet8b7,pet8b8,
     *        pet8b9
      integer pet9b1,pet9b2,pet9b3,pet9b4,pet9b5,pet9b6,pet9b7,pet9b8,
     *        pet9b9
      integer pt10b1,pt10b2,pt10b3,pt10b4,pt10b5,pt10b6,pt10b7,pt10b8,
     *        pt10b9
      integer pt11b1,pt11b2,pt11b3,pt11b4,pt11b5,pt11b6,pt11b7,pt11b8,
     *        pt11b9
      integer pt12b1,pt12b2,pt12b3,pt12b4,pt12b5,pt12b6,pt12b7,pt12b8,
     *        pt12b9
      integer pvfvec,pvfmag,peuflt,pevflt,pefvnm,pefvtg,pb1vec,pb1mag,
     &        peub1,pevb1,pb2vec,pb2mag,peub2,pevb2,pb3vec,pb3mag,peub3,
     &        pevb3

      parameter (pebath=9  ,pebtht=60 ,pebthv=61 ,pebuoy=20 ,pebvor=27 )
      parameter (pecden=69 ,pedano=8  ,pedbar=28 ,pedemg=63 ,pedevc=62 )
      parameter (pedubr=64 ,pedvbr=65 ,peevec=72 ,peemag=73 ,pegmag=15 )
      parameter (pegvec=16 ,pegvnm=95 ,pegvtg=96 ,pehsta=19 ,peimag=14 )
      parameter (peivec=13 ,peivnm=93 ,peivtg=94 ,pekets=43 ,peket1=44 )
      parameter (peket2=45 ,peket3=46 ,peket4=47 ,peket5=48 ,peket6=49 )
      parameter (peket7=50 ,peket8=51 ,peket9=52 ,pekt10=53 ,pekt11=54 )
      parameter (peltrk=18 ,pemldh=29 ,penh4p=39 ,peno3p=40 ,pepbar=4  )
      parameter (pepfer=204,pepoer=104,percbv=17 ,pesalt=6  ,pesfer=206)
      parameter (peshfx=83 ,pesigt=12 ,pesmfm=84 ,pesmfv=85 ,pesmfx=86 )
      parameter (pesmfy=87 ,pesnds=67 ,pesoer=106,pesprs=71 ,pesrad=88 )
      parameter (peswfx=89 ,petdmg=80 ,petdsf=81 ,petdvc=79 ,peteke=42 )
      parameter (petemp=5  ,petfer=205,petmag=11 ,petmsk=57 ,petoer=105)
      parameter (petrc1=30 ,petrc2=31 ,petrc3=32 ,petrc4=33 ,petrc5=34 )
      parameter (petrc6=35 ,petrc7=36 ,petrc8=37 ,petrc9=38 ,petvec=10 )
      parameter (petvnm=97 ,petvtg=98 ,pet1fe=207,pet1oe=107,pet2fe=208)
      parameter (pet2oe=108,pet3fe=209,pet3oe=109,pet4fe=210,pet4oe=110)
      parameter (pet5fe=211,pet5oe=111,pet6fe=212,pet6oe=112,pet7fe=213)
      parameter (pet7oe=113,pet8fe=214,pet8oe=114,pet9fe=215,pet9oe=115)
      parameter (peubar=74 ,peufer=201,peugeo=23 ,peuhat=21 ,peuoer=101)
      parameter (peutid=77 ,peutot=1  ,pevbar=75 ,pevfer=202,pevgeo=24 )
      parameter (pevhat=22 ,pevmsk=58 ,pevnrm=91 ,pevoer=102,pevtid=78 )
      parameter (pevtng=92 ,pevtot=2  ,pewvst=3  ,pewvsv=7  ,pewvzt=25 )
      parameter (pewvzv=26 ,pezoog=41 ,pt10fe=216,pt10oe=116,ptrc10=55 )
      parameter (pt11fe=217,pt11oe=117,ptrc11=56 ,pevdc =66 ,pemxld=70 )
      parameter (pt12fe=218,pt12oe=118,ptrc12=59 ,pevvc =68 ,peross=76 )
      parameter (pettb1=500,pettb2=501,pettb3=502,pettb4=503,pettb5=504,
     &           pettb6=505,pettb7=506,pettb8=507,pettb9=508,pehspr=82 )
      parameter (petsb1=520,petsb2=521,petsb3=522,petsb4=523,petsb5=524,
     &           petsb6=525,petsb7=526,petsb8=527,petsb9=528)
      parameter (pet1b1=540,pet1b2=541,pet1b3=542,pet1b4=543,pet1b5=544,
     &           pet1b6=545,pet1b7=546,pet1b8=547,pet1b9=548)
      parameter (pet2b1=560,pet2b2=561,pet2b3=562,pet2b4=563,pet2b5=564,
     &           pet2b6=565,pet2b7=566,pet2b8=567,pet2b9=568)
      parameter (pet3b1=580,pet3b2=581,pet3b3=582,pet3b4=583,pet3b5=584,
     &           pet3b6=585,pet3b7=586,pet3b8=587,pet3b9=588)
      parameter (pet4b1=600,pet4b2=601,pet4b3=602,pet4b4=603,pet4b5=604,
     &           pet4b6=605,pet4b7=606,pet4b8=607,pet4b9=608)
      parameter (pet5b1=620,pet5b2=621,pet5b3=622,pet5b4=623,pet5b5=624,
     &           pet5b6=625,pet5b7=626,pet5b8=627,pet5b9=628)
      parameter (pet6b1=640,pet6b2=641,pet6b3=642,pet6b4=643,pet6b5=644,
     &           pet6b6=645,pet6b7=646,pet6b8=647,pet6b9=648)
      parameter (pet7b1=660,pet7b2=661,pet7b3=662,pet7b4=663,pet7b5=664,
     &           pet7b6=665,pet7b7=666,pet7b8=667,pet7b9=668)
      parameter (pet8b1=680,pet8b2=681,pet8b3=682,pet8b4=683,pet8b5=684,
     &           pet8b6=685,pet8b7=686,pet8b8=687,pet8b9=688)
      parameter (pet9b1=700,pet9b2=701,pet9b3=702,pet9b4=703,pet9b5=704,
     &           pet9b6=705,pet9b7=706,pet9b8=707,pet9b9=708)
      parameter (pt10b1=720,pt10b2=721,pt10b3=722,pt10b4=723,pt10b5=724,
     &           pt10b6=725,pt10b7=726,pt10b8=727,pt10b9=728)
      parameter (pt11b1=740,pt11b2=741,pt11b3=742,pt11b4=743,pt11b5=744,
     &           pt11b6=745,pt11b7=746,pt11b8=747,pt11b9=748)
      parameter (pt12b1=760,pt12b2=761,pt12b3=762,pt12b4=763,pt12b5=764,
     &           pt12b6=765,pt12b7=766,pt12b8=767,pt12b9=768)
      parameter (ptrc13=300,ptrc14=301,ptrc15=302,ptrc16=303,ptrc17=304,
     &           ptrc18=305,ptrc19=306,ptrc20=307,ptrc21=308,ptrc22=309,
     &           ptrc23=310,ptrc24=311,ptrc25=312,ptrc26=313,ptrc27=314,
     &           ptrc28=315,ptrc29=316,ptrc30=317,ptrc31=318,ptrc32=319,
     &           ptrc33=320,ptrc34=321,ptrc35=322,ptrc36=323,ptrc37=324,
     &           ptrc38=325,ptrc39=326,ptrc40=327,ptrc41=328,ptrc42=329,
     &           ptrc43=330,ptrc44=331,ptrc45=332)
      parameter (pvfvec=160,pvfmag=161,peuflt=162,pevflt=163,pefvnm=164,
     &           pefvtg=164,pb1vec=166,pb1mag=167,peub1=168,pevb1=169,
     &           pb2vec=170,pb2mag=171,peub2=172,pevb2=173,pb3vec=174,
     &           pb3mag=175,peub3=176,pevb3=177)
c
      integer tid(maxtrc),tbalid(tterms,maxtrc),toerid(maxtrc),
     *                  tferid(maxtrc)
      common /ipefldid/ tid,tbalid,toerid,tferid
c
      character*44 tname(3,maxtrc),tbterm(9)
      common /cpefldid/ tname,tbterm
