      subroutine pltvec(u,v,x,y,im,m,n,is,js,vmin,vmax,vscl,vref,
     *                  vrefx,vrefy,thetad,label)
c
c=======================================================================
c                                                                    ===
c  This routine draws vector fields. It uses NCAR graphics routines  ===
c  to draw the field and assumes that SET has been call by the user  ===
c  in such a way as to  properly  scale the  plotting  instructions  ===
c  used by this routine.                                             ===
c                                                                    ===
c  On Input:                                                         ===
c                                                                    ===
c     U      vector x-direction component (real array)               ===
c     V      vector y-direction component (real array)               ===
c     X      x-location of the vector (real array)                   ===
c     Y      y-location of the vector (real array)                   ===
c     IM     first dimension of arrays U, V, X, Y in the calling     ===
c            program (integer)                                       ===
c     M      number of data values to be plotted in the x-direction  ===
c            (integer)                                               ===
c     N      number of data values to be plotted in the y-direction  ===
c            (integer)                                               ===
c     IS     sample interval in the x-direction (integer)            ===
c     JS     sample interval in the y-direction (integer)            ===
c     VMIN   minimum vector magnitude value to consider (real)       ===
c     VMAX   maximum vector magnitude value to consider (real)       ===
c     VSCL   vector length scale (real)                              ===
c     VREF   magnitude of reference vector (real)                    ===
c     VREFX  x-position for reference vector (real)                  ===
c     VREFY  y-position for reference vector (real)                  ===
c     THETAD domain rotation (degrees, real)                         ===
c     LABEL  reference label (integer):                              ===
c            LABEL = 0   "cm/s"                                      ===
c            LABEL = 1   "m/s"                                       ===
c            LABEL = 2   "dyne/cm^2"                                 ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
#include <cdefs.h>
#include <pconst.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer i,im,ip,is,j,js,label,m,n,sb,sb2,se,se2,sl,sl2
      integer no_digit
      real fontsize,headang,theta,thetad,uvel,vdis,vhls,vmag,vmax,vmin,
     *     vref,vrefx,vrefy,vscl,vvel,xhalf,xhead,xlab,xtail,x0,x1,
     *     yhalf,yhead,ylab,ytail,y0,y1
      real    u(*),v(*),x(*),y(*)
      logical      graph
      character*80  fmt
      character*256 wkstr
      character*256 vlabel
#ifndef mediumfont
      parameter (fontsize=c5, graph=.true.)
# else
      parameter (fontsize=15.0, graph=.true.)
#endif
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c-----------------------------------------------------------------------
c  Set value of the vector used in the label, if not provided.
c-----------------------------------------------------------------------
c
       if(vref.le.c0) then
         vref=c0
         if(vmax.lt.c1) vref=c1
         if((c1.le.vmax).and.(vmax.lt.c25)) vref=c5
         if((c25.le.vmax).and.(vmax.lt.c50)) vref=c25
         if((c50.le.vmax).and.(vmax.lt.c100)) vref=c50
         if(vmax.gt.c100) vref=c100
       endif
c
c-----------------------------------------------------------------------
c  Set vector-head scales (at 25 percent length of label vector).
c-----------------------------------------------------------------------
c
       headang=c10
       headang=deg2rad*headang
#ifndef big_head
       vhls=r10*vref*vscl
# else
       vhls=p25*vref*vscl
#endif
       theta=thetad*deg2rad
c
c-----------------------------------------------------------------------
c  Draw vector field.
c-----------------------------------------------------------------------
c
c  Turn on the clipping indicator.
c
      call sflush
      call gsclip (1)
c
c  Draw vectors.
c
       do 30 j=2,n,js
         do 20 i=2,m,is
           ip=i+(j-1)*im
           if((u(ip).gt.spval0).or.(v(ip).gt.spval0)) goto 10
             vmag=sqrt(u(ip)*u(ip)+v(ip)*v(ip))
             if((vmin.le.vmag).and.(vmag.le.vmax)) then
               call maptrn(y(ip),x(ip),x0,y0)
               uvel=u(ip)*cos(theta)-v(ip)*sin(theta)
               vvel=u(ip)*sin(theta)+v(ip)*cos(theta)
               x1=x0+uvel*vscl
               y1=y0+vvel*vscl
               xhalf=p5*(x1-x0)
               yhalf=p5*(y1-y0)
               xtail=x0-xhalf
               ytail=y0-yhalf
               xhead=x1-xhalf
               yhead=y1-yhalf
               call arrow(xtail,ytail,xhead,yhead,headang,vhls)
             endif
  10       continue
  20     continue
  30   continue
c
c  Turn off the clipping indicator.
c
      call sflush
      call gsclip (0)
c
c-----------------------------------------------------------------------
c  Draw scale vector its label.
c-----------------------------------------------------------------------
c
       call maptrn(vrefy,vrefx,x0,y0)
       x1=x0+vref*vscl
       y1=y0
       call arrow(x0,y0,x1,y1,headang,vhls)
       vdis=abs(x1-x0)
       xlab=x0-r20*vdis
       ylab=y0-p5*vdis
       write (fmt,40) no_digit(nint(vref))
  40   format('(i',i2.2,')')
       write (vlabel,fmt) nint(vref)
       if(label.eq.0) then
         call set_units ('centimeter second-1',graph,wkstr)
       elseif(label.eq.1) then
         call set_units ('meter second-1',graph,wkstr)
       elseif(label.eq.2) then
         call set_units ('dyne centimeter-2',graph,wkstr)
       endif
       call length (vlabel,sl,sb,se)
       call length (wkstr,sl2,sb2,se2)
       vlabel = vlabel(sb:se)//' '//wkstr((sb2+1):(se2-1))
       call length (vlabel,sl,sb,se)
       call PLTCHR(xlab,ylab,vlabel(sb:se),fontsize,c0,cm1)
       return
       end
