      subroutine psi2dynh(dh,psi,im,jm,ncinpid,spv,spval)
c
c=======================================================================
c                                                                    ===
c  This routine computes dynamic height from QG streamfunction.      ===
c                                                                    ===
c  On input:                                                         ===
c                                                                    ===
c     PSI      nondimensional streamfunction field (real array).     ===
c     IM       number of points in the x-direction (integer).        ===
c     JM       number of points in the y-direction (integer).        ===
c     NCINPID  NetCDf ID for input file (integer).                   ===
c     SPV      missing data/fill data value (real).                  ===
c     SPVAL    special value (real).                                 ===
c                                                                    ===
c  On Output:                                                        ===
c                                                                    ===
c     DH       dynamic height (real array, dynamic meters)           ===
c                                                                    ===
c  Required common blocks:                                           ===
c                                                                    ===
c     NETCDF,  PLTIO                                                 ===
c                                                                    ===
c  Calls:                                                            ===
c                                                                    ===
c     NCVID   (NetCDF library)                                       ===
c     EXITUS, NCVGET1                                                ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <pconst.h>
#include <netcdf.inc>
#include <pltio.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer i,im,j,jm,ncinpid,rcode,varid
      real dhor,f0,r0,scale,spv,spval,t0,v0
      real dh(im,jm),psi(im,jm)
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c  Read in scaling parameters.  They are read each time to facilitate
c  generality.
c
      varid=ncvid(ncinpid,'r0',rcode)
      if(rcode.eq.0) then
        call ncvget1(ncinpid,varid,1,r0,rcode)
      else
        write(stdout,900) 'r0',ncinpid
        call exitus('PSI2DYNH')
      endif
      varid=ncvid(ncinpid,'t0',rcode)
      if(rcode.eq.0) then
        call ncvget1(ncinpid,varid,1,t0,rcode)
      else
        write(stdout,900) 't0',ncinpid
        call exitus('PSI2DYNH')
      endif
      varid=ncvid(ncinpid,'dhor',rcode)
      if(rcode.eq.0) then
        call ncvget1(ncinpid,varid,1,dhor,rcode)
      else
        write(stdout,900) 'dhor',ncinpid
        call exitus('PSI2DYNH')
      endif
      varid=ncvid(ncinpid,'v0',rcode)
      if(rcode.eq.0) then
        call ncvget1(ncinpid,varid,1,v0,rcode)
      else
        write(stdout,900) 'v0',ncinpid
        call exitus('PSI2DYNH')
      endif
c
c  Compute dynamic height.
c
      f0=c1/(r0*t0)
      scale=f0*v0*dhor/grav
      do 10 j=1,jm
      do 10 i=1,im
        if(psi(i,j).ge.spv) then
          dh(i,j)=spval
        else
          dh(i,j)=scale*psi(i,j)
        endif
  10  continue
c
 900  format(/' PSI2DYNH - cannot find variable: ',a,2x,
     *        ' in input NetCDF file ID = ',i2)
      return
      end
