      subroutine readtopo (h,im,jm,hfile,itopo,stdout)
c
c=======================================================================
c                                                                    ===
c  This routine reads bottom topography file at tracer points.       ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <netcdf.inc>
#ifdef cjtopo
#  include <pconst.h>
#endif
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer im,itopo,jm,lenstr,ncid,nx,ny,rcode,stdout,varid
#ifdef cjtopo
     &        ,i,j
#endif
      integer count(2),start(2)
      integer lnblk
      real h(im,jm)
      character*128 name
      character*(*) hfile
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c-----------------------------------------------------------------------
c  Open GRIDS netCDF file.
c-----------------------------------------------------------------------
c
      ncid = ncopn (hfile,ncnowrit,rcode)
      if (rcode.ne.0) then
        write (stdout,900) hfile
        call exitus ('READTOPO')
      endif
c
c-----------------------------------------------------------------------
c  Inquire about longitudinal dimension.
c-----------------------------------------------------------------------
c
      varid = ncdid (ncid,'tlon',rcode)
      if (rcode.ne.0) then
        write (stdout,910) 'dimension','tlon',hfile
        call exitus ('READTOPO')
      endif
c
      call ncdinq (ncid,varid,name,nx,rcode)
      if (rcode.ne.0) then
        write (stdout,920) 'dimension','tlon',hfile
        call exitus ('READTOPO')
      endif
c
c-----------------------------------------------------------------------
c  Inquire about latitudinal dimension.
c-----------------------------------------------------------------------
c
      varid = ncdid (ncid,'tlat',rcode)
      if (rcode.ne.0) then
        write (stdout,910) 'dimension','tlat',hfile
        call exitus ('READTOPO')
      endif
c
      call ncdinq (ncid,varid,name,ny,rcode)
      if (rcode.ne.0) then
        write (stdout,920) 'dimension','tlat',hfile
        call exitus ('READTOPO')
      endif
c
c-----------------------------------------------------------------------
c  Make sure dimensions are equivalent.
c-----------------------------------------------------------------------
c
      if (nx.ne.im) write (stdout,930) 'nx-field',im,'nx-topo',nx
      if (ny.ne.jm) write (stdout,930) 'ny-field',jm,'ny-topo',ny
c
      if ((nx.ne.im).or.(ny.ne.jm)) call exitus ('READTOPO')
c
c-----------------------------------------------------------------------
c  Read in bathymetry (meters)
c-----------------------------------------------------------------------
c
c  Select type of bathymetry
c
      if (itopo.eq.2) then
         name = 'raw_bath'
        else if (itopo.eq.3) then
         name = 'trg_bath'
        else
         name = 'tbath'
      end if
c
      lenstr = lnblk (name,len(name))
c
c  Read in bathymetry
c
      varid = ncvid (ncid,name(1:lenstr),rcode)
      if (rcode.ne.0) then
        write (stdout,910) 'variable',name(1:lenstr),hfile
        call exitus ('READTOPO')
      endif
c
      start(1) = 1
      start(2) = 1
      count(1) = im
      count(2) = jm
c
      call ncvgt (ncid,varid,start,count,h,rcode)
      if (rcode.ne.0) then
        write (stdout,920) 'variable',name(1:lenstr),hfile
        call exitus ('READTOPO')
      endif
c
c-----------------------------------------------------------------------
c  Close GRIDS netCDF file.
c-----------------------------------------------------------------------
c
      call ncclos (ncid,rcode)
      if (rcode.ne.0) then
        write (stdout,940) hfile
        call exitus ('READTOPO')
      endif
c
#ifdef cjtopo
c-----------------------------------------------------------------------
c  Compute model T-grid topography from average of V-grid topography.
c-----------------------------------------------------------------------
c
      if ((itopo.ne.2).and.(itopo.ne.3)) then
c
c  Compute V-grid topography.
c
         do 20 j = 1,jm-1
            do 10 i = 1,im-1
               h(i,j) = p25*(h(i,j)+h(i+1,j)+h(i,j+1)+h(i+1,j+1))
  10        continue
            h(im,j) = p5*(h(im,j)+h(im,j+1))
  20     continue
         do 30 i = 1,im-1
            h(i,jm) = p5*(h(i,jm)+h(i+1,jm))
  30     continue
c
c  Compute T-grid topography from average of V-grid.
c
         do 50 j = jm,2,-1
            do 40 i = im,2,-1
               h(i,j) = p25*(h(i,j)+h(i-1,j)+h(i,j-1)+h(i-1,j-1))
  40        continue
            h(1,j) = p5*(h(1,j)+h(1,j-1))
  50     continue
         do 60 i = im,2,-1
            h(i,1) = p5*(h(i,1)+h(i-1,1))
  60     continue
c
      end if
c
#endif
      return
c
 900  format(/' READTOPO - unable to open NetCDF file: ',a)
 910  format(/' READTOPO - unable to find ',a,1x,1h",a,1h",' in file: ',
     &       a)
 920  format(/' READTOPO - unable to read ',a,1x,1h",a,1h",' in file: ',
     &       a)
 930  format(/' READTOPO - incompatible dimension:'/12x,a,2x,i10/12x,a,
     &       2x,i10)
 940  format(/' READTOPO - unable to close NetCDF file: ',a)
c
      end
