      subroutine sec_axis
c
c=======================================================================
c                                                                    ===
c  This routine sets and draws the axis for the cross-section box.   ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <cdefs.h>
#include <param.h>
#include <pconst.h>
#include <pltncar.h>
#include <secpos.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      real d,dbot,delmaj,delmin,dlef,dmax,dmin,drig,dtop,fbs,fls,fntscl,
     *     frs,ftc1,ftc2,fts,fxl,fzl,xlab,ylab1,ylab2,zlab
      real fontsizel,fontsizev,fontsizeh
      integer ifont
      integer no_digit
      character*5 dlab
      character*8 fmt,latlab,lonlab
#ifndef lowchr
      parameter (fntscl=c1)
#else
      parameter (fntscl=1.2)
#endif
c
c=======================================================================
c  Begin executive code.
c=======================================================================
c
c
c Set fontsizes
c
#ifdef mediumfont
c Medium size fonts
      ifont=0
#else
c Default fonts
      ifont=1
#endif
      if (ifont.eq.0) then
         fontsizev=15.0*fntscl
         fontsizel=15.0*fntscl
         fontsizeh=21.0*fntscl
      else
         fontsizev=10.0*fntscl
         fontsizel=10.0*fntscl
         fontsizeh=12.0*fntscl
      endif
c
c
c  Set plotting frame.
c
      call set(fl,fr,fb,ft,ul,ur,ub,ut,1)
c
c  Draw section box.
c
      call gslwsc(c2)
      call gridal(0,0,0,0,0,0,5,c0,c0)
      call gslwsc(c1)
c
c  Draw horizontal axis minor tick marks.
c
      dmin=ul
      dmax=ur
      if(int((dmax-dmin)/c5).le.10) then
        delmin=c5
        delmaj=c25
      elseif(int((dmax-dmin)/c10).le.10) then
        delmin=c10
        delmaj=c50
      elseif(int((dmax-dmin)/c100).le.5) then
        delmin=c20
        delmaj=c100
      elseif(int((dmax-dmin)/c200).le.5) then
        delmin=c50
        delmaj=c200
      elseif(int((dmax-dmin)/c500).le.5) then
        delmin=c100
        delmaj=c500
      elseif(int((dmax-dmin)/c1000).le.5) then
        delmin=c200
        delmaj=c1000
      else
        delmin=c500
        delmaj=c5000
      endif
      fts=ft-r100
      fbs=fb+r100
      dtop=ub+(ut-ub)*(fts-fb)/(ft-fb)
      dbot=ub+(ut-ub)*(fbs-fb)/(ft-fb)
      d=c0
      do 10 while ((d+delmin).le.dmax)
        d=d+delmin
        if(d.ge.dmin) then
          call line(d,ut,d,dtop)
          call line(d,ub,d,dbot)
        endif
  10  continue
c
c  Label horizontal axis and draw its associated major tick marks.
c
c
      fts=ft-r50
      fbs=fb+r50
      fxl=fb-r100
      dtop=ub+(ut-ub)*(fts-fb)/(ft-fb)
      dbot=ub+(ut-ub)*(fbs-fb)/(ft-fb)
      xlab=ub+(fontsizeh*r10)*(ut-ub)*(fxl-fb)/(ft-fb)
      d=c0
      do 20 while (d.le.dmax)
        if(d.ge.dmin) then
c
          if(fontsizeh.gt.0) then	
             write(dlab,'(i4)') int(d)
             if(d.eq.c0) then
                dlab='0 km '
                call PLTCHR(d,xlab,dlab,fontsizeh,c0,-c1)
             else
                call PLTCHR(d,xlab,dlab,fontsizeh,c0,c0)
             endif
          endif
          call line(d,ut,d,dtop)
          call line(d,ub,d,dbot)
        endif
        d=d+delmaj
  20  continue
c
c
c  Draw vertical axis minor tick marks.
c
      dmin=abs(ut)
      dmax=abs(ub)
      if(int((dmax-dmin)/c5).le.10) then
        delmin=c5
        delmaj=c25
      elseif(int((dmax-dmin)/c10).le.10) then
        delmin=c10
        delmaj=c50
      elseif(int((dmax-dmin)/c100).le.5) then
        delmin=c20
        delmaj=c100
      elseif(int((dmax-dmin)/c200).le.5) then
        delmin=c50
        delmaj=c200
      elseif(int((dmax-dmin)/c500).le.5) then
        delmin=c100
        delmaj=c500
      else
        delmin=c200
        delmaj=c1000
      endif
      fls=fl+r100
      frs=fr-r100
      dlef=ul+(ur-ul)*(fls-fl)/(fr-fl)
      drig=ul+(ur-ul)*(frs-fl)/(fr-fl)
      d=c0
      do 30 while ((d+delmin).le.dmax)
        d=d+delmin
        if(d.ge.dmin) then
          call line(ul,-d,dlef,-d)
          call line(ur,-d,drig,-d)
        endif
  30  continue
c
c  Label vertical axis and draw its associated major tick marks.
c
      fls=fl+r40
      frs=fr-r40
      fzl=fl-r33
      dlef=ul+(ur-ul)*(fls-fl)/(fr-fl)
      drig=ul+(ur-ul)*(frs-fl)/(fr-fl)
      zlab=ul+0.9*(fontsizev*r10)*(ur-ul)*(fzl-fl)/(fr-fl)
      d=dmin
      if(fontsizev.gt.0) then
         write (fmt,35) no_digit(int(d))
  35     format ('(i',i1,',1hm)')
         write (dlab,fmt) int(d)
         call PLTCHR(zlab,-d,dlab,fontsizev,c0,c0)
      endif
      call line(ul,-d,dlef,-d)
      call line(ur,-d,drig,-d)
      d=c0
      do 40 while (d.le.dmax)
        if(d.gt.dmin) then
           if(fontsizev.gt.0) then
              write(dlab,'(i4)') int(d)
              call PLTCHR(zlab,-d,dlab,fontsizev,c0,c0)
           endif
           call line(ul,-d,dlef,-d)
           call line(ur,-d,drig,-d)
        endif
        d=d+delmaj
  40  continue
      if(fontsizel.gt.0) then
c
c  Write geographical coordinates label.
c
         ftc1=ft+r100*(fontsizel*r10)
         ftc2=ft+r40*(fontsizel*r10)
         ylab1=ub+(ut-ub)*(ftc1-fb)/(ft-fb)
         ylab2=ub+(ut-ub)*(ftc2-fb)/(ft-fb)
         if(slon1.lt.c0) then
            write(lonlab,50) abs(slon1)
 50         format(f6.2,' W')
         else
            write(lonlab,60) abs(slon1)
 60         format(f6.2,' E')
         endif
         if(slat1.gt.c0) then
            write(latlab,70) abs(slat1)
 70         format(' ',f5.2,' N')
         else
            write(latlab,80) abs(slat1)
 80         format(' ',f5.2,' S')
         endif
         call PLTCHR(ul,ylab1,lonlab,fontsizel,c0,-c1)
c
         call PLTCHR(ul,ylab2,latlab,fontsizel,c0,-c1)
c
c
         if(slon2.lt.c0) then
            write(lonlab,50) abs(slon2)
         else
            write(lonlab,60) abs(slon2)
         endif
         if(slat2.gt.c0) then
            write(latlab,70) abs(slat2)
         else
            write(latlab,80) abs(slat2)
         endif
         call PLTCHR(ur,ylab1,lonlab,fontsizel,c0,c1)
         call PLTCHR(ur,ylab2,latlab,fontsizel,c0,c1)
      endif	
      return
      end
