      subroutine set_lltick (srng,fmin,fmax,ds,s0,s1,ist,ind,di)
c
c=======================================================================
c                                                                    ===
c  This routines sets up tick marking data.                          ===
c                                                                    ===
c  ------                                                            ===
c  Input:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     SRNG    Range of axis, user coordinates.          (real vector)===
c     FMIN    Minimum axis frame point.                 (real)       ===
c     FMAX    Maximum axis frame point.                 (real)       ===
c                                                                    ===
c  -------                                                           ===
c  Output:                                                           ===
c  -------                                                           ===
c                                                                    ===
c     DS      Step size for major tick marks.           (real)       ===
c     S0      User coord of plot minimum value.         (real)       ===
c     S1      User coord of plot maximum value.         (real)       ===
c     IST     Starting major tick mark (mult. ds)       (integer)    ===
c     IND     Ending major tick mark (mult. ds)         (integer)    ===
c     DI      Stepping direction for tick marks.        (integer)    ===
c                                                                    ===
c  ------                                                            ===
c  Calls:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     HOPS:    GREAT_INT,  LEAST_INT,  SET_SPACE,  SET60DVSR         ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      real c0,c1,c5,c10,c60,p5
      parameter (c0=0.0, c1=1.0, c5=5.0, c10=10.0, c60=60.0, p5=0.5)
c
      integer di,ind,ist
      integer great_int,least_int
      real    ds,fmax,fmin,s0,s1,slope
      real srng(2)
      real set60dvsr,set_space
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c-----------------------------------------------------------------------
c  Set major tick mark size for approximately 5 major tick marks.
c-----------------------------------------------------------------------
c
      ds = set_space ((srng(2)-srng(1)),5)
c
c  Replace fractional degrees with minutes/seconds.
c  (hardwire to accept nothing smaller than one minute).
c
      if (ds.lt.c1) then
         ds = ds*c60
c         if (ds.ge.c1) then
            ds = set60dvsr (ds)
c          else
c            ds = ds*c60
c            ds = set60dvsr (ds)
c            ds = ds/c60
c         end if
         ds = ds/c60
      end if
c
c-----------------------------------------------------------------------
c  Determine position of major tick marks.
c-----------------------------------------------------------------------
c
      ist = least_int (srng(1)/ds)
      ind = great_int (srng(2)/ds)
      di  = sign (1,ind-ist)
c
c-----------------------------------------------------------------------
c  Determine user coordinates for entire range of plot.
c-----------------------------------------------------------------------
c
      slope = (srng(2)-srng(1))/(fmax-fmin)
c
      s0 = srng(1) - slope*fmin
      s1 = slope + s0
c
      return
      end
