      subroutine set_units (instr,grfflg,outstr)
c
c=======================================================================
c                                                                    ===
c  This routine parses an English string of units and produces an    ===
c  NCAR string for labelling.                                        ===
c                                                                    ===
c  ------                                                            ===
c  Input:                                                            ===
c  ------                                                            ===
c                                                                    ===
c  instr....Input string of units (no symbols).                      ===
c  grfflg.....Flag to indicate whether to print as graphics or plain.===
c             [.true.]   print as graphics                           ===
c             [.false.]  print as plain                              ===
c                                                                    ===
c  Common Blocks:                                                    ===
c                                                                    ===
c  /PLTNCAR/                                                         ===
c                                                                    ===
c     ESC_CHAR...escape character to be used in special NCAR strings ===
c                                                                    ===
c  -------                                                           ===
c  Output:                                                           ===
c  -------                                                           ===
c                                                                    ===
c  outstr...Output units string with NCAR symbols & exponents.       ===
c                                                                    ===
c  Calls:  ASSEM_UNIT, XTR_EXP, XTR_PREFIX, XTR_UNITS                ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <pltncar.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer no_den,no_num,ptr,sbgn,sb1,send,se1,slen,sl1
      logical       dnxpnd,fnd_exp,fnd_pre,grfflg,numflag,nmxpnd,sqbkt
      character*256 denstr,expstr,numstr,prfstr,remstr,wkstr
      character*(*) instr,outstr
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c-----------------------------------------------------------------------
c  Find beginning & end of input string.
c-----------------------------------------------------------------------
c
      call length (instr,slen,sbgn,send)
      no_num = 0
      no_den = 0
      numstr = ' '
      denstr = ' '
c
c-----------------------------------------------------------------------
c  Parse units string
c-----------------------------------------------------------------------
c
      do 10 while (sbgn.lt.send)
c
c        ---------------------------------------------------------
c        --- Get correct fore & aft pointers for current unit. ---
c        ---------------------------------------------------------
c
         call length (instr(sbgn:send),sl1,sb1,se1)
         sbgn = sbgn + sb1 - 1
         ptr = index (instr(sbgn:send),' ') + sbgn - 2
         if (ptr.lt.sbgn) ptr=send
c
c        ---------------------------
c        --- Parse current unit. ---
c        ---------------------------
c
         wkstr = instr(sbgn:ptr)
         call xtr_prefix (wkstr,grfflg,fnd_pre,prfstr,remstr)
c
         call length (remstr,sl1,sb1,se1)
         wkstr = remstr(sb1:se1)
         call xtr_exp (wkstr,grfflg,fnd_exp,numflag,expstr,remstr)
c
         call length (remstr,sl1,sb1,se1)
         call xtr_units (remstr(sb1:se1),grfflg,wkstr)
c
         call length (wkstr,sl1,sb1,se1)
         if ( (wkstr(sb1:se1).eq.'g') .and. (.not.fnd_pre)) wkstr = 'gm'
c
c        -----------------------------------------------
c        --- Assemble unit in graphic-friendly form. ---
c        -----------------------------------------------
c
         if (numflag) then
            call assem_unit (numstr,no_num,prfstr,fnd_pre,wkstr,
     &                                                   expstr,fnd_exp)
            nmxpnd = fnd_exp
           else
            call assem_unit (denstr,no_den,prfstr,fnd_pre,wkstr,
     &                                                   expstr,fnd_exp)
            dnxpnd = fnd_exp
         end if
c
c        ---------------------------------------------
c        --- Increment fore pointer for next unit. ---
c        ---------------------------------------------
c
         sbgn = ptr + 1
c
  10  continue
c
c-----------------------------------------------------------------------
c  Final assembly.
c-----------------------------------------------------------------------
c
c--------------------------------
c--- Place leading delimitor. ---
c--------------------------------
c
      sqbkt = (no_den.gt.1) .or. ( (no_den.gt.0).and.(no_num.gt.1) )
c
      if (sqbkt) then
# if !defined medchr & !defined lowchr
         if (grfflg) then
            wkstr = esc_char//'PRL'//esc_char//'('//esc_char//'PRU'//
     &              esc_char
           else
            wkstr = '['
         end if
# else
          wkstr = '['
#endif
        else
         wkstr = '('
      end if
c
      call length (wkstr,slen,sbgn,send)
      outstr = wkstr(sbgn:send)
      call length (outstr,slen,sbgn,send)
c
c----------------------
c--- Add numerator. ---
c----------------------
c
      if ((no_den.gt.0).and.(no_num.gt.1)) then
c
         call length (numstr,sl1,sb1,se1)
         if ((.not.nmxpnd).or.(.not.grfflg)) then
            outstr = outstr(sbgn:send)//'('//numstr(sb1:se1)//')'
          else
            outstr = outstr(sbgn:send)//'('//numstr(sb1:se1)//' )'
         end if
         call length (outstr,slen,sbgn,send)
c
        elseif (no_num.gt.0) then
c
         call length (numstr,sl1,sb1,se1)
         outstr = outstr(sbgn:send)//numstr(sb1:se1)
         call length (outstr,slen,sbgn,send)
c
        elseif (no_den.gt.0) then
c
         outstr = outstr(sbgn:send)//'1'
         call length (outstr,slen,sbgn,send)
c
      end if
c
c------------------------
c--- Add denominator. ---
c------------------------
c
      if (no_den.gt.1) then
c
         call length (denstr,sl1,sb1,se1)
         if ((.not.dnxpnd).or.(.not.grfflg)) then
            outstr = outstr(sbgn:send)//'/('//denstr(sb1:se1)//')'
          else
            outstr = outstr(sbgn:send)//'/('//denstr(sb1:se1)//' )'
            dnxpnd = .false.
         end if
         call length (outstr,slen,sbgn,send)
c
        elseif (no_den.gt.0) then
c
         call length (denstr,sl1,sb1,se1)
         outstr = outstr(sbgn:send)//'/'//denstr(sb1:se1)
         call length (outstr,slen,sbgn,send)
c
      end if
c
c---------------------------------
c--- Place trailing delimitor. ---
c---------------------------------
c
      if (sqbkt) then
# if !defined medchr & !defined lowchr
         if (grfflg) then
            wkstr = esc_char//'PRL'//esc_char//')'//esc_char//'PRU'//
     &              esc_char
           else
            wkstr = ']'
         end if
# else
          wkstr = ']'
#endif
        else
         wkstr = ')'
      end if
c
      call length (wkstr,sl1,sb1,se1)
      if ((.not.dnxpnd).or.(.not.grfflg)) then
         outstr = outstr(sbgn:send)//wkstr(sb1:se1)
       else
         outstr = outstr(sbgn:send)//' '//wkstr(sb1:se1)
      end if
c
      return
      end
