      subroutine setcolpal(lmsk)
c
c=======================================================================
c                                                                    ===
c  This routine sets the color indices that contain the desired      ===
c  color palette:                                                    ===
c                                                                    ===
c           INDEX = 0              background color                  ===
c                 = 1              foregound color                   ===
c                 = 2,...,ncl+1    NCL color levels to apply         ===
c                 = ncl+2          color for land areas              ===
c                 = ncl+3          color for water areas             ===
c                                                                    ===
c  These indices are selected according to the value of the flag     ===
c  IPAL specified in the input color palette file:                   ===
c                                                                    ===
c            IPAL = 1    indeces from the permutation array RGB      ===
c                 = 2    (R,G,B) values ranging between 0 and 255    ===
c                 = 3    (R,G,B) values ranging between 0.0 and 1.0  ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <pconst.h>
#include <colpal.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      logical first
      integer i,ib,ig,index,ir,j,k,lmsk,n,ndx
      real b,g,r
#ifdef blckndwht
      real idum,qdum,ydum
#endif
      real clrs(9)
      parameter (ir=9,ig=9,ib=9)
c
      save first
c
      data first /.true./
      data clrs /0.,32.,64.,96.,128.,160.,192.,224.,255./
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define the RGB color triples needed.  This is done by filling the
c  RGB array with all 729 permutations for a  9x9x9  color cube. All
c  values are normalized to fall in the range 0 to 1.
c-----------------------------------------------------------------------
c
      if(first.and.(ipal.eq.1)) then
        index=0
        do 30 i=1,ir
          do 20 j=1,ig
            do 10 k=1,ib
              index=index+1
              rgb(1,index)=clrs(i)/c255
              rgb(2,index)=clrs(j)/c255
              rgb(3,index)=clrs(k)/c255
  10        continue
  20      continue
  30    continue
        ipc=3
        isc=index
        first=.false.
      endif
c
c-----------------------------------------------------------------------
c  Load color indices.
c-----------------------------------------------------------------------
c
      do 40 n=1,ncl+2
        index=n-1
        if(ipal.eq.3) then
          r=rgbpal(1,n)
          g=rgbpal(2,n)
          b=rgbpal(3,n)
        elseif(ipal.eq.2) then
          r=rgbpal(1,n)/c255
          g=rgbpal(2,n)/c255
          b=rgbpal(3,n)/c255
        elseif(ipal.eq.1) then
          ndx=icolpal(n)
          r=rgb(1,ndx)
          g=rgb(2,ndx)
          b=rgb(3,ndx)
        endif
#ifndef blckndwht
        call gscr(1,index,r,g,b)
# else
        call rgbyiq (r,g,b,ydum,idum,qdum)
        call gscr(1,index,ydum,ydum,ydum)
#endif
  40  continue
c
c-----------------------------------------------------------------------
c  Set color for land areas.
c-----------------------------------------------------------------------
c
#ifndef blckndwht
      if(lmsk.eq.1) then
        call gscr(1,ncl+2,0.25,0.12,0.0)
      elseif(lmsk.eq.2) then
        call gscr(1,ncl+2,0.65,0.16,0.16)
      elseif(lmsk.eq.3) then
        call gscr(1,ncl+2,0.86,0.58,0.44)
      endif
# else
      if(lmsk.eq.1) then
        call rgbyiq (0.25,0.12,0.0,ydum,idum,qdum)
        call gscr(1,ncl+2,ydum,ydum,ydum)
      elseif(lmsk.eq.2) then
        call rgbyiq (0.65,0.16,0.16,ydum,idum,qdum)
        call gscr(1,ncl+2,ydum,ydum,ydum)
      elseif(lmsk.eq.3) then
        call rgbyiq (0.86,0.58,0.44,ydum,idum,qdum)
        call gscr(1,ncl+2,ydum,ydum,ydum)
      endif
#endif
c
c-----------------------------------------------------------------------
c  Set color for water areas (blue).
c-----------------------------------------------------------------------
c
#ifndef blckndwht
      call gscr(1,ncl+3,0.75,0.88,1.)
# else
      call rgbyiq (0.75,0.88,1.,ydum,idum,qdum)
      call gscr(1,ncl+3,ydum,ydum,ydum)
#endif
      return
      end
