      subroutine setllstr (latlon,posstr,negstr,label)
c
c=======================================================================
c                                                                    ===
c  This routine constructs a geographic label string from the given  ===
c  decimal degree coordinate.                                        ===
c                                                                    ===
c  ------                                                            ===
c  Input:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     LATLON   Latitude or longitude coordinate.   (real; dec. deg)  ===
c     POSSTR   Positive indicator.                 (string)          ===
c     NEGSTR   Negative indicator.                 (string)          ===
c                                                                    ===
c  Common Blocks:                                                    ===
c                                                                    ===
c  /PLTNCAR/                                                         ===
c                                                                    ===
c     ESC_CHAR  Escape character to be used in NCAR.  (string)       ===
c                                                                    ===
c  -------                                                           ===
c  Output:                                                           ===
c  -------                                                           ===
c                                                                    ===
c     LABEL    Position label                      (string)          ===
c                                                                    ===
c  ------                                                            ===
c  Calls:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     HOPS:    LENGTH,  NO_DIGIT                                     ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <pltncar.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      real       c0,c60
      parameter (c0=0.0, c60=60.0)
c
      real latlon,rwk
      integer degree,minute,sbn,sbn2,second,sln,sln2,snd,snd2
      integer      no_digit
      character*80  fmt,wkstr
      character*(*) label,negstr,posstr
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c-----------------------------------------------------------------------
c  Decompose into degrees, minutes and seconds.
c-----------------------------------------------------------------------
c
      rwk = abs(latlon)
c
c  Do initial break-up
c
      degree = int(rwk)
      rwk    = (rwk-float(degree))*c60
      minute = int(rwk)
      second = nint((rwk-float(minute))*c60)
c
c  Take up rounding issues.
c
      if (second.ge.60) then
         minute = minute + (second/60)
         second = mod(second,60)
      end if
c
      if (minute.ge.60) then
         degree = degree + (minute/60)
         minute = mod(minute,60)
      end if
c
c-----------------------------------------------------------------------
c  Write degrees into label.
c-----------------------------------------------------------------------
c
      write (fmt,900) no_digit(degree)
      write (label,fmt) degree
#if !defined medchr & !defined lowchr
      call length (label,sln,sbn,snd)
      label = label(sbn:snd)//esc_char//'S1PGU1'//esc_char//'Z'//
     &                        esc_char//'PRU'//esc_char
#endif
c
c-----------------------------------------------------------------------
c  Optionally add minutes to label.
c-----------------------------------------------------------------------
c
      if ((minute.gt.0).or.(second.gt.0)) then
         write (fmt,900) no_digit(minute)
         write (wkstr,fmt) minute
         call length (label,sln,sbn,snd)
         call length (wkstr,sln2,sbn2,snd2)
         label = label(sbn:snd)//' '//wkstr(sbn2:snd2)//
#if !defined medchr & !defined lowchr
     &           esc_char//'PGL'//esc_char//'4'//esc_char//'PRU'//
     &           esc_char
#else
     &           char(39)
#endif
      end if
c
c-----------------------------------------------------------------------
c  Optionally add seconds to label.
c-----------------------------------------------------------------------
c
      if (second.gt.0) then
         write (fmt,900) no_digit(second)
         write (wkstr,fmt) second
         call length (label,sln,sbn,snd)
         call length (wkstr,sln2,sbn2,snd2)
         label = label(sbn:snd)//' '//wkstr(sbn2:snd2)//
#if !defined medchr & !defined lowchr
     &           esc_char//'PGL'//esc_char//'9'//esc_char//'PRU'//
     &           esc_char
#else
     &           char(32)
#endif
      end if
c
c-----------------------------------------------------------------------
c  Add positive/negative indicator.
c-----------------------------------------------------------------------
c
      if (latlon.ge.c0) then
         wkstr = posstr
       else
         wkstr = negstr
      end if
c
      call length (label,sln,sbn,snd)
      call length (wkstr,sln2,sbn2,snd2)
      label = label(sbn:snd)//wkstr(sbn2:snd2)
c
      return
c
 900  format ('(i',i2,')')
c
      end
