      subroutine smooth_under (ims,kms,sec,spval,mspval,wk)
c
c=======================================================================
c                                                                    ===
c  This routine smoothly extends the data to areas under a special   ===
c  value mask.                                                       ===
c                                                                    ===
c  Calls:  none                                                      ===
c                                                                    ===
c  ------                                                            ===
c  Input:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     ims......Number of gridpoints along line.          (integer)   ===
c     kms......Number of gridpoints in vertical.         (integer)   ===
c     sec......Array of data and mask values.            (real array)===
c     spval....Mask value of inactive points.            (real)      ===
c     mspval...Mask value of active points to be filled. (real)      ===
c     wk.......Workspace of size (2*kms)                 (real array)===
c                                                                    ===
c  -------                                                           ===
c  Output:                                                           ===
c  -------                                                           ===
c                                                                    ===
c     sec......Array with all active nodes filled.       (real array)===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <pconst.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer i,ims,k,kms,nmin,no_pts
      real    mspval,spval
      real    sec(ims,kms),wk(kms,0:1)
      logical isbad
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c-----------------------------------------------------------------------
c  Perform smoothing, reducing the minimum number of acceptable
c  averaging points.
c-----------------------------------------------------------------------
c
      nmin = 5
      isbad = .true.
      do 10 while (isbad .and. (nmin.gt.0))
         call smoother (ims,kms,sec,spval,mspval,nmin,wk,isbad)
         nmin = nmin - 1
  10  continue
c
c-----------------------------------------------------------------------
c  Report on any remaining unfilled values.
c-----------------------------------------------------------------------
c
      if (isbad) then
         no_pts = 0
         do 20 i = 1, ims
         do 20 k = 1, kms
            if (sec(i,k).eq.mspval) then
               no_pts   = no_pts + 1
               sec(i,k) = spval
            end if
 20      continue
         write (6,30) no_pts,ims*kms
      end if
c
      return
c
 30   format (/'+++Warning:  SMOOTH_UNDER - unable to complete ',
     &         'extrapolation.'/13x,'unfilled points:  ',i10/13x,
     &         'total points:  ',i10)
c
      end
