      subroutine smoother (ims,kms,sec,spval,mspval,nmin,wk,isbad)
c
c=======================================================================
c                                                                    ===
c  This routine smoothly extends the data to areas under a special   ===
c  value mask.                                                       ===
c                                                                    ===
c  Calls:  none                                                      ===
c                                                                    ===
c  ------                                                            ===
c  Input:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     ims......Number of gridpoints along line.          (integer)   ===
c     kms......Number of gridpoints in vertical.         (integer)   ===
c     sec......Array of data and mask values.            (real array)===
c     spval....Mask value of inactive points.            (real)      ===
c     mspval...Mask value of active points to be filled. (real)      ===
c     nmin.....Minimum number of good values to average. (integer)   ===
c     wk.......Workspace of size (2*kms)                 (real array)===
c                                                                    ===
c  -------                                                           ===
c  Output:                                                           ===
c  -------                                                           ===
c                                                                    ===
c     sec......Array with all active nodes filled.       (real array)===
c     isbad....Flag indicating remaining points to fill. (logical)   ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <pconst.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer back,curr,i,ims,k,kms,nmin,no_pts
      real    mspval,spval,tst,val
      real    sec(ims,kms),wk(kms,0:1)
      logical haschg,isbad
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c-----------------------------------------------------------------------
c  Set to enter loop.
c-----------------------------------------------------------------------
c
      haschg = .true.
      isbad = .true.
c
c-----------------------------------------------------------------------
c  Loop while there are active nodes to fill.
c-----------------------------------------------------------------------
c
      do 40 while (isbad.and.haschg)
c
         haschg = .false.
         isbad  = .false.
         back   = 0
         curr   = 1
         do 10 k = 1, kms
            wk(k,0) = sec(1,k)
            wk(k,1) = sec(1,k)
 10      continue
c
         do 30 i = 1, ims
c
            back = 1 - back
            curr = 1 - curr
c
            do 20 k = 1, kms
c
               wk(k,curr) = sec(i,k)
c
               if (sec(i,k).eq.mspval) then
c
c                 -------------------------------------
c                 --- Attempt to replace value with ---
c                 ---  average of filled neighbors  ---
c                 -------------------------------------
c
                  no_pts = 0
                  val    = c0
c
c                 -----------------
c                 --- Row above ---
c                 -----------------
c
                  if (k.gt.1) then
c
                     if (i.gt.1) then
                        tst = wk(k-1,back)
                        if ((tst.ne.spval).and.(tst.ne.mspval)) then
                           no_pts = no_pts + 1
                           val    = val    + tst
                        end if
                     end if
c
                     tst = wk(k-1,curr)
                     if ((tst.ne.spval).and.(tst.ne.mspval)) then
                        no_pts = no_pts + 1
                        val    = val    + tst
                     end if
c
                     if (i.lt.ims) then
                        tst = sec(i+1,k-1)
                        if ((tst.ne.spval).and.(tst.ne.mspval)) then
                           no_pts = no_pts + 1
                           val    = val    + tst
                        end if
                     end if
c
                  end if
c
c                 -----------------
c                 --- Row below ---
c                 -----------------
c
                  if (k.lt.kms) then
c
                     if (i.gt.1) then
                        tst = wk(k+1,back)
                        if ((tst.ne.spval).and.(tst.ne.mspval)) then
                           no_pts = no_pts + 1
                           val    = val    + tst
                        end if
                     end if
c
                     tst = sec(i,k+1)
                     if ((tst.ne.spval).and.(tst.ne.mspval)) then
                        no_pts = no_pts + 1
                        val    = val    + tst
                     end if
c
                     if (i.lt.ims) then
                        tst = sec(i+1,k+1)
                        if ((tst.ne.spval).and.(tst.ne.mspval)) then
                           no_pts = no_pts + 1
                           val    = val    + tst
                        end if
                     end if
c
                  end if
c
c                 -------------------
c                 --- Current row ---
c                 -------------------
c
                  if (i.gt.1) then
                     tst = wk(k,back)
                     if ((tst.ne.spval).and.(tst.ne.mspval)) then
                        no_pts = no_pts + 1
                        val    = val    + tst
                     end if
                  end if
c
                  if (i.lt.ims) then
                     tst = sec(i+1,k)
                     if ((tst.ne.spval).and.(tst.ne.mspval)) then
                        no_pts = no_pts + 1
                        val    = val    + tst
                     end if
                  end if
c
c                 -------------------------------------
c                 --- Either replace or mark as bad ---
c                 -------------------------------------
c
                  if (no_pts.ge.nmin) then
                     sec(i,k) = val/float(no_pts)
                     haschg = .true.
                    else
                     isbad = .true.
                  end if
c
               end if
 20         continue
 30      continue
 40   continue
c
      return
      end
