      subroutine vel_nt (np,u,v,which)
c
c=======================================================================
c                                                                    ===
c  This routine computes the velocity component either normal or     ===
c  tangential to a requested section.                                ===
c                                                                    ===
c  Calls:  none                                                      ===
c                                                                    ===
c  ---------                                                         ===
c  On Input:                                                         ===
c  ---------                                                         ===
c                                                                    ===
c  NP      Number of data points.          (integer)                 ===
c  U       Zonal velocity.                 (real array;  cm/s)       ===
c  V       Meridional velocity.            (real array;  cm/s)       ===
c  WHICH   Component flag.                 (integer)                 ===
c          [0] normal component.                                     ===
c          [1] tangential component.                                 ===
c                                                                    ===
c  Common Blocks:                                                    ===
c                                                                    ===
c  /SECPOS/                                                          ===
c                                                                    ===
c  SLAT1   Left latitude of section.       (real;  degrees)          ===
c  SLAT2   Right latitude of section.      (real;  degrees)          ===
c  SLON1   Left longitude of section.      (real;  degrees)          ===
c  SLON2   Right longitude of section.     (real;  degrees)          ===
c                                                                    ===
c  ----------                                                        ===
c  On Output:                                                        ===
c  ----------                                                        ===
c                                                                    ===
c  U       Requested velocity component.   (real array;  cm/s)       ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <param.h>
#include <secpos.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer n,normal,np,tangent,which
      real    dtot,dx,dy,vecx,vecy
      real    u(np),v(np)
c
      parameter (normal=0, tangent=1)
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c-----------------------------------------------------------------------
c  Compute direction vector components.
c-----------------------------------------------------------------------
c
      dx   = slon2 - slon1
      dy   = slat2 - slat1
      dtot = sqrt ( dx*dx + dy*dy )
c
      if (which.eq.tangent) then
         vecx = dx/dtot
         vecy = dy/dtot
        else
         vecx = -dy/dtot
         vecy =  dx/dtot
      end if
c
c-----------------------------------------------------------------------
c  Compute requested velocity component.
c-----------------------------------------------------------------------
c
      do 10 n = 1, np
         u(n) = vecx*u(n) + vecy*v(n)
  10  continue
c
      return
      end
