      subroutine veritas(icolor)
c
c=======================================================================
c                                                                    ===
c  This routine draws Harvard veritas logo.                          ===
c                                                                    ===
c  Calls:  book, clrbox                                              ===
c                                                                    ===
c  NCAR Calls:  curve, gscr, gstxci, PLTCHR, plotit, set, sflush     ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data. The position of the upper left corner of the
c  shield is determined by the parameters XO & YO.  The size of the
c  shield is determined by the parameter HGHT.  The size of the
c  characters is determined by the parmeter CHR_SZ
c-----------------------------------------------------------------------
c
#include <cdefs.h>
#include <pconst.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer n_shld
      logical skipmid,noskip
      real    chr_sz,hght,wdth,xo,yo
      parameter (chr_sz=7.0, hght=0.14, n_shld=44, noskip=.true.,
     *           skipmid=.false., wdth=9.1/10.6*hght, xo=0.08, yo=0.995)
c
      integer icolor,i
      real    xc_let,xl_let,xlab,xr_let,xshift,yc_let,yl_let,ylab,
     &     yr_let,yshift
      real x(n_shld),xbkbgn(3),x_shld(n_shld),y(n_shld),ybkbgn(3),
     &     y_shld(n_shld)
c
      data x_shld / 0.0000, 1.0000, 1.0000, 0.9919, 0.9839, 0.9677,
     *              0.9516, 0.9355, 0.9194, 0.8871, 0.8710, 0.8548,
     *              0.8226, 0.7903, 0.7581, 0.7258, 0.6935, 0.6613,
     *              0.6290, 0.5968, 0.5645, 0.5323, 0.5000, 0.4677,
     *              0.4355, 0.4032, 0.3710, 0.3387, 0.3065, 0.2742,
     *              0.2419, 0.2097, 0.1774, 0.1452, 0.1290, 0.1129,
     *              0.0806, 0.0645, 0.0484, 0.0323, 0.0161, 0.0081,
     *              0.0000, 0.0000/
      data y_shld / 0.0000, 0.0000,-0.2235,-0.3059,-0.3529,-0.4588,
     *             -0.5294,-0.5706,-0.6059,-0.6647,-0.6941,-0.7176,
     *             -0.7588,-0.7941,-0.8294,-0.8588,-0.8824,-0.9059,
     *             -0.9294,-0.9529,-0.9706,-0.9882,-1.0000,-0.9882,
     *             -0.9706,-0.9529,-0.9294,-0.9059,-0.8824,-0.8588,
     *             -0.8294,-0.7941,-0.7588,-0.7176,-0.6941,-0.6647,
     *             -0.6059,-0.5706,-0.5294,-0.4588,-0.3529,-0.3059,
     *             -0.2235, 0.0000/
      data xbkbgn / 0.0968, 0.5806, 0.3387/
      data ybkbgn /-0.1294,-0.1294,-0.5294/
      data xl_let,xc_let,xr_let / 0.1069, 0.1613, 0.2157/
      data yl_let,yc_let,yr_let /-0.1235,-0.1235,-0.1235/
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c-----------------------------------------------------------------------
c  Set local viewport.
c-----------------------------------------------------------------------
c
      call set(c0,c1,c0,c1,c0,c1,c0,c1,1)
c
c-----------------------------------------------------------------------
c  Set colors
c-----------------------------------------------------------------------
c
      if(icolor.eq.1) then
         call plotit(0,0,0)
         call plotit(0,0,2)
         call plotif(c0,c0,2)
         call sflush
         call gscr(1,100,0.50,0.12,0.25)
         call gscr(1,101,1.00,1.00,0.88)
         call gscr(1,102,1.00,1.00,1.00)
      endif
c
c-----------------------------------------------------------------------
c  Draw shield.
c-----------------------------------------------------------------------
c
      do 10 i=1,n_shld
        x(i)=xo+x_shld(i)*wdth
        y(i)=yo+y_shld(i)*hght
 10   continue
c
      if(icolor.eq.1) call clrbox(x,y,n_shld,100)
      call curve(x,y,n_shld)
c
c-----------------------------------------------------------------------
c  Draw left book.
c-----------------------------------------------------------------------
c
      xshift=xo+xbkbgn(1)*wdth
      yshift=yo+ybkbgn(1)*hght
      call book(icolor,101,wdth,hght,xshift,yshift,noskip)
      xlab=xshift+xl_let*wdth
      ylab=yshift+yl_let*hght
      call gstxci(102)
      call PLTCHR(xlab,ylab,'V',chr_sz,c0,c0)
      xlab=xshift+xr_let*wdth
      ylab=yshift+yr_let*hght
      call gstxci(102)
      call PLTCHR(xlab,ylab,'E',chr_sz,c0,c0)
c
c-----------------------------------------------------------------------
c  Draw right book.
c-----------------------------------------------------------------------
c
      xshift=xo+xbkbgn(2)*wdth
      yshift=yo+ybkbgn(2)*hght
      call book(icolor,101,wdth,hght,xshift,yshift,noskip)
      xlab=xshift+xl_let*wdth
      ylab=yshift+yl_let*hght
      call gstxci(102)
      call PLTCHR(xlab,ylab,'R',chr_sz,c0,c0)
      xlab=xshift+xr_let*wdth
      ylab=yshift+yr_let*hght
      call gstxci(102)
      call PLTCHR(xlab,ylab,'I',chr_sz,c0,c0)
c
c-----------------------------------------------------------------------
c  Draw bottom book.
c-----------------------------------------------------------------------
c
      xshift=xo+xbkbgn(3)*wdth
      yshift=yo+ybkbgn(3)*hght
      call book(icolor,101,wdth,hght,xshift,yshift,skipmid)
      xlab=xshift+xc_let*wdth
      ylab=yshift+yc_let*hght
      call gstxci(102)
      call PLTCHR(xlab,ylab,'TAS',chr_sz,c0,c0)
      return
      end
