      subroutine what_flds(ncinpid,nvars,file,inpnam)
c
c=======================================================================
c                                                                    ===
c  This routine reports plottable fields and thier times available   ===
c  in NetCDF file INPNAM.                                            ===
c                                                                    ===
c  On Input:                                                         ===
c                                                                    ===
c     NCINPID    NetCDF file ID (integer).                           ===
c     NVARS      number of variables in NetCDF file (integer).       ===
c     FILE       flag for primary (FILE=1) or secondary (FILE=2)     ===
c                NetCDF file (integer).                              ===
c     INPNAM     Input NetCDF file name (character).                 ===
c                                                                    ===
c  Calls:
c            LNBLK                                                   ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <param.h>
#include <pconst.h>
#include <netcdf.inc>
#include <hybrid.h>
#include <inpcdf.h>
#include <pltio.h>
#include <zdat.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer file,i,ic,idfld,lenatt,lenfld,lenstr,n,ncinpid,nvars,
     *        nvatts,nvdims,vartyp
      integer vdims(maxvdims)
      integer fldnam2id,lnblk
      character*128  attnam,varnam
      character*240 field
      character*(*) inpnam
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
      lenstr=lnblk(inpnam,len(inpnam))
      if(file.eq.1) then
        write(stdout,900) inpnam(1:lenstr)
      elseif(file.eq.2) then
        write(stdout,901) inpnam(1:lenstr)
      endif
c
c  Inquire variables with the attribute "field".
c
      ic=0
      do 20 i=1,nvars
        varid=i
        call ncvinq(ncinpid,varid,varnam,vartyp,nvdims,vdims,nvatts,
     *              rcode)
        if(rcode.eq.0) then
          do 10 n=1,nvatts
            call ncanam(ncinpid,varid,n,attnam,rcode)
            if(rcode.eq.0) then
              lenatt=lnblk(attnam,len(attnam))
              if(attnam(1:lenatt).eq.'field') then
                call ncagtc(ncinpid,varid,'long_name',field,len(field),
     *                      rcode)
                if(rcode.eq.0) then
                  lenfld=lnblk(field,len(field))
                  ic=ic+1
                  if(file.eq.1) then
                    if((type1(1:ltype1).eq.'QG MODEL').or.
     *                 (type1(1:ltype1).eq.'FM MODEL').or.
     *                 (type1(1:ltype1).eq.'OA')) then
                      idfld=fldnam2id(varnam,qgclass)
                      if(idfld.ne.-99) then
                        write(stdout,902) 'QGID=',idfld,field(1:lenfld)
                      endif
                    else
                      idfld=fldnam2id(varnam,peclass)
                      if(idfld.ne.-99) then
                        write(stdout,902) 'PEID=',idfld,field(1:lenfld)
                      endif
                    endif
                  elseif(file.eq.2) then
                    if((type2(1:ltype2).eq.'QG MODEL').or.
     *                 (type2(1:ltype2).eq.'FM MODEL').or.
     *                 (type2(1:ltype2).eq.'OA')) then
                      idfld=fldnam2id(varnam,qgclass)
                      if(idfld.ne.-99) then
                        write(stdout,902) 'QGID=',idfld,field(1:lenfld)
                      endif
                    else
                      idfld=fldnam2id(varnam,peclass)
                      if(idfld.ne.-99) then
                        write(stdout,902) 'PEID=',idfld,field(1:lenfld)
                      endif
                    endif
                  endif
                endif
              endif
            endif
  10      continue
        endif
  20  continue
c
c  Report available times.
c
      write(stdout,903)
      if(file.eq.1) then
        if(type1(1:ltype1).eq.'PE FORCING') then
          if(nt1shf.gt.0) write(stdout,904) (t1shf(i),i=1,nt1shf)
          if(nt1smf.gt.0) write(stdout,904) (t1smf(i),i=1,nt1smf)
          if(nt1swf.gt.0) write(stdout,904) (t1swf(i),i=1,nt1swf)
          if(nt1swr.gt.0) write(stdout,904) (t1swr(i),i=1,nt1swr)
        elseif(type1(1:ltype1).eq.'PE MODEL') then
          write(stdout,904) (sec2day*time1(i),i=1,ntime1)
        elseif(type1(1:ltype1).eq.'QG MODEL') then
          write(stdout,904) (sec2day*time1(i),i=1,ntime1)
        else
          write(stdout,904) (time1(i),i=1,ntime1)
        endif
      elseif(file.eq.2) then
        if(type2(1:ltype2).eq.'PE FORCING') then
          if(nt2shf.gt.0) write(stdout,904) (t2shf(i),i=1,nt2shf)
          if(nt2smf.gt.0) write(stdout,904) (t2smf(i),i=1,nt2smf)
          if(nt2swf.gt.0) write(stdout,904) (t2swf(i),i=1,nt2swf)
          if(nt2swr.gt.0) write(stdout,904) (t2swr(i),i=1,nt2swr)
        elseif(type2(1:ltype2).eq.'PE MODEL') then
          write(stdout,904) (sec2day*time2(i),i=1,ntime2)
        elseif(type2(1:ltype2).eq.'QG MODEL') then
          write(stdout,904) (sec2day*time2(i),i=1,ntime2)
        else
          write(stdout,904) (time2(i),i=1,ntime2)
        endif
      endif
c
c  Report available levels.
c
      write(stdout,905)
      if(file.eq.1) then
        if(type1(1:ltype1).eq.'PE MODEL') then
          write(stdout,906) (n,peout(n),n=1,peoutlev)
        elseif(type1(1:ltype1).eq.'PE_INITIAL') then
          write(stdout,906) (n,n,n=1,pelev)
        elseif(type1(1:ltype1).eq.'PE FORCING') then
          write(stdout,906) 1,0
        else
          write(stdout,907) (n,zmid(n),n=1,qglev)
        endif
      elseif(file.eq.2) then
        if(type2(1:ltype2).eq.'PE MODEL') then
          write(stdout,906) (n,peout(n),n=1,peoutlev)
        elseif(type2(1:ltype2).eq.'PE_INITIAL') then
          write(stdout,906) (n,n,n=1,pelev)
        elseif(type2(1:ltype2).eq.'PE FORCING') then
          write(stdout,906) 1,0
        else
          write(stdout,907) (n,zmid(n),n=1,qglev)
        endif
      endif
c
 900  format(/,2x,'Plottable Fields in Primary NetCDF File: ',/,2x,
     *       '---------------------------------------',//,10x,a,/)
 901  format(/,2x,'Plottable Fields in Secondary NetCDF File: ',/,2x,
     *       '-----------------------------------------',//,10x,a,/)
 902  format(1x,'[',a,i3,']',1x,a)
 903  format(/,2x,'Available Times: ',/,2x,'---------------',/)
 904  format(5g15.7)
 905  format(/,2x,'Available levels: ',/,2x,'----------------',/)
 906  format(1x,'[',i2,']',1x,'for PE Level',1x,i5)
 907  format(1x,'[',i2,']',1x,'for Depth',1x,g15.7)
      return
      end
