      subroutine xsection(sec,x,y,z,ims,kms,fld,zfld,im,jm,km,vintrp,
     *                    spval)
c
c=======================================================================
c                                                                    ===
c  This subroutine extracts a data section from a  3-D field using   ===
c  Bessel interpolation in the horizontal and spline interpolation   ===
c  in the vertical.  It assumes that the field is uniformly grided   ===
c  in the X-Y plane.                                                 ===
c                                                                    ===
c  On Input:                                                         ===
c                                                                    ===
c     X       section x-coordinate (nondimensional, grid units).     ===
c     Y       section y-coordinate (nondimensional, grid units).     ===
c     Z       depths of the section to extract (meters).             ===
c     IMS     number of section points in the horizontal direction.  ===
c     KMS     number of section points in the Z-direction.           ===
c     FLD     field from which the section is extracted.             ===
c     ZFLD    depths of field FLD (meters).                          ===
c     IM      number of field points in the X-direction.             ===
c     JM      number of field points in the Y-direction.             ===
c     KM      number of field points in the Z-direction.             ===
c     VINTRP  vertical interpolation switch (integer):               ===
c             [0] linear, [1] cubic spline.                          ===
c     SPVAL   special value to flag missing data.                    ===
c     WK      Work space for extrapolations.                         ===
c                                                                    ===
c  On Output:                                                        ===
c                                                                    ===
c     SEC     extracted section (real).                              ===
c                                                                    ===
c  Calls:                                                            ===
c                                                                    ===
c     BES2DE, BILIN, CELL, LINTRP, SPLINE, SPLINT                    ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <param.h>
#include <pconst.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer i,im,ims,jm,k,kend,km,kms,kpts,kstr,status,vintrp
      integer hintrp,kmbot
      integer intrpindx
      real der1,derlz,frstd,spval,spv,zv,zbot,ztop
#ifndef no_xtrp
      real mspval,val
#endif
      real fk(nk),fld(im,jm,km),sec(ims,kms),wk(nk),x(ims),y(ims),
     *     z(kms),zfld(im,jm,km),zk(nk)
#ifndef no_xtrp
      real wk2(nk,2)
#endif
#ifndef no_cjl
      real bes2de
# else
      real bes2d
#endif
      real bilin
      real fcel(16,nk),s,t
      logical good
      integer ix(16),iy(16),node,j
      parameter (der1=c1ep30,derlz=c1ep30,spv=spval0)
cjl check value
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
cjl---------------------------
cjl later on pass hintrp as an argument meanwhile
      hintrp=vintrp
cjl---------------------------
c
c
c  Flag out data
c
#ifdef no_xtrp
      do 10 k=1,kms
         do 1 i=1,ims
            sec(i,k)=spval
  1      continue
 10   continue
# else
      mspval = -spval
c
      do 10 i = 1,ims
         ztop = abs( bilin(x(i),y(i),zfld(1,1,1),im,jm,spv,spval) )
         zbot = abs( bilin(x(i),y(i),zfld(1,1,km),im,jm,spv,spval) )
         do 5 k = 1, kms
            zv = abs( z(k) )
            if ( max(ztop,zbot) .ge. min(spv,spval) ) then
               sec(i,k) = spval
              elseif ( (ztop.le.zv) .and. (zv.le.zbot) ) then
               sec(i,k) = mspval
              else
               sec(i,k) = spval
            end if
  5      continue
 10   continue
#endif
c
      do 80 i=1,ims
c
c Find horizontal cell
c
         call cell (x(i),y(i),ix,iy,s,t,im,jm,node,hintrp,nk,fcel,spval,
     &              good)
         if (good) then
            do 50 j=1,node
               do 20 k=1,km
                  fk(k)=fld(ix(j),iy(j),k)
                  zk(k)=abs(zfld(ix(j),iy(j),k))
 20            continue
               kmbot = km
               
c
c  Perform vertical interpolation.  First, check viable indices in
c  extracted vertical profile.
c
               status=intrpindx(fk,kmbot,spv,kstr,kend)
               if(status.eq.0) then
                  kpts=kend-kstr+1
                  ztop=zk(kstr)
                  zbot=zk(kend)
                  if(vintrp.eq.0) then
                     do 30 k=1,kms
                        zv=abs(z(k))
#ifndef cnst_xtrp
                     if(ztop.le.zv.and.zv.le.zbot) then
#endif
                        call lintrp (kpts,zk(kstr),fk(kstr),1,zv,
     &                                                        fcel(j,k))
#ifndef cnst_xtrp
c                     else
c                        fcel(j,k)=spval
                     endif
#endif
 30               continue
               elseif(vintrp.eq.1) then
                  call spline(zk(kstr),fk(kstr),kpts,der1,derlz,wk)
                  do 40 k=1,kms
                     zv=abs(z(k))
                     if(ztop.le.zv.and.zv.le.zbot) then
                        call splint (zk(kstr),fk(kstr),wk,kpts,zv,
     &                                                  fcel(j,k),frstd)
c                     else
c                        fcel(j,k)=spval
                     endif
 40               continue
               endif
            endif
c
 50         continue
            if(hintrp.eq.0) then
               do 60 k=1,kms
#ifdef no_xtrp
                  sec(i,k)=bilin(s,t,fcel(1,k),2,2,spv,spval)
# else
                  val=bilin(s,t,fcel(1,k),2,2,spv,spval)
                  if (val.lt.min(spv,spval)) sec(i,k)=val
#endif
 60            continue
            elseif(hintrp.eq.1) then
               do 70 k=1,kms
#ifdef no_xtrp
#  ifndef no_cjl
                  sec(i,k)=bes2de(s,t,fcel(1,k),4,4,spv,spval)
#   else
                  sec(i,k)=bes2d(s,t,fcel(1,k),4,4,spv,spval)
#  endif
# else
#  ifndef no_cjl
                  val=bes2de(s,t,fcel(1,k),4,4,spv,spval)
#   else
                  val=bes2d(s,t,fcel(1,k),4,4,spv,spval)
#  endif
                  if (val.lt.min(spv,spval)) sec(i,k)=val
#endif
 70            continue
            endif
         endif
 80   continue
c
#ifndef no_xtrp
c
c  Spread interpolated data into active regions where
c  the interpolation scheme fails.
c
      call smooth_under (ims,kms,sec,spval,mspval,wk2)
c
#endif
      return
      end
