      subroutine xtr_exp (instring,grfflg,fnd,numflag,expstr,remstr)
c
c=======================================================================
c                                                                    ===
c  This routine extracts an exponent from a given string.           ===
c                                                                    ===
c  ------                                                            ===
c  Input:                                                            ===
c  ------                                                            ===
c                                                                    ===
c  instring...Given units string.                                    ===
c  grfflg.....Flag to indicate whether to print as graphics or plain.===
c             [.true.]   print as graphics                           ===
c             [.false.]  print as plain                              ===
c                                                                    ===
c  Common Blocks:                                                    ===
c                                                                    ===
c  /PLTNCAR/                                                         ===
c                                                                    ===
c     ESC_CHAR...escape character to be used in special NCAR strings ===
c                                                                    ===
c  -------                                                           ===
c  Output:                                                           ===
c  -------                                                           ===
c                                                                    ===
c  fnd........Flag indicating whether an exponent was extracted.     ===
c             [.true.]   a prefix was extracted                      ===
c             [.false.]  no prefix was found                         ===
c  numflg.....Flag indicating whether units string is in numerator.  ===
c             [.true.]   unit string belongs in numerator.           ===
c             [.false.]  unit string belongs in denominator.         ===
c  expstr.....Extracted exponent string in NCAR format.              ===
c  remstr.....Remainder of input string.                             ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <pltncar.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer ptr,slen,sbgn,send
      logical     fnd,grfflg,isnum,numflag
      character*1   s
      character*(*) instring,expstr,remstr
c
      isnum(s) = ((ichar(s).gt.47).and.(ichar(s).lt.58)) .or. (s.eq.'-')
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c-----------------------------------------------------------------------
c  Initialize flags.  Get pointers to string ends.
c-----------------------------------------------------------------------
c
      fnd     = .false.
      numflag = .true.
      remstr  = instring
c
      call length (instring,slen,sbgn,send)
      if (slen.lt.1) return
c
c-----------------------------------------------------------------------
c  Look for and extract any exponents.
c-----------------------------------------------------------------------
c
c-------------------------------------------------------------
c--- Get pointer to end of non-exponent portion of string. ---
c-------------------------------------------------------------
c
      ptr = send
c
      do 10 while ( (ptr.gt.sbgn) .and. isnum(instring(ptr:ptr)) )
         ptr = ptr - 1
 10   continue
c
c--------------------------------------------
c--- Save non-exponent portion of string. ---
c--------------------------------------------
c
      remstr = instring(sbgn:ptr)
c
c----------------------------------------
c--- Determine if exponent was found. ---
c----------------------------------------
c
      fnd = (ptr.lt.send) .or. isnum(instring(send:send))
c
c------------------------------------------
c--- If exponent was found, extract it. ---
c------------------------------------------
c
      if (fnd) then
c
         ptr     = ptr + 1
         numflag = instring(ptr:ptr) .ne. '-'
         if (.not.numflag) ptr = ptr + 1
c
         fnd = (ptr.lt.send) .or. (instring(ptr:ptr).ne.'1')
         if (fnd) then
#if !defined medchr & !defined lowchr
            if (grfflg) then
               expstr = esc_char//'S1'//esc_char//instring(ptr:send)//
     &                  esc_char//'N'//esc_char
              else
               expstr = instring(ptr:send)
            end if
# else
            expstr = instring(ptr:send)
#endif
         end if
      end if
c
      return
      end
