      subroutine xtr_prefix (instring,grfflg,fnd,prefstr,remstr)
c
c=======================================================================
c                                                                    ===
c  This routine extracts an SI prefix from a given string.           ===
c                                                                    ===
c  ------                                                            ===
c  Input:                                                            ===
c  ------                                                            ===
c                                                                    ===
c  instring...Given units string.                                    ===
c  grfflg.....Flag to indicate whether to print as graphics or plain.===
c             [.true.]   print as graphics                           ===
c             [.false.]  print as plain                              ===
c                                                                    ===
c  Common Blocks:                                                    ===
c                                                                    ===
c  /PLTNCAR/                                                         ===
c                                                                    ===
c     ESC_CHAR...escape character to be used in special NCAR strings ===
c                                                                    ===
c  -------                                                           ===
c  Output:                                                           ===
c  -------                                                           ===
c                                                                    ===
c  fnd........Flag indicating whether a prefix was extracted.        ===
c             [.true.]   a prefix was extracted                      ===
c             [.false.]  no prefix was found                         ===
c  prefstr....Extracted prefix string in NCAR format.                ===
c  remstr.....Remainder of input string.                             ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <pltncar.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer slen,sbgn,send
      logical       fnd,grfflg
      character*256 work
      character*(*) instring,prefstr,remstr
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c-----------------------------------------------------------------------
c  Make lower case copy of string.  Return if string only contains white
c  space.
c-----------------------------------------------------------------------
c
      fnd    = .false.
      remstr = instring
      call length (instring,slen,sbgn,send)
      if (slen.lt.1) return
      call all_lc (instring(sbgn:send),work)
c
c-----------------------------------------------------------------------
c  Look for and extract any SI prefixes.
c-----------------------------------------------------------------------
c
      if (index(work,'yotta').eq.1) then
c                                                 10**24
         fnd = .true.
         prefstr = 'Y'
         remstr  = instring((sbgn+5):send)
c
        elseif (index(work,'zetta').eq.1) then
c                                                 10**21
         fnd = .true.
         prefstr = 'Z'
         remstr  = instring((sbgn+5):send)
c
        elseif (index(work,'exa').eq.1) then
c                                                 10**18
         fnd = .true.
         prefstr = 'E'
         remstr  = instring((sbgn+3):send)
c
        elseif (index(work,'peta').eq.1) then
c                                                 10**15
         fnd = .true.
         prefstr = 'P'
         remstr  = instring((sbgn+4):send)
c
        elseif (index(work,'tera').eq.1) then
c                                                 10**12
         fnd = .true.
         prefstr = 'T'
         remstr  = instring((sbgn+4):send)
c
        elseif (index(work,'giga').eq.1) then
c                                                 10**9
         fnd = .true.
         prefstr = 'G'
         remstr  = instring((sbgn+4):send)
c
        elseif (index(work,'mega').eq.1) then
c                                                 10**6
         fnd = .true.
         prefstr = 'M'
         remstr  = instring((sbgn+4):send)
c
        elseif (index(work,'kilo').eq.1) then
c                                                 10**3
         fnd = .true.
         prefstr = 'k'
         remstr  = instring((sbgn+4):send)
c
        elseif (index(work,'hecto').eq.1) then
c                                                 100
         fnd = .true.
         prefstr = 'h'
         remstr  = instring((sbgn+5):send)
c
        elseif ( (index(work,'deca').eq.1) .or.
     &           (index(work,'deka').eq.1)) then
c                                                 10
         fnd = .true.
         prefstr = 'da'
         remstr  = instring((sbgn+4):send)
c
        elseif (index(work,'deci').eq.1) then
c                                                 0.1
         fnd = .true.
         prefstr = 'd'
         remstr  = instring((sbgn+4):send)
c
        elseif (index(work,'centi').eq.1) then
c                                                 0.01
         fnd = .true.
         prefstr = 'c'
         remstr  = instring((sbgn+5):send)
c
        elseif (index(work,'milli').eq.1) then
c                                                 10**(-3)
         fnd = .true.
         prefstr = 'm'
         remstr  = instring((sbgn+5):send)
c
        elseif (index(work,'micro').eq.1) then
c                                                 10**(-6)
         fnd = .true.
#if !defined medchr & !defined lowchr
         if (grfflg) then
            prefstr = esc_char//'PGL'//esc_char//'L'//esc_char//'PRU'//
     &                esc_char
           else
            prefstr = 'u'
         end if
# else
         prefstr = 'u'
#endif
         remstr  = instring((sbgn+5):send)
c
        elseif (index(work,'nano').eq.1) then
c                                                 10**(-9)
         fnd = .true.
         prefstr = 'n'
         remstr  = instring((sbgn+4):send)
c
        elseif (index(work,'pico').eq.1) then
c                                                 10**(-12)
         fnd = .true.
         prefstr = 'p'
         remstr  = instring((sbgn+4):send)
c
        elseif (index(work,'femto').eq.1) then
c                                                 10**(-15)
         fnd = .true.
         prefstr = 'f'
         remstr  = instring((sbgn+5):send)
c
        elseif (index(work,'atto').eq.1) then
c                                                 10**(-18)
         fnd = .true.
         prefstr = 'a'
         remstr  = instring((sbgn+4):send)
c
        elseif (index(work,'zepto').eq.1) then
c                                                 10**(-21)
         fnd = .true.
         prefstr = 'z'
         remstr  = instring((sbgn+5):send)
c
        elseif (index(work,'yocto').eq.1) then
c                                                 10**(-24)
         fnd = .true.
         prefstr = 'y'
         remstr  = instring((sbgn+5):send)
c
      end if
c
      return
      end
