      subroutine xtr_units (instring,grfflg,untstr)
c
c=======================================================================
c                                                                    ===
c  This routine converts the given string to an SI abbreviation, if  ===
c  possible.  This routine assumes any prefixes or exponents have    ===
c  already been removed.                                             ===
c                                                                    ===
c  ------                                                            ===
c  Input:                                                            ===
c  ------                                                            ===
c                                                                    ===
c  instring...Given units string.                                    ===
c  grfflg.....Flag to indicate whether to print as graphics or plain.===
c             [.true.]   print as graphics                           ===
c             [.false.]  print as plain                              ===
c                                                                    ===
c  -------                                                           ===
c  Output:                                                           ===
c  -------                                                           ===
c                                                                    ===
c  untstr.....Resultant units string.                                ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data.
c-----------------------------------------------------------------------
c
#include <pltncar.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer slen,sbgn,send
      logical       grfflg
      character*256 work
      character*(*) instring,untstr
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c-----------------------------------------------------------------------
c  Make lower case copy of string.  Return if string only contains white
c  space.
c-----------------------------------------------------------------------
c
      call length (instring,slen,sbgn,send)
      if (slen.lt.1) return
      call all_lc (instring(sbgn:send),work)
c
c-----------------------------------------------------------------------
c  Convert supplied units to known symbols.
c-----------------------------------------------------------------------
c
      if (index(work,'meter').eq.1) then
         untstr  = 'm'
c
        elseif (index(work,'gram').eq.1) then
         untstr  = 'g'
c
        elseif (index(work,'second').eq.1) then
         untstr  = 's'
c
        elseif (index(work,'amp').eq.1) then
         untstr  = 'A'
c
        elseif (index(work,'kelvin').eq.1) then
         untstr  = 'K'
c
        elseif (index(work,'celsius').eq.1) then
#if !defined medchr & !defined lowchr
         if (grfflg) then
            untstr  = esc_char//'S1PGU1'//esc_char//'Z'//esc_char//'PRU'
     &                //esc_char//' C'
           else
            untstr  = 'deg C'
         end if
# else
         untstr  = 'deg C'
#endif
c
        elseif (index(work,'mole').eq.1) then
         untstr  = 'mol'
c
        elseif (index(work,'candela').eq.1) then
         untstr  = 'cd'
c
        elseif (index(work,'watt').eq.1) then
         untstr  = 'W'
c
        elseif (index(work,'joule').eq.1) then
         untstr  = 'J'
c
        elseif (index(work,'calorie').eq.1) then
         untstr  = 'cal'
c
        elseif (index(work,'pascal').eq.1) then
         untstr  = 'Pa'
c
        elseif (index(work,'liter').eq.1) then
         untstr  = 'l'
c
        elseif (index(work,'atmosphere').eq.1) then
         untstr  = 'atm'
c
        elseif (index(work,'mercury').eq.1) then
         untstr  = 'Hg'
c
        elseif (index(work,'nitrogen').eq.1) then
         untstr  = 'N'
c
        else
         untstr  = instring(sbgn:send)
c
      end if
c
      return
      end
