      subroutine psconv (n,ipar,fpar,sol,w,isfirst)
c
c=======================================================================
c                                                                    ===
c  This routine combines the standard SparsKit convergence with a    ===
c  local gradient test (equivalent of velconv for streamfunction).   ===
c                                                                    ===
c  ------                                                            ===
c  Input:                                                            ===
c  ------                                                            ===
c                                                                    ===
c     N         Number of points in solution.       (integer)        ===
c     IPAR      SparsKit communication parameters.  (integer vector)
c     FPAR      SparsKit communication parameters.  (real vector)
c     SOL       Storage for the solution.           (db.prc. vector)
c     W         Working storage.                    (db.prc. array)
c     ISFIRST   Flag for first pass.                (logical)        ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data
c-----------------------------------------------------------------------
c
#include <cdefs.h>
#include <convinfo.h>
c
c-----------------------------------------------------------------------
c  Define local data.
c-----------------------------------------------------------------------
c
      integer ihold,idelptr,n
      integer ipar(16)
      logical isconv,isfirst
      logical          stopbis
      double precision alpha
      double precision fpar(16),sol(n),w(n,*)
      double precision distdot
c
      save idelptr
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c-----------------------------------------------------------------------
c  On first call of an iterative set, determine initial residual and
c  clear gradient rolling storage.
c-----------------------------------------------------------------------
c
      if (isfirst) then
         fpar(4) = fpar(1)*fpar(3) + fpar(2)
         if (ipar(2).ge.2) then
            idelptr = 4
         else
            idelptr = 5
         endif
         call gcinit
         isfirst = .false.
      end if
c
c-----------------------------------------------------------------------
c  Perform convergence tests.
c-----------------------------------------------------------------------
c
c  First examine gradient convergence.
c
      call gradconv (n,w(1,idelptr),fpar(2),greltl,isconv)
c
c  Then, combine with standard test.
c
      alpha   = fpar(7) / distdot(n,w(1,2),1,w(1,3),1)
      ihold   = ipar(3)
      ipar(3) = 1
c
      if (stopbis(n,ipar,1,fpar,w,w(1,2),alpha).and.isconv) then
         ipar(11) = 1
      else
         ipar(11) = 0
      end if
c
      ipar(3) = ihold
c
c-----------------------------------------------------------------------
c  Note:  if maximum number of iterations has occurred, stopbis
c         sets ipar(1) to -1.  Clean-up is more easily performed here.
c-----------------------------------------------------------------------
c
      if (ipar(1).lt.0) call tidycg (n,ipar,fpar,sol,w(1,idelptr))
c
      return
      end
